/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 02391
 |             NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE, 1996
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\02391-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE skpmartl  1='(1) Respondent is 12-14 years old - SKIP'
                  2='(2) Respondent is 15 years old or older'
                  3='(3) 12-14 years old LOGICALLY ASSIGNED - SKI'
                  4='(4) 15 years or older LOGICALLY ASSIGNED' ;
  VALUE marital   1='(1) Married' 2='(2) Widowed' 3='(3) Divorced or separated'
                  4='(4) Never been married' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE nomarr    85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skpmilt   1='(1) Respondent is 12-16 years old - SKIP'
                  2='(2) Respondent is 17 years old or older'
                  3='(3) 12-16 years old LOGICALLY ASSIGNED - SKI'
                  4='(4) 17 years or older LOGICALLY ASSIGNED' ;
  VALUE service   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE milstat   2='(2) In a reserves component'
                  3='(3) Now separated or retired from reserves/a'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE educ      0='(0) No schooling' 1='(1) First grade' 2='(2) Second grade'
                  3='(3) Third grade' 4='(4) Fourth grade' 5='(5) Fifth grade'
                  6='(6) Sixth grade' 7='(7) Seventh grade' 8='(8) Eighth grade'
                  9='(9) Ninth grade' 10='(10) Tenth grade' 11='(11) Eleventh grade'
                  12='(12) Twelfth grade' 13='(13) Freshman/13th year'
                  14='(14) Sophomore/14th year' 15='(15) Junior/15th year'
                  16='(16) Senior/16th year'
                  17='(17) Graduate/Professional School (or higher)'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE diploma   1='(1) High School Diploma' 2='(2) GED Certificate'
                  3='(3) Neither of the above'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE enrolld   1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE workstat  1='(1) Working full-time, 35 hours or more a we'
                  2='(2) Working part-time, less than 35 hours a'
                  3='(3) Have a job but out: illness/leave/furlou'
                  4='(4) Have a job but it is seasonal'
                  5='(5) Unemployed or laid off and looking for w'
                  6='(6) Unemployed and not looking for work'
                  7='(7) Full-time homemaker' 8='(8) In school only' 9='(9) Retired'
                  10='(10) Disabled for work' 11='(11) Other, not specified'
                  21='(21) Working full-time, 35 hours or more a we'
                  22='(22) Working part-time, less than 35 hours a'
                  23='(23) Have a job but out: illness/leave/furlou'
                  24='(24) Have a job, but it is seasonal'
                  25='(25) Unemployed or laid off and looking for w'
                  27='(27) Full-time homemaker' 28='(28) In school only'
                  30='(30) Disabled for work' 31='(31) Other, in labor force'
                  32='(32) Other, not in the labor force'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE htininch  985='(985) BAD DATA Logically assigned' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE pounds    985='(985) BAD DATA Logically assigned' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE health    1='(1) Excellent' 2='(2) Very good' 3='(3) Good' 4='(4) Fair' 5='(5) Poor'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cigever   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cigtry    981='(981) NEVER USED CIGARETTES Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED CIGARETTES' 994='(994) DONT KNOW' 995='(995) BAD DATA'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE cigtot    1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED CIGARETTES Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CIGARETTES'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cigrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED CIGARETTES Logically assigned'
                  91='(91) NEVER USED CIGARETTES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cig30use  35='(35) Date specified within the past 30 days'
                  81='(81) NEVER USED CIGARETTES Logically assigned'
                  83='(83) DID NOT USE CIGARETTES IN PAST 30 DAYS L'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CIGARETTES'
                  93='(93) DID NOT USE CIGARETTES IN THE PAST 30 DA'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE avcig     1='(1) At least a puff but less than one cig ea'
                  2='(2) 1 to 5 cigarettes each day'
                  3='(3) 6 to 15 cigarettes (about 1/2 pack) each'
                  4='(4) 16 to 25 cigarettes (about 1 pack) each'
                  5='(5) 26 to 35 cigarettes (about 1 1/2 pk) eac'
                  6='(6) 35 or more cigarettes (about 2 packs) ea'
                  81='(81) NEVER USED CIGARETTES Logically assigned'
                  83='(83) DID NOT USE CIGARETTES PAST 30 DAYS Log'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CIGARETTES'
                  93='(93) DID NOT USE CIGARETTES IN THE PAST 30 DA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cig30wok  1='(1) 5 minutes or less' 2='(2) 6 to 30 minutes'
                  3='(3) 31 to 60 minutes' 4='(4) 1 to 3 hours' 5='(5) 4 or more hours'
                  81='(81) NEVER USED CIGARETTES Logically assigned'
                  83='(83) DID NOT USE CIGARETTES IN PAST 30 DAYS L'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CIGARETTES'
                  93='(93) DID NOT USE CIGARETTES IN THE PAST 30 DA' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cigevyda  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cigage    981='(981) NEVER USED CIGARETTES Logically assigned'
                  983='(983) NEVER USED CIGARETTES EVERYDAY Log assn'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED CIGARETTES'
                  993='(993) NEVER USED CIGARETTES EVERYDAY' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE cigyrs    0='(0) I smoked cigs every day but only for < o'
                  981='(981) NEVER USED CIGARETTES Logically assigned'
                  983='(983) NEVER USED CIGARETTES EVERYDAY Log assn'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED CIGARETTES'
                  993='(993) NEVER USED CIGARETTES EVERYDAY' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE snufever  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE snufrec   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED SMOKELESS TOBACCO Logically a'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED SMOKELESS TOBACCO' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpalcrd  1='(1) Yes, respondent can complete the answer'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE alcread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE alcever   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' ;
  VALUE alctry    981='(981) NEVER USED ALCOHOL Logically assigned'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED ALCOHOL'
                  994='(994) DONT KNOW' 995='(995) BAD DATA' 998='(998) BLANK (NO ANSWER)' ;
  VALUE alcrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  91='(91) NEVER USED ALCOHOL' ;
  VALUE alcpat    1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN PAST 12 MONTHS Lo'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE drunkyr   1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN PAST 12 MONTHS Lo'
                  85='(85) BAD DATA Logically assigned'
                  90='(90) HAD A DRINK BUT DID NOT GET DRUNK PST 12'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE alcdays   81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN THE PAST 30 DAYS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nodr30a   81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT USE ALCOHOL IN THE PAST 30 DAYS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE dr5day    0='(0) No days' 81='(81) NEVER USED ALCOHOL Logically assigned'
                  83='(83) DID NOT DRINK ALCOHOL IN PAST 30 DAYS Lo'
                  85='(85) BAD DATA Logically assigned'
                  90='(90) HAD A DRINK BUT NEVER MORE THAN 5 PAST 3'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjever    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' ;
  VALUE mjage     981='(981) NEVER USED MARIJUANA Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED MARIJUANA' 994='(994) DONT KNOW'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE mjtot     1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjrec     1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  91='(91) NEVER USED MARIJUANA' ;
  VALUE mjyrfreq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA PAST 12 MOS Log as'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjday30a  81='(81) NEVER USED MARIJUANA Logically assigned'
                  83='(83) DID NOT USE MARIJUANA IN THE PAST 30 DAY'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 30 DAY' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpcocrd  1='(1) Yes, respondent can complete the answer'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cocread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE cocever   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' ;
  VALUE cocage    981='(981) NEVER USED COCAINE Logically assigned'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED COCAINE'
                  995='(995) BAD DATA' 998='(998) BLANK (NO ANSWER)' ;
  VALUE coctot    1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  91='(91) NEVER USED COCAINE' ;
  VALUE cocyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE IN PAST 12 MONTHS Lo'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN PAST 12 MONTHS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocus30a  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) DID NOT USE COCAINE IN THE PAST 30 DAYS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 30 DAYS' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpcrkrd  1='(1) Yes, respondent can complete answer shee'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE crkread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE crkever   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE crkage    981='(981) NEVER USED CRACK Logically assigned'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED CRACK'
                  995='(995) BAD DATA' 998='(998) BLANK (NO ANSWER)' ;
  VALUE crktot    1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED CRACK Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE crakrec   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED CRACK Logically assigned'
                  91='(91) NEVER USED CRACK' 98='(98) BLANK (NO ANSWER)' ;
  VALUE crkyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK PAST 12 MONTHS Log a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE crkus30a  81='(81) NEVER USED CRACK Logically assigned'
                  83='(83) DID NOT USE CRACK IN THE PAST 30 DAYS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN THE PAST 30 DAYS' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpherrd  1='(1) Yes, respondent can complete answer shee'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE herread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE herever   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE herage    981='(981) NEVER USED HEROIN Logically assigned'
                  985='(985) BAD DATA Logically assigned' 991='(991) NEVER USED HEROIN'
                  994='(994) DONT KNOW' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE hertot    1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE herrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  91='(91) NEVER USED HEROIN' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE heryrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  83='(83) DID NOT USE HEROIN PAST 12 MONTHS Log as'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  93='(93) DID NOT USE HEROIN IN THE PAST 12 MONTHS'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE her30use  81='(81) NEVER USED HEROIN Logically assigned'
                  83='(83) DID NOT USE HEROIN IN PAST 30 DAYS Log a'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  93='(93) DID NOT USE HEROIN IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skphalrd  1='(1) Yes, respondent can complete answer shee'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE halread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE lsd       1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (LSDREC=1,2,3,4 o'
                  4='(4) No LOGICALLY ASSIGNED (LSDREC=81 or 91)'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pcp       1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (PCPREC=1,2,3,4 o'
                  4='(4) No LOGICALLY ASSIGNED (PCPREC=81 or 91)'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE peyote    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mesc      1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE psilcy    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ecstasy   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE haldknam  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halnolst  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halnewa   116='(116) Methaqualone, Parest, Quaalude, Sopor' 129='(129) Reds'
                  142='(142) Belladona' 318='(318) Ritalin, Methylphenidate'
                  322='(322) Methamphetamine (speed or ice or cr'
                  327='(327) Black beauties, Black Beauty' 336='(336) Diet pills'
                  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  501='(501) Gasoline or lighter fluids'
                  506='(506) Amyl nitrate, poppers, locker room odo'
                  508='(508) Nitrous oxide, whippets, dentist gas'
                  510='(510) OTHER Inhalant, NOT SPECIFIED' 520='(520) Old paint, paint'
                  601='(601) LSD (acid, white lightning) [see als'
                  604='(604) Psilocybin (mushrooms), shooms'
                  605='(605) PCP (angel dust, phencyclidine)'
                  607='(607) OTHER Hallucinogen, NOT SPECIFIED' 610='(610) Crystal T'
                  614='(614) MDA, Methylenedioxy amphetamine'
                  616='(616) DET, Dimethyltryptamine, DMT'
                  617='(617) Morning glory seeds' 636='(636) STP' 639='(639) Cloves, Nutmeg'
                  690='(690) RID' 691='(691) Maximum impact' 692='(692) sic' 693='(693) Lemon drops'
                  694='(694) sic' 695='(695) sic' 697='(697) sic' 703='(703) Opium'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 802='(802) THC, cannabinol'
                  803='(803) sic' 814='(814) Caffeine' 829='(829) Robitussin DM' 857='(857) sic'
                  864='(864) Dramamine <OTC>, Motion sickness pill <O'
                  3009='(3009) CAT, Ephedrone, Methcathinone'
                  6001='(6001) Collapsing little birds' 6002='(6002) sic'
                  9991='(9991) NEVER USED HALLUCINOGENS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE halnewb   110='(110) Tuinal, rainbows'
                  116='(116) Methaqualone, Parest, Quaalude, Sopor'
                  305='(305) Biphetamine' 348='(348) Crystal' 459='(459) Ketamine'
                  502='(502) Spray paints' 639='(639) Cloves, Nutmeg' 658='(658) Special K'
                  696='(696) sic' 698='(698) Nexus, 2C-B' 802='(802) THC, cannabinol'
                  864='(864) Dramamine <OTC>, Motion sickness pill <O'
                  9991='(9991) NEVER USED HALLUCINOGENS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE halnewc   201='(201) Valium' 267='(267) Marezine' 328='(328) Pink hearts' 401='(401) Darvon'
                  614='(614) MDA, Methylenedioxy amphetamine'
                  617='(617) Morning glory seeds' 699='(699) BOHA-49B'
                  9991='(9991) NEVER USED HALLUCINOGENS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE halnewd   142='(142) Belladona' 9991='(9991) NEVER USED HALLUCINOGENS'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE halnewe   689='(689) sic' 9991='(9991) NEVER USED HALLUCINOGENS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE hallage   981='(981) NEVER USED HALLUCINOGENS Logically assig'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED HALLUCINOGENS' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE halltot   1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hallrec   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halyrfrq  1='(1) More than 300 days (every day/almost eve'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than 1 day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  83='(83) DID NOT USE HALLUCINOGENS PST 12 MOS Log'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS'
                  93='(93) DID NOT USE HALLUCINOGENS IN THE PAST 12' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hal30use  81='(81) NEVER USED HALLUCINOGENS Logically assig'
                  83='(83) DID NOT USE HALLUCINOGENS IN PAST 30 DAY'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS'
                  93='(93) DID NOT USE HALLUCINOGENS IN THE PAST 30' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE lsdrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED LSD Logically assigned' 91='(91) NEVER USED LSD'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pcprec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED PCP Logically assigned' 91='(91) NEVER USED PCP'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skpinhrd  1='(1) Yes, respondent can complete the answer'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE amylnit   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cleflu    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE gas       1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE glue      1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ether     1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE solvent   1='(1) Yes' 2='(2) No' 81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE lgas      1='(1) Yes' 2='(2) No' 81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nitoxid   1='(1) Yes' 2='(2) No' 81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sppaint   1='(1) Yes' 2='(2) No' 81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE aeros     1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhdknam  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhnolst  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhnewa   112='(112) Rasepam, Restoril, Temaz, Temazepam' 304='(304) Benzedrine'
                  322='(322) Methamphetamine (speed or ice or cr' 419='(419) Stadol'
                  501='(501) Gasoline or lighter fluids' 503='(503) Other aerosol sprays'
                  504='(504) Shoeshine liq, glue,toluene,Super Glue,r'
                  506='(506) Amyl nitrate, poppers, locker room odo'
                  507='(507) Halothane, ether, or other anesthetics;'
                  509='(509) Corr flds, degreasers, cleaning flds, Li'
                  510='(510) OTHER Inhalant, NOT SPECIFIED'
                  511='(511) Markers, felt-tip pens, ink pens' 516='(516) Freon'
                  518='(518) Acetone, nail polish remover' 519='(519) Helium'
                  520='(520) Old paint, paint' 523='(523) Matches' 524='(524) see also 509'
                  526='(526) Nail polish' 528='(528) Whipped-cream can'
                  530='(530) Asthma inhaler, asthma med., bronchial d'
                  539='(539) ScotchGard' 540='(540) PAM' 543='(543) Liquid oxygen'
                  545='(545) Car tailpipe exhaust fumes, CO2'
                  548='(548) Cologne, isopropanol vapors, rubbing alc' 580='(580) sic'
                  585='(585) TCL' 586='(586) Carbon from empty softdrink bottle'
                  587='(587) Mineral ice' 691='(691) Maximum impact' 803='(803) sic'
                  809='(809) Pills' 9981='(9981) NEVER USED INHALANTS Logically assigned'
                  9991='(9991) NEVER USED INHALANTS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE inhnewb   501='(501) Gasoline or lighter fluids'
                  509='(509) Corr flds, degreasers, cleaning flds, Li'
                  524='(524) see also 509' 9991='(9991) NEVER USED INHALANTS'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE inhnewc   504='(504) Shoeshine liq, glue,toluene,Super Glue,r'
                  9991='(9991) NEVER USED INHALANTS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE inhnewd   504='(504) Shoeshine liq, glue,toluene,Super Glue,r'
                  9991='(9991) NEVER USED INHALANTS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE inhnewe   504='(504) Shoeshine liq, glue,toluene,Super Glue,r'
                  9991='(9991) NEVER USED INHALANTS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE inhage    981='(981) NEVER USED INHALANTS Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED INHALANTS' 994='(994) DONT KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE inhtot    1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE inhrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  7='(7) Use in past 30 days LOGICALLY ASSIGNED'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANTS IN PAST 12 MONTHS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE inhdy30a  81='(81) NEVER USED INHALANTS Logically assigned'
                  83='(83) DID NOT USE INHALANTS IN THE PAST 30 DAY'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 30 DAY' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpanlrd  1='(1) Yes, respondent can complete answer shee'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE anlread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE codeine   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE darvon    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE demerol   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dilaud    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE methdon   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE morphine  1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE percodan  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE talwin    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tylcod    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anldknam  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlnolst  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE analnewa  116='(116) Methaqualone, Parest, Quaalude, Sopor' 129='(129) Reds'
                  135='(135) Mini Thins' 157='(157) Barbituates'
                  161='(161) Rohypnol, Roofies, Rope, Roples, Rufinal' 201='(201) Valium'
                  209='(209) Xanax' 234='(234) Cyclobenzaprine, Flexeril' 275='(275) Loxitane'
                  318='(318) Ritalin, Methylphenidate' 403='(403) SK-65' 407='(407) Demerol'
                  410='(410) Phenaphen with Codeine, Phenaphen 3' 411='(411) Talwin'
                  414='(414) Propoxyphene' 415='(415) Codeine' 419='(419) Stadol'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  421='(421) USED ANALGESIC, DONT KNOW NAME' 422='(422) Motrin'
                  423='(423) Percocet' 424='(424) Fioricet'
                  426='(426) Butalbital, Esgic, Fiorinal, Phrenilin F'
                  427='(427) Darvocet' 430='(430) Aspirin, Ecotrin, Empirin <OTC>'
                  431='(431) Tylox' 434='(434) Anexia, Co-Gesic, Hydrocodone, Lortab, e'
                  435='(435) Tylenol, Tylenol Extra Strength <OTC>'
                  436='(436) Bufferin <OTC>' 438='(438) Anaprox, Naprosyn' 440='(440) Soma'
                  442='(442) Ibuprofen'
                  456='(456) Lorcet HD, Lorcet Plus, Lortab [see also'
                  465='(465) Fentanyl' 491='(491) PDR' 492='(492) sic' 493='(493) IBU'
                  496='(496) Tramadol, Ultram' 497='(497) sic'
                  498='(498) Ponstel, Mefenamic acid' 821='(821) Amoxicillin, Ampicillin'
                  840='(840) Cough medicine (contents not specified)'
                  864='(864) Dramamine <OTC>, Motion sickness pill <O'
                  895='(895) Tagamet, Cimetidine' 9991='(9991) NEVER USED PAIN KILLERS'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE analnewb  113='(113) Halcion' 116='(116) Methaqualone, Parest, Quaalude, Sopor'
                  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  161='(161) Rohypnol, Roofies, Rope, Roples, Rufinal' 201='(201) Valium'
                  209='(209) Xanax' 234='(234) Cyclobenzaprine, Flexeril'
                  240='(240) Lithium carbonate' 326='(326) White cross'
                  406='(406) Oxycodone, Percodan, Roxicet' 419='(419) Stadol'
                  423='(423) Percocet' 427='(427) Darvocet'
                  430='(430) Aspirin, Ecotrin, Empirin <OTC>' 431='(431) Tylox'
                  434='(434) Anexia, Co-Gesic, Hydrocodone, Lortab, e'
                  438='(438) Anaprox, Naprosyn' 896='(896) Catapres, Clonidine'
                  9991='(9991) NEVER USED PAIN KILLERS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE analnewc  115='(115) Phenobarbital' 129='(129) Reds' 206='(206) Tranxene'
                  227='(227) Thorazine' 407='(407) Demerol' 423='(423) Percocet' 427='(427) Darvocet'
                  434='(434) Anexia, Co-Gesic, Hydrocodone, Lortab, e'
                  495='(495) Red cross' 9991='(9991) NEVER USED PAIN KILLERS'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE analnewd  110='(110) Tuinal, rainbows' 201='(201) Valium'
                  406='(406) Oxycodone, Percodan, Roxicet' 415='(415) Codeine'
                  426='(426) Butalbital, Esgic, Fiorinal, Phrenilin F'
                  9991='(9991) NEVER USED PAIN KILLERS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE analnewe  9991='(9991) NEVER USED PAIN KILLERS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE analnone  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  4='(4) Response not circled LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE analage   981='(981) NEVER USED PAIN KILLERS Logically assign'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED PAIN KILLERS' 994='(994) DONT KNOW' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE analtot   1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE analrec   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  91='(91) NEVER USED PAIN KILLERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE anlyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED PAIN KILLERS Logically assign'
                  83='(83) DID NOT USE PAIN KILLERS IN PST 12 MONTH'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED PAIN KILLERS'
                  93='(93) DID NOT USE PAIN KILLERS IN THE PAST 12' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skptrnrd  1='(1) Yes, I think resp can complete answer sh'
                  2='(2) No, I doubt that resp. can complt. it al'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE trnread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE atarax    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ativan    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE diazepam  1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE librium   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tranxene  1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE valium    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE xanax     1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trdknam   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trnolst   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trnewa    113='(113) Halcion' 116='(116) Methaqualone, Parest, Quaalude, Sopor'
                  129='(129) Reds' 131='(131) Haldol, Haloperidol'
                  161='(161) Rohypnol, Roofies, Rope, Roples, Rufinal' 201='(201) Valium'
                  205='(205) Serax' 208='(208) Centrax' 209='(209) Xanax' 211='(211) Buspar'
                  213='(213) Equanil' 220='(220) Meprobamate, Meprospan'
                  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  222='(222) USED TRANQUILIZER, DONT KNOW NAME' 239='(239) see also 228'
                  246='(246) Clonopin, Klonopin' 271='(271) Zoloft' 422='(422) Motrin'
                  434='(434) Anexia, Co-Gesic, Hydrocodone, Lortab, e' 440='(440) Soma'
                  491='(491) PDR' 658='(658) Special K' 9991='(9991) NEVER USED TRANQUILIZERS'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE trnewb    116='(116) Methaqualone, Parest, Quaalude, Sopor'
                  161='(161) Rohypnol, Roofies, Rope, Roples, Rufinal' 419='(419) Stadol'
                  456='(456) Lorcet HD, Lorcet Plus, Lortab [see also'
                  9991='(9991) NEVER USED TRANQUILIZERS' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE trnewc    494='(494) sic' 9991='(9991) NEVER USED TRANQUILIZERS'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE trnewd    431='(431) Tylox' 9991='(9991) NEVER USED TRANQUILIZERS'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE trnewe    9991='(9991) NEVER USED TRANQUILIZERS' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE notranq   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  4='(4) Response not circled LOGICALLY ASSIGNED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tranage   981='(981) NEVER USED TRANQUILIZERS Logically assig'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED TRANQUILIZERS' 994='(994) DONT KNOW'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE trantot   1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tranrec   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  91='(91) NEVER USED TRANQUILIZERS' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trnyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED TRANQUILIZERS Logically assig'
                  83='(83) DID NOT USE TRANQUILIZERS PAST 12 MOS Lo'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 12'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpstmrd  1='(1) Yes, I think respondent can complete it'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stmread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE benz      1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE biphet    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dexamyl   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE dexed     1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE fastin    1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ionamin   1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE methamp   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE methi     1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE preludin  1='(1) Yes' 2='(2) No'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stmdknam  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stmnolst  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stimnewa  135='(135) Mini Thins'
                  306='(306) Desoxyn, Methamphetamine hydrochloride'
                  307='(307) Tenuate, Diethylpropion' 315='(315) Voranil'
                  318='(318) Ritalin, Methylphenidate' 319='(319) Cylert'
                  322='(322) Methamphetamine (speed or ice or cr'
                  325='(325) USED STIMULANT, DONT KNOW NAME' 326='(326) White cross'
                  327='(327) Black beauties, Black Beauty' 328='(328) Pink hearts'
                  329='(329) Bird eggs, robins eggs, speckled eggs'
                  331='(331) Blancas, Whites' 332='(332) see also 346'
                  333='(333) 357 Magnum, Magnum 44' 334='(334) Crossroads, cross tops'
                  336='(336) Diet pills' 339='(339) Amphetamines (speed generically)'
                  345='(345) Black Molly' 348='(348) Crystal' 353='(353) No-Doz <OTC>'
                  354='(354) Vivarin <OTC>' 364='(364) Sinutab, Sudafed {OTC}'
                  377='(377) Ventolin' 606='(606) sic' 658='(658) Special K'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  814='(814) Caffeine' 815='(815) Coffee' 898='(898) Propylene'
                  3001='(3001) Brown and clear' 3007='(3007) Nasal inhalant'
                  3008='(3008) Miniwhites' 3010='(3010) KOOD12' 3011='(3011) Escalation'
                  9900='(9900) NOT A DRUG' 9991='(9991) NEVER USED STIMULANTS'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE stimnewb  135='(135) Mini Thins' 317='(317) Mazanor'
                  318='(318) Ritalin, Methylphenidate'
                  322='(322) Methamphetamine (speed or ice or cr' 326='(326) White cross'
                  327='(327) Black beauties, Black Beauty'
                  329='(329) Bird eggs, robins eggs, speckled eggs'
                  330='(330) Blue birds, blue jays, blue robins, spec'
                  331='(331) Blancas, Whites' 333='(333) 357 Magnum, Magnum 44'
                  339='(339) Amphetamines (speed generically)' 353='(353) No-Doz <OTC>'
                  364='(364) Sinutab, Sudafed {OTC}' 3006='(3006) Green Amps'
                  9991='(9991) NEVER USED STIMULANTS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE stimnewc  326='(326) White cross' 327='(327) Black beauties, Black Beauty'
                  332='(332) see also 346' 814='(814) Caffeine'
                  9991='(9991) NEVER USED STIMULANTS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE stimnewd  336='(336) Diet pills' 9991='(9991) NEVER USED STIMULANTS'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE stimnewe  9991='(9991) NEVER USED STIMULANTS' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE nostims   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  4='(4) Response not circled LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stimage   981='(981) NEVER USED STIMULANTS Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED STIMULANTS' 995='(995) BAD DATA' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' ;
  VALUE stimtot   1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stimrec   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  91='(91) NEVER USED STIMULANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE stmyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  83='(83) DID NOT USE STIMULANTS IN PAST 12 MONTHS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 12 MO' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpsedrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sedread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dalmane   1='(1) Yes' 2='(2) No' 81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE halcion   1='(1) Yes' 2='(2) No' 81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE methaq    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nembutal  1='(1) Yes' 2='(2) No' 81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE phenobar  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE placidyl  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE seconal   1='(1) Yes' 2='(2) No' 81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tuinal    1='(1) Yes' 2='(2) No' 81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE seddknam  1='(1) Yes' 2='(2) No' 81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sednolst  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sednewa   105='(105) Placidyl' 111='(111) Dalmane, Durapam' 114='(114) Amobarbital'
                  116='(116) Methaqualone, Parest, Quaalude, Sopor'
                  120='(120) Downers; OTHER Sedative, NOT SPECIFIED'
                  121='(121) USED SEDATIVE, DONT KNOW NAME' 129='(129) Reds' 138='(138) sic'
                  161='(161) Rohypnol, Roofies, Rope, Roples, Rufinal' 201='(201) Valium'
                  227='(227) Thorazine' 275='(275) Loxitane' 326='(326) White cross'
                  362='(362) Benadryl' 435='(435) Tylenol, Tylenol Extra Strength <OTC>'
                  440='(440) Soma' 468='(468) Excedrin <OTC>'
                  843='(843) Antihistamine, cold tablets <OTC>'
                  9991='(9991) NEVER USED SEDATIVES' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE sednewb   110='(110) Tuinal, rainbows' 115='(115) Phenobarbital' 170='(170) sic'
                  9991='(9991) NEVER USED SEDATIVES' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE sednewc   9991='(9991) NEVER USED SEDATIVES' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE sednewd   9991='(9991) NEVER USED SEDATIVES' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE sednewe   9991='(9991) NEVER USED SEDATIVES' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' ;
  VALUE nosedat   1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  4='(4) Response not circled LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedage    981='(981) NEVER USED SEDATIVES Logically assigned'
                  985='(985) BAD DATA Logically assigned'
                  991='(991) NEVER USED SEDATIVES' 994='(994) DONT KNOW' 995='(995) BAD DATA'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' ;
  VALUE sedtot    1='(1) More than 300 days'
                  2='(2) At least 101 but not more than 300 days'
                  3='(3) At least 12 but not more than 100 days'
                  4='(4) At least 3 but not more than 11 days'
                  5='(5) At least 1 but not more than 2 days'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedrec    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  8='(8) Use in past year LOGICALLY ASSIGNED'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  91='(91) NEVER USED SEDATIVES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE sedyrfrq  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  81='(81) NEVER USED SEDATIVES Logically assigned'
                  83='(83) DID NOT USE SEDATIVES IN PAST 12 MONTHS'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE birmonth  98='(98) BLANK (NO ANSWER)' ;
  VALUE biryear   9998='(9998) BLANK (NO ANSWER)' ;
  VALUE iiage     1='(1) Age from birthdate' 2='(2) Age from cover of questionnaire'
                  3='(3) Age from roster'
                  4='(4) Age statistically imputed using age gr f' ;
  VALUE irsex     1='(1) Male' 2='(2) Female' ;
  VALUE iisex     1='(1) Sex from questionnaire'
                  2='(2) Sex from relationship on roster' 3='(3) Sex from roster' ;
  VALUE irrace    1='(1) American Indian or Alaskan native'
                  2='(2) Asian or Pacific islander' 3='(3) Black' 4='(4) White' ;
  VALUE iirace    1='(1) Race from questionnaire'
                  2='(2) Race from interview observation' 3='(3) Race from roster'
                  4='(4) Race status imputed using race - Other' ;
  VALUE irhoind   1='(1) Hispanic' 2='(2) Nonhispanic' ;
  VALUE iihoind   1='(1) Hispanicity derived from questionnaire'
                  2='(2) Hispanicity derived from roster' ;
  VALUE irhogrp   1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 4='(4) Other'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE iihogrp   1='(1) Hispanic-Origin Group taken from questio'
                  3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP Respondent is not hispan' ;
  VALUE irhogrpf  1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 4='(4) Other'
                  5='(5) Central American' 6='(6) South American' 7='(7) Caribbean'
                  99='(99) LEGITIMATE SKIP Respondent is not hispan' ;
  VALUE iihogrpf  1='(1) Hispanic-Origin Group taken from questio'
                  3='(3) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP Respondent is not hispan' ;
  VALUE irmarit   1='(1) Married' 2='(2) Widowed' 3='(3) Divorced or Separated'
                  4='(4) Never Married' 99='(99) LEGITIMATE SKIP' ;
  VALUE iimarit   1='(1) Questionnaire data' 3='(3) Statistically imputed data'
                  4='(4) Logically imputed data from roster'
                  5='(5) Statistically imputed data'
                  9='(9) LEGITIMATE SKIP (less than or = 14 years' ;
  VALUE ireduc    0='(0) No schooling' 1='(1) First grade' 2='(2) Second grade'
                  3='(3) Third grade' 4='(4) Fourth grade' 5='(5) Fifth grade'
                  6='(6) Sixth grade' 7='(7) Seventh grade' 8='(8) Eighth grade'
                  9='(9) Ninth grade' 10='(10) Tenth grade' 11='(11) Eleventh grade'
                  12='(12) Twelfth grade' 13='(13) Freshman/13th year'
                  14='(14) Sophomore/14th year' 15='(15) Junior/15th year'
                  16='(16) Senior/16th year'
                  17='(17) Graduate/Professional School (or higher)' ;
  VALUE iieduc    1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irhsgrad  1='(1) Yes, graduated from high school'
                  2='(2) No, did not graduate from high school' ;
  VALUE iihsgrad  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irworkst  1='(1) Working full-time, 35 hours or more a we'
                  2='(2) Working part-time, less than 35 hours a'
                  3='(3) Have a job, but not at work, illness/mat'
                  4='(4) Have a job but not at work b/c it is sea'
                  5='(5) Unemployed or laid off and looking for w'
                  6='(6) Unemployed or laid off and not looking f'
                  7='(7) Full-time homemaker' 8='(8) In school only' 9='(9) Retired'
                  10='(10) Disabled for work' 11='(11) Other, in labor force'
                  12='(12) Other, not in labor force' ;
  VALUE iiworkst  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE ircigrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never smoked cigarettes' ;
  VALUE iicigrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irotbrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used smokeless tobacco' ;
  VALUE iiotbrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iralcrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used alcohol' ;
  VALUE iialcrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irmjrc    1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used marijuana' ;
  VALUE iimjrc    1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE ircocrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used cocaine' ;
  VALUE iicocrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE ircrkrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used crack' ;
  VALUE iicrkrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irherrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used heroin' ;
  VALUE iiherrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irhalrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used hallucinogens' ;
  VALUE iihalrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irlsdrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used LSD' ;
  VALUE iilsdrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irpcprc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used PCP' ;
  VALUE iipcprc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irinhrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used inhalants' ;
  VALUE iiinhrc   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iranlrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used analgesics' ;
  VALUE iianlrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irtrnrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used tranquilizers' ;
  VALUE iitrnrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irstmrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used stimulants' ;
  VALUE iistmrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irsedrc   1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 9='(9) Never used sedatives' ;
  VALUE iisedrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iralcfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iialcfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irmjfq    1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iimjfq    1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE ircocfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iicocfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE ircrkfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week past year'
                  3='(3) Used 3-4 days per week past year'
                  4='(4) Used 1-2 days per week past year'
                  5='(5) Used 3-4 days per month past year'
                  6='(6) Used 1-2 days per month past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iicrkfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irherfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iiherfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irhalfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iihalfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irinhfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iiinhfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iranlfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iianlfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irtrnfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iitrnfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irstmfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iistmfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irsedfq   1='(1) Used daily in past year'
                  2='(2) Used 5-6 days per week in past year'
                  3='(3) Used 3-4 days per week in past year'
                  4='(4) Used 1-2 days per week in past year'
                  5='(5) Used 3-4 days per month in past year'
                  6='(6) Used 1-2 days per month in past year'
                  7='(7) Used less than one day per month in past'
                  8='(8) Used 3-5 days in past 12 months'
                  9='(9) Used 1-2 days in past 12 months'
                  10='(10) Never used or did not use in the past ye' ;
  VALUE iisedfq   1='(1) Questionnaire data' 2='(2) Imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE catage    1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26-34 years'
                  4='(4) 35+ years' ;
  VALUE catag2ff  1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26+ years' ;
  VALUE catag3ff  1='(1) 12-17 years' 2='(2) 18-25 years' 3='(3) 26-34 years'
                  4='(4) 35-49 years' 5='(5) 50+ years' ;
  VALUE race      1='(1) White (IRRACE = 4 and IRHOIND = 2)'
                  2='(2) Black (IRRACE = 3 and IRHOIND = 2)'
                  3='(3) Hispanic (IRHOIND = 1)'
                  4='(4) Other (IRRACE = 1-2 and IRHOIND = 2)' ;
  VALUE hisprace  1='(1) Hispanic' 2='(2) Nonhispanic Black' 3='(3) Nonhispanic Nonblack' ;
  VALUE educcatf  1='(1) Less than high school (IREDUC=0-11 and I'
                  2='(2) High school graduate (IREDUC = 12 and IR'
                  3='(3) Some college (IREDUC = 13-15 and IRAGE ='
                  4='(4) College graduate (IREDUC = 16-17 and IRA'
                  5='(5) 12-17 year olds (IRAGE = 12-17)' ;
  VALUE empstatf  1='(1) Full=time (IRWORKST = 1,3 and IRAGE => 1'
                  2='(2) Part-time (IRWORKST = 2 and IRAGE => 18)'
                  3='(3) Unemployed (IRWORKST = 4,5,6,11 and IRAG'
                  4='(4) Other (IRWORKST = 7,8,9,10,12 and IRAGE'
                  5='(5) 12-17 year olds (IRAGE = 12-17)' ;
  VALUE maristat  1='(1) Married (IRMARIT=1)' 2='(2) Not Married (IRMARIT=2,3,4)'
                  3='(3) LEGITIMATE SKIP (IRMARIT=99)' ;
  VALUE notmar    1='(1) Never Married (IRMARIT=4)'
                  2='(2) Divorced/Separated or Widowed (IRMARIT=2'
                  3='(3) Married/Legitimate Skip (IRMARIT=1,99)' ;
  VALUE cigflag   0='(0) Never used (IRCIGRC = 9)' 1='(1) Ever used (IRCIGRC = 1-4)' ;
  VALUE cigyr     0='(0) Did not use in the past year (IRCIGRC ='
                  1='(1) Used within the past year (IRCIGRC = 1,2' ;
  VALUE cigmon    0='(0) Did not use in the past month (IRCIGRC ='
                  1='(1) Used within the past month (IRCIGRC = 1)' ;
  VALUE smkflag   0='(0) Never used (IROTBRC = 9)' 1='(1) Ever used (IROTBRC = 1-4)' ;
  VALUE smkyr     0='(0) Did not use in the past year (IROTBRC ='
                  1='(1) Used within the past year (IROTBRC = 1,2' ;
  VALUE smkmon    0='(0) Did not use in the past month (IROTBRC ='
                  1='(1) Used within the past month (IROTBRC = 1)' ;
  VALUE alcflag   0='(0) Never used (IRALCRC = 9)' 1='(1) Ever used (IRALCRC = 1-4)' ;
  VALUE alcyr     0='(0) Did not use in the past year (IRALCRC ='
                  1='(1) Used within the past year (IRALCRC = 1,2' ;
  VALUE alcmon    0='(0) Did not use in the past month (IRALCRC ='
                  1='(1) Used within the past month (IRALCRC = 1)' ;
  VALUE mrjflag   0='(0) Never used (IRMJRC = 9)' 1='(1) Ever used (IRMJRC = 1-4)' ;
  VALUE mrjyr     0='(0) Did not use in the past year (IRMJRC = 3'
                  1='(1) Used within the past year (IRMJRC = 1,2)' ;
  VALUE mrjmon    0='(0) Did not use in the past month (IRMJRC ='
                  1='(1) Used within the past month (IRMJRC = 1)' ;
  VALUE cocflag   0='(0) Never used (IRCOCRC = 9)' 1='(1) Ever used (IRCOCRC = 1-4)' ;
  VALUE cocyr     0='(0) Did not use in the past year (IRCOCRC ='
                  1='(1) Used within the past year (IRCOCRC = 1,2' ;
  VALUE cocmon    0='(0) Did not use in the past month (IRCOCRC ='
                  1='(1) Used within the past month (IRCOCRC = 1)' ;
  VALUE crkflag   0='(0) Never used (IRCRKRC = 9)' 1='(1) Ever used (IRCRKRC = 1-4)' ;
  VALUE crkyr     0='(0) Did not use in the past year (IRCRKRC= 3'
                  1='(1) Used within the past year (IRCRKRC = 1,2' ;
  VALUE crkmon    0='(0) Did not use in the past month (IRCRKRC ='
                  1='(1) Used within the past month (IRCRKRC = 1)' ;
  VALUE herflag   0='(0) Never used (IRHERRC = 9)' 1='(1) Ever used (IRHERRC = 1-4)' ;
  VALUE heryr     0='(0) Did not use in the past year (IRHERRC ='
                  1='(1) Used within the past year (IRHERRC = 1,2' ;
  VALUE hermon    0='(0) Did not use in the past month (IRHERRC ='
                  1='(1) Used within the past month (IRHERRC = 1)' ;
  VALUE halflag   0='(0) Never used (IRHALRC = 9)' 1='(1) Ever used (IRHALRC = 1-4)' ;
  VALUE halyr     0='(0) Did not use in the past year (IRHALRC ='
                  1='(1) Used within the past year (IRHALRC = 1,2' ;
  VALUE halmon    0='(0) Did not use in the past month (IRHALRC ='
                  1='(1) Used within the past month (IRHALRC = 1)' ;
  VALUE lsdflag   0='(0) Never used (IRLSDRC = 9)' 1='(1) Ever used (IRLSDRC = 1-4)' ;
  VALUE lsdyr     0='(0) Did not use in the past year (IRLSDRC ='
                  1='(1) Used within the past year (IRLSDRC = 1,2' ;
  VALUE lsdmon    0='(0) Did not use in the past month (IRLSDRC ='
                  1='(1) Used within the past month (IRLSDRC = 1)' ;
  VALUE pcpflag   0='(0) Never used (IRPCPRC = 9)' 1='(1) Ever used (IRPCPRC = 1-4)' ;
  VALUE pcpyr     0='(0) Did not use in the past year (IRPCPRC ='
                  1='(1) Used within the past year (IRPCPRC = 1,2' ;
  VALUE pcpmon    0='(0) Did not use in the past month (IRPCPRC ='
                  1='(1) Used within the past month (IRPCPRC = 1)' ;
  VALUE inhflag   0='(0) Never used (IRINHRC = 9)' 1='(1) Ever used (IRINHRC = 1-4)' ;
  VALUE inhyr     0='(0) Did not use in the past year (IRINHRC ='
                  1='(1) Used within the past year (IRINHRC = 1,2' ;
  VALUE inhmon    0='(0) Did not use in the past month (IRINHRC ='
                  1='(1) Used within the past month (IRINHRC = 1)' ;
  VALUE anlflag   0='(0) Never used (IRANLRC = 9)' 1='(1) Ever used (IRANLRC = 1-4)' ;
  VALUE anlyr     0='(0) Did not use in the past year (IRANLRC ='
                  1='(1) Used within the past year (IRANLRC = 1,2' ;
  VALUE anlmon    0='(0) Did not use in the past month (IRANLRC ='
                  1='(1) Used within the past month (IRANLRC = 1)' ;
  VALUE trqflag   0='(0) Never used (IRTRNRC = 9)' 1='(1) Ever used (IRTRNRC = 1-4)' ;
  VALUE trqyr     0='(0) Did not use in the past year (IRTRNRC ='
                  1='(1) Used within the past year (IRTRNRC = 1,2' ;
  VALUE trqmon    0='(0) Did not use in the past month (IRTRNRC ='
                  1='(1) Used within the past month (IRTRNRC = 1)' ;
  VALUE stmflag   0='(0) Never used (IRSTMRC = 9)' 1='(1) Ever used (IRSTMRC = 1-4)' ;
  VALUE stmyr     0='(0) Did not use in the past year (IRSTMRC ='
                  1='(1) Used within the past year (IRSTMRC = 1,2' ;
  VALUE stmmon    0='(0) Did not use in the past month (IRSTMRC ='
                  1='(1) Used within the past month (IRSTMRC = 1)' ;
  VALUE sedflag   0='(0) Never used (IRSEDRC = 9)' 1='(1) Ever used (IRSEDRC = 1-4)' ;
  VALUE sedyr     0='(0) Did not use in the past year (IRSEDRC ='
                  1='(1) Used within the past year (IRSEDRC = 1,2' ;
  VALUE sedmon    0='(0) Did not use in the past month (IRSEDRC ='
                  1='(1) Used within the past month (IRSEDRC = 1)' ;
  VALUE alcyrf    0='(0) Never used or not used in past year (IRA'
                  1='(1) Any use within the past year (IRALCFQ=1-' ;
  VALUE alcmonf   0='(0) Did not use monthly/more past year (IRAL'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE alcwkf    0='(0) Did not use weekly or more pst year (IRA'
                  1='(1) Used weekly or more in past year (IRALCF' ;
  VALUE alcoccf   0='(0) Used monthly/more or none pst yr (IRALCF'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE alcdlyf   0='(0) Did not use daily/almost dly pst yr(IRAL'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE mrjyrf    0='(0) Never used or did not use in past year ('
                  1='(1) Any use within the past year (IRMJFQ=1-9' ;
  VALUE mrjmonf   0='(0) Did not use monthly/more past year (IRMJ'
                  1='(1) Used monthly or more in past year (IRMJF' ;
  VALUE mrjwkf    0='(0) Did not use weekly/more past year (IRMJF'
                  1='(1) Used weekly or more in past year (IRMJFQ' ;
  VALUE mrjoccf   0='(0) Used monthly/more or none in pst yr(IRMJ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE mrjdlyf   0='(0) Did not use daily/almost daily pst yr(IR'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE cocyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRCOCFQ =' ;
  VALUE cocmonf   0='(0) Did not use monthly/more past year (IRCO'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE cocwkf    0='(0) Did not use weekly or more pst year (IRC'
                  1='(1) Used weekly or more often past year (IRC' ;
  VALUE cococcf   0='(0) Used monthly/more or none in pst yr(IRCO'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE cocdlyf   0='(0) Did not use daily/almost dly pst yr(IRCO'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE crkyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRCRKFQ =' ;
  VALUE crkmonf   0='(0) Did not use monthly/more past year (IRCR'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE crkwkf    0='(0) Did not use weekly or more pst year (IRC'
                  1='(1) Used weekly or more often past year (IRC' ;
  VALUE crkoccf   0='(0) Used monthly/more or none in pst yr(IRCR'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE crkdlyf   0='(0) Did not use daily/almost dly pst yr(IRCR'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE heryrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRHERFQ=1-' ;
  VALUE hermonf   0='(0) Did not use monthly/more past year (IRHE'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE herwkf    0='(0) Did not use weekly or more pst year (IRH'
                  1='(1) Used weekly or more often past year (IRH' ;
  VALUE heroccf   0='(0) Used monthly/more or none pst yr(IRHERFQ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE herdlyf   0='(0) Did not use daily/almost daly pst yr(IRH'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE halyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRHALFQ=1-' ;
  VALUE halmonf   0='(0) Did not use monthly/more past year (IRHA'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE halwkf    0='(0) Did not use weekly or more pst year (IRH'
                  1='(1) Used weekly or more often past year (IRH' ;
  VALUE haloccf   0='(0) Used monthly/more or none pst yr(IRHALFQ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE haldlyf   0='(0) Did not use daily/almost dly pst yr(IRHA'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE inhyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRINHFQ=1-' ;
  VALUE inhmonf   0='(0) Did not use monthly/more past year (IRIN'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE inhwkf    0='(0) Did not use weekly or more pst year (IRI'
                  1='(1) Used weekly or more often past year (IRI' ;
  VALUE inhoccf   0='(0) Used monthly/more or none pst yr(IRINHFQ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE inhdlyf   0='(0) Did not use daily/almost dly pst yr(IRIN'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE anlyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRANLFQ=1-' ;
  VALUE anlmonf   0='(0) Did not use monthly/more past year (IRAN'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE anlwkf    0='(0) Did not use weekly or more pst year (IRA'
                  1='(1) Used weekly or more often past year (IRA' ;
  VALUE anloccf   0='(0) Used monthly/more or none pst yr(IRANLFQ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE anldlyf   0='(0) Did not use daily/almost dly pst yr(IRAN'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE trqyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRTRNFQ=1-' ;
  VALUE trqmonf   0='(0) Did not use monthly/more past year (IRTR'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE trqwkf    0='(0) Did not use weekly or more pst year (IRT'
                  1='(1) Used weekly or more often past year (IRT' ;
  VALUE trqoccf   0='(0) Used monthly/more or none pst yr(IRTRNFQ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE trqdlyf   0='(0) Did not use daily/almost dly pst yr(IRTR'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE stmyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRSTMFQ=1-' ;
  VALUE stmmonf   0='(0) Did not use monthly/more past year (IRST'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE stmwkf    0='(0) Did not use weekly or more pst year (IRS'
                  1='(1) Used weekly or more often past year (IRS' ;
  VALUE stmoccf   0='(0) Used monthly/more or none in pst yr(IRST'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE stmdlyf   0='(0) Did not use daily/almost dly pst yr(IRST'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE sedyrf    0='(0) Never used or did not use in pst year (I'
                  1='(1) Any use within the past year (IRSEDFQ=1-' ;
  VALUE sedmonf   0='(0) Did not use monthly/more past year (IRSE'
                  1='(1) Used monthly or more often past year (IR' ;
  VALUE sedwkf    0='(0) Did not use weekly or more pst year (IRS'
                  1='(1) Used weekly or more often past year (IRS' ;
  VALUE sedoccf   0='(0) Used monthly/more or none pst yr(IRSEDFQ'
                  1='(1) Used past year but less than monthly (IR' ;
  VALUE seddlyf   0='(0) Did not use daily/almost dly pst yr(IRSE'
                  1='(1) Used daily/almost daily in past year (IR' ;
  VALUE psyflagf  0='(0) Never used (ALL SOURCE VARIABLES = 9)'
                  1='(1) Ever used (ANY SOURCE VARIABLE < 9)' ;
  VALUE psyyr2ff  0='(0) Did not use within past year (ALL SOURCE'
                  1='(1) Used in past year (ANY SOURCE VARIABLE <' ;
  VALUE psymon2f  0='(0) Did not use in past month (ALL SOURCE VA'
                  1='(1) Used in past month (ANY SOURCE VARIABLE' ;
  VALUE sumflag   0='(0) Never used (ALL SOURCE VARIABLES = 0)'
                  1='(1) Ever used (ANY SOURCE VARIABLE = 1)' ;
  VALUE sumyr     0='(0) Did not use in past year (ALL SOURCE VAR'
                  1='(1) Used in past year (ANY SOURCE VARIABLE =' ;
  VALUE summon    0='(0) Did not use in past month (ALL SOURCE VA'
                  1='(1) Used in past month (ANY SOURCE VARIABLE' ;
  VALUE mjoflag   0='(0) Never used MJ/has used both MJ & anothr'
                  1='(1) Marijuana is only (illicit) drug ever us' ;
  VALUE mjoyr2ff  0='(0) MJ not used past yr/Used MJ & othr drug'
                  1='(1) Marijuana is only (illicit) drug in past' ;
  VALUE mjomon2f  0='(0) MJ not used past mnth/Used MJ & othr dr'
                  1='(1) Marijuana only (illicit) drug in past mo' ;
  VALUE iemflag   0='(0) Never used drug/used only marijuana'
                  1='(1) Illicit drug except for marijuana are ev' ;
  VALUE iemyr     0='(0) Never used drug/used only marijuana past'
                  1='(1) Illicit drug except for marijuana used p' ;
  VALUE iemmon    0='(0) Never used drug/used only marijuana past'
                  1='(1) Illicit drug except for marijuana used p' ;
  VALUE bingedrk  0='(0) Never/No Binge ALC use (DR5DAY=0,81,83'
                  1='(1) Binge alcohol use (DR5DAY = 1-30)'
                  99='(99) Unknown (DR5DAY = 85,94,95,98)' ;
  VALUE hvydrk2f  0='(0) Never/No heavy ALC use(DR5DAY=0-4,81,83,'
                  1='(1) Heavy alcohol use (DR5DAY = 5-30)'
                  99='(99) Unknown (DR5DAY = 85,94,95,98)' ;
  VALUE bingehvy  1='(1) Heavy alcohol use'
                  2='(2) Binge alcohol use but not heavy use'
                  3='(3) Past 30 day alcohol use but not binge'
                  4='(4) Did not use alcohol in the past 30 days' 99='(99) Unknown' ;
  VALUE peyote2f  0='(0) No/Unknown (PEYOTE=2,81,91,94,97,98)' 1='(1) Yes (PEYOTE=1)' ;
  VALUE mesc2fff  0='(0) No/Unknown (MESC=2,81,91,94,97,98)' 1='(1) Yes (MESC=1)' ;
  VALUE psilcy2f  0='(0) No/Unknown (PSILCY=2,81,91,94,97,98)'
                  1='(1) Yes (PSILCY=1,3)' ;
  VALUE ecstasyf  0='(0) No/Unknown (ECSTASY=2,81,91,94,97,98)'
                  1='(1) Yes (ECSTASY=1)' ;
  VALUE methampf  0='(0) No/Unknown (METHAMP=2,81,91,97,98)'
                  1='(1) Yes (METHAMP=1,3)' ;
  VALUE hersmokf  0='(0) No/Unknown (HERSMOKE=2,85,89,97,98,99)'
                  1='(1) Yes (HERSMOKE=1,3)' ;
  VALUE hersniff  0='(0) No/Unknown (HERSNIFF=2,4,85,89,97,98,99)'
                  1='(1) Yes (HERSNIFF=1,3)' ;
  VALUE amylnitf  0='(0) No/Unknown (AMYLNIT=2,81,91,97,98)'
                  1='(1) Yes (AMYLNIT=1,3)' ;
  VALUE cleflu2f  0='(0) No/Unknown (CLEFLU=2,81,91,97,98)' 1='(1) Yes (CLEFLU=1,3)' ;
  VALUE gas2ffff  0='(0) No/Unknown (GAS=2,81,91,97,98)' 1='(1) Yes (GAS=1,3)' ;
  VALUE glue2fff  0='(0) No/Unknown (GLUE=2,81,91,97,98)' 1='(1) Yes (GLUE=1,3)' ;
  VALUE ether2ff  0='(0) No/Unknown (ETHER=2,81,91,97,98)' 1='(1) Yes (ETHER=1,3)' ;
  VALUE solventf  0='(0) No/Unknown (SOLVENT=2,81,91,97,98)' 1='(1) Yes (SOLVENT=1)' ;
  VALUE lgas2fff  0='(0) No/Unknown (LGAS=2,81,91,97,98)' 1='(1) Yes (LGAS=1)' ;
  VALUE nitoxidf  0='(0) No/Unknown (NITOXID=2,81,91,97,98)' 1='(1) Yes (NITOXID=1)' ;
  VALUE sppaintf  0='(0) No/Unknown (SPPAINT=2,81,91,97,98)'
                  1='(1) Yes (SPPAINT=1,3)' ;
  VALUE aeros2ff  0='(0) No/Unknown (AEROS=2,81,91,97,98)' 1='(1) Yes (AEROS=1,3)' ;
  VALUE cg04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED CIGARETTES' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cg12ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED SMOKELESS TOBACCO' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE al03ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED ALCOHOL' 98='(98) BLANK (NO ANSWER)' ;
  VALUE al04ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mj04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED MARIJUANA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mj05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 12 MON' 95='(95) BAD DATA'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cc04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED COCAINE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE cc05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ck04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED CRACK' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ck05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED CRACK'
                  93='(93) DID NOT USE CRACK IN THE PAST 12 MONTH'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE he04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HEROIN' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE he05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED HEROIN'
                  93='(93) DID NOT USE HEROIN IN THE PAST 12 MONTHS'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ls04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ls05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED HALLUCINOGENS'
                  93='(93) DID NOT USE HALLUCINOGENS IN THE PAST 12' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ls07ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED LSD' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ls08ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED PCP' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE in04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED INHALANTS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE in05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED INHALANTS'
                  93='(93) DID NOT USE INHALANTS IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE pk04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pk05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned'
                  93='(93) DID NOT USE PAIN KILLERS IN THE PAST 12' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE tr04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tr05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 12' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE st04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE st05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 12 MO' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE se04ffff  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE se05ffff  1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days ( 1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days in the past 12 months'
                  9='(9) 1 to 2 days in the past 12 months'
                  85='(85) BAD DATA Logically assigned'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 12 MON' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE skpsdrd   1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sdread    1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hranyfrm  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hersmoke  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (HRAN' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (HRANYFRM = 2, 4)' ;
  VALUE hrsmkrec  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  83='(83) USED HEROIN BUT NEVER SMOKED IT Logicall'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (HRAN'
                  93='(93) USED HEROIN BUT NEVER SMOKED IT' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (HRANYFRM = 2, 4)' ;
  VALUE hersni0f  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (HRAN' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (HRANYFRM = 2, 4)' ;
  VALUE hrsnfrec  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  83='(83) USED HEROIN BUT NEVER SNIFFED IT Log ass'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (HRAN'
                  93='(93) USED HEROIN BUT NEVER SNIFFED IT' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (HRANYFRM = 2, 4)' ;
  VALUE gnndllif  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocneedl  1='(1) Yes' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  91='(91) NEVER USED COCAINE'
                  93='(93) USED COCAINE BUT NEVER WITH A NEEDLE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE condlrec  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED COCAINE Logically assigned'
                  83='(83) USED COCAINE BUT NEVER WITH A NEEDLE Log'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  91='(91) NEVER USED COCAINE'
                  93='(93) USED COCAINE BUT NEVER WITH A NEEDLE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE herneedl  1='(1) Yes' 3='(3) Yes LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  91='(91) NEVER USED HEROIN'
                  93='(93) USED HEROIN BUT NEVER WITH A NEEDLE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE hrndlrec  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED HEROIN Logically assigned'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  91='(91) NEVER USED HEROIN'
                  93='(93) USED HEROIN BUT NEVER WITH A NEEDLE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE stneedle  1='(1) Yes' 3='(3) Yes LOGICALLY ASSIGNED'
                  83='(83) USED STIMULANTS BUT NEVER WITH A NEEDLE'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) USED STIMULANTS BUT NEVER WITH A NEEDLE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE stndlrec  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED STIMULANTS Logically assigned'
                  83='(83) USED STIMULANTS BUT NEVER WITH A NEEDLE'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) USED STIMULANTS BUT NEVER WITH A NEEDLE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE gnndreus  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE gnndlshf  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE gnndclen  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE gnndls0f  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE gnndget   1='(1) I bought the needle from a pharmacy'
                  2='(2) I got the needle from a needle exchange'
                  3='(3) I bought the needle on the street'
                  4='(4) I got the needle in a shooting gallery'
                  5='(5) I got the needle some other way'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (GNND'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE gnndgtsp  6='(6) Given by, stolen from a friend'
                  8='(8) Given by, stolen from someone, relation'
                  13='(13) I bought the needle on the street'
                  15='(15) Given by, stolen from medical facility/p'
                  16='(16) Given by, stolen from work'
                  17='(17) Given by, stolen from a pharmacy'
                  18='(18) Bought, given, stolen from place/locatio'
                  19='(19) Homemade/self-made needle' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (GNNDLLIF = 2)' ;
  VALUE skprskrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE rskpkcig  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskmjocc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskmjreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcococc  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rkcocreg  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rk5drink  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskbinge  1='(1) No risk' 2='(2) Slight risk' 3='(3) Moderate risk'
                  4='(4) Great risk' 94='(94) DONT KNOW' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rskdifmj  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdifcoc  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdifcrk  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rkdifher  1='(1) Probably impossible' 2='(2) Very difficult'
                  3='(3) Fairly difficult' 4='(4) Fairly easy' 5='(5) Very easy'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE rsksell   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skpdrgrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE drgread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE usedcig   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedalc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedmrj   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedcoc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedher   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedhal   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedinh   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedanl   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedtrn   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedstm   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE usedsed   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nodrugyr  1='(1) Response circled' 2='(2) Response not circled'
                  3='(3) Response circled LOGICALLY ASSIGNED'
                  4='(4) Response not circled LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE grtmcig   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE grtmalc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE grtmmrj   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE grtmcoc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE grtmher   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE grtmhal   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE grtminh   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE grtmanl   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE grtmtrn   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE grtmstm   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE grtmsed   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamtcig   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamtalc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamtmrj   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamtcoc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamther   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamthal   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamtinh   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamtanl   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamttrn   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamtstm   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE lamtsed   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btolcig   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btolalc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btolmrj   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btolcoc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btolher   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btolhal   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btolinh   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btolanl   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btoltrn   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btolstm   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE btolsed   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdcig   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdalc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdmrj   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdcoc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdher   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdhal   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdinh   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdanl   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdtrn   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdstm   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE acrdsed   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbcig   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbalc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbmrj   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbcoc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbher   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbhal   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbinh   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbanl   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbtrn   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbstm   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE empbsed   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbcig   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbalc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbmrj   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbcoc   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbher   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbhal   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbinh   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbanl   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbtrn   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbstm   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE hlpbsed   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdcig    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdalc    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdmrj    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdcoc    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdher    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdhal    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdinh    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdanl    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdtrn    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdstm    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE ucdsed    1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (NODR'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NODRUGYR = 1, 3)' ;
  VALUE skpsptrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt it alo'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sptread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ndtxrcvd  1='(1) Yes' 2='(2) No' 5='(5) Yes (NDTXNEED=YES) LOGICALLY ASSIGNED'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ndtxneed  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXRCVD=1)'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXRCVD=1)' ;
  VALUE ndtxalc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxmj    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxcoc   1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxher   1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxhal   1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxinh   1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxanl   1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxtran  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxstim  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxsed   2='(2) No' 89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxsod   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxdrgf  322='(322) Methamphetamine (speed or ice or cr'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  818='(818) Nicotine' 9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE ndtxdr0f  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE ndtxdr1f  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE ndtxdr2f  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE ndtxdr3f  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE ndtxstep  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxtrsp  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxtfar  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxbdhr  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxopen  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxtype  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxmony  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxhcap  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxtcmp  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxlang  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxspsv  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxsor   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE ndtxrscf  3='(3) Programs hours were not convenient'
                  5='(5) Programs did not offer what I wanted'
                  9='(9) Counselors didnt meet ethnic/language n'
                  12='(12) Did not need it'
                  13='(13) Do not have a problem/feeling OK now'
                  14='(14) Do not want to (quit/get treatment)'
                  15='(15) Was using at the time/not ready/unmotiva'
                  16='(16) Can do it myself'
                  18='(18) Do not use/infrequently use drugs and al'
                  21='(21) Unsuccessful in the past'
                  24='(24) Can do it with the support of my family/'
                  26='(26) Treatment unavailable'
                  89='(89) LEGITIMATE SKIP Log assn (NDTXNEED=2,89,' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NDTXNEED=2,89,99)' ;
  VALUE booked    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE nobookyr  83='(83) NOT BEEN ARRSTD & BKD PAST 12 MONTHS Lo'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (BOOK'
                  93='(93) NOT ARRESTED AND BOOKED PAST 12 MONTHS' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (BOOKED=2)' ;
  VALUE bklarcny  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkburgl   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkagaslt  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bksmaslt  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkmvthft  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkrob     1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkrape    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkmurder  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkarson   1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkdrvinf  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkdrunk   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkdrug    1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkpros    1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkvandal  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkoth     1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Log assn (NOBOOKYR=83,89'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (NOBOOKYR=83,89,93,99)' ;
  VALUE bkothoff  1='(1) Larceny or theft'
                  4='(4) Other assault, such as simple assault or'
                  10='(10) Driving under the influence'
                  11='(11) Drunkenness or other liquor law violatio'
                  12='(12) Possession or sale of drugs'
                  14='(14) Oth proprty offns:- fraud, poss stln goo'
                  15='(15) Other offenses (NOT SPECIFIED)' 16='(16) Weapons offenses'
                  17='(17) Other offenses against persons'
                  18='(18) Violation of court order, parole, probat'
                  19='(19) Public order offenses' 20='(20) Juvenile status offenses'
                  22='(22) Traffic violations' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE probaton  1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE parole    1='(1) Yes' 2='(2) No' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE drvaldr   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE driveal   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE drivedr   1='(1) Yes' 2='(2) No' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skptmtrd  1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE tmtread   1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE txever    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE txtimelf  0='(0) No times' 975='(975) Indicated treatment received at least on'
                  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned (TXEV'
                  994='(994) DONT KNOW' 995='(995) BAD DATA' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txyrfreq  0='(0) No times' 975='(975) Indicated treatment received at least on'
                  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned (TXEV'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txalhosp  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTHOSP'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txalrfin  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTRFIN'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txalrfop  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTRFOP'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txalmhc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTMHC'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txalemrg  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXLTEMRG'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txaldoc   1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXLTDOC'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txaljail  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXLTJAIL'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txalshg   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTSHG'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txalsop   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTSOP'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txalsp    4='(4) AA or NA or CA' 5='(5) Residential placement'
                  10='(10) Church or religious influence'
                  13='(13) Court or correctional facilities'
                  14='(14) Counselor, therapist, psychologist' 15='(15) School'
                  19='(19) Alternative medicine' 22='(22) Hospital'
                  24='(24) Drug treatment or rehab. center'
                  25='(25) Mental health center' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txdrhosp  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTHOSP'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txdrfin   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTRFIN'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txdrfop   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTRFOP'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txdrmhc   1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXLTMHC'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txdremrg  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTEMRG or'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txdrdoc   1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXLTDOC'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txdrjail  1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXLTJAIL'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txdrshg   1='(1) Yes' 2='(2) No' 5='(5) Yes LOGICALLY ASSIGNED from TXLTSHG'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txdrsop   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes LOGICALLY ASSIGNED from TXLTSOP'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txdrsp    4='(4) AA or NA or CA' 5='(5) Residential placement'
                  10='(10) Church or religious influence'
                  13='(13) Court or correctional facilities'
                  14='(14) Counselor, therapist, psychologist' 15='(15) School'
                  16='(16) Home, family' 19='(19) Alternative medicine' 22='(22) Hospital'
                  24='(24) Drug treatment or rehab. center' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txyremrg  0='(0) No times' 975='(975) Indicated treatment received at least on'
                  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned (TXEV'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txadgrec  1='(1) Within the past 30 days'
                  2='(2) More than 30 days ago but within the pas'
                  3='(3) More than 12 months ago but within the p'
                  4='(4) More than 3 years ago'
                  8='(8) Treatment in past year LOGICALLY ASSIGNE'
                  9='(9) Treatment in lifetime LOGICALLY ASSIGNED'
                  81='(81) NEVER USED ALCOHOL OR DRUGS Logically as'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV'
                  91='(91) NEVER USED ALCOHOL OR DRUGS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txlthosp  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltrfin  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltrfop  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltmhc   1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltemrg  1='(1) Response marked'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltdoc   1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltjail  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltshg   1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltsop   1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  6='(6) Response not marked LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltsp    4='(4) AA or NA or CA' 5='(5) Residential placement'
                  10='(10) Church or religious influence'
                  13='(13) Court or correctional facilities'
                  14='(14) Counselor, therapist, psychologist' 15='(15) School'
                  16='(16) Home, family' 18='(18) Homeless shelter'
                  19='(19) Alternative medicine' 22='(22) Hospital'
                  24='(24) Drug treatment or rehab. center'
                  25='(25) Mental health center' 85='(85) BAD DATA Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltalc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltmj    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltcoc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txlther   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txlthal   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltinh   1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltanl   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltran   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltstim  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltsed   1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txltsod   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Treatment drug unknown, LOGICALLY ASSIGN'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txlta     161='(161) Rohypnol, Roofies, Rope, Rophynol, Rople' 241='(241) Prozac'
                  322='(322) Methamphetamine (speed or ice or cr'
                  339='(339) Amphetamines (speed generically)'
                  420='(420) OTHER Analgesic, NOT SPECIFIED'
                  805='(805) Cocaine, coca, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  814='(814) Caffeine' 9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txltb     318='(318) Ritalin, Methylphenidate'
                  339='(339) Amphetamines (speed generically)' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE txltc     9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txltd     9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txlte     9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txdrga    116='(116) Methaqualone, Parest, Quaalude, Sopor' 201='(201) Valium'
                  207='(207) Ativan' 209='(209) Xanax' 241='(241) Prozac'
                  322='(322) Methamphetamine (speed or ice or cr'
                  339='(339) Amphetamines (speed generically)' 355='(355) Crystal meth'
                  407='(407) Demerol' 420='(420) OTHER Analgesic, NOT SPECIFIED'
                  447='(447) Synalgos DC'
                  601='(601) LSD (acid, white lightning) [see als' 702='(702) Heroin'
                  705='(705) Speed Ball (heroin + cocaine)'
                  801='(801) OTHER Drugs, NOT SPECIFIED' 803='(803) sic'
                  805='(805) Cocaine, coca, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  814='(814) Caffeine' 9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txdrgb    322='(322) Methamphetamine (speed or ice or cr'
                  339='(339) Amphetamines (speed generically)'
                  434='(434) Anexia, Co-Gesic, Hydrocodone, Lortab, T'
                  601='(601) LSD (acid, white lightning) [see als' 702='(702) Heroin'
                  803='(803) sic' 805='(805) Cocaine, coca, coke' 806='(806) Crack, rock'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txdrgc    702='(702) Heroin' 805='(805) Cocaine, coca, coke' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE txdrgd    9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txdrge    9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE txoutc    1='(1) Still in treatment' 2='(2) Successfully completed treatment'
                  3='(3) Had a problem with program'
                  4='(4) Couldnt afford to continue treatment'
                  5='(5) Family needed me' 6='(6) Began using drug(s) again'
                  7='(7) Other outcome, not specified' 8='(8) Didnt need treatment'
                  10='(10) Successful because of own efforts, not t'
                  11='(11) Use to a lesser extent' 12='(12) Kicked out of program'
                  13='(13) Moved' 15='(15) Discontinued treatment, success unknown'
                  16='(16) Completed treatment, outcome unknown'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txtime    0='(0) No days' 9975='(9975) Indicated treatment received at least on'
                  9989='(9989) LEGITIMATE SKIP Logically assigned (TXEV'
                  9995='(9995) BAD DATA' 9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdins   1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdcare  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdcaid  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdsave  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdfmly  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdempl  1='(1) Yes' 2='(2) No'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdfree  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdsos   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  5='(5) Yes, payment source not specified LOGICA'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txpdsp    1='(1) Health Insurance' 2='(2) Own savings or earnings'
                  3='(3) Family member' 6='(6) Free' 8='(8) Friend/Sponsor'
                  9='(9) State/city public assistance/welfare/rel' 10='(10) Court'
                  12='(12) School' 14='(14) Veterans administration/military service'
                  15='(15) Treatment program' 17='(17) Social Security'
                  85='(85) BAD DATA Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE txenroll  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned (TXEV' 95='(95) BAD DATA'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (TXEVER=2)' ;
  VALUE skycpban  1='(1) Resp is 18-59 years old - SKIP TO PERS B'
                  2='(2) Resp is 60 years or older - SKIP TO DRIV'
                  3='(3) Respondent is 12-17 years old'
                  4='(4) 18-59 years old - SKIP TO PB - LOG ASSIG'
                  5='(5) 60 years or older - SKIP TO DB - LOG ASS'
                  6='(6) 12-17 years old - LOGICALLY ASSIGNED' ;
  VALUE skpycrd   1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ycread    1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE yactyng   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yallergy  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yargue    1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yasthma   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yacoppsx  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ylkaniml  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ybrag     1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ytrbconc  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ycnthgts  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ytrbsit   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ydptadlt  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yflonely  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yflconfu  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ycrylot   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yhonest   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ymeanoth  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ydaydrem  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ytryklsf  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ytryattn  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ydstythg  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ydstyoth  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ydsbypar  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ydsbysch  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ydnteatw  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ydntkids  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ydntglty  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yjealoth  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yhelpoth  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yafrplac  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yafrschl  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yafrbad   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yflprfct  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yflnolov  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yflgetme  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yflwthls  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yacchurt  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yfights   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ygteased  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ykidstrb  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yhrvoics  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yacttnk   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yalone    1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ylie      1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ybitnail  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ynervous  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ybtwitch  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ynghtmar  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ynotkids  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ydobettr  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yanxious  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yfldizzy  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yflguilt  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yeatmuch  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yfltired  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yovrwght  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yaches    1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yheadach  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ynausea   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yeyeprob  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yrashes   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ycramps   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yvomit    1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yattack   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ypkbpart  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ypfrndly  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ytrythng  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yscpoor   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yclumsy   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yoldkids  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yyngkids  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yrfstalk  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yrepactn  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yrunhome  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yscream   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ysecret   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yseethng  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yslfcons  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ysetfire  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ywelhnds  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yshowoff  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yshy      1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yslpless  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yslpmore  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ygdimag   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yspchprb  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ystdrght  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ystealho  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ystealpl  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ydntneed  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ydostrng  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ythstrng  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ystuborn  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ymoods    1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yenjoy    1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ysuspics  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ydrtlang  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ythkklsf  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ylklaugh  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ytalkmch  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ytease    1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ytemper   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ythnksex  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ythrtpeo  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ylkhelp   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yconneat  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ytrbslep  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yskipsch  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ynoenrgy  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yunhappy  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ylouder   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yusedrug  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yfairoth  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yenjyjok  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ylifeasy  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ytryhelp  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE ywsoppsx  1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yinvoth   1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE yworry    1='(1) Not true' 2='(2) Somewhat or sometimes true'
                  3='(3) Very true or often true'
                  89='(89) LEGITIMATE SKIP Logically assigned (SKPY'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP (SKPYCANS=1,3)' ;
  VALUE skpbdban  1='(1) Respondent is 12-15 years old - SKIP TO'
                  2='(2) Respondent is 16-17 years old - SKIP TO'
                  3='(3) Respondent is 12-15 years old LOGICALLY'
                  4='(4) Respondent is 16-17 years old LOGICALLY'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE skppbrd   1='(1) Yes, I think that respondent can complet'
                  2='(2) No, I doubt that resp. can complt. it al'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE pbread    1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xsexyr    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xrelnow   1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xrelyr    1='(1) Yes' 2='(2) No' 3='(3) Yes LOG ASSN (1<= PB-4 <=5 or 1<= PB-5 <'
                  4='(4) No LOG ASSN (XNRELYR=1 or 3, and sex w/1'
                  5='(5) Yes LOGICALLY ASSIGNED (PB-19=1)'
                  6='(6) No LOGICALLY ASSIGNED (sex w/1 pers & P'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xrelcdv   1='(1) A condom was used every single time'
                  2='(2) A condom was used almost every single ti'
                  3='(3) A condom was used at least half of the t'
                  4='(4) A condom was used at least once but less'
                  5='(5) A condom was never used'
                  11='(11) Used condoms at least once LOGICALLY ASS'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  93='(93) DID NOT HAVE VAG SEX IN ON-GOING REL IN' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xrelcda   1='(1) A condom was used every single time'
                  2='(2) A condom was used almost every single ti'
                  3='(3) A condom was used at least half of the t'
                  4='(4) A condom was used at least once but less'
                  5='(5) A condom was never used'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  93='(93) DID NOT HAVE ANAL SEX IN ON-GOING REL IN'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE xnrelyr   1='(1) Yes' 2='(2) No' 3='(3) Yes LOG ASSN (1<= PB-7 <=5 or 1<= PB-8 <'
                  4='(4) No LOG ASSN (on-going rel and sex w/1 pe'
                  5='(5) Yes LOGICALLY ASSIGNED (PB-19=2)'
                  6='(6) No LOGICALLY ASSIGNED (sex w/1 pers & P'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE xnrelcdv  1='(1) A condom was used every single time'
                  2='(2) A condom was used almost every single ti'
                  3='(3) A condom was used at least half of the t'
                  4='(4) A condom was used at least once but less'
                  5='(5) A condom was never used'
                  11='(11) Used condoms at least once LOGICALLY ASS'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  93='(93) DID NOT HAVE VAG SEX OUTSIDE ON-GO REL P'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xnrelcda  1='(1) A condom was used every single time'
                  2='(2) A condom was used almost every single ti'
                  3='(3) A condom was used at least half of the t'
                  4='(4) A condom was used at least once but less'
                  5='(5) A condom was never used'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  93='(93) DID NOT HAVE ANAL SEX OUTSIDE ON-GO REL'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xyrdifpp  1='(1) 1 person' 2='(2) 2 different people'
                  3='(3) 3 to 5 different people' 4='(4) 6 to 10 different people'
                  5='(5) 11 to 20 different people' 6='(6) 21 to 30 different people'
                  7='(7) 31 or more different people'
                  11='(11) 1 person (& sex in both types of relati'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xyrwthmf  1='(1) Only males' 2='(2) Only females' 3='(3) Both males and females'
                  11='(11) Only males (R is male but vag sex also i'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xyrhiv    1='(1) Yes' 2='(2) No' 3='(3) I dont know'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xyrmoney  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE xyrdrugs  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xcdever   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE xcdlast   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE xcdpreg   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (XCDRSN1=1 or 4)'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE xcdstd    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (XCDRSN1=2 or 4)'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE xcdnmess  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (XCDRSN1=4)'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE xcdotrsn  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (1<=XCDRSN1<80)'
                  5='(5) Yes LOG ASSN (Yes not given in PB-16)'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE xcdrsn1f  1='(1) Used condom to prevent pregnancy'
                  2='(2) Used condom to prevent sexually transmit'
                  4='(4) All of the above' 5='(5) Used condom out of curiosity'
                  6='(6) Used condom for hygienic/medical reasons'
                  7='(7) Used condom because wanted to, reg. rout'
                  8='(8) Used condom for general health and safet'
                  10='(10) Used condom bc not mutually monogamous r'
                  11='(11) Used condom to increase intensity/prolon'
                  12='(12) Used condom because partner requested'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE xncdpreg  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (XNCDRSN1=1)'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE xncdmono  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (XNCDRSN1=2)'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE xncdstd   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (XNCDRSN1=3)'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE xncdobc   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (XNCDRSN1=4)'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE xncdrelg  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xncdptnr  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (XNCDRSN1=6)'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE xncdna    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (XNCDRSN1=7)'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE xncdhow   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xncdsafe  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (XNCDRSN1=9)'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE xncdorsn  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (1<=XNCDRSN1<80)'
                  5='(5) Yes LOG ASSN (Yes not given in PB-17)'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE xncdrsnf  1='(1) We are trying to have a baby (get pregna'
                  2='(2) Did not need since only having sex with'
                  3='(3) Did not need since neither of us has AID'
                  4='(4) We used another birth control method'
                  6='(6) My partner did not want us to use a cond'
                  7='(7) A condom was not available or handy'
                  9='(9) The kind of sex we had was not that risk'
                  10='(10) Rape, nonconsensual sex' 11='(11) Already pregnant'
                  12='(12) Lesbian sex' 13='(13) Did not need to, no reason to'
                  14='(14) Oral sex' 15='(15) Have never discussed'
                  16='(16) Less pleasurable/intimate'
                  17='(17) Do not like them/do not want to/not inte'
                  18='(18) Allergic to latex' 19='(19) Too expensive'
                  20='(20) Never use them'
                  21='(21) Under the influence of drugs/alcohol'
                  22='(22) Infertile/sterile'
                  23='(23) Sterilized (tubal ligation, vasectomy, h'
                  24='(24) Inconvenient/interferes with the act'
                  25='(25) Personal reasons' 26='(26) Careless/forgot'
                  27='(27) Do not believe in/use/need birth control'
                  28='(28) Bad quality/defective condom'
                  29='(29) Condoms irritate/uncomfortable' 30='(30) Infrequent sex'
                  31='(31) Indicates distrust'
                  32='(32) Afraid of condoms/dont trust condoms'
                  33='(33) Will lose erection' 34='(34) Menstruating'
                  35='(35) Just for the fun of it'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE xcdmood   1='(1) Agree' 2='(2) Disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xcdresp   1='(1) Agree' 2='(2) Disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xcdfeel   1='(1) Agree' 2='(2) Disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xcdtrst   1='(1) Agree' 2='(2) Disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xcdembr   1='(1) Agree' 2='(2) Disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xcdcost   1='(1) Agree' 2='(2) Disagree'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xrellast  1='(1) The last time, I had sex w/someone in on'
                  2='(2) The last time, I did not have sex in on-'
                  3='(3) Sex in on-going rel LOG ASSN (PB-19 NE 2'
                  4='(4) Sex not in on-going rel LOG ASSN (PB-19'
                  5='(5) Sex in on-going rel LOG ASSN (PB-19=2)'
                  6='(6) Sex not in on-going rel LOG ASSN (PB-19='
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xlfblood  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xbld385f  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xltbldmo  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xltbldyr  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 996='(996) MULTIPLE RESPONSE' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE xhivtest  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE xlthivmo  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE xlthivyr  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 996='(996) MULTIPLE RESPONSE' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE xhivrslt  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skpdbrd   1='(1) Yes, respondent can complete answer shee'
                  2='(2) No, I doubt that resp. can complt. it al'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE dbread    1='(1) Wants interviewer to read questions alou'
                  2='(2) Wants to complete the answer sheet on hi'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vdrvyr    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vyrfreq   1='(1) More than 300 days (every day or almost'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than 1 day a month)' 8='(8) 3 to 5 days'
                  9='(9) 1 to 2 days' 89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE valdrvyr  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED from DB-4 or DB-5'
                  5='(5) Yes LOGICALLY ASSIGNED from elsewhere on'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE valyrfrq  1='(1) More than 300 days (which is every day o'
                  2='(2) 201 to 300 days (5 to 6 days a week)'
                  3='(3) 101 to 200 days (3 to 4 days a week)'
                  4='(4) 51 to 100 days (1 to 2 days a week)'
                  5='(5) 25 to 50 days (3 to 4 days a month)'
                  6='(6) 12 to 24 days (1 to 2 days a month)'
                  7='(7) 6 to 11 days (less than one day a month)'
                  8='(8) 3 to 5 days' 9='(9) 1 to 2 days'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE val30use  83='(83) DID NOT DRV W/IN 2 HRS DRNKNG PST 30 DAY'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  93='(93) DID NOT DRV W/IN 2 HRS DRNKNG PST 30 DAY'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE valcnodr  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE valctime  1='(1) More than 8 hours'
                  2='(2) At least 6 hours but not more than 8 hou'
                  3='(3) At least 4 hours but not more than 6 hou'
                  4='(4) At least 2 hours but not more than 4 hou'
                  5='(5) At least 1 hour but not more than 2 hour'
                  6='(6) At least 30 minutes but not more than 1'
                  7='(7) Less than 30 minutes'
                  8='(8) I only had one drink on this most recent'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE valdtime  1='(1) 2 hours' 2='(2) At least 1 hour but not more than 2 hour'
                  3='(3) At least 30 minutes but not more than 1'
                  4='(4) At least 15 minutes but not more than 30'
                  5='(5) At least 5 minutes but not more than 15'
                  6='(6) Less than 5 minutes' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vmjuseyr  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (VMJDRVYR = 1,3)'
                  5='(5) Yes LOGICALLY ASSIGNED (VMJDRVYR = 5)'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vmjdrvyr  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED from DB-11 or DB-'
                  5='(5) Yes LOGICALLY ASSIGNED from elsewhere on'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vmjalcyr  1='(1) Never' 2='(2) Rarely' 3='(3) Sometimes' 4='(4) Often'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vmjcocyr  1='(1) Never' 2='(2) Rarely' 3='(3) Sometimes' 4='(4) Often'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vmjheryr  1='(1) Never' 2='(2) Rarely' 3='(3) Sometimes' 4='(4) Often'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vmjhalyr  1='(1) Never' 2='(2) Rarely' 3='(3) Sometimes' 4='(4) Often'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vmjinhyr  1='(1) Never' 2='(2) Rarely' 3='(3) Sometimes' 4='(4) Often'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vmjanlyr  1='(1) Never' 2='(2) Rarely' 3='(3) Sometimes' 4='(4) Often'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vmjtrnyr  1='(1) Never' 2='(2) Rarely' 3='(3) Sometimes' 4='(4) Often'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vmjstmyr  1='(1) Never' 2='(2) Rarely' 3='(3) Sometimes' 4='(4) Often'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vmjsedyr  1='(1) Never' 2='(2) Rarely' 3='(3) Sometimes'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vmjothyr  1='(1) Never' 2='(2) Rarely' 3='(3) Sometimes' 4='(4) Often'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vmjyrs1f  322='(322) Methamphetamine (speed or ice or cr'
                  420='(420) OTHER Analgesic, NOT SPECIFIED' 803='(803) sic'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vmjyrs2f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vmjyrs3f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vmjyrs4f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vmjyrs5f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vmj30use  83='(83) DID NOT DRV W/IN 2 HRS USE MJ PST 30 DAY'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  93='(93) DID NOT DRV W/IN 2 HRS USE MJ PST 30 DAY'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vltmjalc  1='(1) I used only marijuana or hashish'
                  2='(2) I used marijuana or hashish with alcohol'
                  3='(3) I used marijuana or hashish with other d'
                  13='(13) Used mj or hash with oth drugs LOGICALLY'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vltmjalf  601='(601) LSD (acid, white lightning) [see als'
                  604='(604) Psilocybin (mushrooms), shooms'
                  805='(805) Cocaine, coca, coke'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vltmja0f  601='(601) LSD (acid, white lightning) [see als'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  813='(813) Cigarettes, smoking (subst spec), tobacc'
                  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vltmja1f  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vltmja2f  607='(607) OTHER Hallucinogen, NOT SPECIFIED'
                  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vltmja3f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vltmjfrm  1='(1) My home' 2='(2) A friend or relatives home'
                  3='(3) A bar or nightclub' 4='(4) A restaurant'
                  5='(5) A sporting event' 6='(6) A concert' 7='(7) My workplace'
                  8='(8) Somewhere else' 18='(18) Somewhere else LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vltmjfrs  9='(9) No place in particular (just driving aro'
                  10='(10) Drove while using marijuana/hashish' 18='(18) School'
                  19='(19) A park/recreational area' 20='(20) A party'
                  22='(22) Local hangout/place to use drugs/parking'
                  23='(23) Gambling establishment/race track/casino'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vltmjto   1='(1) My home' 2='(2) A friend or relatives home'
                  3='(3) A bar or nightclub' 4='(4) A restaurant'
                  5='(5) A sporting event' 6='(6) A concert' 7='(7) My workplace'
                  8='(8) No place in particular (I was just drivi'
                  9='(9) Somewhere else' 19='(19) Somewhere else LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vltmjtos  10='(10) Place to purchase drugs/alcohol'
                  13='(13) A bar or nightclub'
                  18='(18) No place in particular (just driving aro'
                  19='(19) A park/recreational area/gym' 20='(20) A restroom'
                  21='(21) Store/place of business'
                  22='(22) Local hangout/place to use drugs'
                  23='(23) Driving to another location, place unspe' 24='(24) Jail'
                  25='(25) A movie theater' 26='(26) School' 27='(27) Others workplace'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vltmjhwy  1='(1) I drove on an interstate, highway, or fr'
                  2='(2) I drove only on smaller roads'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vltmjurb  1='(1) Rural area (open country)' 2='(2) Urban area (city or town)'
                  3='(3) Suburban area (town just outside of a la'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vltmjwkd  1='(1) Monday' 2='(2) Tuesday' 3='(3) Wednesday' 4='(4) Thursday'
                  5='(5) Friday' 6='(6) Saturday' 7='(7) Sunday'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vltmjtim  1='(1) 12:00 AM to 2:59 AM' 2='(2) 3:00 AM to 5:59 AM'
                  3='(3) 6:00 AM to 8:59 AM' 4='(4) 9:00 AM to 11:59 AM'
                  5='(5) 12:00 PM to 2:59 PM' 6='(6) 3:00 PM to 5:59 PM'
                  7='(7) 6:00 PM to 8:59 PM' 8='(8) 9:00 PM to 11:59 PM'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vltmjabl  1='(1) A lot' 2='(2) A little' 3='(3) Not at all'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vmjnoway  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vmjnhigh  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vmjnpolc  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vmjnodvr  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vmjappt   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vmjother  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vmjothsp  1='(1) There was no other way to get to where I'
                  2='(2) I wasnt high enough to cause a crash'
                  4='(4) No one else was available to drive my mo'
                  5='(5) I had an appointment or curfew' 6='(6) Was not thinking'
                  7='(7) No other place to use it' 8='(8) To get more drugs/alcohol'
                  9='(9) Just to have fun/drive around/just wante'
                  10='(10) To get something to eat'
                  11='(11) To run an errand/get something'
                  12='(12) Do not let anyone else drive my car/pref'
                  13='(13) To go to work/school'
                  14='(14) I was not as high as others with me' 15='(15) Bored'
                  16='(16) To relax/relieve stress' 17='(17) More convenient'
                  18='(18) Accustomed to driving high/unaffected/dr'
                  19='(19) Meet friends/family' 20='(20) To go home'
                  21='(21) To be by myself' 22='(22) Long drive ahead / on a road trip'
                  23='(23) My turn to drive' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vmjstop   1='(1) A lot more likely' 2='(2) A little more likely'
                  3='(3) No more likely' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vmjabil   1='(1) A lot' 2='(2) A little' 3='(3) Not at all'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vccuseyr  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (VCCDRVYR = 1,3)'
                  5='(5) Yes LOGICALLY ASSIGNED (VCCDRVYR = 5)'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vccdrvyr  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED from DB-26 or DB-'
                  5='(5) Yes LOGICALLY ASSIGNED from elsewhere on'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vccalcyr  1='(1) Never' 2='(2) Rarely' 3='(3) Sometimes' 4='(4) Often'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vccmrjyr  1='(1) Never' 2='(2) Rarely' 3='(3) Sometimes' 4='(4) Often'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vccheryr  1='(1) Never' 2='(2) Rarely' 3='(3) Sometimes' 4='(4) Often'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vcchalyr  1='(1) Never' 2='(2) Rarely' 3='(3) Sometimes'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vccinhyr  1='(1) Never' 2='(2) Rarely' 3='(3) Sometimes'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vccanlyr  1='(1) Never' 2='(2) Rarely' 3='(3) Sometimes'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vcctrnyr  1='(1) Never' 2='(2) Rarely' 3='(3) Sometimes' 4='(4) Often'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vccstmyr  1='(1) Never' 2='(2) Rarely' 3='(3) Sometimes' 4='(4) Often'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vccsedyr  1='(1) Never' 2='(2) Rarely' 3='(3) Sometimes'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vccothyr  1='(1) Never' 2='(2) Rarely' 3='(3) Sometimes'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vccyrs1f  161='(161) Rohypnol, Roofies, Rope, Roples, Rufinal'
                  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vccyrs2f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vccyrs3f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vccyrs4f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vccyrs5f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vcc30use  83='(83) DID NOT DRV W/IN 2 HRS USE COC PST 30 DA'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  93='(93) DID NOT DRV W/IN 2 HRS USE COC PST 30 DA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vltccalc  1='(1) I used only cocaine' 2='(2) I used cocaine with alcohol'
                  3='(3) I used cocaine with one or more other dr'
                  13='(13) Used cocaine with other drugs LOGICALLY'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vltccalf  221='(221) OTHER Tranquilizer, NOT SPECIFIED' 803='(803) sic'
                  807='(807) Alcohol, beer, ethanol, EtOH, pink champ'
                  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vltcca0f  803='(803) sic' 9989='(9989) LEGITIMATE SKIP Logically assigned'
                  9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE vltcca1f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vltcca2f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vltcca3f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vltccfrm  1='(1) My home' 2='(2) A friend or relatives home'
                  3='(3) A bar or nightclub' 4='(4) A restaurant' 7='(7) My workplace'
                  8='(8) Somewhere else' 18='(18) Somewhere else LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vltccfrs  9='(9) No place in particular (just driving aro' 18='(18) School'
                  21='(21) Store / place of business'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vltccto   1='(1) My home' 2='(2) A friend or relatives home'
                  3='(3) A bar or nightclub'
                  8='(8) No place in particular (I was just drivi'
                  9='(9) Somewhere else' 19='(19) Somewhere else LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vltcctos  10='(10) Place to purchase drugs/alcohol'
                  18='(18) No place in particular (just driving aro'
                  21='(21) Store / place of business' 26='(26) School'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vltcchwy  1='(1) I drove on an interstate, highway, or fr'
                  2='(2) I drove only on smaller roads'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vltccurb  1='(1) Rural area (open country)' 2='(2) Urban area (city or town)'
                  3='(3) Suburban area (town just outside of a la'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vltccwkd  1='(1) Monday' 2='(2) Tuesday' 3='(3) Wednesday' 4='(4) Thursday'
                  5='(5) Friday' 6='(6) Saturday' 7='(7) Sunday'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vltcctim  1='(1) 12:00 AM to 2:59 AM' 2='(2) 3:00 AM to 5:59 AM'
                  3='(3) 6:00 AM to 8:59 AM' 4='(4) 9:00 AM to 11:59 AM'
                  5='(5) 12:00 PM to 2:59 PM' 6='(6) 3:00 PM to 5:59 PM'
                  7='(7) 6:00 PM to 8:59 PM' 8='(8) 9:00 PM to 11:59 PM'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vltccabl  1='(1) A lot' 2='(2) A little' 3='(3) Not at all'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vccnoway  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vccnhigh  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vccnpolc  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vccnodvr  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vccappt   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vccother  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vccothsp  2='(2) I wasnt high enough to cause a crash'
                  5='(5) I had an appointment or curfew'
                  8='(8) To get more drugs/alcohol'
                  9='(9) Just to have fun/drive around/just wante'
                  11='(11) To run an errand/get something'
                  13='(13) To go to work/school' 16='(16) To relax/relieve stress'
                  18='(18) Accustomed to driving high/unaffected/dr'
                  20='(20) To go home' 22='(22) Long drive ahead / on a road trip'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vccstop   1='(1) A lot more likely' 2='(2) A little more likely'
                  3='(3) No more likely' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vccabil   1='(1) A lot' 2='(2) A little' 3='(3) Not at all'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vtruseyr  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (VTRDRVYR = 1,3)'
                  5='(5) Yes LOGICALLY ASSIGNED (VTRDRVYR = 5)'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vtrdrvyr  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED from DB-41'
                  5='(5) Yes LOGICALLY ASSIGNED from elsewhere on'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vtr30use  83='(83) DID NOT DRV W/IN 2 HRS USE TRQ PST 30 DA'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  93='(93) DID NOT DRV W/IN 2 HRS USE TRQ PST 30 DA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vlttrmed  1='(1) I used tranquilizers for medical reason'
                  2='(2) I used tranquilizers for the experience'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vlttralc  1='(1) I used only tranquilizers'
                  2='(2) I used tranquilizers with alcohol'
                  3='(3) I used tranquilizers with one or more dr'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vlttralf  241='(241) Prozac' 803='(803) sic' 805='(805) Cocaine, coca, coke'
                  891='(891) Famotidine, Pepcid' 893='(893) Estrogen'
                  894='(894) Depakene, Depakote, Valproic acid'
                  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vlttra0f  225='(225) Desyrel, Trazodone hydrochloride, Trazor' 493='(493) IBU'
                  892='(892) Carafate. Sucralfate'
                  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vlttra1f  427='(427) Darvocet' 874='(874) Premarin'
                  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vlttra2f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vlttra3f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vlttrabl  1='(1) A lot' 2='(2) A little' 3='(3) Not at all'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vstuseyr  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (VSTDRVYR = 1,3)'
                  5='(5) Yes LOGICALLY ASSIGNED (VSTDRVYR = 5)'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vstdrvyr  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED from DB-47'
                  5='(5) Yes LOGICALLY ASSIGNED from elsewhere on'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vst30use  83='(83) DID NOT DRV W/IN 2 HRS USE STM PST 30 DA'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  93='(93) DID NOT DRV W/IN 2 HRS USE STM PST 30 DA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vltstmed  1='(1) I used stimulants for a medical reason'
                  2='(2) I used stimulants for the experience or'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vltstalc  1='(1) I used only stimulants'
                  2='(2) I used stimulants with alcohol'
                  3='(3) I used stimulants with one or more other'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vltstalf  803='(803) sic' 897='(897) Synthroid, Levothyroxine'
                  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vltsta0f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vltsta1f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vltsta2f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vltsta3f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vltstabl  1='(1) A lot' 2='(2) A little' 3='(3) Not at all'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vseuseyr  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED (VSEDRVYR = 1,3)'
                  5='(5) Yes LOGICALLY ASSIGNED (VSEDRVYR = 5)'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vsedrvyr  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED from DB-53'
                  5='(5) Yes LOGICALLY ASSIGNED from elsewhere on'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE vse30use  83='(83) DID NOT DRV W/IN 2 HRS USE SED PST 30 DA'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  93='(93) DID NOT DRV W/IN 2 HRS USE SED PST 30 DA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vltsemed  1='(1) I used sedatives for a medical reason'
                  2='(2) I used sedatives for the experience or f'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vltsealc  1='(1) I used only sedatives' 2='(2) I used sedatives with alcohol'
                  3='(3) I used sedatives with one or more other'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE vltsealf  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  805='(805) Cocaine, coca, coke'
                  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vltsea0f  221='(221) OTHER Tranquilizer, NOT SPECIFIED'
                  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vltsea1f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vltsea2f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vltsea3f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9997='(9997) REFUSED'
                  9998='(9998) BLANK (NO ANSWER)' 9999='(9999) LEGITIMATE SKIP' ;
  VALUE vltseabl  1='(1) A lot' 2='(2) A little' 3='(3) Not at all'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skpwkstf  1='(1) Work stat=Now in labor force (codes 1-4/'
                  2='(2) Work stat=Not in labor frc (5-11/25-32)'
                  3='(3) Work stat=Now in labor force LOGICALLY A'
                  4='(4) Work stat=Not in labor frc LOG ASSN - SK' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE workdays  0='(0) No days' 89='(89) LEGITIMATE SKIP Logically assigned'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE workblah  0='(0) No days' 89='(89) LEGITIMATE SKIP Logically assigned'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE skppreg   1='(1) Respondent is female less than 45 years'
                  2='(2) Respondent is female 45 years or older -'
                  3='(3) Respondent is male - SKIP'
                  4='(4) Female less than 45 LOGICALLY ASSIGNED'
                  5='(5) Female 45 years or older LOGICALLY ASSIG'
                  6='(6) Male LOGICALLY ASSIGNED - SKIP' ;
  VALUE pregnant  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE pregmos   85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skpmhc    1='(1) Respondent is 18 years or older'
                  2='(2) Respondent is 12-17 years old - SKIP'
                  3='(3) 18 or older LOGICALLY ASSIGNED'
                  4='(4) 12 to 17 LOGICALLY ASSIGNED - SKIP' ;
  VALUE depress   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depdays   1='(1) All day long' 2='(2) Most of the day' 3='(3) About half the day'
                  4='(4) Less than half the day'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depfreq   1='(1) Every day' 2='(2) Almost every day' 3='(3) Less often'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE lostintf  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tired1ff  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wtchng1f  1='(1) Gained weight' 2='(2) Lost weight'
                  3='(3) Both gained and lost weight' 4='(4) Stayed the same'
                  5='(5) Respondent was on a diet'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE lbschngf  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE slplossf  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE slpfreqf  1='(1) Every night' 2='(2) Nearly every night' 3='(3) Less often'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE concen1f  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE down1fff  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ideat1ff  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skpdep1f  1='(1) Yes' 2='(2) No - SKIP' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED - SKIP'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depwks1f  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE depmo1ff  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE depyr1ff  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE lostin0f  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE losinday  1='(1) All day long' 2='(2) Most of the day' 3='(3) About half the day'
                  4='(4) Less than half the day'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE losinfrq  1='(1) Every day' 2='(2) Almost every day' 3='(3) Less often'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE tired2ff  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wtchng2f  1='(1) Gained weight' 2='(2) Lost weight'
                  3='(3) Both gained and lost weight' 4='(4) Stayed the same'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE lbschn0f  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE slplos0f  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE slpfre0f  1='(1) Every night' 2='(2) Nearly every night' 3='(3) Less often'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE concen2f  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE down2fff  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ideat2ff  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skpdep2f  1='(1) Yes' 2='(2) No - SKIP' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED - SKIP'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depwks2f  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 95='(95) BAD DATA'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE depmo2ff  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE depyr2ff  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE worried   1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE worend    1='(1) Ended' 2='(2) Still going on' 3='(3) Ended LOGICALLY ASSIGNED'
                  4='(4) Still going on LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wornomof  9989='(9989) LEGITIMATE SKIP Logically assigned' 9994='(9994) DONT KNOW'
                  9995='(9995) BAD DATA' 9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE worhapnf  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE worserif  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wordifff  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wornom0f  9989='(9989) LEGITIMATE SKIP Logically assigned' 9994='(9994) DONT KNOW'
                  9995='(9995) BAD DATA' 9997='(9997) REFUSED' 9998='(9998) BLANK (NO ANSWER)'
                  9999='(9999) LEGITIMATE SKIP' ;
  VALUE worhap0f  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE worser0f  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE wordif0f  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skpwor    1='(1) Question HE-33 or HE-37 = 6 months or mo'
                  2='(2) Question HE-33 or HE-37 < 6 mo. - SKIP'
                  3='(3) Q.HE-33 or HE-37 = 6 mo. or more LOG ASS'
                  4='(4) Q.HE-33 or HE-37 < 6 mo. LOG ASSN - SKIP'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE worrest   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE woredge   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE worirrit  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE worheart  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE wortired  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE worsleep  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE worfaint  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE fearpub   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE fearout   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE fearbrdg  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skpfearf  1='(1) Any yes answer' 2='(2) All answered no - SKIP'
                  3='(3) Any yes answer LOGICALLY ASSIGNED'
                  4='(4) All answered no LOGICALLY ASSIGNED - SKI'
                  85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE fearoft   1='(1) Every time' 2='(2) Most of the time' 3='(3) Some of the time'
                  4='(4) Only one or two times'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE fearyrs   1='(1) Less than 1 year' 2='(2) Between 1 and 5 years'
                  3='(3) More than 5 years'
                  5='(5) Between 1 and 5 yrs LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE fearmos   85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE fearfant  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE feartrap  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE fearhelp  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE panic1ff  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE panic2ff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE panicnum  985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE panicmo   89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  95='(95) BAD DATA' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE panicyr   985='(985) BAD DATA Logically assigned'
                  989='(989) LEGITIMATE SKIP Logically assigned' 994='(994) DONT KNOW'
                  995='(995) BAD DATA' 997='(997) REFUSED' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE panidang  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE skpfea0f  1='(1) Any yes answer' 2='(2) All answered no - SKIP'
                  3='(3) Any yes answer LOGICALLY ASSIGNED'
                  4='(4) All answered no LOGICALLY ASSIGNED - SKI'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE panifear  1='(1) Yes' 2='(2) No' 85='(85) BAD DATA Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE paninofr  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE panihart  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE panipain  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE paniswet  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE panishak  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE panihot   1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE paniunrl  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE nuertmt   0='(0) No times' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nuhspov   0='(0) No nights' 94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE nuhsppe   0='(0) No nights' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE outptpe   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE proxable  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned (FAMS' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP (FAMSKIP=1)' ;
  VALUE proxyrel  1='(1) Respondents spouse/live-in partner'
                  2='(2) Respondents father' 3='(3) Respondents mother'
                  4='(4) Respondents brother' 5='(5) Respondents sister'
                  6='(6) Other family member (specify relation to'
                  20='(20) Parent/Guardian'
                  21='(21) Step/Adopted/Foster Parent/Future Step P'
                  50='(50) Grandparent/Great+ Grandparent'
                  61='(61) Friend/Roommate/Companion' 71='(71) Cousin/Cousins Spouse'
                  91='(91) Other Non-Relative, Gender not specified' 110='(110) Husband'
                  121='(121) Step/Adopted/Foster Father/Future Step F' 130='(130) Son'
                  133='(133) Grandson' 150='(150) Grandfather/Great+ Grandfather'
                  161='(161) Male Fiance/Boyfriend/Roommate/Companion'
                  170='(170) Uncle/Step Uncle/Aunts Husband'
                  191='(191) Other Male Non-Relative' 210='(210) Wife'
                  220='(220) Mother/Female Guardian'
                  221='(221) Step/Adopted/Foster Mother/Future Step M'
                  230='(230) Daughter' 242='(242) Sister In-Law'
                  250='(250) Grandmother/Great+ Grandmother' 270='(270) Aunt'
                  271='(271) Female Cousin/Cousins Wife'
                  281='(281) Other Female God Relative'
                  292='(292) Other Female, Relation Unspecified'
                  989='(989) LEGITIMATE SKIP Logically assigned' 997='(997) REFUSED'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE proxhome  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE proxjoin  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE careusu   1='(1) Yes' 2='(2) No' 3='(3) Dont know'
                  4='(4) There is more than one place' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ncarersn  1='(1) Two or more usual doctors/places' 2='(2) Dont need a doctor'
                  3='(3) Dont like/trust/believe in doctors'
                  4='(4) Dont know where to go'
                  5='(5) Previous doctor is not available/moved'
                  6='(6) No insurance/cant afford it'
                  7='(7) Speak a different language'
                  8='(8) No care available/care too far away/inco'
                  9='(9) Other specify (see NCRRSNSP & NCRRSNSC)' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ncrrsnsp  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ncrrsnsc  1='(1) Two or more usual doctors/places' 2='(2) Dont need a doctor'
                  3='(3) Dont like/trust/believe in doctors'
                  4='(4) Dont know where to go'
                  5='(5) Previous doctor is not available/moved'
                  6='(6) No insurance/cant afford it'
                  8='(8) No care available/care too far away or i'
                  10='(10) New to area/recently moved'
                  11='(11) Do not have a regular doctor'
                  12='(12) Self treatment/treatment by family membe'
                  13='(13) Religious reasons'
                  14='(14) Health care plan determines source'
                  15='(15) Hospital/urgent care/clinic' 16='(16) School/workplace'
                  17='(17) Medicare/Medicaid/public assistance'
                  18='(18) Alternative medicine'
                  19='(19) Difficulty getting to medical care bc of'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE careoft   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE pyrcare   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE pyrcrtyp  1='(1) Doctors office or private clinic'
                  2='(2) Company or school health clinic/center'
                  3='(3) Community/migrant/rural clinic or center'
                  4='(4) County/city/public hospital outpatient c'
                  5='(5) Private/other hospital outpatient clinic'
                  6='(6) Hospital emergency room' 7='(7) HMO'
                  9='(9) VA hospital or clinic'
                  10='(10) Military health care facility'
                  11='(11) Some other place specified (see PYRCRTSP'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE pyrcrtsp  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE pyrcrtsc  2='(2) Company or school health clinic/center'
                  3='(3) Community/migrant/rural clinic or center'
                  4='(4) County/city/public hospital outpatient c'
                  5='(5) Private/other hospital outpatient clinic'
                  12='(12) Self treatment/family member' 15='(15) Religion/church'
                  16='(16) Alternative medicine' 18='(18) Family planning clinic'
                  19='(19) Indian clinic or hospital'
                  20='(20) Drug treatment/rehab center'
                  22='(22) Workmans Compensation health provider'
                  23='(23) Prison/correctional facility'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE carenow   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE mnrsnncr  1='(1) Respondent changed residence/moved'
                  2='(2) Respondent changed jobs'
                  3='(3) Employer changed insurance companies'
                  4='(4) Formal usual source left area'
                  5='(5) Owed money to former usual source'
                  6='(6) Dissatsfd with frmr source/like new sour'
                  7='(7) Medical care needs changed'
                  8='(8) Frmr usual source stopped taking ins/cov'
                  9='(9) Other reason specified (see MNRSNNSP/SC)' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE mnrsnnsp  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE mnrsnnsc  1='(1) Respondent changed residence/moved'
                  2='(2) Respondent changed jobs'
                  3='(3) Employer change insurance companies'
                  4='(4) Former usual source left area'
                  5='(5) Owed money to former usual source'
                  6='(6) Dissatsfd with frmr source/liked new sou'
                  7='(7) Medical care needs changed'
                  11='(11) Medical care received through workmans'
                  12='(12) Do not need/like doctors'
                  13='(13) Cannot afford it/no insurance' 16='(16) Former student'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ucaretyp  1='(1) Doctors office or private clinic'
                  2='(2) Company or school health clinic/center'
                  3='(3) Community/migrant/rural clinic or center'
                  4='(4) County/city/public hospital outpatient c'
                  5='(5) Private/other hospital outpatient clinic'
                  6='(6) Hospital emergency room' 7='(7) HMO'
                  8='(8) Psychiatric hospital or clinic'
                  9='(9) VA hospital or clinic'
                  10='(10) Military health care facility'
                  11='(11) Some other place specified (see UCRTYPSP' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ucrtypsp  1='(1) Response marked' 3='(3) Response marked LOGICALLY ASSIGNED'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ucrtypsc  1='(1) Doctors office or private clinic'
                  2='(2) Company or school health clinic/center'
                  3='(3) Community/migrant/rural clinic or center'
                  4='(4) County/city/public hospital outpatient c'
                  5='(5) Private/other hospital outpatient clinic'
                  6='(6) Hospital emergency room'
                  7='(7) HMO (Health maintenance organization/pre'
                  9='(9) VA hospital or clinic'
                  10='(10) Military health care facility'
                  12='(12) Self treatment/family member' 13='(13) Friend'
                  14='(14) Urgent care/walk-in medical facility'
                  15='(15) Religion/church' 16='(16) Alternative medicine'
                  17='(17) Non-physician health care professional'
                  18='(18) Family planning clinic' 19='(19) Indian clinic or hospital'
                  23='(23) Prison/correctional facility'
                  85='(85) BAD DATA Logically assigned' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE medicare  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE medicaid  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE champus   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE prvhltin  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE grphltin  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE pdhinprm  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE hltinalc  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hltindrg  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hltinmnt  1='(1) Yes' 2='(2) No' 89='(89) LEGITIMATE SKIP Logically assigned'
                  94='(94) DONT KNOW' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE soc1ffff  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE soc2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ssi1ffff  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE ssi2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE pub1ffff  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pub2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE afdc      1='(1) AFDC/ADC' 2='(2) OTHER' 3='(3) BOTH'
                  4='(4) AFDC/ADC Logically assigned'
                  5='(5) OTHER Logically assigned' 6='(6) BOTH Logically assigned'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE int1ffff  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE int2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE chd1ffff  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE chd2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE oth1ffff  1='(1) Yes' 2='(2) No' 4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE oth2ffff  1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE fstamp    1='(1) Yes' 2='(2) No' 3='(3) Yes LOGICALLY ASSIGNED'
                  4='(4) No LOGICALLY ASSIGNED' 94='(94) DONT KNOW'
                  96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE pinc1fff  1='(1) $20,000 or more' 2='(2) Less than $20,000' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' ;
  VALUE skptfmin  1='(1) Yes' 2='(2) No - SKIP' 96='(96) MULTIPLE RESPONSE' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE finc1fff  1='(1) $20,000 or more' 2='(2) Less than $20,000'
                  89='(89) LEGITIMATE SKIP Logically assigned' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE telno     0='(0) No telephone lines' 95='(95) BAD DATA' 97='(97) REFUSED'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE irpinsur  1='(1) Yes, respondent does have private health'
                  2='(2) No, respondent does not have private hea' ;
  VALUE iipinsur  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irinsur   1='(1) Yes, respondent does have health insuran'
                  2='(2) No, respondent does not have health insu' ;
  VALUE iiinsur   1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irsoc1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iisoc1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irssi1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iissi1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irpub1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iipub1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irafdc    1='(1) AFDC/ADC' 2='(2) OTHER' 3='(3) BOTH'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE iiafdc    1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irint1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iiint1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irchd1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iichd1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE iroth1ff  1='(1) Yes' 2='(2) No' ;
  VALUE iioth1ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irfstamp  1='(1) Yes' 2='(2) No' ;
  VALUE iifstamp  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irpinc1f  1='(1) $20,000 or more' 2='(2) Less than $20,000' ;
  VALUE iipinc1f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irfinc1f  1='(1) $20,000 or more' 2='(2) Less than $20,000'
                  89='(89) LEGITIMATE SKIP Logically assigned'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE iifinc1f  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irsoc2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iisoc2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irssi2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iissi2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irpub2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iipub2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irint2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iiint2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irchd2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iichd2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iroth2ff  1='(1) Yes' 2='(2) No' ;
  VALUE iioth2ff  1='(1) Questionnaire data' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irkids    0='(0) No children under 12' ;
  VALUE parstat   1='(1) Respondent has no children'
                  2='(2) Respondent has at least one child < 2 yr'
                  3='(3) Resp has at least 1 child < 17, none < 2' ;
  VALUE fembaby   0='(0) No' 1='(1) Yes' ;
  VALUE femkids   0='(0) No' 1='(1) Yes' ;
  VALUE malebaby  0='(0) No' 1='(1) Yes' ;
  VALUE malekids  0='(0) No' 1='(1) Yes' ;
  VALUE f15_44ff  0='(0) Otherwise' 1='(1) Female age 15-44' ;
  VALUE m15_44ff  0='(0) Otherwise' 1='(1) Male age 15-44' ;
  VALUE preg      0='(0) Otherwise' 1='(1) Pregnant female age 12-44' ;
  VALUE preg2fff  1='(1) Pregnant (PREGNANT = 1,3)'
                  2='(2) Not pregnant (PREGNANT = 2)'
                  3='(3) Males/Females not age 12-44 (PREGNANT ='
                  99='(99) Unknown (PREGNANT = 94,97,98)' ;
  VALUE trimest   1='(1) 1st 3 months of pregnancy (PREG=1 & PRE'
                  2='(2) 2nd 3 months of pregnancy (PREG=1 & PRE'
                  3='(3) Last 3 months of pregnancy (PREG=1 & PR'
                  4='(4) Males/Not pregnant females (PREG=0)'
                  99='(99) Unknown (PREG=1 and PREGMOS=85,94,98)' ;
  VALUE indcat    1='(1) $0' 2='(2) $1-$4,999' 3='(3) $5,000-$6,999' 4='(4) $7,000-$8,999'
                  5='(5) $9,000-$11,999' 6='(6) $12,000-$14,999' 7='(7) $15,000-$19,999'
                  8='(8) $20,000-$24,999' 9='(9) $25,000-$29,999'
                  10='(10) $30,000-$39,999' 11='(11) $40,000-$49,999'
                  12='(12) $50,000-$74,999' 13='(13) $75,000+' ;
  VALUE perinc    1='(1) $0-$8,999' 2='(2) $9,000-$19,999' 3='(3) $20,000-$39,999'
                  4='(4) $40,000-$74,999' 5='(5) $75,000+' ;
  VALUE perinc2f  1='(1) $0-9,999' 2='(2) $10,000-$19,999' 3='(3) $20,000-$29,999'
                  4='(4) $30,000-$39,999' 5='(5) $40,000-$49,999' 6='(6) $50,000-$74,999'
                  7='(7) $75,000+' ;
  VALUE perinc3f  1='(1) $0-$9,999' 2='(2) $10,000-$19,999' 3='(3) $20,000-$29,999'
                  4='(4) $30,000-$39,999' 5='(5) $40,000-$49,999' 6='(6) $50,000-$74,999'
                  7='(7) $75,000+' 8='(8) 12-17 Years Old' ;
  VALUE totcat    1='(1) $0' 2='(2) $1-$4,999' 3='(3) $5,000-$6,999' 4='(4) $7,000-$8,999'
                  5='(5) $9,000-$11,999' 6='(6) $12,000-$14,999' 7='(7) $15,000-$19,999'
                  8='(8) $20,000-$24,999' 9='(9) $25,000-$29,999'
                  10='(10) $30,000-$39,999' 11='(11) $40,000-$49,999'
                  12='(12) $50,000-$74,999' 13='(13) $75,000+' ;
  VALUE faminc    1='(1) $0-$8,999' 2='(2) $9,000-$19,999' 3='(3) $20,000-$39,999'
                  4='(4) $40,000-$74,000' 5='(5) $75,000+' ;
  VALUE faminc2f  1='(1) $0-$9,999' 2='(2) $10,000-$19,999' 3='(3) $20,000-$29,999'
                  4='(4) $30,000-$39,999' 5='(5) $40,000-$49,999' 6='(6) $50,000-$74,999'
                  7='(7) $75,000+' ;
  VALUE faminc3f  1='(1) $0-$9,999' 2='(2) $10,000-$19,999' 3='(3) $20,000-$29,999'
                  4='(4) $30,000-$39,999' 5='(5) $40,000-$49,999' 6='(6) $50,000-$74,999'
                  7='(7) $75,000+' 8='(8) 12-17 Years old' ;
  VALUE welfare   1='(1) Yes, respondent or another fam member on'
                  2='(2) No, there was no one in the family on we' ;
  VALUE needlrec  1='(1) Within the past month (30 days)'
                  2='(2) More than 1 month ago but less than 12 m'
                  3='(3) 12 or more months ago but less than 3 ye'
                  4='(4) More than 3 years ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED A NEEDLE TO INJECT ANY DRUG'
                  98='(98) NEEDLE USE NOT INDICATED BUT 1+ SOURCE V' ;
  VALUE nedflagf  0='(0) Never used (GNNDLLIF=2,97,98)'
                  1='(1) Ever used (GNNDLLIF=1,3)' ;
  VALUE nedyr4ff  0='(0) Never used (NEEDLREC=3,4,9,91,98)'
                  1='(1) Ever used (NEEDLREC=1,2)' ;
  VALUE withdrw   98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE somcom    98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE anxdep    98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE socprob   98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE thprob    98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE attprob   98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE delbeh    98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE aggbeh    98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE withdrwt  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE somcomt   998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE anxdept   998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE socprobt  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE thprobt   998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE attprobt  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE delbeht   998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE aggbeht   998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE sxhivlf   1='(1) Yes' 2='(2) No' 12='(12) Never actively tested for HIV'
                  94='(94) DONT KNOW' 97='(97) REFUSED' 98='(98) UNKNOWN, ALL OTHER REASONS'
                  99='(99) LEGITIMATE SKIP (IRAGE<18 OR IRAGE>59)' ;
  VALUE sxhivyr   1='(1) Yes' 2='(2) No' 11='(11) Tested in 1995, same month as INTDATE'
                  12='(12) Tested in 1995, month unknown'
                  22='(22) Tested in lifetime but not actively in p'
                  32='(32) Never actively tested in lifetime' 94='(94) DONT KNOW'
                  97='(97) REFUSED' 98='(98) UNKNOWN, ALL OTHER REASONS'
                  99='(99) LEGITIMATE SKIP (IRAGE<18 OR IRAGE>59)' ;
  VALUE sxrel     1='(1) Did not have sex in past year'
                  2='(2) Sex w/ 1 pers past yr, only on-going rel'
                  3='(3) Sex w/ 1 pers past yr, on-go & outside'
                  4='(4) Sex w/ 1 pers past yr, only outside on-g'
                  5='(5) Sex w/ >1 pers past yr, only on-going re'
                  6='(6) Sex w/ >1 pers past yr, on-go & outside'
                  7='(7) Sex w/ >1 pers pst yr, only outside on-g'
                  14='(14) Sex w/ 1 person pst yr, type of rel unkn'
                  16='(16) Sex w/ >1 pers pst yr, >=1 relationship'
                  25='(25) Sex only in on-going rels pst yr, # part'
                  26='(26) Sex in both types of rel pst yr, # partn'
                  27='(27) Sex only outside on-going rel, # partner'
                  88='(88) SEX IN PAST YR UNKNOWN' 97='(97) REFUSED'
                  98='(98) UNKNOWN, ALL OTHER REASONS'
                  99='(99) LEGITIMATE SKIP (IRAGE<18 OR IRAGE>59)' ;
  VALUE sxrelmar  1='(1) Did not have sex in past year'
                  2='(2) Married, sex w/ 1 person, only on-going'
                  3='(3) Other mar stat, sex w/ 1 pers, only on-g'
                  4='(4) Oth mar stat, sx w/1 pers, on-go & outs'
                  5='(5) Oth mar stat, sx w/1 pers, outside on-go'
                  6='(6) Sex w/ >1 pers (any mar stat), only on-g'
                  7='(7) Sex w/ >1 pers, on-going & outside on-g'
                  8='(8) Sex w/ >1 pers, only outside on-going re'
                  10='(10) Married, sex w/ 1 pers, >=1 relationship'
                  11='(11) Married, sex w/ 1 pers, on-go & outside'
                  12='(12) Married, sex w/ 1 pers, only outside on-'
                  14='(14) Oth mar stat, sex w/ 1 pers, >=1 rel unk'
                  17='(17) Sex w/ > 1 pers, >=1 relationship unknow'
                  26='(26) Sex only in on-going rels, # partners un'
                  27='(27) Sex in both types of rel, # partners unk'
                  28='(28) Sex only outside on-going rel, # partner'
                  88='(88) SEX IN PAST YR UNKNOWN' 97='(97) REFUSED'
                  98='(98) UNKNOWN, ALL OTHER REASONS'
                  99='(99) LEGITIMATE SKIP (IRAGE<18 OR IRAGE>59)' ;
  VALUE sxcondyr  1='(1) Did not have sex in past year'
                  2='(2) No vaginal or anal sex, past year'
                  3='(3) Condoms always used (where applicable)'
                  4='(4) Condoms used always or nearly always (wh'
                  5='(5) Condoms used at least half the time (whe'
                  6='(6) Condoms used less than half the time (wh'
                  7='(7) Condoms never used for some behavs (wher'
                  8='(8) Condoms never used for any behavs (where'
                  88='(88) SEX IN PAST YR UNKNOWN' 97='(97) REFUSED'
                  98='(98) UNKNOWN, ALL OTHER REASONS'
                  99='(99) LEGITIMATE SKIP (IRAGE<18 OR IRAGE>59)' ;
  VALUE sxrskany  1='(1) Yes' 2='(2) No' 12='(12) No except for XHIVYR=3'
                  88='(88) SEX IN PAST YR UNKNOWN' 97='(97) REFUSED'
                  98='(98) UNKNOWN, ALL OTHER REASONS'
                  99='(99) LEGITIMATE SKIP (IRAGE<18 OR IRAGE>59)' ;
  VALUE sxrskcnt  0='(0) None of 5 higher-risk behaviors, past ye'
                  1='(1) 1 of 5 higher-risk behaviors, past year'
                  2='(2) 2 of 5 higher-risk behaviors, past year'
                  3='(3) 3 of 5 higher-risk behaviors, past year'
                  10='(10) No higher-risk behavs except for XHIVYR='
                  11='(11) 1 of 5 higher-risk behaviors and XHIVYR='
                  12='(12) 2 of 5 higher-risk behaviors and XHIVYR='
                  13='(13) 3 of 5 higher-risk behaviors and XHIVYR='
                  14='(14) 4 of 5 higher-risk behaviors and XHIVYR='
                  51='(51) 1 higher-risk behav, at least 1 behav un'
                  52='(52) 2 higher-risk behavs, at least 1 behav u'
                  53='(53) 3 higher-risk behavs, at least 1 behav u'
                  88='(88) SEX IN PAST YR UNKNOWN' 97='(97) REFUSED'
                  98='(98) UNKNOWN, ALL OTHER REASONS'
                  99='(99) LEGITIMATE SKIP (IRAGE<18 OR IRAGE>59)' ;
  VALUE sxdrany   1='(1) Yes' 2='(2) No' 12='(12) No except for XHIVYR=3'
                  88='(88) SEX IN PAST YR UNKNOWN' 97='(97) REFUSED'
                  98='(98) UNKNOWN, ALL OTHER REASONS'
                  99='(99) LEGITIMATE SKIP (IRAGE<18 OR IRAGE>59)' ;
  VALUE sxdrcnt   0='(0) None of 7 higher-risk behaviors, past ye'
                  1='(1) 1 of 7 higher-risk behaviors, past year'
                  2='(2) 2 of 7 higher-risk behaviors, past year'
                  3='(3) 3 of 7 higher-risk behaviors, past year'
                  4='(4) 4 of 7 higher-risk behaviors, past year'
                  10='(10) No higher-risk behavs except for XHIVYR='
                  11='(11) 1 of 7 higher-risk behaviors and XHIVYR='
                  12='(12) 2 of 7 higher-risk behaviors and XHIVYR='
                  13='(13) 3 of 7 higher-risk behaviors and XHIVYR='
                  14='(14) 4 of 7 higher-risk behaviors and XHIVYR='
                  15='(15) 5 of 7 higher-risk behaviors and XHIVYR='
                  51='(51) 1 higher-risk behav, at least 1 behav un'
                  52='(52) 2 higher-risk behavs, at least 1 behav u'
                  54='(54) 4 higher-risk behavs, at least 1 behav u'
                  88='(88) SEX IN PAST YR UNKNOWN' 97='(97) REFUSED'
                  98='(98) UNKNOWN, ALL OTHER REASONS'
                  99='(99) LEGITIMATE SKIP (IRAGE<18 OR IRAGE>59)' ;
  VALUE mdesfs1f  99='(99) LEGITIMATE SKIP' ;
  VALUE mdesfs3f  99='(99) LEGITIMATE SKIP' ;
  VALUE probmdef  99.0000='(99.0000) LEGITIMATE SKIP' ;
  VALUE probmd0f  99.0000='(99.0000) LEGITIMATE SKIP' ;
  VALUE mde1ffff  0='(0) Probable noncase' 1='(1) Probable case' 99='(99) LEGITIMATE SKIP' ;
  VALUE mde3ffff  0='(0) Probable noncase' 1='(1) Probable case' 99='(99) LEGITIMATE SKIP' ;
  VALUE gadsfs1f  99='(99) LEGITIMATE SKIP' ;
  VALUE gadsfs3f  99='(99) LEGITIMATE SKIP' ;
  VALUE probgadf  99.0000='(99.0000) LEGITIMATE SKIP' ;
  VALUE probga0f  99.0000='(99.0000) LEGITIMATE SKIP' ;
  VALUE gad1ffff  0='(0) Probable noncase' 1='(1) Probable case' 99='(99) LEGITIMATE SKIP' ;
  VALUE gad3ffff  0='(0) Probable noncase' 1='(1) Probable case' 99='(99) LEGITIMATE SKIP' ;
  VALUE agpsfs1f  99='(99) LEGITIMATE SKIP' ;
  VALUE agpsfs3f  99='(99) LEGITIMATE SKIP' ;
  VALUE probagpf  99='(99) LEGITIMATE SKIP' ;
  VALUE probag0f  99='(99) LEGITIMATE SKIP' ;
  VALUE agp1ffff  0='(0) Probable noncase' 1='(1) Probable case' 99='(99) LEGITIMATE SKIP' ;
  VALUE agp3ffff  0='(0) Probable noncase' 1='(1) Probable case' 99='(99) LEGITIMATE SKIP' ;
  VALUE pasfs1ff  99='(99) LEGITIMATE SKIP' ;
  VALUE pasfs3ff  99='(99) LEGITIMATE SKIP' ;
  VALUE probpa1f  99.0000='(99.0000) LEGITIMATE SKIP' ;
  VALUE probpa3f  99.0000='(99.0000) LEGITIMATE SKIP' ;
  VALUE pa1fffff  0='(0) Probable noncase' 1='(1) Probable case' 99='(99) LEGITIMATE SKIP' ;
  VALUE pa3fffff  0='(0) Probable noncase' 1='(1) Probable case' 99='(99) LEGITIMATE SKIP' ;
  VALUE bhour     98='(98) BLANK (NO ANSWER)' ;
  VALUE bmin      98='(98) BLANK (NO ANSWER)' ;
  VALUE bap       98='(98) BLANK (NO ANSWER)' ;
  VALUE eap       98='(98) BLANK (NO ANSWER)' ;
  VALUE langver   1='(1) English' 2='(2) Spanish' ;
  VALUE undint    1='(1) No difficulty--no language or reading pr'
                  2='(2) Just a little difficulty--almost no lang'
                  3='(3) A fair amount of difficulty--some lang/r'
                  4='(4) A lot of difficulty--considerable lang/r'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE coopint   1='(1) Very cooperative' 2='(2) Fairly cooperative'
                  3='(3) Not very cooperative' 4='(4) Openly hostile'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE privacy   1='(1) Completely private-no one present/able t'
                  3='(3) Minor distractions'
                  5='(5) Person(s) in the room or listening 1/3 o'
                  7='(7) Serious interruption of privacy more tha'
                  9='(9) Constant presence of other person(s)'
                  85='(85) BAD DATA Logically assigned' 96='(96) MULTIPLE RESPONSE'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ppres     1='(1) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE spres     2='(2) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE parpres   3='(3) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE oarpres   4='(4) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE oapres    5='(5) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE cpres     6='(6) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE opresnsp  7='(7) Response marked' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE opresspa  10='(10) Spouse' 21='(21) Step/Adopted/Foster Parent/Future Step P'
                  30='(30) Own Child/Own Half Child' 33='(33) Grandchild'
                  37='(37) Child, Relation Unspecified'
                  61='(61) Friend/Roommate/Companion' 71='(71) Cousin/Cousins Spouse'
                  84='(84) Neighbor/Co-Worker/Visitor'
                  90='(90) Other Relative, Gender not specified'
                  91='(91) Other Non-Relative, Gender not specified'
                  92='(92) Other, Relation and Gender Unspecified'
                  113='(113) Childs Father'
                  121='(121) Step/Adopted/Foster Father/Future Step F'
                  122='(122) Father/Step Father/Future Father In-Law' 130='(130) Son'
                  133='(133) Grandson' 140='(140) Brother/Half Brother'
                  142='(142) Brother In-Law' 150='(150) Grandfather/Great+ Grandfather'
                  161='(161) Male Fiance/Boyfriend/Roommate/Companion'
                  170='(170) Uncle/Step Uncle/Aunts Husband' 172='(172) Nephew'
                  191='(191) Other Male Non-Relative'
                  192='(192) Other Male, Relation Unspecified' 210='(210) Wife'
                  220='(220) Mother/Female Guardian'
                  222='(222) Mother/Step Mother/Future Mother In-Law'
                  230='(230) Daughter' 233='(233) Granddaughter' 240='(240) Sister/Half Sister'
                  242='(242) Sister In-Law' 250='(250) Grandmother/Great+ Grandmother'
                  261='(261) Female Fiancee/Girlfriend/Roommate/Compa' 270='(270) Aunt'
                  272='(272) Niece' 282='(282) Female Housekeeper/Maid/Caretaker/Butler'
                  292='(292) Other Female, Relation Unspecified'
                  320='(320) Parents/Guardians'
                  337='(337) Children, Relation Unspecified' 340='(340) Siblings'
                  361='(361) Friends/Roommates/Companions'
                  384='(384) Neighbors/Co-Workers/Visitors'
                  391='(391) Other Non-Relatives, Gender not specifie'
                  392='(392) Others, Relation and Gender Unspecified' 430='(430) Sons'
                  540='(540) Sisters/Half Sisters' 900='(900) NOT A PERSON'
                  998='(998) BLANK (NO ANSWER)' 999='(999) LEGITIMATE SKIP' ;
  VALUE opresspb  37='(37) Child, Relation Unspecified'
                  61='(61) Friend/Roommate/Companion'
                  161='(161) Male Fiance/Boyfriend/Roommate/Companion'
                  230='(230) Daughter' 242='(242) Sister In-Law'
                  250='(250) Grandmother/Great+ Grandmother' 270='(270) Aunt'
                  337='(337) Children, Relation Unspecified'
                  361='(361) Friends/Roommates/Companions'
                  392='(392) Others, Relation and Gender Unspecified'
                  900='(900) NOT A PERSON' 998='(998) BLANK (NO ANSWER)'
                  999='(999) LEGITIMATE SKIP' ;
  VALUE whomarkd  1='(1) Respondent marked all the Answer Sheet r'
                  2='(2) Interviewer marked all the Answer Sheet'
                  96='(96) MULTIPLE RESPONSE' 98='(98) BLANK (NO ANSWER)' ;
  VALUE quarter   1='(1) Quarter 1' 2='(2) Quarter 2' 3='(3) Quarter 3' 4='(4) Quarter 4' ;
  VALUE famskip   0='(0) Respondent has other family members in h'
                  1='(1) Respondent didnt have other family in h' ;
  VALUE gqtype    1='(1) Halfway House' 2='(2) Boarding House' 3='(3) College Dorm'
                  4='(4) Shelter' 5='(5) Other' 9='(9) Not Group Quarters' ;
  VALUE pden      1='(1) Segment in a MSA with 1 million or more'
                  2='(2) Segment in a MSA with fewer than 1 milli'
                  3='(3) Segment not in MSA' ;
  VALUE pden2fff  1='(1) Segment in MSA with 1 million or more pe'
                  2='(2) Segm. in a MSA from 250000 to 999999 per'
                  3='(3) Segment in a MSA with fewer than 250000'
                  4='(4) Segment not in a MSA and not in a rural'
                  5='(5) Segment not in a MSA and in a rural area' ;
  VALUE region    1='(1) Northeast' 2='(2) North Central' 3='(3) South' 4='(4) West' ;
  VALUE division  1='(1) New England' 2='(2) Middle Atlantic' 3='(3) East North Central'
                  4='(4) West North Central' 5='(5) South Atlantic'
                  6='(6) East South Central' 7='(7) West South Central' 8='(8) Mountain'
                  9='(9) Pacific' ;
  VALUE rurorurb  1='(1) Rural' 2='(2) Urban' ;
  VALUE relinthh  0='(0) No other person in hhold interviewed' 10='(10) Spouse'
                  20='(20) Parent/guardian' 21='(21) Step/adopted/foster parent'
                  22='(22) Parent in-law (also step-)' 25='(25) Parents sibling'
                  30='(30) Child' 31='(31) Step/adopted/foster child' 32='(32) Child in-law'
                  35='(35) Siblings child' 36='(36) Cousin' 37='(37) Grandchild'
                  40='(40) Sibling' 41='(41) Step/adopted/foster sibling'
                  42='(42) Sibling in-law' 50='(50) Grandparent'
                  60='(60) Live in partner, fiancee' 61='(61) Friend/roommate'
                  70='(70) Other, relative' 71='(71) Other, non-relative'
                  99='(99) Other, relation unspecified' ;
  VALUE mjtot3ff  1='(1) 1-2 days' 2='(2) 3-11 days' 3='(3) 12-100 days' 4='(4) 101+ days'
                  5='(5) NEVER USED' 99='(99) UNKNOWN/NO ANSWER' ;
  VALUE coctot3f  1='(1) 1-2 days' 2='(2) 3-11 days' 3='(3) 12-100 days' 4='(4) 101+ days'
                  5='(5) NEVER USED/NO ANSWER' 99='(99) UNKNOWN' ;
  VALUE alcdaysf  1='(1) None or never used alcohol' 2='(2) 1-2 days' 3='(3) 3-4 days'
                  4='(4) 5-19 days' 5='(5) 20-30 days' 6='(6) UNKNOWN' ;
  VALUE agecat4f  1='(1) 12-20' 2='(2) 21 and older' ;
  VALUE mjdy30af  1='(1) 1-2 days' 2='(2) 3-4 days' 3='(3) 5-19 days' 4='(4) 20-30 days'
                  5='(5) NONE/NEVER USED MARIJUANA' 6='(6) UNKNOWN/NO ANSWER' ;
  VALUE alcday0f  1='(1) 0' 2='(2) 1-4' 3='(3) 5-19' 4='(4) 20-30' 6='(6) UNKNOWN' ;
  VALUE drinkerf  0='(0) No' 1='(1) Yes' ;
  VALUE hvydrk3f  0='(0) No' 1='(1) Yes' ;
  VALUE avcig2ff  1='(1) 0' 2='(2) 15 cigarettes or less' 3='(3) 16 cigarettes or more'
                  4='(4) UNKNOWN' ;
  VALUE racesex   1='(1) White male' 2='(2) Black male' 3='(3) Hispanic male'
                  4='(4) White female' 5='(5) Black female' 6='(6) Hispanic female'
                  99='(99) Other males and females' ;
  VALUE notmarj   0='(0) No' 1='(1) Yes' ;
  VALUE bingdrkf  0='(0) No' 1='(1) Yes' ;
  VALUE racesexf  1='(1) White male' 2='(2) Black male' 3='(3) Hispanic male'
                  4='(4) Other male' 5='(5) White female' 6='(6) Black female'
                  7='(7) Hispanic female' 8='(8) Other female' ;
  VALUE irbtcigf  0='(0) No' 1='(1) Yes' ;
  VALUE irbtalcf  0='(0) No' 1='(1) Yes' ;
  VALUE irbtmrjf  0='(0) No' 1='(1) Yes' ;
  VALUE irbtcocf  0='(0) No' 1='(1) Yes' ;
  VALUE irgrcigf  0='(0) No' 1='(1) Yes' ;
  VALUE irgralcf  0='(0) No' 1='(1) Yes' ;
  VALUE irgrmrjf  0='(0) No' 1='(1) Yes' ;
  VALUE irgrcocf  0='(0) No' 1='(1) Yes' ;
  VALUE irlacigf  0='(0) No' 1='(1) Yes' ;
  VALUE irlaalcf  0='(0) No' 1='(1) Yes' ;
  VALUE irlamrjf  0='(0) No' 1='(1) Yes' ;
  VALUE irlacocf  0='(0) No' 1='(1) Yes' ;
  VALUE iraccigf  0='(0) No' 1='(1) Yes' ;
  VALUE iracalcf  0='(0) No' 1='(1) Yes' ;
  VALUE iracmrjf  0='(0) No' 1='(1) Yes' ;
  VALUE iraccocf  0='(0) No' 1='(1) Yes' ;
  VALUE iremcigf  0='(0) No' 1='(1) Yes' ;
  VALUE iremalcf  0='(0) No' 1='(1) Yes' ;
  VALUE iremmrjf  0='(0) No' 1='(1) Yes' ;
  VALUE iremcocf  0='(0) No' 1='(1) Yes' ;
  VALUE irhlcigf  0='(0) No' 1='(1) Yes' ;
  VALUE irhlalcf  0='(0) No' 1='(1) Yes' ;
  VALUE irhlmrjf  0='(0) No' 1='(1) Yes' ;
  VALUE irhlcocf  0='(0) No' 1='(1) Yes' ;
  VALUE iruccigf  0='(0) No' 1='(1) Yes' ;
  VALUE irucalcf  0='(0) No' 1='(1) Yes' ;
  VALUE irucmrjf  0='(0) No' 1='(1) Yes' ;
  VALUE iruccocf  0='(0) No' 1='(1) Yes' ;
  VALUE avcig3ff  0='(0) No' 1='(1) Yes' ;
  VALUE alcprobs  0='(0) No' 1='(1) Yes' ;
  VALUE mjprobs   0='(0) No' 1='(1) Yes' ;
  VALUE cocprobs  0='(0) No' 1='(1) Yes' ;
  VALUE cigprobs  0='(0) No' 1='(1) Yes' ;
  VALUE mrj2prob  0='(0) No' 1='(1) Yes' ;
  VALUE mrj3prob  0='(0) No' 1='(1) Yes' ;
  VALUE coc2prob  0='(0) No' 1='(1) Yes' ;
  VALUE coc3prob  0='(0) No' 1='(1) Yes' ;
  VALUE cig2prob  0='(0) No' 1='(1) Yes' ;
  VALUE cig3prob  0='(0) No' 1='(1) Yes' ;
  VALUE alc2prob  0='(0) No' 1='(1) Yes' ;
  VALUE alc3prob  0='(0) No' 1='(1) Yes' ;
  VALUE cigtry2f  99='(99) LEGITIMATE SKIP/NO ANSWER' ;
  VALUE alctry2f  99='(99) LEGITIMATE SKIP/NO ANSWER' ;
  VALUE mjage2ff  99='(99) NEVER USED/NO ANSWER' ;
  VALUE inhage2f  99='(99) NEVER USED/NO ANSWER' ;
  VALUE cocage2f  99='(99) LEGITIMATE SKIP/NO ANSWER' ;
  VALUE hallagef  99='(99) NEVER USED/NO ANSWER' ;
  VALUE herage2f  99='(99) NEVER USED/NO ANSWER' ;
  VALUE stimagef  99='(99) NEVER USED/NO ANSWER' ;
  VALUE sedage2f  99='(99) NEVER USED/NO ANSWER' ;
  VALUE tranagef  99='(99) NEVER USED/NO ANSWER' ;
  VALUE analagef  99='(99) LEGITIMATE SKIP/NO ANSWER' ;
  VALUE alconlyl  0='(0) No' 1='(1) Yes' ;
  VALUE alconlyy  0='(0) No' 1='(1) Yes' ;
  VALUE alconlym  0='(0) No' 1='(1) Yes' ;
  VALUE illonlyl  0='(0) No' 1='(1) Yes' ;
  VALUE illonlyy  0='(0) No' 1='(1) Yes' ;
  VALUE illonlym  0='(0) No' 1='(1) Yes' ;
  VALUE mrjonlyl  0='(0) No' 1='(1) Yes' ;
  VALUE mrjonlyy  0='(0) No' 1='(1) Yes' ;
  VALUE mrjonlym  0='(0) No' 1='(1) Yes' ;
  VALUE psyonlyl  0='(0) No' 1='(1) Yes' ;
  VALUE psyonlyy  0='(0) No' 1='(1) Yes' ;
  VALUE psyonlym  0='(0) No' 1='(1) Yes' ;
  VALUE othonlyl  0='(0) No' 1='(1) Yes' ;
  VALUE othonlyy  0='(0) No' 1='(1) Yes' ;
  VALUE othonlym  0='(0) No' 1='(1) Yes' ;
  VALUE alcilll   0='(0) No' 1='(1) Yes' ;
  VALUE alcilly   0='(0) No' 1='(1) Yes' ;
  VALUE alcillm   0='(0) No' 1='(1) Yes' ;
  VALUE alcmrjl   0='(0) No' 1='(1) Yes' ;
  VALUE alcmrjy   0='(0) No' 1='(1) Yes' ;
  VALUE alcmrjm   0='(0) No' 1='(1) Yes' ;
  VALUE alcpsyl   0='(0) No' 1='(1) Yes' ;
  VALUE alcpsyy   0='(0) No' 1='(1) Yes' ;
  VALUE alcpsym   0='(0) No' 1='(1) Yes' ;
  VALUE alcothl   0='(0) No' 1='(1) Yes' ;
  VALUE alcothy   0='(0) No' 1='(1) Yes' ;
  VALUE alcothm   0='(0) No' 1='(1) Yes' ;
  VALUE sub1lif   0='(0) No' 1='(1) Yes' ;
  VALUE sub2lif   0='(0) No' 1='(1) Yes' ;
  VALUE sub3lif   0='(0) No' 1='(1) Yes' ;
  VALUE sub1yr    0='(0) No' 1='(1) Yes' ;
  VALUE sub2yr    0='(0) No' 1='(1) Yes' ;
  VALUE sub3yr    0='(0) No' 1='(1) Yes' ;
  VALUE sub1mon   0='(0) No' 1='(1) Yes' ;
  VALUE sub2mon   0='(0) No' 1='(1) Yes' ;
  VALUE sub3mon   0='(0) No' 1='(1) Yes' ;
  VALUE psyage    99='(99) NEVER USED/NO ANSWER' ;
  VALUE trmthlpf  0='(0) No' 1='(1) Yes' ;
  VALUE drnkhlpf  0='(0) No' 1='(1) Yes' ;
  VALUE dralhelp  0='(0) No' 1='(1) Yes' ;
  VALUE bklarcnf  0='(0) No' 1='(1) Yes' ;
  VALUE bkburglf  0='(0) No' 1='(1) Yes' ;
  VALUE bkagaslf  0='(0) No' 1='(1) Yes' ;
  VALUE bksmaslf  0='(0) No' 1='(1) Yes' ;
  VALUE bkmvthff  0='(0) No' 1='(1) Yes' ;
  VALUE bkrob2ff  0='(0) No' 1='(1) Yes' ;
  VALUE bkrape2f  0='(0) No' 1='(1) Yes' ;
  VALUE bkmurdef  0='(0) No' 1='(1) Yes' ;
  VALUE bkarsonf  0='(0) No' 1='(1) Yes' ;
  VALUE bkdrvi0f  0='(0) No' 1='(1) Yes' ;
  VALUE bkdrunkf  0='(0) No' 1='(1) Yes' ;
  VALUE bkdrug2f  0='(0) No' 1='(1) Yes' ;
  VALUE bkpros2f  0='(0) No' 1='(1) Yes' ;
  VALUE drunkyrf  1='(1) Yes' 2='(2) No' ;
  VALUE fertage   1='(1) Women ages 15-25' 2='(2) Women ages 26-44'
                  99='(99) Men/women 12-14, 45+' ;
  VALUE preg3fff  1='(1) Pregnant' 2='(2) Not pregnant' 99='(99) Otherwise' ;
  VALUE trimestf  1='(1) 1st 3 mos of pregnancy' 2='(2) 2nd 3 mos of pregnancy'
                  3='(3) Last 3 mos of pregnancy' 99='(99) Otherwise' ;
  VALUE rskcig    0='(0) No' 1='(1) Yes' 99='(99) MISSING' ;
  VALUE rskmj1ff  0='(0) No' 1='(1) Yes' 99='(99) MISSING' ;
  VALUE rskmj2ff  0='(0) No' 1='(1) Yes' 99='(99) MISSING' ;
  VALUE rskcoc1f  0='(0) No' 1='(1) Yes' 99='(99) MISSING' ;
  VALUE rskcoc2f  0='(0) No' 1='(1) Yes' 99='(99) MISSING' ;
  VALUE rskalc1f  0='(0) No' 1='(1) Yes' 99='(99) MISSING' ;
  VALUE rskalc2f  0='(0) No' 1='(1) Yes' 99='(99) MISSING' ;
  VALUE maruse    1='(1) Less than 12 days' 2='(2) 12-50 days' 3='(3) 51-300 days'
                  4='(4) More than 300 days' 5='(5) Did not use in past year' ;
  VALUE cocuse    1='(1) Less than 12 days' 2='(2) 12-50 days' 3='(3) 51-300 days'
                  4='(4) More than 300 days' 5='(5) Has not used in past year' ;
  VALUE alcuse    1='(1) Less than 12 days' 2='(2) 12-50 days' 3='(3) 51-300 days'
                  4='(4) More than 300 days' 5='(5) HAS NOT USED IN PAST YEAR' ;
  VALUE totprob   999.0000='(999.0000) BLANK' ;
  VALUE int       99.0000='(99.0000) BLANK' ;
  VALUE ext       99='(99) BLANK' ;
  VALUE pr_emot   0='(0) No' 1='(1) Yes' 99='(99) BLANK' ;
  VALUE pr_behav  0='(0) No' 1='(1) Yes' 99='(99) BLANK' ;
  VALUE pr_total  0='(0) No' 1='(1) Yes' 99='(99) BLANK' ;
  VALUE pr_wd     0='(0) No' 1='(1) Yes' 99='(99) BLANK/NO ANSWER' ;
  VALUE pr_sc     0='(0) No' 1='(1) Yes' 99='(99) BLANK/NO ANSWER' ;
  VALUE pr_ad     0='(0) No' 1='(1) Yes' 99='(99) BLANK/NO ANSWER' ;
  VALUE pr_sp     0='(0) No' 1='(1) Yes' 99='(99) BLANK/NO ANSWER' ;
  VALUE pr_tp     0='(0) No' 1='(1) Yes' 99='(99) BLANK/NO ANSWER' ;
  VALUE pr_ap     0='(0) No' 1='(1) Yes' 99='(99) BLANK/NO ANSWER' ;
  VALUE pr_db     0='(0) No' 1='(1) Yes' 99='(99) BLANK/NO ANSWER' ;
  VALUE pr_ab     0='(0) No' 1='(1) Yes' 99='(99) BLANK/NO ANSWER' ;
  VALUE any4ment  0='(0) Did not have in past year' 1='(1) Had in past year'
                  99='(99) CHILDREN AGE 12-17' ;
  VALUE alcdriv   0='(0) No' 1='(1) Yes' ;
  VALUE mrjdriv   0='(0) No' 1='(1) Yes' ;
  VALUE agecat3f  1='(1) 12-13' 2='(2) 14-15' 3='(3) 16-17' 4='(4) 18-20' 5='(5) 21-25' 6='(6) 26-29'
                  7='(7) 30-34' 8='(8) 35-39' 9='(9) 40-44' 10='(10) 45-49' 11='(11) 50-102' ;
  VALUE drunky0f  0='(0) No' 1='(1) Yes' 99='(99) CHILDREN AGE 12-17' ;
  VALUE herneedf  0='(0) No' 1='(1) Yes' ;
  VALUE rsksellf  0='(0) No' 1='(1) Yes' ;
  VALUE sexyr     0='(0) No' 1='(1) Yes' 99='(99) LEGITIMATE SKIP' ;
  VALUE relnow    0='(0) No' 1='(1) Yes' 99='(99) LEGITIMATE SKIP' ;
  VALUE hivtest   0='(0) No' 1='(1) Yes' 99='(99) LEGITIMATE SKIP' ;
  VALUE cdalways  0='(0) No' 1='(1) Yes' 99='(99) LEGITIMATE SKIP' ;
  VALUE cdsome    0='(0) No' 1='(1) Yes' 99='(99) LEGITIMATE SKIP' ;
  VALUE cdnever   0='(0) No' 1='(1) Yes' 99='(99) LEGITIMATE SKIP' ;
  VALUE yrdifppf  0='(0) No' 1='(1) Yes' 99='(99) LEGITIMATE SKIP' ;
  VALUE yrdifp0f  0='(0) No' 1='(1) Yes' 99='(99) LEGITIMATE SKIP' ;
  VALUE ehour     94='(94) DONT KNOW' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
  VALUE emin      94='(94) DONT KNOW' 95='(95) BAD DATA' 98='(98) BLANK (NO ANSWER)' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=2873;
INPUT
        CASEID 1-5              RESPID 6-11             VESTR 12-15
        VEREP 16                ENCPSU 17-19            ENCSEG 20-23
        ENCCASE 24-28           SKPMARTL 29             MARITAL 30-31
        NOMARR 32-33            SKPMILT 34              SERVICE 35-36
        MILSTAT 37-38           EDUC 39-40              DIPLOMA 41-42
        ENROLLD 43-44           WORKSTAT 45-46          HTININCH 47-49
        POUNDS 50-52            HEALTH 53-54            CIGEVER 55-56
        CIGTRY 57-59            CIGTOT 60-61            CIGREC 62-63
        CIG30USE 64-65          AVCIG 66-67             CIG30WOK 68-69
        CIGEVYDA 70-71          CIGAGE 72-74            CIGYRS 75-77
        SNUFEVER 78-79          SNUFREC 80-81           SKPALCRD 82-83
        ALCREAD 84-85           ALCEVER 86              ALCTRY 87-89
        ALCREC 90-91            ALCPAT 92-93            DRUNKYR 94-95
        ALCDAYS 96-97           NODR30A 98-99           DR5DAY 100-101
        MJEVER 102              MJAGE 103-105           MJTOT 106-107
        MJREC 108-109           MJYRFREQ 110-111        MJDAY30A 112-113
        SKPCOCRD 114-115        COCREAD 116-117         COCEVER 118
        COCAGE 119-121          COCTOT 122-123          COCREC 124-125
        COCYRFRQ 126-127        COCUS30A 128-129        SKPCRKRD 130-131
        CRKREAD 132-133         CRKEVER 134-135         CRKAGE 136-138
        CRKTOT 139-140          CRAKREC 141-142         CRKYRFRQ 143-144
        CRKUS30A 145-146        SKPHERRD 147-148        HERREAD 149-150
        HEREVER 151-152         HERAGE 153-155          HERTOT 156-157
        HERREC 158-159          HERYRFRQ 160-161        HER30USE 162-163
        SKPHALRD 164-165        HALREAD 166-167         LSD 168-169
        PCP 170-171             PEYOTE 172-173          MESC 174-175
        PSILCY 176-177          ECSTASY 178-179         HALDKNAM 180-181
        HALNOLST 182-183        HALNEWA 184-187         HALNEWB 188-191
        HALNEWC 192-195         HALNEWD 196-199         HALNEWE 200-203
        HALLAGE 204-206         HALLTOT 207-208         HALLREC 209-210
        HALYRFRQ 211-212        HAL30USE 213-214        LSDREC 215-216
        PCPREC 217-218          SKPINHRD 219-220        INHREAD 221-222
        AMYLNIT 223-224         CLEFLU 225-226          GAS 227-228
        GLUE 229-230            ETHER 231-232           SOLVENT 233-234
        LGAS 235-236            NITOXID 237-238         SPPAINT 239-240
        AEROS 241-242           INHDKNAM 243-244        INHNOLST 245-246
        INHNEWA 247-250         INHNEWB 251-254         INHNEWC 255-258
        INHNEWD 259-262         INHNEWE 263-266         INHAGE 267-269
        INHTOT 270-271          INHREC 272-273          INHYRFRQ 274-275
        INHDY30A 276-277        SKPANLRD 278-279        ANLREAD 280-281
        CODEINE 282-283         DARVON 284-285          DEMEROL 286-287
        DILAUD 288-289          METHDON 290-291         MORPHINE 292-293
        PERCODAN 294-295        TALWIN 296-297          TYLCOD 298-299
        ANLDKNAM 300-301        ANLNOLST 302-303        ANALNEWA 304-307
        ANALNEWB 308-311        ANALNEWC 312-315        ANALNEWD 316-319
        ANALNEWE 320-323        ANALNONE 324-325        ANALAGE 326-328
        ANALTOT 329-330         ANALREC 331-332         ANLYRFRQ 333-334
        SKPTRNRD 335-336        TRNREAD 337-338         ATARAX 339-340
        ATIVAN 341-342          DIAZEPAM 343-344        LIBRIUM 345-346
        TRANXENE 347-348        VALIUM 349-350          XANAX 351-352
        TRDKNAM 353-354         TRNOLST 355-356         TRNEWA 357-360
        TRNEWB 361-364          TRNEWC 365-368          TRNEWD 369-372
        TRNEWE 373-376          NOTRANQ 377-378         TRANAGE 379-381
        TRANTOT 382-383         TRANREC 384-385         TRNYRFRQ 386-387
        SKPSTMRD 388-389        STMREAD 390-391         BENZ 392-393
        BIPHET 394-395          DEXAMYL 396-397         DEXED 398-399
        FASTIN 400-401          IONAMIN 402-403         METHAMP 404-405
        METHI 406-407           PRELUDIN 408-409        STMDKNAM 410-411
        STMNOLST 412-413        STIMNEWA 414-417        STIMNEWB 418-421
        STIMNEWC 422-425        STIMNEWD 426-429        STIMNEWE 430-433
        NOSTIMS 434-435         STIMAGE 436-438         STIMTOT 439-440
        STIMREC 441-442         STMYRFRQ 443-444        SKPSEDRD 445-446
        SEDREAD 447-448         DALMANE 449-450         HALCION 451-452
        METHAQ 453-454          NEMBUTAL 455-456        PHENOBAR 457-458
        PLACIDYL 459-460        SECONAL 461-462         TUINAL 463-464
        SEDDKNAM 465-466        SEDNOLST 467-468        SEDNEWA 469-472
        SEDNEWB 473-476         SEDNEWC 477-480         SEDNEWD 481-484
        SEDNEWE 485-488         NOSEDAT 489-490         SEDAGE 491-493
        SEDTOT 494-495          SEDREC 496-497          SEDYRFRQ 498-499
        BIRMONTH 500-501        BIRYEAR 502-505         IRAGE 506-507
        IIAGE 508               IRSEX 509               IISEX 510
        IRRACE 511              IIRACE 512              IRHOIND 513
        IIHOIND 514             IRHOGRP 515-516         IIHOGRP 517
        IRHOGRP2 518-519        IIHOGRP2 520            IRMARIT 521-522
        IIMARIT 523             IREDUC 524-525          IIEDUC 526
        IRHSGRAD 527            IIHSGRAD 528            IRWORKST 529-530
        IIWORKST 531            IRCIGRC 532             IICIGRC 533
        IROTBRC 534             IIOTBRC 535             IRALCRC 536
        IIALCRC 537             IRMJRC 538              IIMJRC 539
        IRCOCRC 540             IICOCRC 541             IRCRKRC 542
        IICRKRC 543             IRHERRC 544             IIHERRC 545
        IRHALRC 546             IIHALRC 547             IRLSDRC 548
        IILSDRC 549             IRPCPRC 550             IIPCPRC 551
        IRINHRC 552             IIINHRC 553             IRANLRC 554
        IIANLRC 555             IRTRNRC 556             IITRNRC 557
        IRSTMRC 558             IISTMRC 559             IRSEDRC 560
        IISEDRC 561             IRALCFQ 562-563         IIALCFQ 564
        IRMJFQ 565-566          IIMJFQ 567              IRCOCFQ 568-569
        IICOCFQ 570             IRCRKFQ 571-572         IICRKFQ 573
        IRHERFQ 574-575         IIHERFQ 576             IRHALFQ 577-578
        IIHALFQ 579             IRINHFQ 580-581         IIINHFQ 582
        IRANLFQ 583-584         IIANLFQ 585             IRTRNFQ 586-587
        IITRNFQ 588             IRSTMFQ 589-590         IISTMFQ 591
        IRSEDFQ 592-593         IISEDFQ 594             CATAGE 595
        CATAG2 596              CATAG3 597              RACE 598
        HISPRACE 599            EDUCCAT2 600            EMPSTAT2 601
        MARISTAT 602            NOTMAR 603              CIGFLAG 604
        CIGYR 605               CIGMON 606              SMKFLAG 607
        SMKYR 608               SMKMON 609              ALCFLAG 610
        ALCYR 611               ALCMON 612              MRJFLAG 613
        MRJYR 614               MRJMON 615              COCFLAG 616
        COCYR 617               COCMON 618              CRKFLAG 619
        CRKYR 620               CRKMON 621              HERFLAG 622
        HERYR 623               HERMON 624              HALFLAG 625
        HALYR 626               HALMON 627              LSDFLAG 628
        LSDYR 629               LSDMON 630              PCPFLAG 631
        PCPYR 632               PCPMON 633              INHFLAG 634
        INHYR 635               INHMON 636              ANLFLAG 637
        ANLYR 638               ANLMON 639              TRQFLAG 640
        TRQYR 641               TRQMON 642              STMFLAG 643
        STMYR 644               STMMON 645              SEDFLAG 646
        SEDYR 647               SEDMON 648              ALCYRF 649
        ALCMONF 650             ALCWKF 651              ALCOCCF 652
        ALCDLYF 653             MRJYRF 654              MRJMONF 655
        MRJWKF 656              MRJOCCF 657             MRJDLYF 658
        COCYRF 659              COCMONF 660             COCWKF 661
        COCOCCF 662             COCDLYF 663             CRKYRF 664
        CRKMONF 665             CRKWKF 666              CRKOCCF 667
        CRKDLYF 668             HERYRF 669              HERMONF 670
        HERWKF 671              HEROCCF 672             HERDLYF 673
        HALYRF 674              HALMONF 675             HALWKF 676
        HALOCCF 677             HALDLYF 678             INHYRF 679
        INHMONF 680             INHWKF 681              INHOCCF 682
        INHDLYF 683             ANLYRF 684              ANLMONF 685
        ANLWKF 686              ANLOCCF 687             ANLDLYF 688
        TRQYRF 689              TRQMONF 690             TRQWKF 691
        TRQOCCF 692             TRQDLYF 693             STMYRF 694
        STMMONF 695             STMWKF 696              STMOCCF 697
        STMDLYF 698             SEDYRF 699              SEDMONF 700
        SEDWKF 701              SEDOCCF 702             SEDDLYF 703
        PSYFLAG2 704            PSYYR2 705              PSYMON2 706
        SUMFLAG 707             SUMYR 708               SUMMON 709
        MJOFLAG 710             MJOYR2 711              MJOMON2 712
        IEMFLAG 713             IEMYR 714               IEMMON 715
        BINGEDRK 716-717        HVYDRK2 718-719         BINGEHVY 720-721
        PEYOTE2 722             MESC2 723               PSILCY2 724
        ECSTASY2 725            METHAMP2 726            HERSMOK2 727
        HERSNIF2 728            AMYLNIT2 729            CLEFLU2 730
        GAS2 731                GLUE2 732               ETHER2 733
        SOLVENT2 734            LGAS2 735               NITOXID2 736
        SPPAINT2 737            AEROS2 738              CG04 739-740
        CG12 741-742            AL03 743-744            AL04 745-746
        MJ04 747-748            MJ05 749-750            CC04 751-752
        CC05 753-754            CK04 755-756            CK05 757-758
        HE04 759-760            HE05 761-762            LS04 763-764
        LS05 765-766            LS07 767-768            LS08 769-770
        IN04 771-772            IN05 773-774            PK04 775-776
        PK05 777-778            TR04 779-780            TR05 781-782
        ST04 783-784            ST05 785-786            SE04 787-788
        SE05 789-790            SKPSDRD 791-792         SDREAD 793-794
        HRANYFRM 795-796        HERSMOKE 797-798        HRSMKREC 799-800
        HERSNIFF 801-802        HRSNFREC 803-804        GNNDLLIF 805-806
        COCNEEDL 807-808        CONDLREC 809-810        HERNEEDL 811-812
        HRNDLREC 813-814        STNEEDLE 815-816        STNDLREC 817-818
        GNNDREUS 819-820        GNNDLSH1 821-822        GNNDCLEN 823-824
        GNNDLSH2 825-826        GNNDGET 827-828         GNNDGTSP 829-830
        SKPRSKRD 831-832        RSKREAD 833-834         RSKPKCIG 835-836
        RSKMJOCC 837-838        RSKMJREG 839-840        RKCOCOCC 841-842
        RKCOCREG 843-844        RK5DRINK 845-846        RSKBINGE 847-848
        RSKDIFMJ 849-850        RKDIFCOC 851-852        RKDIFCRK 853-854
        RKDIFHER 855-856        RSKSELL 857-858         SKPDRGRD 859-860
        DRGREAD 861-862         USEDCIG 863-864         USEDALC 865-866
        USEDMRJ 867-868         USEDCOC 869-870         USEDHER 871-872
        USEDHAL 873-874         USEDINH 875-876         USEDANL 877-878
        USEDTRN 879-880         USEDSTM 881-882         USEDSED 883-884
        NODRUGYR 885-886        GRTMCIG 887-888         GRTMALC 889-890
        GRTMMRJ 891-892         GRTMCOC 893-894         GRTMHER 895-896
        GRTMHAL 897-898         GRTMINH 899-900         GRTMANL 901-902
        GRTMTRN 903-904         GRTMSTM 905-906         GRTMSED 907-908
        LAMTCIG 909-910         LAMTALC 911-912         LAMTMRJ 913-914
        LAMTCOC 915-916         LAMTHER 917-918         LAMTHAL 919-920
        LAMTINH 921-922         LAMTANL 923-924         LAMTTRN 925-926
        LAMTSTM 927-928         LAMTSED 929-930         BTOLCIG 931-932
        BTOLALC 933-934         BTOLMRJ 935-936         BTOLCOC 937-938
        BTOLHER 939-940         BTOLHAL 941-942         BTOLINH 943-944
        BTOLANL 945-946         BTOLTRN 947-948         BTOLSTM 949-950
        BTOLSED 951-952         ACRDCIG 953-954         ACRDALC 955-956
        ACRDMRJ 957-958         ACRDCOC 959-960         ACRDHER 961-962
        ACRDHAL 963-964         ACRDINH 965-966         ACRDANL 967-968
        ACRDTRN 969-970         ACRDSTM 971-972         ACRDSED 973-974
        EMPBCIG 975-976         EMPBALC 977-978         EMPBMRJ 979-980
        EMPBCOC 981-982         EMPBHER 983-984         EMPBHAL 985-986
        EMPBINH 987-988         EMPBANL 989-990         EMPBTRN 991-992
        EMPBSTM 993-994         EMPBSED 995-996         HLPBCIG 997-998
        HLPBALC 999-1000        HLPBMRJ 1001-1002       HLPBCOC 1003-1004
        HLPBHER 1005-1006       HLPBHAL 1007-1008       HLPBINH 1009-1010
        HLPBANL 1011-1012       HLPBTRN 1013-1014       HLPBSTM 1015-1016
        HLPBSED 1017-1018       UCDCIG 1019-1020        UCDALC 1021-1022
        UCDMRJ 1023-1024        UCDCOC 1025-1026        UCDHER 1027-1028
        UCDHAL 1029-1030        UCDINH 1031-1032        UCDANL 1033-1034
        UCDTRN 1035-1036        UCDSTM 1037-1038        UCDSED 1039-1040
        SKPSPTRD 1041-1042      SPTREAD 1043-1044       NDTXRCVD 1045-1046
        NDTXNEED 1047-1048      NDTXALC 1049-1050       NDTXMJ 1051-1052
        NDTXCOC 1053-1054       NDTXHER 1055-1056       NDTXHAL 1057-1058
        NDTXINH 1059-1060       NDTXANL 1061-1062       NDTXTRAN 1063-1064
        NDTXSTIM 1065-1066      NDTXSED 1067-1068       NDTXSOD 1069-1070
        NDTXDRG1 1071-1074      NDTXDRG2 1075-1078      NDTXDRG3 1079-1082
        NDTXDRG4 1083-1086      NDTXDRG5 1087-1090      NDTXSTEP 1091-1092
        NDTXTRSP 1093-1094      NDTXTFAR 1095-1096      NDTXBDHR 1097-1098
        NDTXOPEN 1099-1100      NDTXTYPE 1101-1102      NDTXMONY 1103-1104
        NDTXHCAP 1105-1106      NDTXTCMP 1107-1108      NDTXLANG 1109-1110
        NDTXSPSV 1111-1112      NDTXSOR 1113-1114       NDTXRSC1 1115-1116
        BOOKED 1117-1118        NOBOOKYR 1119-1120      BKLARCNY 1121-1122
        BKBURGL 1123-1124       BKAGASLT 1125-1126      BKSMASLT 1127-1128
        BKMVTHFT 1129-1130      BKROB 1131-1132         BKRAPE 1133-1134
        BKMURDER 1135-1136      BKARSON 1137-1138       BKDRVINF 1139-1140
        BKDRUNK 1141-1142       BKDRUG 1143-1144        BKPROS 1145-1146
        BKVANDAL 1147-1148      BKOTH 1149-1150         BKOTHOFF 1151-1152
        PROBATON 1153-1154      PAROLE 1155-1156        DRVALDR 1157-1158
        DRIVEAL 1159-1160       DRIVEDR 1161-1162       SKPTMTRD 1163-1164
        TMTREAD 1165-1166       TXEVER 1167-1168        TXTIMELF 1169-1171
        TXYRFREQ 1172-1174      TXALHOSP 1175-1176      TXALRFIN 1177-1178
        TXALRFOP 1179-1180      TXALMHC 1181-1182       TXALEMRG 1183-1184
        TXALDOC 1185-1186       TXALJAIL 1187-1188      TXALSHG 1189-1190
        TXALSOP 1191-1192       TXALSP 1193-1194        TXDRHOSP 1195-1196
        TXDRFIN 1197-1198       TXDRFOP 1199-1200       TXDRMHC 1201-1202
        TXDREMRG 1203-1204      TXDRDOC 1205-1206       TXDRJAIL 1207-1208
        TXDRSHG 1209-1210       TXDRSOP 1211-1212       TXDRSP 1213-1214
        TXYREMRG 1215-1217      TXADGREC 1218-1219      TXLTHOSP 1220-1221
        TXLTRFIN 1222-1223      TXLTRFOP 1224-1225      TXLTMHC 1226-1227
        TXLTEMRG 1228-1229      TXLTDOC 1230-1231       TXLTJAIL 1232-1233
        TXLTSHG 1234-1235       TXLTSOP 1236-1237       TXLTSP 1238-1239
        TXLTALC 1240-1241       TXLTMJ 1242-1243        TXLTCOC 1244-1245
        TXLTHER 1246-1247       TXLTHAL 1248-1249       TXLTINH 1250-1251
        TXLTANL 1252-1253       TXLTRAN 1254-1255       TXLTSTIM 1256-1257
        TXLTSED 1258-1259       TXLTSOD 1260-1261       TXLTA 1262-1265
        TXLTB 1266-1269         TXLTC 1270-1273         TXLTD 1274-1277
        TXLTE 1278-1281         TXDRGA 1282-1285        TXDRGB 1286-1289
        TXDRGC 1290-1293        TXDRGD 1294-1297        TXDRGE 1298-1301
        TXOUTC 1302-1303        TXTIME 1304-1307        TXPDINS 1308-1309
        TXPDCARE 1310-1311      TXPDCAID 1312-1313      TXPDSAVE 1314-1315
        TXPDFMLY 1316-1317      TXPDEMPL 1318-1319      TXPDFREE 1320-1321
        TXPDSOS 1322-1323       TXPDSP 1324-1325        TXENROLL 1326-1327
        SKYCPBAN 1328           SKPYCRD 1329-1330       YCREAD 1331-1332
        YACTYNG 1333-1334       YALLERGY 1335-1336      YARGUE 1337-1338
        YASTHMA 1339-1340       YACOPPSX 1341-1342      YLKANIML 1343-1344
        YBRAG 1345-1346         YTRBCONC 1347-1348      YCNTHGTS 1349-1350
        YTRBSIT 1351-1352       YDPTADLT 1353-1354      YFLONELY 1355-1356
        YFLCONFU 1357-1358      YCRYLOT 1359-1360       YHONEST 1361-1362
        YMEANOTH 1363-1364      YDAYDREM 1365-1366      YTRYKLSF 1367-1368
        YTRYATTN 1369-1370      YDSTYTHG 1371-1372      YDSTYOTH 1373-1374
        YDSBYPAR 1375-1376      YDSBYSCH 1377-1378      YDNTEATW 1379-1380
        YDNTKIDS 1381-1382      YDNTGLTY 1383-1384      YJEALOTH 1385-1386
        YHELPOTH 1387-1388      YAFRPLAC 1389-1390      YAFRSCHL 1391-1392
        YAFRBAD 1393-1394       YFLPRFCT 1395-1396      YFLNOLOV 1397-1398
        YFLGETME 1399-1400      YFLWTHLS 1401-1402      YACCHURT 1403-1404
        YFIGHTS 1405-1406       YGTEASED 1407-1408      YKIDSTRB 1409-1410
        YHRVOICS 1411-1412      YACTTNK 1413-1414       YALONE 1415-1416
        YLIE 1417-1418          YBITNAIL 1419-1420      YNERVOUS 1421-1422
        YBTWITCH 1423-1424      YNGHTMAR 1425-1426      YNOTKIDS 1427-1428
        YDOBETTR 1429-1430      YANXIOUS 1431-1432      YFLDIZZY 1433-1434
        YFLGUILT 1435-1436      YEATMUCH 1437-1438      YFLTIRED 1439-1440
        YOVRWGHT 1441-1442      YACHES 1443-1444        YHEADACH 1445-1446
        YNAUSEA 1447-1448       YEYEPROB 1449-1450      YRASHES 1451-1452
        YCRAMPS 1453-1454       YVOMIT 1455-1456        YATTACK 1457-1458
        YPKBPART 1459-1460      YPFRNDLY 1461-1462      YTRYTHNG 1463-1464
        YSCPOOR 1465-1466       YCLUMSY 1467-1468       YOLDKIDS 1469-1470
        YYNGKIDS 1471-1472      YRFSTALK 1473-1474      YREPACTN 1475-1476
        YRUNHOME 1477-1478      YSCREAM 1479-1480       YSECRET 1481-1482
        YSEETHNG 1483-1484      YSLFCONS 1485-1486      YSETFIRE 1487-1488
        YWELHNDS 1489-1490      YSHOWOFF 1491-1492      YSHY 1493-1494
        YSLPLESS 1495-1496      YSLPMORE 1497-1498      YGDIMAG 1499-1500
        YSPCHPRB 1501-1502      YSTDRGHT 1503-1504      YSTEALHO 1505-1506
        YSTEALPL 1507-1508      YDNTNEED 1509-1510      YDOSTRNG 1511-1512
        YTHSTRNG 1513-1514      YSTUBORN 1515-1516      YMOODS 1517-1518
        YENJOY 1519-1520        YSUSPICS 1521-1522      YDRTLANG 1523-1524
        YTHKKLSF 1525-1526      YLKLAUGH 1527-1528      YTALKMCH 1529-1530
        YTEASE 1531-1532        YTEMPER 1533-1534       YTHNKSEX 1535-1536
        YTHRTPEO 1537-1538      YLKHELP 1539-1540       YCONNEAT 1541-1542
        YTRBSLEP 1543-1544      YSKIPSCH 1545-1546      YNOENRGY 1547-1548
        YUNHAPPY 1549-1550      YLOUDER 1551-1552       YUSEDRUG 1553-1554
        YFAIROTH 1555-1556      YENJYJOK 1557-1558      YLIFEASY 1559-1560
        YTRYHELP 1561-1562      YWSOPPSX 1563-1564      YINVOTH 1565-1566
        YWORRY 1567-1568        SKPBDBAN 1569-1570      SKPPBRD 1571-1572
        PBREAD 1573-1574        XSEXYR 1575-1576        XRELNOW 1577-1578
        XRELYR 1579-1580        XRELCDV 1581-1582       XRELCDA 1583-1584
        XNRELYR 1585-1586       XNRELCDV 1587-1588      XNRELCDA 1589-1590
        XYRDIFPP 1591-1592      XYRWTHMF 1593-1594      XYRHIV 1595-1596
        XYRMONEY 1597-1598      XYRDRUGS 1599-1600      XCDEVER 1601-1602
        XCDLAST 1603-1604       XCDPREG 1605-1606       XCDSTD 1607-1608
        XCDNMESS 1609-1610      XCDOTRSN 1611-1612      XCDRSN1 1613-1614
        XNCDPREG 1615-1616      XNCDMONO 1617-1618      XNCDSTD 1619-1620
        XNCDOBC 1621-1622       XNCDRELG 1623-1624      XNCDPTNR 1625-1626
        XNCDNA 1627-1628        XNCDHOW 1629-1630       XNCDSAFE 1631-1632
        XNCDORSN 1633-1634      XNCDRSN1 1635-1636      XCDMOOD 1637-1638
        XCDRESP 1639-1640       XCDFEEL 1641-1642       XCDTRST 1643-1644
        XCDEMBR 1645-1646       XCDCOST 1647-1648       XRELLAST 1649-1650
        XLFBLOOD 1651-1652      XBLD385 1653-1654       XLTBLDMO 1655-1656
        XLTBLDYR 1657-1659      XHIVTEST 1660-1661      XLTHIVMO 1662-1663
        XLTHIVYR 1664-1666      XHIVRSLT 1667-1668      SKPDBRD 1669-1670
        DBREAD 1671-1672        VDRVYR 1673-1674        VYRFREQ 1675-1676
        VALDRVYR 1677-1678      VALYRFRQ 1679-1680      VAL30USE 1681-1682
        VALCNODR 1683-1684      VALCTIME 1685-1686      VALDTIME 1687-1688
        VMJUSEYR 1689-1690      VMJDRVYR 1691-1692      VMJALCYR 1693-1694
        VMJCOCYR 1695-1696      VMJHERYR 1697-1698      VMJHALYR 1699-1700
        VMJINHYR 1701-1702      VMJANLYR 1703-1704      VMJTRNYR 1705-1706
        VMJSTMYR 1707-1708      VMJSEDYR 1709-1710      VMJOTHYR 1711-1712
        VMJYRS1 1713-1716       VMJYRS2 1717-1720       VMJYRS3 1721-1724
        VMJYRS4 1725-1728       VMJYRS5 1729-1732       VMJ30USE 1733-1734
        VLTMJALC 1735-1736      VLTMJAL1 1737-1740      VLTMJAL2 1741-1744
        VLTMJAL3 1745-1748      VLTMJAL4 1749-1752      VLTMJAL5 1753-1756
        VLTMJFRM 1757-1758      VLTMJFRS 1759-1760      VLTMJTO 1761-1762
        VLTMJTOS 1763-1764      VLTMJHWY 1765-1766      VLTMJURB 1767-1768
        VLTMJWKD 1769-1770      VLTMJTIM 1771-1772      VLTMJABL 1773-1774
        VMJNOWAY 1775-1776      VMJNHIGH 1777-1778      VMJNPOLC 1779-1780
        VMJNODVR 1781-1782      VMJAPPT 1783-1784       VMJOTHER 1785-1786
        VMJOTHSP 1787-1788      VMJSTOP 1789-1790       VMJABIL 1791-1792
        VCCUSEYR 1793-1794      VCCDRVYR 1795-1796      VCCALCYR 1797-1798
        VCCMRJYR 1799-1800      VCCHERYR 1801-1802      VCCHALYR 1803-1804
        VCCINHYR 1805-1806      VCCANLYR 1807-1808      VCCTRNYR 1809-1810
        VCCSTMYR 1811-1812      VCCSEDYR 1813-1814      VCCOTHYR 1815-1816
        VCCYRS1 1817-1820       VCCYRS2 1821-1824       VCCYRS3 1825-1828
        VCCYRS4 1829-1832       VCCYRS5 1833-1836       VCC30USE 1837-1838
        VLTCCALC 1839-1840      VLTCCAL1 1841-1844      VLTCCAL2 1845-1848
        VLTCCAL3 1849-1852      VLTCCAL4 1853-1856      VLTCCAL5 1857-1860
        VLTCCFRM 1861-1862      VLTCCFRS 1863-1864      VLTCCTO 1865-1866
        VLTCCTOS 1867-1868      VLTCCHWY 1869-1870      VLTCCURB 1871-1872
        VLTCCWKD 1873-1874      VLTCCTIM 1875-1876      VLTCCABL 1877-1878
        VCCNOWAY 1879-1880      VCCNHIGH 1881-1882      VCCNPOLC 1883-1884
        VCCNODVR 1885-1886      VCCAPPT 1887-1888       VCCOTHER 1889-1890
        VCCOTHSP 1891-1892      VCCSTOP 1893-1894       VCCABIL 1895-1896
        VTRUSEYR 1897-1898      VTRDRVYR 1899-1900      VTR30USE 1901-1902
        VLTTRMED 1903-1904      VLTTRALC 1905-1906      VLTTRAL1 1907-1910
        VLTTRAL2 1911-1914      VLTTRAL3 1915-1918      VLTTRAL4 1919-1922
        VLTTRAL5 1923-1926      VLTTRABL 1927-1928      VSTUSEYR 1929-1930
        VSTDRVYR 1931-1932      VST30USE 1933-1934      VLTSTMED 1935-1936
        VLTSTALC 1937-1938      VLTSTAL1 1939-1942      VLTSTAL2 1943-1946
        VLTSTAL3 1947-1950      VLTSTAL4 1951-1954      VLTSTAL5 1955-1958
        VLTSTABL 1959-1960      VSEUSEYR 1961-1962      VSEDRVYR 1963-1964
        VSE30USE 1965-1966      VLTSEMED 1967-1968      VLTSEALC 1969-1970
        VLTSEAL1 1971-1974      VLTSEAL2 1975-1978      VLTSEAL3 1979-1982
        VLTSEAL4 1983-1986      VLTSEAL5 1987-1990      VLTSEABL 1991-1992
        SKPWKST3 1993-1994      WORKDAYS 1995-1996      WORKBLAH 1997-1998
        SKPPREG 1999            PREGNANT 2000-2001      PREGMOS 2002-2003
        TOTPEOP 2004-2005       SKPMHC 2006             DEPRESS 2007-2008
        DEPDAYS 2009-2010       DEPFREQ 2011-2012       LOSTINT1 2013-2014
        TIRED1 2015-2016        WTCHNG1 2017-2018       LBSCHNG1 2019-2021
        SLPLOSS1 2022-2023      SLPFREQ1 2024-2025      CONCEN1 2026-2027
        DOWN1 2028-2029         IDEAT1 2030-2031        SKPDEP1 2032-2033
        DEPWKS1 2034-2035       DEPMO1 2036-2037        DEPYR1 2038-2040
        LOSTINT2 2041-2042      LOSINDAY 2043-2044      LOSINFRQ 2045-2046
        TIRED2 2047-2048        WTCHNG2 2049-2050       LBSCHNG2 2051-2053
        SLPLOSS2 2054-2055      SLPFREQ2 2056-2057      CONCEN2 2058-2059
        DOWN2 2060-2061         IDEAT2 2062-2063        SKPDEP2 2064-2065
        DEPWKS2 2066-2067       DEPMO2 2068-2069        DEPYR2 2070-2072
        WORRIED 2073-2074       WOREND 2075-2076        WORNOMO1 2077-2080
        WORHAPN1 2081-2082      WORSERI1 2083-2084      WORDIFF1 2085-2086
        WORNOMO2 2087-2090      WORHAPN2 2091-2092      WORSERI2 2093-2094
        WORDIFF2 2095-2096      SKPWOR 2097-2098        WORREST 2099-2100
        WOREDGE 2101-2102       WORIRRIT 2103-2104      WORHEART 2105-2106
        WORTIRED 2107-2108      WORSLEEP 2109-2110      WORFAINT 2111-2112
        FEARPUB 2113-2114       FEAROUT 2115-2116       FEARBRDG 2117-2118
        SKPFEAR1 2119-2120      FEAROFT 2121-2122       FEARYRS 2123-2124
        FEARMOS 2125-2126       FEARFANT 2127-2128      FEARTRAP 2129-2130
        FEARHELP 2131-2132      PANIC1 2133-2134        PANIC2 2135-2136
        PANICNUM 2137-2139      PANICMO 2140-2141       PANICYR 2142-2144
        PANIDANG 2145-2146      SKPFEAR2 2147-2148      PANIFEAR 2149-2150
        PANINOFR 2151-2152      PANIHART 2153-2154      PANIPAIN 2155-2156
        PANISWET 2157-2158      PANISHAK 2159-2160      PANIHOT 2161-2162
        PANIUNRL 2163-2164      NUERTMT 2165-2166       NUHSPOV 2167-2168
        NUHSPPE 2169-2170       OUTPTPE 2171-2172       PROXABLE 2173-2174
        PROXYREL 2175-2177      PROXHOME 2178-2179      PROXJOIN 2180-2181
        CAREUSU 2182-2183       NCARERSN 2184-2185      NCRRSNSP 2186-2187
        NCRRSNSC 2188-2189      CAREOFT 2190-2191       PYRCARE 2192-2193
        PYRCRTYP 2194-2195      PYRCRTSP 2196-2197      PYRCRTSC 2198-2199
        CARENOW 2200-2201       MNRSNNCR 2202-2203      MNRSNNSP 2204-2205
        MNRSNNSC 2206-2207      UCARETYP 2208-2209      UCRTYPSP 2210-2211
        UCRTYPSC 2212-2213      MEDICARE 2214-2215      MEDICAID 2216-2217
        CHAMPUS 2218-2219       PRVHLTIN 2220-2221      GRPHLTIN 2222-2223
        PDHINPRM 2224-2225      HLTINALC 2226-2227      HLTINDRG 2228-2229
        HLTINMNT 2230-2231      SOC1 2232-2233          SOC2 2234-2235
        SSI1 2236-2237          SSI2 2238-2239          PUB1 2240-2241
        PUB2 2242-2243          AFDC 2244-2245          INT1 2246-2247
        INT2 2248-2249          CHD1 2250-2251          CHD2 2252-2253
        OTH1 2254-2255          OTH2 2256-2257          FSTAMP 2258-2259
        PINC1 2260-2261         SKPTFMIN 2262-2263      FINC1 2264-2265
        TELNO 2266-2267         IRPINSUR 2268           IIPINSUR 2269
        IRINSUR 2270            IIINSUR 2271            IRSOC1 2272
        IISOC1 2273             IRSSI1 2274             IISSI1 2275
        IRPUB1 2276             IIPUB1 2277             IRAFDC 2278-2279
        IIAFDC 2280             IRINT1 2281             IIINT1 2282
        IRCHD1 2283             IICHD1 2284             IROTH1 2285
        IIOTH1 2286             IRFSTAMP 2287           IIFSTAMP 2288
        IRPINC1 2289            IIPINC1 2290            IRFINC1 2291-2292
        IIFINC1 2293            IRSOC2 2294             IISOC2 2295
        IRSSI2 2296             IISSI2 2297             IRPUB2 2298
        IIPUB2 2299             IRINT2 2300             IIINT2 2301
        IRCHD2 2302             IICHD2 2303             IROTH2 2304
        IIOTH2 2305             IRPEOP 2306-2307        IRKIDS 2308
        PARSTAT 2309            FEMBABY 2310            FEMKIDS 2311
        MALEBABY 2312           MALEKIDS 2313           F15_44 2314
        M15_44 2315             PREG 2316               PREG2 2317-2318
        TRIMEST 2319-2320       INDCAT 2321-2322        PERINC 2323
        PERINC2 2324            PERINC3 2325            TOTCAT 2326-2327
        FAMINC 2328             FAMINC2 2329            FAMINC3 2330
        WELFARE 2331            NEEDLREC 2332-2333      NEDFLAG4 2334
        NEDYR4 2335             WITHDRW 2336-2337       SOMCOM 2338-2339
        ANXDEP 2340-2341        SOCPROB 2342-2343       THPROB 2344-2345
        ATTPROB 2346-2347       DELBEH 2348-2349        AGGBEH 2350-2351
        WITHDRWT 2352-2354      SOMCOMT 2355-2357       ANXDEPT 2358-2360
        SOCPROBT 2361-2363      THPROBT 2364-2366       ATTPROBT 2367-2369
        DELBEHT 2370-2372       AGGBEHT 2373-2375       SXHIVLF 2376-2377
        SXHIVYR 2378-2379       SXREL 2380-2381         SXRELMAR 2382-2383
        SXCONDYR 2384-2385      SXRSKANY 2386-2387      SXRSKCNT 2388-2389
        SXDRANY 2390-2391       SXDRCNT 2392-2393       MDESFS1 2394-2395
        MDESFS3 2396-2397       PROBMDE1 2398-2404 .4   PROBMDE3 2405-2411 .4
        MDE1 2412-2413          MDE3 2414-2415          GADSFS1 2416-2417
        GADSFS3 2418-2419       PROBGAD1 2420-2426 .4   PROBGAD3 2427-2433 .4
        GAD1 2434-2435          GAD3 2436-2437          AGPSFS1 2438-2439
        AGPSFS3 2440-2441       PROBAGP1 2442-2443      PROBAGP3 2444-2445
        AGP1 2446-2447          AGP3 2448-2449          PASFS1 2450-2451
        PASFS3 2452-2453        PROBPA1 2454-2460 .4    PROBPA3 2461-2467 .4
        PA1 2468-2469           PA3 2470-2471           BHOUR 2472-2473
        BMIN 2474-2475          BAP 2476-2477           EAP 2478-2479
        LANGVER 2480            UNDINT 2481-2482        COOPINT 2483-2484
        PRIVACY 2485-2486       PPRES 2487-2488         SPRES 2489-2490
        PARPRES 2491-2492       OARPRES 2493-2494       OAPRES 2495-2496
        CPRES 2497-2498         OPRESNSP 2499-2500      OPRESSPA 2501-2503
        OPRESSPB 2504-2506      WHOMARKD 2507-2508      QUARTER 2509
        FAMSKIP 2510            GQTYPE 2511             PDEN 2512
        PDEN2 2513              REGION 2514             DIVISION 2515
        ANALWT 2516-2526 .4     ANALWT1 2527-2537 .4    ANALWT2 2538-2548 .4
        ANALWT3 2549-2560 .4    ANALWT4 2561-2572 .4    WT1 2573-2580 .4
        WT2 2581-2589 .4        WT3 2590                WT4 2591-2597 .4
        WT5 2598-2604 .4        WT6 2605-2610 .4        WT7 2611-2616 .4
        WT8 2617-2623 .4        WT9 2624                WT10 2625-2630 .4
        WT11 2631-2636 .4       WT12 2637-2642 .4       RURORURB 2643
        INTMONTH 2644-2645      RELINTHH 2646-2647      MJTOT3 2648-2649
        COCTOT3 2650-2651       ALCDAYS2 2652           AGECAT4 2653
        MJDY30A3 2654           ALCDAYS3 2655           DRINKER2 2656
        HVYDRK3 2657            AVCIG2 2658             RACESEX 2659-2660
        NOTMARJ 2661            BINGDRK2 2662           RACESEX2 2663
        IRBTCIG2 2664           IRBTALC2 2665           IRBTMRJ2 2666
        IRBTCOC2 2667           IRGRCIG2 2668           IRGRALC2 2669
        IRGRMRJ2 2670           IRGRCOC2 2671           IRLACIG2 2672
        IRLAALC2 2673           IRLAMRJ2 2674           IRLACOC2 2675
        IRACCIG2 2676           IRACALC2 2677           IRACMRJ2 2678
        IRACCOC2 2679           IREMCIG2 2680           IREMALC2 2681
        IREMMRJ2 2682           IREMCOC2 2683           IRHLCIG2 2684
        IRHLALC2 2685           IRHLMRJ2 2686           IRHLCOC2 2687
        IRUCCIG2 2688           IRUCALC2 2689           IRUCMRJ2 2690
        IRUCCOC2 2691           AVCIG3 2692             ALCPROBS 2693
        MJPROBS 2694            COCPROBS 2695           CIGPROBS 2696
        MRJ2PROB 2697           MRJ3PROB 2698           COC2PROB 2699
        COC3PROB 2700           CIG2PROB 2701           CIG3PROB 2702
        ALC2PROB 2703           ALC3PROB 2704           CIGTRY2 2705-2706
        ALCTRY2 2707-2708       MJAGE2 2709-2710        INHAGE2 2711-2712
        COCAGE2 2713-2714       HALLAGE2 2715-2716      HERAGE2 2717-2718
        STIMAGE2 2719-2720      SEDAGE2 2721-2722       TRANAGE2 2723-2724
        ANALAGE2 2725-2726      ALCONLYL 2727           ALCONLYY 2728
        ALCONLYM 2729           ILLONLYL 2730           ILLONLYY 2731
        ILLONLYM 2732           MRJONLYL 2733           MRJONLYY 2734
        MRJONLYM 2735           PSYONLYL 2736           PSYONLYY 2737
        PSYONLYM 2738           OTHONLYL 2739           OTHONLYY 2740
        OTHONLYM 2741           ALCILLL 2742            ALCILLY 2743
        ALCILLM 2744            ALCMRJL 2745            ALCMRJY 2746
        ALCMRJM 2747            ALCPSYL 2748            ALCPSYY 2749
        ALCPSYM 2750            ALCOTHL 2751            ALCOTHY 2752
        ALCOTHM 2753            SUB1LIF 2754            SUB2LIF 2755
        SUB3LIF 2756            SUB1YR 2757             SUB2YR 2758
        SUB3YR 2759             SUB1MON 2760            SUB2MON 2761
        SUB3MON 2762            PSYAGE 2763-2764        TRMTHLP2 2765
        DRNKHLP2 2766           DRALHELP 2767           BKLARCN2 2768
        BKBURGL2 2769           BKAGASL2 2770           BKSMASL2 2771
        BKMVTHF2 2772           BKROB2 2773             BKRAPE2 2774
        BKMURDE2 2775           BKARSON2 2776           BKDRVIN2 2777
        BKDRUNK2 2778           BKDRUG2 2779            BKPROS2 2780
        DRUNKYR2 2781           FERTAGE 2782-2783       PREG3 2784-2785
        TRIMEST2 2786-2787      RSKCIG 2788-2789        RSKMJ1 2790-2791
        RSKMJ2 2792-2793        RSKCOC1 2794-2795       RSKCOC2 2796-2797
        RSKALC1 2798-2799       RSKALC2 2800-2801       MARUSE 2802
        COCUSE 2803             ALCUSE 2804             TOTPROB 2805-2812 .4
        INT 2813-2819 .4        EXT 2820-2821           PR_EMOT 2822-2823
        PR_BEHAV 2824-2825      PR_TOTAL 2826-2827      PR_WD 2828-2829
        PR_SC 2830-2831         PR_AD 2832-2833         PR_SP 2834-2835
        PR_TP 2836-2837         PR_AP 2838-2839         PR_DB 2840-2841
        PR_AB 2842-2843         ANY4MENT 2844-2845      ALCDRIV 2846
        MRJDRIV 2847            AGECAT3 2848-2849       DRUNKYR3 2850-2851
        HERNEED2 2852           RSKSELL2 2853           SEXYR 2854-2855
        RELNOW 2856-2857        HIVTEST 2858-2859       CDALWAYS 2860-2861
        CDSOME 2862-2863        CDNEVER 2864-2865       YRDIFPP1 2866-2867
        YRDIFPP2 2868-2869      EHOUR 2870-2871         EMIN 2872-2873
        ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   RESPID  = 'RESPONDENT IDENTIFICATION NUMBER'
   VESTR   = 'VARIANCE STRATUM'
   VEREP   = 'VARIANCE REPLICATE WITHIN VARIANCE STRAT'
   ENCPSU  = 'PRIMARY SAMPLING UNIT (ENCRYPTED)'
   ENCSEG  = 'SEGMENT IDENTIFICATION NUMBER (ENCRYPTED'
   ENCCASE = 'HOUSEHOLD LEVEL IDENTIFICATION NUMBER (E'
   SKPMARTL= 'SKIP OVER MARITAL Q''S TO SKPMILT, BASED'
   MARITAL = 'MARITAL STATUS'
   NOMARR  = '# TIMES MARRIED'
   SKPMILT = 'SKIP OVER MILITARY Q''S TO EDUC, BASED O'
   SERVICE = 'EVER BEEN IN UNITED STATES'' ARMED FORCE'
   MILSTAT = 'CURRENT MILITARY STATUS'
   EDUC    = 'LAST GRADE COMPLETED IN SCHOOL'
   DIPLOMA = 'EVIDENCE OF HIGH SCHOOL COMPLETION'
   ENROLLD = 'NOW ENROLLED IN ANY SCHOOL'
   WORKSTAT= 'PRESENT WORK SITUATION'
   HTININCH= 'HEIGHT IN INCHES (WITHOUT SHOES)'
   POUNDS  = 'WEIGHT IN POUNDS WITHOUT SHOES'
   HEALTH  = 'HEALTH IN GENERAL'
   CIGEVER = 'EVER SMOKED A CIGARETTE'
   CIGTRY  = 'AGE WHEN FIRST SMOKED A CIGARETTE'
   CIGTOT  = '# DAYS SMOKED CIGARETTES IN LIFE'
   CIGREC  = 'TIME SINCE LAST SMOKED A CIGARETTE'
   CIG30USE= '# DAYS SMOKED PAST 30 DAYS'
   AVCIG   = '# CIGARETTES SMOKED PER DAY PAST 30 DAYS'
   CIG30WOK= 'TIME BEFORE SMOKING FIRST CIGARETTE AFTE'
   CIGEVYDA= 'EVER SMOKED DAILY'
   CIGAGE  = 'AGE WHEN FIRST STARTED SMOKING CIGARETTE'
   CIGYRS  = '# YEARS SMOKED CIGARETTES EVERYDAY'
   SNUFEVER= 'EVER USED SMOKELESS TOBACCO'
   SNUFREC = 'TIME SINCE LAST USED SMOKELESS TOBACCO'
   SKPALCRD= 'CAN RESPONDENT COMPLETE ALCOHOL ANSWER S'
   ALCREAD = 'ALCOHOL - READING PREFERENCE'
   ALCEVER = 'EVER HAD DRINK OF ALCOHOLIC BEVERAGE'
   ALCTRY  = 'AGE WHEN HAD FIRST DRINK OF ALCOHOLIC BE'
   ALCREC  = 'TIME SINCE LAST DRANK AN ALCOHOLIC BEVER'
   ALCPAT  = '# DAYS DRANK ALCOHOLIC BEVERAGE PAST 12'
   DRUNKYR = '# DAYS GOT DRUNK PAST 12 MONTHS'
   ALCDAYS = '# DAYS HAD ONE OR MORE DRINKS PAST 30 DA'
   NODR30A = 'USUAL # DRINKS PER DAY PAST 30 DAYS'
   DR5DAY  = '# DAYS HAD FIVE OR MORE DRINKS PAST 30 D'
   MJEVER  = 'EVER USED MARIJUANA/HASHISH'
   MJAGE   = 'AGE WHEN FIRST USED MARIJUANA/HASHISH'
   MJTOT   = '# DAYS USED MARIJUANA/HASHISH IN LIFE'
   MJREC   = 'TIME SINCE LAST USED MARIJUANA/HASHISH'
   MJYRFREQ= '# DAYS USED MARIJUANA/HASHISH PAST 12 MO'
   MJDAY30A= '# DAYS USED MARIJUANA/HASHISH PAST 30 DA'
   SKPCOCRD= 'CAN RESPONDENT COMPLETE COCAINE ANSWER S'
   COCREAD = 'COCAINE - READING PREFERENCE'
   COCEVER = 'EVER USED COCAINE'
   COCAGE  = 'AGE WHEN FIRST USED COCAINE'
   COCTOT  = '# DAYS USED COCAINE IN LIFE'
   COCREC  = 'TIME SINCE LAST USED COCAINE (IN ANY FOR'
   COCYRFRQ= '# DAYS USED COCAINE PAST 12 MONTHS'
   COCUS30A= '# DAYS USED COCAINE PAST 30 DAYS'
   SKPCRKRD= 'CAN RESPONDENT COMPLETE ''CRACK'' ANSWER S'
   CRKREAD = '''CRACK'' - READING PREFERENCE'
   CRKEVER = 'EVER USED ''CRACK'''
   CRKAGE  = 'AGE WHEN FIRST USED ''CRACK'''
   CRKTOT  = '# DAYS USED ''CRACK'' IN LIFE'
   CRAKREC = 'TIME SINCE LAST USED ''CRACK'''
   CRKYRFRQ= '# DAYS USED ''CRACK'' PAST 12 MONTHS'
   CRKUS30A= '# DAYS USED ''CRACK'' PAST 30 DAYS'
   SKPHERRD= 'CAN RESPONDENT COMPLETE HEROIN ANS SHEET'
   HERREAD = 'HEROIN - READING PREFERENCE'
   HEREVER = 'EVER USED HEROIN'
   HERAGE  = 'AGE WHEN FIRST USED HEROIN'
   HERTOT  = '# DAYS USED HEROIN IN LIFE'
   HERREC  = 'TIME SINCE LAST USED HEROIN'
   HERYRFRQ= '# DAYS USED HEROIN PAST 12 MONTHS'
   HER30USE= '# DAYS USED HEROIN PAST 30 DAYS'
   SKPHALRD= 'CAN RESP COMPLETE HALLUCINOGEN ANS SHEET'
   HALREAD = 'HALLUCINOGEN - READING PREFERENCE'
   LSD     = 'EVER USED LSD (''ACID'')'
   PCP     = 'EVER USED PCP (''ANGEL DUST,'' PHENCYCLIDI'
   PEYOTE  = 'EVER USED PEYOTE'
   MESC    = 'EVER USED MESCALINE'
   PSILCY  = 'EVER USED PSILOCYBIN (MUSHROOMS)'
   ECSTASY = 'EVER USED ''ECSTASY'' (MDMA)'
   HALDKNAM= 'USED HALLUCINOGEN, DON''T KNOW NAME'
   HALNOLST= 'USED HALLUCINOGEN NOT LISTED ABOVE'
   HALNEWA = 'OTHER HALLUCINOGEN (FIRST MENTION)'
   HALNEWB = 'OTHER HALLUCINOGEN (SECOND MENTION)'
   HALNEWC = 'OTHER HALLUCINOGEN (THIRD MENTION)'
   HALNEWD = 'OTHER HALLUCINOGEN (FOURTH MENTION)'
   HALNEWE = 'OTHER HALLUCINOGEN (FIFTH MENTION)'
   HALLAGE = 'AGE WHEN FIRST USED LSD/PCP/OTHER HALLUC'
   HALLTOT = '# DAYS USED LSD/PCP/OTHER HALLUCINOGENS'
   HALLREC = 'TIME SINCE LAST USED LSD/PCP/OTHR HALLUC'
   HALYRFRQ= '# DAYS USED HALLUCINOGENS PAST 12 MONTHS'
   HAL30USE= '# DAYS USED HALLUCINOGENS PAST 30 DAYS'
   LSDREC  = 'TIME SINCE LAST USED LSD'
   PCPREC  = 'TIME SINCE LAST USED PCP'
   SKPINHRD= 'CAN RESPONDENT COMPLETE INHALANTS ANS SH'
   INHREAD = 'INHALANTS - READING PREFERENCE'
   AMYLNIT = 'EVER INHALED AMYL NITRITE, ''POPPERS,'' RU'
   CLEFLU  = 'EVER INHALED CORRECTION FLUID, DEGREASER'
   GAS     = 'EVER INHALED GASOLINE OR LIGHTER FLUID'
   GLUE    = 'EVER INHALED GLUE, SHOE POLISH, OR TOLUE'
   ETHER   = 'EVER INHALED HALOTHANE, ETHER, OR OTHER'
   SOLVENT = 'EVER INHALED LACQUER THINNER, OTHER PAIN'
   LGAS    = 'EVER INHALED LIGHTER GASES (BUTANE, PROP'
   NITOXID = 'EVER INHALED NITROUS OXIDE OR ''WHIPPETS'''
   SPPAINT = 'EVER INHALED SPRAY PAINTS'
   AEROS   = 'EVER INHALED OTHER AEROSOL SPRAYS'
   INHDKNAM= 'USED INHALANT, DON''T KNOW NAME'
   INHNOLST= 'USED INHALANT NOT LISTED ABOVE'
   INHNEWA = 'USED OTHER INHALANT (FIRST MENTION)'
   INHNEWB = 'USED OTHER INHALANT (SECOND MENTION)'
   INHNEWC = 'USED OTHER INHALANT (THIRD MENTION)'
   INHNEWD = 'USED OTHER INHALANT (FOURTH MENTION)'
   INHNEWE = 'USED OTHER INHALANT (FIFTH MENTION)'
   INHAGE  = 'AGE WHEN FIRST USED INHALANTS'
   INHTOT  = '# DAYS USED INHALANTS IN LIFE'
   INHREC  = 'TIME SINCE LAST USED INHALANTS'
   INHYRFRQ= '# DAYS USED INHALANTS PAST 12 MONTHS'
   INHDY30A= '# DAYS USED INHALANTS PAST 30 DAYS'
   SKPANLRD= 'CAN RESP. COMPLETE PAIN KILLERS ANS. SHE'
   ANLREAD = 'PAIN KILLERS - READING PREFERENCE'
   CODEINE = 'EVER USED CODEINE ''NONMEDICALLY'''
   DARVON  = 'EVER USED DARVON ''NONMEDICALLY'''
   DEMEROL = 'EVER USED DEMEROL ''NONMEDICALLY'''
   DILAUD  = 'EVER USED DILAUDID ''NONMEDICALLY'''
   METHDON = 'EVER USED METHADONE ''NONMEDICALLY'''
   MORPHINE= 'EVER USED MORPHINE ''NONMEDICALLY'''
   PERCODAN= 'EVER USED PERCODAN ''NONMEDICALLY'''
   TALWIN  = 'EVER USED TALWIN ''NONMEDICALLY'''
   TYLCOD  = 'EVER USED TYLENOL WITH CODEINE ''NONMEDIC'
   ANLDKNAM= 'USED PAIN KILLER ''NONMEDICALLY'', DON''T'
   ANLNOLST= 'USED PAIN KILLER ''NONMEDICALLY'' NOT LIST'
   ANALNEWA= 'USED OTHER PAIN KILLER (FIRST MENTION)'
   ANALNEWB= 'USED OTHER PAIN KILLER (SECOND MENTION)'
   ANALNEWC= 'USED OTHER PAIN KILLER (THIRD MENTION)'
   ANALNEWD= 'USED OTHER PAIN KILLER (FOURTH MENTION)'
   ANALNEWE= 'USED OTHER PAIN KILLER (FIFTH MENTION)'
   ANALNONE= 'NEVER USED PAIN KILLERS ''NONMEDICALLY'''
   ANALAGE = 'AGE WHEN FIRST USED PAIN KILLERS ''NONMED'
   ANALTOT = '# DAYS USED PAIN KILLERS ''NONMEDICALLY'''
   ANALREC = 'TIME SINCE LAST USED PAIN KILLERS ''NONME'
   ANLYRFRQ= '# DAYS USED PAIN KILLERS ''NONMEDICALLY'''
   SKPTRNRD= 'CAN RESP COMPLETE TRANQUILIZERS ANS SHEE'
   TRNREAD = 'TRANQUILIZERS - READING PREFERENCE'
   ATARAX  = 'EVER USED ATARAX ''NONMEDICALLY'''
   ATIVAN  = 'EVER USED ATIVAN ''NONMEDICALLY'''
   DIAZEPAM= 'EVER USED DIAZEPAM ''NONMEDICALLY'''
   LIBRIUM = 'EVER USED LIBRIUM ''NONMEDICALLY'''
   TRANXENE= 'EVER USED TRANXENE ''NONMEDICALLY'''
   VALIUM  = 'EVER USED VALIUM ''NONMEDICALLY'''
   XANAX   = 'EVER USED XANAX ''NONMEDICALLY'''
   TRDKNAM = 'USED TRANQUILIZER ''NONMEDICALLY'', DON''T'
   TRNOLST = 'USED TRANQUILIZER ''NONMEDICALLY'' NOT LIS'
   TRNEWA  = 'USED OTHER TRANQUILIZER (FIRST MENTION)'
   TRNEWB  = 'USED OTHER TRANQUILIZER (SECOND MENTION)'
   TRNEWC  = 'USED OTHER TRANQUILIZER (THIRD MENTION)'
   TRNEWD  = 'USED OTHER TRANQUILIZER (FOURTH MENTION)'
   TRNEWE  = 'USED OTHER TRANQUILIZER (FIFTH MENTION)'
   NOTRANQ = 'NEVER USED TRANQUILIZERS ''NONMEDICALLY'''
   TRANAGE = 'AGE WHEN FIRST USED TRANQUILIZERS ''NONME'
   TRANTOT = '# DAYS USED TRANQUILIZERS ''NONMEDICALLY'''
   TRANREC = 'TIME SINCE LAST USED TRANQUILIZERS ''NONM'
   TRNYRFRQ= '# DAYS USED TRANQUILIZERS ''NONMEDICALLY'''
   SKPSTMRD= 'CAN RESP COMPLETE STIMULANTS ANS SHEET A'
   STMREAD = 'STIMULANTS - READING PREFERENCE'
   BENZ    = 'EVER USED BENZEDRINE ''NONMEDICALLY'''
   BIPHET  = 'EVER USED BIPHETAMINE ''NONMEDICALLY'''
   DEXAMYL = 'EVER USED DEXAMYL ''NONMEDICALLY'''
   DEXED   = 'EVER USED DEXEDRINE ''NONMEDICALLY'''
   FASTIN  = 'EVER USED FASTIN ''NONMEDICALLY'''
   IONAMIN = 'EVER USED IONAMIN ''NONMEDICALLY'''
   METHAMP = 'EVER USED METHAMPHETAMINE ''NONMEDICALLY'''
   METHI   = 'EVER USED METHEDRINE ''NONMEDICALLY'''
   PRELUDIN= 'EVER USED PRELUDIN ''NONMEDICALLY'''
   STMDKNAM= 'USED STIMULANT ''NONMEDICALLY'', DON''T KN'
   STMNOLST= 'USED STIMULANT ''NONMEDICALLY'' NOT LISTED'
   STIMNEWA= 'USED OTHER STIMULANT (FIRST MENTION)'
   STIMNEWB= 'USED OTHER STIMULANT (SECOND MENTION)'
   STIMNEWC= 'USED OTHER STIMULANT (THIRD MENTION)'
   STIMNEWD= 'USED OTHER STIMULANT (FOURTH MENTION)'
   STIMNEWE= 'USED OTHER STIMULANT (FIFTH MENTION)'
   NOSTIMS = 'NEVER USED STIMULANTS ''NONMEDICALLY'''
   STIMAGE = 'AGE WHEN FIRST USED STIMULANTS ''NONMEDIC'
   STIMTOT = '# DAYS USED STIMULANTS ''NONMEDICALLY'' IN'
   STIMREC = 'TIME SINCE LAST USED STIMULANTS ''NONMEDI'
   STMYRFRQ= '# DAYS USED STIMULANTS ''NONMEDICALLY'' PS'
   SKPSEDRD= 'CAN RESP COMPLETE SEDATIVES ANS SHEET AL'
   SEDREAD = 'SEDATIVES - READING PREFERENCE'
   DALMANE = 'EVER USED DALMANE ''NONMEDICALLY'''
   HALCION = 'EVER USED HALCION ''NONMEDICALLY'''
   METHAQ  = 'EVER USED METHAQUALONE ''NONMEDICALLY'''
   NEMBUTAL= 'EVER USED NEMBUTAL ''NONMEDICALLY'''
   PHENOBAR= 'EVER USED PHENOBARBITAL ''NONMEDICALLY'''
   PLACIDYL= 'EVER USED PLACIDYL ''NONMEDICALLY'''
   SECONAL = 'EVER USED SECONAL ''NONMEDICALLY'''
   TUINAL  = 'EVER USED TUINAL ''NONMEDICALLY'''
   SEDDKNAM= 'OTHER SEDATIVE ''NONMEDICALLY'', DON''T KN'
   SEDNOLST= 'OTHER SEDATIVE ''NONMEDICALLY'' NOT LISTED'
   SEDNEWA = 'USED OTHER SEDATIVE (FIRST MENTION)'
   SEDNEWB = 'USED OTHER SEDATIVE (SECOND MENTION)'
   SEDNEWC = 'USED OTHER SEDATIVE (THIRD MENTION)'
   SEDNEWD = 'USED OTHER SEDATIVE (FOURTH MENTION)'
   SEDNEWE = 'USED OTHER SEDATIVE (FIFTH MENTION)'
   NOSEDAT = 'NEVER USED SEDATIVES ''NONMEDICALLY'''
   SEDAGE  = 'AGE WHEN FIRST USED SEDATIVES ''NONMEDICA'
   SEDTOT  = '# DAYS USED SEDATIVES ''NONMEDICALLY'' IN'
   SEDREC  = 'TIME SINCE LAST USED SEDATIVES ''NONMEDIC'
   SEDYRFRQ= '# DAYS USED SEDATIVES ''NONMEDICALLY'' PST'
   BIRMONTH= 'BIRTH MONTH'
   BIRYEAR = 'BIRTH YEAR'
   IRAGE   = 'IMPUTATION-REVISED AGE OF RESPONDENT'
   IIAGE   = 'IRAGE INDICATOR'
   IRSEX   = 'SEX - IMPUTATION REVISED'
   IISEX   = 'IRSEX INDICATOR'
   IRRACE  = 'IMPUTATION-REVISED RACE OF RESPONDENT'
   IIRACE  = 'IRRACE INDICATOR'
   IRHOIND = 'IMPUTATION-REVISED HISPANIC ORIGIN'
   IIHOIND = 'IRHOIND INDICATOR'
   IRHOGRP = 'IMPUTATION-REVISED HISPANIC-ORIGIN GROUP'
   IIHOGRP = 'IMPUTATION INDICATOR FOR HISPANIC GROUP'
   IRHOGRP2= 'IMPUTATION-REVISED HISPANIC-ORIGIN GROUP'
   IIHOGRP2= 'IMPUTATION INDICATOR FOR HISPANIC GROUP'
   IRMARIT = 'MARITAL STATUS - IMPUTATION REVISED'
   IIMARIT = 'IRMARIT INDICATOR'
   IREDUC  = 'EDUCATION - IMPUTATION REVISED'
   IIEDUC  = 'EDUCATION - IMPUTATION INDICATOR'
   IRHSGRAD= 'HIGH SCHOOL GRADUATE - IMPUTATION REVISE'
   IIHSGRAD= 'HIGH SCHOOL GRADUATE - IMPUTATION INDICA'
   IRWORKST= 'WORK STATUS - IMPUTATION REVISED'
   IIWORKST= 'WORK STATUS - IMPUTATION INDICATOR'
   IRCIGRC = 'CIGARETTE RECENCY - IMPUTATION REVISED'
   IICIGRC = 'CIGARETTE RECENCY - IMPUTATION INDICATOR'
   IROTBRC = 'SMOKELESS TOBACCO RECENCY - IMPUTATION R'
   IIOTBRC = 'SMOKELESS TOBACCO RECENCY - IMPUTATION I'
   IRALCRC = 'ALCOHOL RECENCY - IMPUTATION REVISED'
   IIALCRC = 'ALCOHOL RECENCY - IMPUTATION INDICATOR'
   IRMJRC  = 'MARIJUANA RECENCY - IMPUTATION REVISED'
   IIMJRC  = 'MARIJUANA RECENCY - IMPUTATION INDICATOR'
   IRCOCRC = 'COCAINE RECENCY - IMPUTATION REVISED'
   IICOCRC = 'COCAINE RECENCY - IMPUTATION INDICATOR'
   IRCRKRC = '''CRACK'' RECENCY - IMPUTATION REVISED'
   IICRKRC = '''CRACK'' RECENCY - IMPUTATION INDICATOR'
   IRHERRC = 'HEROIN RECENCY - IMPUTATION REVISED'
   IIHERRC = 'HEROIN RECENCY - IMPUTATION INDICATOR'
   IRHALRC = 'HALLUCINOGEN RECENCY - IMPUTATION REVISE'
   IIHALRC = 'HALLUCINOGEN RECENCY - IMPUTATION INDICA'
   IRLSDRC = 'LSD RECENCY - IMPUTATION REVISED'
   IILSDRC = 'LSD RECENCY - IMPUTATION INDICATOR'
   IRPCPRC = 'PCP RECENCY - IMPUTATION REVISED'
   IIPCPRC = 'PCP RECENCY - IMPUTATION INDICATOR'
   IRINHRC = 'INHALANT RECENCY - IMPUTATION REVISED'
   IIINHRC = 'INHALANT RECENCY - IMPUTATION INDICATOR'
   IRANLRC = 'ANALGESIC RECENCY - IMPUTATION REVISED'
   IIANLRC = 'ANALGESIC RECENCY - IMPUTATION INDICATOR'
   IRTRNRC = 'TRANQUILIZER RECENCY - IMPUTATION REVISE'
   IITRNRC = 'TRANQUILIZER RECENCY - IMPUTATION INDICA'
   IRSTMRC = 'STIMULANT RECENCY - IMPUTATION REVISED'
   IISTMRC = 'STIMULANT RECENCY - IMPUTATION INDICATOR'
   IRSEDRC = 'SEDATIVE RECENCY - IMPUTATION REVISED'
   IISEDRC = 'SEDATIVE RECENCY - IMPUTATION INDICATOR'
   IRALCFQ = 'ALCOHOL FREQUENCY PAST  YEAR - IMPUTATIO'
   IIALCFQ = 'ALCOHOL FREQUENCY - IMPUTATION INDICATOR'
   IRMJFQ  = 'MARIJUANA FREQUENCY PAST YEAR - IMPUTATI'
   IIMJFQ  = 'MARIJUANA FREQUENCY - IMPUTATION INDICAT'
   IRCOCFQ = 'COCAINE FREQUENCY PAST YEAR - IMPUTATION'
   IICOCFQ = 'COCAINE RECENCY - IMPUTATION INDICATOR'
   IRCRKFQ = '''CRACK'' FREQUENCY PAST YEAR - IMPUTATION'
   IICRKFQ = '''CRACK'' FREQUENCY - IMPUTATION INDICATOR'
   IRHERFQ = 'HEROIN FREQUENCY PAST YEAR - IMPUTATION'
   IIHERFQ = 'HEROIN FREQUENCY - IMPUTATION INDICATOR'
   IRHALFQ = 'HALLUCINOGENS FREQUENCY - IMPUTATION REV'
   IIHALFQ = 'HALLUCINOGENS FREQUENCY - IMPUTATION IND'
   IRINHFQ = 'INHALANTS FREQUENCY - IMPUTATION REVISED'
   IIINHFQ = 'INHALANTS FREQUENCY - IMPUTATION INDICAT'
   IRANLFQ = 'ANALGESICS FREQUENCY - IMPUTATION REVISE'
   IIANLFQ = 'ANALGESICS FREQUENCY - IMPUTATION INDICT'
   IRTRNFQ = 'TRANQUILIZERS FREQUENCY - IMPUTATION REV'
   IITRNFQ = 'TRANQUILIZERS FREQUENCY - IMPUTATION IND'
   IRSTMFQ = 'STIMULANTS FREQUENCY - IMPUTATION REVISE'
   IISTMFQ = 'STIMULANTS FREQUENCY - IMPUTATION INDICA'
   IRSEDFQ = 'SEDATIVES FREQUENCY - IMPUTATION REVISED'
   IISEDFQ = 'SEDATIVES FREQUENCY - IMPUTATION INDICAT'
   CATAGE  = 'AGE CATEGORY'
   CATAG2  = 'AGE CATEGORY RECODE (3 LEVELS)'
   CATAG3  = 'AGE CATEGORY RECODE (5 LEVELS)'
   RACE    = 'RACE/HISPANIC-ORIGIN RECODE'
   HISPRACE= 'RACE ETHNICITY'
   EDUCCAT2= 'EDUCATION RECODE'
   EMPSTAT2= 'EMPLOYMENT STATUS RECODE'
   MARISTAT= 'MARITAL STATUS RECODE'
   NOTMAR  = 'NOT MARRIED STATUS'
   CIGFLAG = 'CIGARETTES - EVER USED'
   CIGYR   = 'CIGARETTES - PAST YEAR USE'
   CIGMON  = 'CIGARETTES - PAST MONTH USE'
   SMKFLAG = 'SMOKELESS TOBACCO - EVER USED'
   SMKYR   = 'SMOKELESS TOBACCO - PAST YEAR USE'
   SMKMON  = 'SMOKELESS TOBACCO - PAST MONTH USE'
   ALCFLAG = 'ALCOHOL - EVER USED'
   ALCYR   = 'ALCOHOL - PAST YEAR USE'
   ALCMON  = 'ALCOHOL - PAST MONTH USE'
   MRJFLAG = 'MARIJUANA - EVER USED'
   MRJYR   = 'MARIJUANA - PAST YEAR USE'
   MRJMON  = 'MARIJUANA - PAST MONTH USE'
   COCFLAG = 'COCAINE - EVER USED'
   COCYR   = 'COCAINE - PAST YEAR USE'
   COCMON  = 'COCAINE - PAST MONTH USE'
   CRKFLAG = '''CRACK'' - EVER USED'
   CRKYR   = '''CRACK'' - PAST YEAR USE'
   CRKMON  = '''CRACK'' - PAST MONTH USE'
   HERFLAG = 'HEROIN - EVER USED'
   HERYR   = 'HEROIN - PAST YEAR USE'
   HERMON  = 'HEROIN - PAST MONTH USE'
   HALFLAG = 'HALLUCINOGENS - EVER USED'
   HALYR   = 'HALLUCINOGENS - PAST YEAR USE'
   HALMON  = 'HALLUCINOGENS - PAST MONTH USE'
   LSDFLAG = 'LSD - EVER USED'
   LSDYR   = 'LSD - PAST YEAR USE'
   LSDMON  = 'LSD - PAST MONTH USE'
   PCPFLAG = 'PCP - EVER USED'
   PCPYR   = 'PCP - PAST YEAR USE'
   PCPMON  = 'PCP - PAST MONTH USE'
   INHFLAG = 'INHALANTS - EVER USED'
   INHYR   = 'INHALANTS - PAST YEAR USE'
   INHMON  = 'INHALANTS - PAST MONTH USE'
   ANLFLAG = 'ANALGESICS - EVER USED'
   ANLYR   = 'ANALGESICS - PAST YEAR USE'
   ANLMON  = 'ANALGESICS - PAST MONTH USE'
   TRQFLAG = 'TRANQUILIZERS - EVER USED'
   TRQYR   = 'TRANQUILIZERS - PAST YEAR USE'
   TRQMON  = 'TRANQUILIZERS - PAST MONTH USE'
   STMFLAG = 'STIMULANTS - EVER USED'
   STMYR   = 'STIMULANTS - PAST YEAR USE'
   STMMON  = 'STIMULANTS - PAST MONTH USE'
   SEDFLAG = 'SEDATIVES - EVER USED'
   SEDYR   = 'SEDATIVES - PAST YEAR USE'
   SEDMON  = 'SEDATIVES - PAST MONTH USE'
   ALCYRF  = 'ALCOHOL - ANY USE PAST YEAR'
   ALCMONF = 'ALCOHOL - MONTHLY OR MORE FREQUENT USE P'
   ALCWKF  = 'ALCOHOL - WEEKLY OR MORE FREQUENT USE PA'
   ALCOCCF = 'ALCOHOL OCCASIONAL FLAG'
   ALCDLYF = 'ALCOHOL DAILY/ALMOST FLAG'
   MRJYRF  = 'MARIJUANA - ANY USE PAST YEAR'
   MRJMONF = 'MARIJUANA - MONTHLY OR MORE FREQUENT USE'
   MRJWKF  = 'MARIJUANA - WEEKLY OR MORE FREQUENT USE'
   MRJOCCF = 'MARIJUANA OCCASIONAL FLAG'
   MRJDLYF = 'MARIJUANA DAILY/ALMOST FLAG'
   COCYRF  = 'COCAINE - ANY USE PAST YEAR'
   COCMONF = 'COCAINE - MONTHLY OR MORE FREQUENT USE P'
   COCWKF  = 'COCAINE - WEEKLY OR MORE FREQUENT USE PA'
   COCOCCF = 'COCAINE OCCASIONAL FLAG'
   COCDLYF = 'COCAINE DAILY/ALMOST DAILY FLAG'
   CRKYRF  = '''CRACK'' YEAR FLAG'
   CRKMONF = '''CRACK'' MONTH FLAG'
   CRKWKF  = '''CRACK'' WEEK FLAG'
   CRKOCCF = '''CRACK'' OCCASIONAL FLAG'
   CRKDLYF = '''CRACK'' DAILY/ALMOST DAILY FLAG'
   HERYRF  = 'HEROIN YEAR FLAG'
   HERMONF = 'HEROIN MONTH FLAG'
   HERWKF  = 'HEROIN WEEK FLAG'
   HEROCCF = 'HEROIN OCCASIONAL FLAG'
   HERDLYF = 'HEROIN DAILY/ALMOST DAILY FLAG'
   HALYRF  = 'HALLUCINOGENS YEAR FLAG'
   HALMONF = 'HALLUCINOGENS MONTH FLAG'
   HALWKF  = 'HALLUCINOGENS WEEK FLAG'
   HALOCCF = 'HALLUCINOGENS OCCASIONAL FLAG'
   HALDLYF = 'HALLUCINOGENS DAILY/ALMOST DAILY FLAG'
   INHYRF  = 'INHALANTS YEAR FLAG'
   INHMONF = 'INHALANTS MONTH FLAG'
   INHWKF  = 'INHALANTS WEEK FLAG'
   INHOCCF = 'INHALANTS OCCASIONAL FLAG'
   INHDLYF = 'INHALANTS DAILY/ALMOST FLAG'
   ANLYRF  = 'ANALGESICS YEAR FLAG'
   ANLMONF = 'ANALGESICS MONTH FLAG'
   ANLWKF  = 'ANALGESICS WEEK FLAG'
   ANLOCCF = 'ANALGESICS OCCASIONAL FLAG'
   ANLDLYF = 'ANALGESICS DAILY/ALMOST DAILY FLAG'
   TRQYRF  = 'TRANQUILIZERS YEAR FLAG'
   TRQMONF = 'TRANQUILIZERS MONTH FLAG'
   TRQWKF  = 'TRANQUILIZERS WEEK FLAG'
   TRQOCCF = 'TRANQUILIZERS OCCASIONAL FLAG'
   TRQDLYF = 'TRANQUILIZERS DAILY/ALMOST DAILY FLAG'
   STMYRF  = 'STIMULANTS YEAR FLAG'
   STMMONF = 'STIMULANTS MONTH FLAG'
   STMWKF  = 'STIMULANTS WEEK FLAG'
   STMOCCF = 'STIMULANTS OCCASIONAL FLAG'
   STMDLYF = 'STIMULANTS DAILY/ALMOST DAILY FLAG'
   SEDYRF  = 'SEDATIVES YEAR FLAG'
   SEDMONF = 'SEDATIVES MONTH FLAG'
   SEDWKF  = 'SEDATIVES WEEK FLAG'
   SEDOCCF = 'SEDATIVES OCCASIONAL FLAG'
   SEDDLYF = 'SEDATIVES DAILY/ALMOST DAILY FLAG'
   PSYFLAG2= 'ANY PSYCHOTHERAPEUTICS - EVER USED'
   PSYYR2  = 'ANY PSYCHOTHERAPEUTICS - PAST YEAR USE'
   PSYMON2 = 'ANY PSYCHOTHERAPEUTICS - PAST MONTH USE'
   SUMFLAG = 'ANY ILLICIT DRUG - EVER USED'
   SUMYR   = 'ANY ILLICIT DRUG - PAST YEAR USE'
   SUMMON  = 'ANY ILLICIT DRUG - PAST MONTH USE'
   MJOFLAG = 'MARIJUANA ONLY - EVER USED'
   MJOYR2  = 'MARIJUANA ONLY - PAST YEAR USE'
   MJOMON2 = 'MARIJUANA ONLY - PAST MONTH USE'
   IEMFLAG = 'ILLICIT DRUG EXCEPT FOR MARIJUANA - EVER'
   IEMYR   = 'ILLICIT DRUG EXCEPT FOR MARIJUANA - PAST'
   IEMMON  = 'ILLICIT DRUG EXCEPT FOR MARIJUANA-PAST M'
   BINGEDRK= 'BINGE ALCOHOL USE PAST 30 DAYS'
   HVYDRK2 = 'HEAVY ALCOHOL USE PAST 30 DAYS'
   BINGEHVY= 'LEVEL OF ALCOHOL USE PAST 30 DAYS'
   PEYOTE2 = 'EVER USED PEYOTE'
   MESC2   = 'EVER USED MESC'
   PSILCY2 = 'EVER USED PSILOCYBIN (MUSHROOMS)'
   ECSTASY2= 'EVER USED ''ECSTASY'' (MDMA)'
   METHAMP2= 'EVER USED METHAMPHETAMINE ''NONMEDICALLY'''
   HERSMOK2= 'EVER SMOKED HEROIN'
   HERSNIF2= 'EVER SNIFFED HEROIN'
   AMYLNIT2= 'EVER INHALED AMYL NITRITE, ''POPPERS,'' RU'
   CLEFLU2 = 'EVER INHALED CORRECTION FLUID, DEGREASER'
   GAS2    = 'EVER INHALED GASOLINE OR LIGHTER FLUID'
   GLUE2   = 'EVER INHALED GLUE, SHOE POLISH, OR TOLUE'
   ETHER2  = 'EVER INHALED HALOTHANE, ETHER, OR OTHER'
   SOLVENT2= 'EVER INHALED LACQUER THINNER, OTHER PAIN'
   LGAS2   = 'EVER INHALED LIGHTER GASES (BUTANE, PROP'
   NITOXID2= 'EVER INHALED NITROUS OXIDE OR ''WHIPPETS'''
   SPPAINT2= 'EVER INHALED SPRAY PAINTS'
   AEROS2  = 'EVER INHALED OTHER AEROSOL SPRAYS'
   CG04    = 'TIME SINCE LAST SMOKED A CIGARETTE'
   CG12    = 'TIME SINCE LAST USED SMOKELESS TOBACCO'
   AL03    = 'TIME SINCE LAST DRANK AN ALCOHOLIC BEVER'
   AL04    = '# DAYS HAD ALCOHOLIC BEVERAGE PAST 12 MO'
   MJ04    = 'TIME SINCE LAST USED MARIJUANA/HASHISH'
   MJ05    = '# DAYS USED MARIJUANA/HASHISH IN PAST 12'
   CC04    = 'TIME SINCE LAST USED COCAINE (IN ANY FOR'
   CC05    = '# DAYS USED COCAINE PAST 12 MONTHS'
   CK04    = 'TIME SINCE LAST USED ''CRACK'''
   CK05    = '# DAY USED ''CRACK'' IN PAST 12 MONTHS'
   HE04    = 'TIME SINCE LAST USED HEROIN'
   HE05    = '# DAYS USED HEROIN PAST 12 MONTHS'
   LS04    = 'TIME SINCE LAST USED LSD/PCP/OTHR HALLUC'
   LS05    = '# DAYS USED HALLUCINOGENS PAST 12 MONTHS'
   LS07    = 'TIME SINCE LAST USED LSD'
   LS08    = 'TIME SINCE LAST USED PCP'
   IN04    = 'TIME SINCE LAST USED INHALANTS'
   IN05    = '# DAYS USED INHALANTS IN PAST 12 MONTHS'
   PK04    = 'TIME SINCE LAST USED PAIN KILLERS ''NONME'
   PK05    = '# DAYS USED PAIN KILLERS ''NONMEDICALLY'''
   TR04    = 'TIME SINCE LAST USED TRANQUILIZERS ''NONM'
   TR05    = '# DAYS USED TRANQUILIZERS ''NONMEDICALLY'''
   ST04    = 'TIME SINCE LAST USED STIMULANTS ''NONMEDI'
   ST05    = '# DAYS USED STIMULANTS ''NONMEDICALLY'' PS'
   SE04    = 'TIME SINCE LAST USED SEDATIVES ''NONMEDIC'
   SE05    = '# DAYS USED SEDATIVE ''NONMEDICALLY'' PAST'
   SKPSDRD = 'CAN RESP COMPLETE SPECIAL DRUGS ANS SHEE'
   SDREAD  = 'SPECIAL DRUGS - READING PREFERENCE'
   HRANYFRM= 'EVER USED HEROIN'
   HERSMOKE= 'EVER SMOKED HEROIN'
   HRSMKREC= 'TIME SINCE LAST SMOKED HEROIN'
   HERSNIFF= 'EVER SNIFFED HEROIN'
   HRSNFREC= 'TIME SINCE LAST SNIFFED HEROIN'
   GNNDLLIF= 'EVER USED A NEEDLE TO INJECT DRUGS'
   COCNEEDL= 'EVER USED A NEEDLE TO INJECT COCAINE'
   CONDLREC= 'TIME SINCE LAST USED NEEDLE TO INJECT C'
   HERNEEDL= 'EVER USED A NEEDLE TO INJECT HEROIN'
   HRNDLREC= 'TIME SINCE LAST USED NEEDLE TO INJECT H'
   STNEEDLE= 'EVER USED A NEEDLE TO INJECT A STIMULAN'
   STNDLREC= 'TIME SINCE LAST USED NEEDLE TO INJECT S'
   GNNDREUS= 'LAST TIME REUSED NEEDLE USED BEFORE'
   GNNDLSH1= 'LAST NEEDLE HAD BEEN USED BY SOMEONE EL'
   GNNDCLEN= 'USED BLEACH TO CLEAN LAST NEEDLE BEFORE'
   GNNDLSH2= 'SOMEONE ELSE USED LAST NEEDLE AFTER YOU'
   GNNDGET = 'PLACE YOU GOT THE NEEDLE LAST TIME'
   GNNDGTSP= 'GOT LAST NEEDLE SOME OTHER WAY'
   SKPRSKRD= 'CAN RESP. COMPLETE RISK/AVAIL. ANS. SHEE'
   RSKREAD = 'RISK/AVAILABILITY - READING PREFERENCE'
   RSKPKCIG= 'RISK IF SMOKE 1 OR MORE PACKS CIGARETTE'
   RSKMJOCC= 'RISK IF SMOKE MARIJUANA ONCE A MONTH'
   RSKMJREG= 'RISK IF SMOKE MARIJUANA ONCE OR TWICE A'
   RKCOCOCC= 'RISK IF USE COCAINE ONCE A MONTH'
   RKCOCREG= 'RISK IF USE COCAINE ONCE OR TWICE A WEE'
   RK5DRINK= 'RISK OF HAVING 4 TO 5 DRINKS NEARLY EVE'
   RSKBINGE= 'RISK OF HAVING FIVE+ DRINKS ONCE OR TWI'
   RSKDIFMJ= 'DIFFICULTY OF GETTING MARIJUANA'
   RKDIFCOC= 'DIFFICULTY OF GETTING COCAINE'
   RKDIFCRK= 'DIFFICULTY OF GETTING ''CRACK'''
   RKDIFHER= 'DIFFICULTY OF GETTING HEROIN'
   RSKSELL = 'SOMEONE APPROACH YOU TO SELL ILLEGAL DR'
   SKPDRGRD= 'CAN RESPONDENT COMPLETE DRUGS ANS. SHEET'
   DRGREAD = 'DRUGS - READING PREFERENCE'
   USEDCIG = 'USED CIGARETTES PAST 12 MONTHS'
   USEDALC = 'USED ALCOHOL PAST 12 MONTHS'
   USEDMRJ = 'USED MARIJUANA/HASHISH PAST 12 MONTHS'
   USEDCOC = 'USED COCAINE (INCLUDING ''CRACK'') PAST 1'
   USEDHER = 'USED HEROIN PAST 12 MONTHS'
   USEDHAL = 'USED HALLUCINOGENS (LSD,PCP,ETC.) PAST'
   USEDINH = 'USED INHALANTS (GLUE,SPRAY PAINT,ETC) P'
   USEDANL = 'USED PAIN KILLERS (CODEINE,ETC.) PAST 1'
   USEDTRN = 'USED TRANQUILIZERS (VALIUM,ETC) PAST 12'
   USEDSTM = 'USED STIMULANTS (''SPEED,''ETC.) PAST 12'
   USEDSED = 'USED SEDATIVES (METHAQUALONE,ETC.) PAST'
   NODRUGYR= 'DID NOT USE DRUGS IN PAST 12 MONTHS'
   GRTMCIG = 'SPENT MONTH OR MORE ON CIGARETTES PAST'
   GRTMALC = 'SPENT MONTH OR MORE ON ALCOHOL PAST 12'
   GRTMMRJ = 'SPENT MONTH OR MORE ON MARIJUANA/HASH P'
   GRTMCOC = 'SPENT MONTH OR MORE ON COCAINE, ''CRACK'''
   GRTMHER = 'SPENT MONTH OR MORE ON HEROIN PAST 12 M'
   GRTMHAL = 'SPENT MONTH OR MORE ON HALLUCINOGENS PA'
   GRTMINH = 'SPENT MONTH OR MORE ON INHALANTS PAST 1'
   GRTMANL = 'SPENT MONTH OR MORE ON PAIN KILLERS PAS'
   GRTMTRN = 'SPENT MONTH OR MORE ON TRANQUILIZERS PA'
   GRTMSTM = 'SPENT MONTH OR MORE ON STIMULANTS PAST'
   GRTMSED = 'SPENT MONTH OR MORE ON SEDATIVES PAST 1'
   LAMTCIG = 'USED CIG MORE OFTEN THAN INTENDED PAST'
   LAMTALC = 'USED ALCOHOL MORE OFTEN THAN INTENDED P'
   LAMTMRJ = 'USED MJ/HASH MORE OFTEN THAN INTENDED P'
   LAMTCOC = 'USED COCAINE MORE OFTEN THAN INTENDED P'
   LAMTHER = 'USED HEROIN MORE OFTEN THAN INTENDED PA'
   LAMTHAL = 'USED HALL MORE OFTEN THAN INTENDED PAST'
   LAMTINH = 'USED INH MORE OFTEN THAN INTENDED PAST'
   LAMTANL = 'USED PAIN KILLERS MORE OFT THAN INT PAS'
   LAMTTRN = 'USED TRANQ MORE OFTEN THAN INTENDED PST'
   LAMTSTM = 'USED STIM MORE OFTEN THAN INTENDED PAST'
   LAMTSED = 'USED SED MORE OFTEN THAN INTENDED PAST'
   BTOLCIG = 'BUILT UP TOLERANCE FOR CIGARETTES PAST'
   BTOLALC = 'BUILT UP TOLERANCE FOR ALCOHOL PAST 12'
   BTOLMRJ = 'BUILT UP TOLERANCE FOR MARIJUANA/HASH P'
   BTOLCOC = 'BUILT UP TOLERANCE FOR COCAINE PAST 12'
   BTOLHER = 'BUILT UP TOLERANCE FOR HEROIN PAST 12 M'
   BTOLHAL = 'BUILT UP TOLERANCE FOR HALLUCINOGENS PA'
   BTOLINH = 'BUILT UP TOLERANCE FOR INHALANTS PAST 1'
   BTOLANL = 'BUILT UP TOLERANCE FOR PAIN KILLERS PAS'
   BTOLTRN = 'BUILT UP TOLERANCE FOR TRANQUILIZERS PA'
   BTOLSTM = 'BUILT UP TOLERANCE FOR STIMULANTS PAST'
   BTOLSED = 'BUILT UP TOLERANCE FOR SEDATIVES PAST 1'
   ACRDCIG = 'CIG REDUCED IMPORTANT ACTIVITIES PST 12'
   ACRDALC = 'ALCOHOL REDUCED IMPORTANT ACTIVITIES PS'
   ACRDMRJ = 'MJ/HASH REDUCED IMPORTANT ACTIVITIES PS'
   ACRDCOC = 'COCAINE REDUCED IMPORTANT ACTIVITIES PS'
   ACRDHER = 'HEROIN REDUCED IMPORTANT ACTIVITIES PST'
   ACRDHAL = 'HALL REDUCED IMPORTANT ACTIVITIES PST 1'
   ACRDINH = 'INHALANTS REDUCED IMPORTANT ACTIVITIES'
   ACRDANL = 'PAIN KILLER REDUCED IMPORTANT ACTVITIES'
   ACRDTRN = 'TRANQ REDUCED IMPORTANT ACTIVITIES PST'
   ACRDSTM = 'STIM REDUCED IMPORTANT ACTIVITIES PST 1'
   ACRDSED = 'SEDATIVES REDUCED IMPORTANT ACTIVITIES'
   EMPBCIG = 'CIGARETTES CAUSED EMOTIONAL PROBLEMS PA'
   EMPBALC = 'ALCOHOL CAUSED EMOTIONAL PROBLEMS PAST'
   EMPBMRJ = 'MJ/HASH CAUSED EMOTIONAL PROBLEMS PAST'
   EMPBCOC = 'COCAINE CAUSED EMOTIONAL PROBLEMS PAST'
   EMPBHER = 'HEROIN CAUSED EMOTIONAL PROBLEMS PAST 1'
   EMPBHAL = 'HALLUCINOGENS CAUSED EMOTIONAL PROBLEMS'
   EMPBINH = 'INHALANTS CAUSED EMOTIONAL PROBLEMS PAS'
   EMPBANL = 'PAIN KILLERS CAUSED EMOTIONAL PROBLEMS'
   EMPBTRN = 'TRANQUILIZERS CAUSED EMOTIONAL PROBLEMS'
   EMPBSTM = 'STIMULANTS CAUSED EMOTIONAL PROBLEMS PA'
   EMPBSED = 'SEDATIVES CAUSED EMOTIONAL PROBLEMS PAS'
   HLPBCIG = 'CIGARETTES CAUSED HEALTH PROBLEMS PAST'
   HLPBALC = 'ALCOHOL CAUSED HEALTH PROBLEMS PAST 12'
   HLPBMRJ = 'MARIJUANA/HASH CAUSED HEALTH PROBLEMS P'
   HLPBCOC = 'COCAINE CAUSED HEALTH PROBLEMS PAST 12'
   HLPBHER = 'HEROIN CAUSED HEALTH PROBLEMS PAST 12 M'
   HLPBHAL = 'HALLUCINOGENS CAUSED HEALTH PROBLEMS PA'
   HLPBINH = 'INHALANTS CAUSED HEALTH PROBLEMS PAST 1'
   HLPBANL = 'PAIN KILLERS CAUSED HEALTH PROBLEMS PAS'
   HLPBTRN = 'TRANQUILIZERS CAUSED HEALTH PROBLEMS PA'
   HLPBSTM = 'STIMULANTS CAUSED HEALTH PROBLEMS PAST'
   HLPBSED = 'SEDATIVES CAUSED HEALTH PROBLEMS PAST 1'
   UCDCIG  = 'WANTED TO CUT DOWN ON CIGARETTES PAST 1'
   UCDALC  = 'WANTED TO CUT DOWN ON ALCOHOL PAST 12 M'
   UCDMRJ  = 'WANTED TO CUT DOWN ON MARIJUANA/HASH PA'
   UCDCOC  = 'WANTED TO CUT DOWN ON COCAINE PAST 12 M'
   UCDHER  = 'WANTED TO CUT DOWN ON HEROIN PAST 12 MO'
   UCDHAL  = 'WANTED TO CUT DOWN ON HALLUCINOGENS PAS'
   UCDINH  = 'WANTED TO CUT DOWN ON INHALANTS PAST 12'
   UCDANL  = 'WANTED TO CUT DOWN ON PAIN KILLERS PAST'
   UCDTRN  = 'WANTED TO CUT DOWN ON TRANQUILIZERS PAS'
   UCDSTM  = 'WANTED TO CUT DOWN ON STIMULANTS PAST 1'
   UCDSED  = 'WANTED TO CUT DOWN ON SEDATIVES PAST 12'
   SKPSPTRD= 'CAN RESP COMPLETE SPECIAL TOPICS ANS SHE'
   SPTREAD = 'SPECIAL TOPICS - READING PREFERENCE'
   NDTXRCVD= 'RECEIVE COUNSELING/TRMT FOR DRG/ALC USE'
   NDTXNEED= 'NEED COUNSELING/TRMT FOR DRUG/ALC USE P'
   NDTXALC = 'NEEDED TRMT/COUNS FOR ALCOHOL PAST 12 M'
   NDTXMJ  = 'NEEDED TRMT/COUNS FOR MARIJUANA PAST 12'
   NDTXCOC = 'NEEDED TRMT/COUNS FOR COCAINE/''CRACK'' P'
   NDTXHER = 'NEEDED TRMT/COUNS FOR HEROIN PAST 12 MO'
   NDTXHAL = 'NEEDED TRMT/COUNS FOR HALLUCINOGENS PAS'
   NDTXINH = 'NEEDED TRMT/COUNS FOR INHALANTS PAST 12'
   NDTXANL = 'NEEDED TRMT FOR PRESC PAIN KILLERS PAST'
   NDTXTRAN= 'NEEDED TRMT FOR PRESC TRANQUILIZERS PAS'
   NDTXSTIM= 'NEEDED TRMT FOR PRESC STIMULANTS PAST 1'
   NDTXSED = 'NEEDED TRMT FOR PRESC SEDATIVES PAST 12'
   NDTXSOD = 'NEEDED TRMT FOR SOME OTHER DRUG PAST 12'
   NDTXDRG1= 'OTHER DRUG (FIRST MENTION)'
   NDTXDRG2= 'OTHER DRUG (SECOND MENTION)'
   NDTXDRG3= 'OTHER DRUG (THIRD MENTION)'
   NDTXDRG4= 'OTHER DRUG (FOURTH MENTION)'
   NDTXDRG5= 'OTHER DRUG (FIFTH MENTION)'
   NDTXSTEP= 'TAKE STEPS TO OBTAIN TRMT PAST 12 MONTH'
   NDTXTRSP= 'NO TRANSPORTATION TO TRMT/COUNSELING PR'
   NDTXTFAR= 'NEAREST TRMT/COUNSELING PROGRAMS TOO FA'
   NDTXBDHR= 'TRMT/COUNSELING PROGRAMS'' HOURS NOT CO'
   NDTXOPEN= 'NO OPENINGS IN THE TRMT/COUNSELING PROG'
   NDTXTYPE= 'PROGRAMS DID NOT OFFER TYPE OF TRMT I W'
   NDTXMONY= 'DID NOT HAVE INSURANCE OR MONEY TO PAY'
   NDTXHCAP= 'PROGRMS'' FACILITIES NOT ACCESSIBLE TO'
   NDTXTCMP= 'PARTICIPATION IN PROGRAM WAS TOO COMPLI'
   NDTXLANG= 'PGM''S COUNSELORS DIDN''T MEET ETHNIC/L'
   NDTXSPSV= 'PROGRAMS DID NOT OFFER SPECIAL SERVICES'
   NDTXSOR = 'DID NOT OBTAIN TRMT/COUNSELING FOR SOME'
   NDTXRSC1= 'OTH REASON DID NOT OBTAIN TRMT PAST 12'
   BOOKED  = 'EVER ARRESTED & BOOKED FOR BREAKING THE'
   NOBOOKYR= '# TIMES ARRESTED AND BOOKED IN PAST 12'
   BKLARCNY= 'ARRSTD & BOOKED FOR LARCENY/THEFT IN PA'
   BKBURGL = 'ARRSTD & BOOKED FOR BURGLARY OR B&E IN'
   BKAGASLT= 'ARRSTD & BOOKED FOR AGGRAVATED ASSAULT'
   BKSMASLT= 'ARRSTD & BOOKED FOR OTHER ASSAULT IN PS'
   BKMVTHFT= 'ARRSTD & BOOKED FOR MOTOR VEHICLE THEFT'
   BKROB   = 'ARRSTD & BOOKED FOR ROBBERY IN PAST 12'
   BKRAPE  = 'ARRSTD & BOOKD FOR FORCIBLE RAPE IN PST'
   BKMURDER= 'ARRST & BKD FOR MURDER/HOMICDE/MNSLGHTR'
   BKARSON = 'ARRSTD & BOOKED FOR ARSON IN PAST 12 MO'
   BKDRVINF= 'ARRSTD & BOOKED FOR DUI IN PAST 12 MONT'
   BKDRUNK = 'ARRST & BKD FOR DRNKNSS/OTH LIQ LAW VIO'
   BKDRUG  = 'ARRSTD & BKED FOR POSSESS/SALE OF DRUGS'
   BKPROS  = 'ARRSTD & BOOKED FOR PROSTITUTION IN PAS'
   BKVANDAL= 'ARRSTD & BOOKED FOR OTHR PROP OFFENSE P'
   BKOTH   = 'ARRSTD & BOOKED FOR OTHER OFFENSES PST'
   BKOTHOFF= 'ARRSTD & BOOKED FOR OTHER OFFENSES PST'
   PROBATON= 'ON PROBATION AT ANY TIME IN PAST 12 MON'
   PAROLE  = 'ON PAROLE AT ANY TIME IN PAST 12 MONTHS'
   DRVALDR = 'DROVE UNDER INFLU OF ALC & ILL DRGS PAS'
   DRIVEAL = 'DROVE WHILE UNDER INFLU OF ALCOHOL PAST'
   DRIVEDR = 'DROVE UNDER INFLUENCE OF ILLEGAL DRUGS'
   SKPTMTRD= 'CAN RESPONDENT COMPLETE TREATMENT ANS SH'
   TMTREAD = 'TREATMENT - READING PREFERENCE'
   TXEVER  = 'EVER RECEIVED ALCOHOL OR DRUG TREATMENT'
   TXTIMELF= '# TIMES RECEIVD ALCOHOL OR DRUG TREATME'
   TXYRFREQ= '# TIMES RECEIVD ALCOHOL/DRUG TRMT PAST'
   TXALHOSP= 'RCVD ALC TRMT IN HOSPITAL/OVERNIGHT PAS'
   TXALRFIN= 'RCVD ALC TRMT REHAB CENTER/OVERNIGHT PS'
   TXALRFOP= 'RCVD ALC TRMT REHAB CENTER/OUTPATIENT P'
   TXALMHC = 'RCVD ALC TRMT MENT HEALTH CENTER/OUTPT'
   TXALEMRG= 'RCVD ALC TRMT IN AN EMERGENCY ROOM PAST'
   TXALDOC = 'RCVD ALC TRMT IN PRIV DOCTOR''S OFFICE'
   TXALJAIL= 'RCVD ALC TRMT IN PRISON OR JAIL PAST 12'
   TXALSHG = 'RCVD ALCOHOL TRMT IN SELF-HELP GROUP PA'
   TXALSOP = 'RCVD ALC TRMT IN SOME OTHER PLACE PAST'
   TXALSP  = 'OTHER FACILITY RECEIVED ALC TRMT PAST 1'
   TXDRHOSP= 'RECEIVED DRUG TRMT HOSPITAL/OVERNIGHT P'
   TXDRFIN = 'RCVD DRUG TRMT REHAB CENTER/OVERNIGHT P'
   TXDRFOP = 'RCVD DRUG TRMT REHAB CENTER/OP PAST 12'
   TXDRMHC = 'RCVD DRUG TRMT M.HEALTH CENTER PAST 12'
   TXDREMRG= 'RCVD DRUG TRMT IN EMERGENCY ROOM PAST 1'
   TXDRDOC = 'RCVD DRUG TRMT IN PRIV DOCTOR''S OFF PS'
   TXDRJAIL= 'RCVD DRUG TRMT IN PRISON PAST 12 MONTHS'
   TXDRSHG = 'RCVD DRUG TREAT IN SELF-HELP GROUP PAST'
   TXDRSOP = 'RECEIVED DRUG TRMT IN SOME OTH PLACE PS'
   TXDRSP  = 'OTHER FACILITY RECEIVED DRUG TRMT PAST'
   TXYREMRG= '# TIMES EMER RM FOR TRMT OF ILL DRUGS P'
   TXADGREC= 'TIME SINCE LAST ALCOHOL OR DRUG TREATME'
   TXLTHOSP= 'LAST ALCOHOL OR DRUG TRMT OVERNIGHT AT'
   TXLTRFIN= 'LAST ALC/DRG TRMT OVERNITE AT RES DRUG'
   TXLTRFOP= 'LAST ALC/DRUG TRMT OUTPATIENT DRUG REHA'
   TXLTMHC = 'LAST ALC/DRG TRMT OUTPATIENT AT MENT HE'
   TXLTEMRG= 'LAST ALCOHOL OR DRUG TRMT AT EMERGENCY'
   TXLTDOC = 'LAST ALCOHOL OR DRUG TRMT AT PRIVATE DO'
   TXLTJAIL= 'LAST ALCOHOL OR DRUG TREATMENT IN PRISO'
   TXLTSHG = 'LAST ALCOHOL OR DRUG TREATMENT IN SELF-'
   TXLTSOP = 'LAST ALCOHOL OR DRUG TREATMENT IN SOME'
   TXLTSP  = 'OTHER FACILITY RECEIVED LAST TREATMENT'
   TXLTALC = 'LAST TREATMENT FOR ALCOHOL'
   TXLTMJ  = 'LAST TREATMENT FOR MARIJUANA/HASHISH'
   TXLTCOC = 'LAST TREATMENT FOR COCAINE/''CRACK'''
   TXLTHER = 'LAST TREATMENT FOR HEROIN'
   TXLTHAL = 'LAST TREATMENT FOR HALLUCINOGENS'
   TXLTINH = 'LAST TREATMENT FOR INHALANTS'
   TXLTANL = 'LAST TREATMENT FOR PRESCRIPTION PAIN KI'
   TXLTRAN = 'LAST TREATMENT FOR PRESCRIPTION TRANQUI'
   TXLTSTIM= 'LAST TREATMENT FOR PRESCRIPTION STIMULA'
   TXLTSED = 'LAST TREATMENT FOR PRESCRIPTION SEDATIV'
   TXLTSOD = 'LAST TREATMENT FOR SOME OTHER DRUG(S)'
   TXLTA   = 'OTHER DRUG LAST TREATED (FIRST MENTION)'
   TXLTB   = 'OTHER DRUG LAST TREATED (SECOND MENTION'
   TXLTC   = 'OTHER DRUG LAST TREATED (THIRD MENTION)'
   TXLTD   = 'OTHER DRUG LAST TREATED (FOURTH MENTION'
   TXLTE   = 'OTHER DRUG LAST TREATED (FIFTH MENTION)'
   TXDRGA  = 'PRIMARY DRUG OF TREATMENT (FIRST MENTIO'
   TXDRGB  = 'PRIMARY DRUG OF TREATMENT (SECOND MENTI'
   TXDRGC  = 'PRIMARY DRUG OF TREATMENT (THIRD MENTIO'
   TXDRGD  = 'PRIMARY DRUG OF TREATMENT (FOURTH MENTI'
   TXDRGE  = 'PRIMARY DRUG OF TREATMENT (FIFTH MENTIO'
   TXOUTC  = 'OUTCOME OF TREATMENT LAST RECEIVED'
   TXTIME  = 'LENGTH OF LAST DRUG/ALCOHOL TREATMENT I'
   TXPDINS = 'HEALTH INSURANCE PAID FOR LAST TREATMEN'
   TXPDCARE= 'MEDICARE PAID FOR LAST TREATMENT'
   TXPDCAID= 'MEDICAID PAID FOR LAST TREATMENT'
   TXPDSAVE= 'OWN SAVINGS OR EARNINGS PAID FOR LAST T'
   TXPDFMLY= 'FAMILY MEMBERS PAID FOR LAST TREATMENT'
   TXPDEMPL= 'EMPLOYER PAID FOR LAST TREATMENT'
   TXPDFREE= 'LAST TREATMENT WAS FREE'
   TXPDSOS = 'LAST TREATMENT PAID FOR BY SOME OTHER S'
   TXPDSP  = 'OTHER PAYER FOR LAST TREATMENT'
   TXENROLL= 'ENROLLED IN TREATMENT ON OCTOBER 1, 199'
   SKYCPBAN= 'SKIP OVER YTH CHCKLST TO PERS BEH OR DRI'
   SKPYCRD = 'CAN RESP COMPLETE YOUTH CHECKLIST ANS SH'
   YCREAD  = 'YOUTH CHECKLIST - READING PREFERENCE'
   YACTYNG = 'I ACT TOO YOUNG FOR MY AGE'
   YALLERGY= 'I HAVE AN ALLERGY'
   YARGUE  = 'I ARGUE A LOT'
   YASTHMA = 'I HAVE ASTHMA'
   YACOPPSX= 'I ACT LIKE THE OPPOSITE SEX'
   YLKANIML= 'I LIKE ANIMALS'
   YBRAG   = 'I BRAG'
   YTRBCONC= 'I HAVE TROUBLE CONCENTRATING OR PAYING A'
   YCNTHGTS= 'I CAN''T GET MY MIND OFF CERTAIN THOUGHT'
   YTRBSIT = 'I HAVE TROUBLE SITTING STILL'
   YDPTADLT= 'I''M TOO DEPENDENT ON ADULTS'
   YFLONELY= 'I FEEL LONELY'
   YFLCONFU= 'I FEEL CONFUSED OR IN A FOG'
   YCRYLOT = 'I CRY A LOT'
   YHONEST = 'I AM PRETTY HONEST'
   YMEANOTH= 'I AM MEAN TO OTHERS'
   YDAYDREM= 'I DAYDREAM A LOT'
   YTRYKLSF= 'I DELIBERATELY TRY TO HURT OR KILL MYSEL'
   YTRYATTN= 'I TRY TO GET A LOT OF ATTENTION'
   YDSTYTHG= 'I DESTROY MY OWN THINGS'
   YDSTYOTH= 'I DESTROY THINGS BELONGING TO OTHERS'
   YDSBYPAR= 'I DISOBEY MY PARENTS'
   YDSBYSCH= 'I DISOBEY AT SCHOOL'
   YDNTEATW= 'I DON''T EAT AS WELL AS I SHOULD'
   YDNTKIDS= 'I DON''T GET ALONG WITH OTHER KIDS'
   YDNTGLTY= 'I DON''T FEEL GUILTY AFTER DOING SOMETHI'
   YJEALOTH= 'I AM JEALOUS OF OTHERS'
   YHELPOTH= 'I AM WILLING TO HELP OTHERS WHEN THEY NE'
   YAFRPLAC= 'I AM AFRAID OF CERTAIN ANIMALS/SIT/PLACE'
   YAFRSCHL= 'I AM AFRAID OF GOING TO SCHOOL'
   YAFRBAD = 'I AM AFRAID I MIGHT THINK OR DO SOMETHIN'
   YFLPRFCT= 'I FEEL THAT I HAVE TO BE PERFECT'
   YFLNOLOV= 'I FEEL THAT NO ONE LOVES ME'
   YFLGETME= 'I FEEL THAT OTHERS ARE OUT TO GET ME'
   YFLWTHLS= 'I FEEL WORTHLESS OR INFERIOR'
   YACCHURT= 'I ACCIDENTALLY GET HURT A LOT'
   YFIGHTS = 'I GET IN MANY FIGHTS'
   YGTEASED= 'I GET TEASED A LOT'
   YKIDSTRB= 'I HANG AROUND WITH KIDS WHO GET IN TROUB'
   YHRVOICS= 'I HEAR SOUNDS OR VOICES THAT OTHER PEOPL'
   YACTTNK = 'I ACT WITHOUT STOPPING TO THINK'
   YALONE  = 'I WOULD RATHER BE ALONE THAN WITH OTHERS'
   YLIE    = 'I LIE OR CHEAT'
   YBITNAIL= 'I BITE MY FINGERNAILS'
   YNERVOUS= 'I AM NERVOUS OR TENSE'
   YBTWITCH= 'PARTS OF MY BODY TWITCH OR MAKE NERVOUS'
   YNGHTMAR= 'I HAVE NIGHTMARES'
   YNOTKIDS= 'I AM NOT LIKED BY OTHER KIDS'
   YDOBETTR= 'I CAN DO CERTAIN THINGS BETTER THAN MOST'
   YANXIOUS= 'I AM TOO FEARFUL OR ANXIOUS'
   YFLDIZZY= 'I FEEL DIZZY'
   YFLGUILT= 'I FEEL TOO GUILTY'
   YEATMUCH= 'I EAT TOO MUCH'
   YFLTIRED= 'I FEEL OVERTIRED'
   YOVRWGHT= 'I AM OVERWEIGHT'
   YACHES  = 'ACHES OR PAINS (NOT HEADACHES)'
   YHEADACH= 'HEADACHES'
   YNAUSEA = 'NAUSEA, FEEL SICK'
   YEYEPROB= 'PROBLEMS WITH EYES'
   YRASHES = 'RASHES OR OTHER SKIN PROBLEMS'
   YCRAMPS = 'STOMACH ACHES OR CRAMPS'
   YVOMIT  = 'VOMITING, THROWING UP'
   YATTACK = 'I PHYSICALLY ATTACK PEOPLE'
   YPKBPART= 'I PICK MY SKIN OR OTHER PARTS OF MY BODY'
   YPFRNDLY= 'I CAN BE PRETTY FRIENDLY'
   YTRYTHNG= 'I LIKE TO TRY NEW THINGS'
   YSCPOOR = 'MY SCHOOL WORK IS POOR'
   YCLUMSY = 'I AM POORLY COORDINATED OR CLUMSY'
   YOLDKIDS= 'I WOULD RATHER BE W/OLDER KIDS THAN KIDS'
   YYNGKIDS= 'I WOULD RATHER BE W/YOUNGER KIDS THAN KI'
   YRFSTALK= 'I REFUSE TO TALK'
   YREPACTN= 'I REPEAT CERTAIN ACTIONS OVER AND OVER'
   YRUNHOME= 'I RUN AWAY FROM HOME'
   YSCREAM = 'I SCREAM A LOT'
   YSECRET = 'I AM SECRETIVE OR KEEP THINGS TO MYSELF'
   YSEETHNG= 'I SEE THINGS THAT OTHER PEOPLE THINK ARE'
   YSLFCONS= 'I AM SELF-CONSCIOUS OR EASILY EMBARRASSE'
   YSETFIRE= 'I SET FIRES'
   YWELHNDS= 'I CAN WORK WELL WITH MY HANDS'
   YSHOWOFF= 'I SHOW OFF OR CLOWN'
   YSHY    = 'I AM SHY'
   YSLPLESS= 'I SLEEP LESS THAN MOST KIDS'
   YSLPMORE= 'I SLEEP MORE THAN MOST KIDS DURING DAY/N'
   YGDIMAG = 'I HAVE A GOOD IMAGINATION'
   YSPCHPRB= 'I HAVE A SPEECH PROBLEM'
   YSTDRGHT= 'I STAND UP FOR MY RIGHTS'
   YSTEALHO= 'I STEAL AT HOME'
   YSTEALPL= 'I STEAL FROM PLACES OTHER THAN HOME'
   YDNTNEED= 'I STORE UP THINGS I DON''T NEED'
   YDOSTRNG= 'I DO THINGS OTHER PEOPLE THINK ARE STRAN'
   YTHSTRNG= 'I HAVE THOUGHTS PEOPLE WOULD THINK ARE S'
   YSTUBORN= 'I AM STUBBORN'
   YMOODS  = 'MY MOODS OR FEELINGS CHANGE SUDDENLY'
   YENJOY  = 'I ENJOY BEING WITH OTHER PEOPLE'
   YSUSPICS= 'I AM SUSPICIOUS'
   YDRTLANG= 'I SWEAR OR USE DIRTY LANGUAGE'
   YTHKKLSF= 'I THINK ABOUT KILLING MYSELF'
   YLKLAUGH= 'I LIKE TO MAKE OTHERS LAUGH'
   YTALKMCH= 'I TALK TOO MUCH'
   YTEASE  = 'I TEASE OTHERS A LOT'
   YTEMPER = 'I HAVE A HOT TEMPER'
   YTHNKSEX= 'I THINK ABOUT SEX TOO MUCH'
   YTHRTPEO= 'I THREATEN TO HURT PEOPLE'
   YLKHELP = 'I LIKE TO HELP OTHERS'
   YCONNEAT= 'I AM TOO CONCERNED ABOUT BEING NEAT OR C'
   YTRBSLEP= 'I HAVE TROUBLE SLEEPING'
   YSKIPSCH= 'I CUT CLASSES OR SKIP SCHOOL'
   YNOENRGY= 'I DON''T HAVE MUCH ENERGY'
   YUNHAPPY= 'I AM UNHAPPY, SAD, OR DEPRESSED'
   YLOUDER = 'I AM LOUDER THAN OTHER KIDS'
   YUSEDRUG= 'I USE ALCOHOL OR DRUGS FOR NONMEDICAL PU'
   YFAIROTH= 'I TRY TO BE FAIR TO OTHERS'
   YENJYJOK= 'I ENJOY A GOOD JOKE'
   YLIFEASY= 'I LIKE TO TAKE LIFE EASY'
   YTRYHELP= 'I TRY TO HELP OTHER PEOPLE WHEN I CAN'
   YWSOPPSX= 'I WISH I WAS OF THE OPPOSITE SEX'
   YINVOTH = 'I KEEP FROM GETTING INVOLVED WITH OTHERS'
   YWORRY  = 'I WORRY A LOT'
   SKPBDBAN= 'SKIP OVER PB/DB TO DEMOGRAPHICS, ON AGE'
   SKPPBRD = 'CAN RESPONDENT COMPLETE PERS. BEH. ANS S'
   PBREAD  = 'PERSONAL BEHAVIORS - READING PREFERENCE'
   XSEXYR  = 'HAD SEX IN PAST 12 MONTHS'
   XRELNOW = 'CURRENTLY INVOLVED IN ON-GOING SEXUAL RE'
   XRELYR  = 'HAD ON-GOING SEXUAL RELATIONSHIP IN PAST'
   XRELCDV = 'HOW OFTN CONDOM USED W/VAG SEX IN ON-GOI'
   XRELCDA = 'HOW OFTN CONDOM USED W/ANAL SEX IN ON-GO'
   XNRELYR = 'HAD SEX NOT IN ON-GOING RELATIONSHIP PST'
   XNRELCDV= 'HOW OFTN CONDOM USED W/VAG SEX NOT IN ON'
   XNRELCDA= 'HOW OFTN CONDOM USED W/ANAL SEX NOT IN O'
   XYRDIFPP= '# PEOPLE HAD SEX WITH IN PAST 12 MONTHS'
   XYRWTHMF= 'HAD SEX WITH MALES, FEMALES, OR BOTH IN'
   XYRHIV  = 'IN PAST 12 MOS HAD SEX WITH ANYONE WHO H'
   XYRMONEY= 'IN PAST 12 MOS PAID OR REC''D MONEY FOR'
   XYRDRUGS= 'IN PAST 12 MOS GIVEN OR REC''D DRUGS FOR'
   XCDEVER = 'EVER USED A CONDOM WHEN YOU HAD SEX'
   XCDLAST = 'CONDOM USED THE LAST TIME YOU HAD SEX'
   XCDPREG = 'CONDOM USED LAST TIME TO PREVENT PREGNAN'
   XCDSTD  = 'CONDOM USED LAST TIME TO PREVENT DISEASE'
   XCDNMESS= 'CONDOM USED LAST TIME BECAUSE LESS MESSY'
   XCDOTRSN= 'CONDOM USED LAST TIME FOR OTHER REASON'
   XCDRSN1 = 'OTHER REASON MENTIONED FOR CONDOM USE'
   XNCDPREG= 'NO CONDOM USE LAST TIME--TRYING TO HAVE'
   XNCDMONO= 'NO CONDOM USE LAST TIME--SEX WITH 1 PART'
   XNCDSTD = 'NO CONDOM USE LAST TIME--DIDN''T HAVE DI'
   XNCDOBC = 'NO CONDOM USE LAST TIME--USED OTHER BIRT'
   XNCDRELG= 'NO CONDOM USE LAST TIME--FOR RELIGIOUS R'
   XNCDPTNR= 'NO CONDOM USE LAST TIME--PARTNER DIDN''T'
   XNCDNA  = 'NO CONDOM USE LAST TIME--CONDOM NOT AVAI'
   XNCDHOW = 'NO CONDOM USE LAST TIME--DK HOW TO USE C'
   XNCDSAFE= 'NO CONDOM USE LAST TIME--TYPE OF SEX WAS'
   XNCDORSN= 'NO CONDOM USE LAST TIME--OTHER REASON'
   XNCDRSN1= 'OTHER REASON MENTIONED FOR NOT USING CON'
   XCDMOOD = 'AGREE/DISAGREE CONDOMS RUIN THE MOOD'
   XCDRESP = 'AGREE/DISAGREE FEEL RESPONSIBLE WITH CON'
   XCDFEEL = 'AGREE/DISAGREE SEX DOESN''T FEEL GOOD WI'
   XCDTRST = 'AGREE/DISAGREE CONDOMS BUILD TRUST WITH'
   XCDEMBR = 'AGREE/DISAGREE EMBARRASSING TO BUY CONDO'
   XCDCOST = 'AGREE/DISAGREE CONDOMS COST TOO MUCH'
   XRELLAST= 'TYPE OF RELATIONSHIP, LAST TIME YOU HAD'
   XLFBLOOD= 'EVER GIVEN A BLOOD DONATION'
   XBLD385 = 'GIVEN BLOOD SINCE MARCH 1985'
   XLTBLDMO= 'MONTH LAST GAVE BLOOD'
   XLTBLDYR= 'YEAR LAST GAVE BLOOD'
   XHIVTEST= 'EVER HAD BLOOD TEST FOR HIV'
   XLTHIVMO= 'MONTH OF LAST BLOOD TEST FOR HIV'
   XLTHIVYR= 'YEAR OF LAST BLOOD TEST FOR HIV'
   XHIVRSLT= 'GOT THE RESULTS OF LAST BLOOD TEST FOR H'
   SKPDBRD = 'CAN R COMPLETE DRIVING BEHAVIOR ANSWER S'
   DBREAD  = 'DRIVING BEHAVIORS - READING PREFERENCE'
   VDRVYR  = 'DRIVEN A CAR IN THE PAST 12 MONTHS'
   VYRFREQ = 'NUMBER OF DAYS DRIVEN IN PAST 12 MONTHS'
   VALDRVYR= 'DROVE WITHIN 2 HRS OF DRINKING PAST 12'
   VALYRFRQ= '# DAYS DROVE WITHIN 2 HRS OF DRINKING P'
   VAL30USE= 'DAYS DROVE WITHIN 2 HRS OF DRINKING PAS'
   VALCNODR= '# DRINKS LAST TIME DROVE W/IN 2 HRS OF'
   VALCTIME= 'TIME BETWEEN 1ST AND LAST DRINK THE LAS'
   VALDTIME= 'TIME BETWEEN LAST DRINK AND DRIVING THE'
   VMJUSEYR= 'USED MARIJUANA/HASHISH IN PAST 12 MONTH'
   VMJDRVYR= 'DROVE WITHIN 2 HRS AFTER MJ/HASH USE PA'
   VMJALCYR= 'HOW OFTEN ALCOHOL USED W/MJ & DROVE PST'
   VMJCOCYR= 'HOW OFTEN COCAINE USED W/MJ & DROVE PST'
   VMJHERYR= 'HOW OFTEN HEROIN USED W/MJ & DROVE PST'
   VMJHALYR= 'HOW OFTEN HALLUC USED W/MJ & DROVE PST'
   VMJINHYR= 'HOW OFTEN INHALANT USED W/MJ & DROVE PS'
   VMJANLYR= 'HOW OFT ANALGESIC USED W/MJ & DROVE PST'
   VMJTRNYR= 'HOW OFTEN TRANQ USED W/MJ & DROVE PST 1'
   VMJSTMYR= 'HOW OFT STIMULANT USED W/MJ & DROVE PST'
   VMJSEDYR= 'HOW OFT SEDATIVE USED W/MJ & DROVE PST'
   VMJOTHYR= 'HOW OFT OTHER DRUG USED W/MJ & DROVE PS'
   VMJYRS1 = 'OTHER DRUG USED W/MJ & DROVE (FIRST MEN'
   VMJYRS2 = 'OTHER DRUG USED W/MJ & DROVE (SECOND ME'
   VMJYRS3 = 'OTHER DRUG USED W/MJ & DROVE (THIRD MEN'
   VMJYRS4 = 'OTHER DRUG USED W/MJ & DROVE (FOURTH ME'
   VMJYRS5 = 'OTHER DRUG USED W/MJ & DROVE (FIFTH MEN'
   VMJ30USE= '# DAYS DROVE WITHIN 2 HRS OF MJ USE, PA'
   VLTMJALC= 'WHAT USED W/MJ THE LAST TIME USED MJ &'
   VLTMJAL1= 'OTHER DRUG USED LAST TIME W/MJ (FIRST M'
   VLTMJAL2= 'OTHER DRUG USED LAST TIME W/MJ (SECOND'
   VLTMJAL3= 'OTHER DRUG USED LAST TIME W/MJ (THIRD M'
   VLTMJAL4= 'OTHER DRUG USED LAST TIME W/MJ (FOURTH'
   VLTMJAL5= 'OTHER DRUG USED LAST TIME W/MJ (FIFTH M'
   VLTMJFRM= 'PLACE DROVE FROM THE LAST TIME USED MJ'
   VLTMJFRS= 'OTHER PLACE DROVE FROM AFTER USING MJ/H'
   VLTMJTO = '1ST PLACE DROVE TO THE LAST TIME USED M'
   VLTMJTOS= 'OTHER PLACE DROVE TO AFTER USING MJ/HAS'
   VLTMJHWY= 'DROVE LAST TIME ON HWY/SMALLER ROAD AFT'
   VLTMJURB= 'TYPE OF AREA THE LAST TIME USED MJ & DR'
   VLTMJWKD= 'DAY OF WEEK THE LAST TIME USED MJ & DRO'
   VLTMJTIM= 'TIME BEGAN DRIVING THE LAST TIME USED M'
   VLTMJABL= 'HOW MUCH MJ AFFECTED DRIVING ABIL THE L'
   VMJNOWAY= 'USED MJ & DROVE--NO OTHER WAY TO GET TH'
   VMJNHIGH= 'USED MJ & DROVE--NOT HIGH ENOUGH TO CAU'
   VMJNPOLC= 'USED MJ & DROVE--POLICE WOULDN''T CATCH'
   VMJNODVR= 'USED MJ & DROVE--NO ONE ELSE AVAILABLE'
   VMJAPPT = 'USED MJ & DROVE--HAD AN APPOINTMENT/CUR'
   VMJOTHER= 'USED MJ & DROVE FOR SOME OTHER REASON'
   VMJOTHSP= 'OTHER REASON DROVE AFTER USING MJ/HASH'
   VMJSTOP = 'HOW LIKELY STOPPED BY POLICE IF USE MJ'
   VMJABIL = 'HOW MUCH MJ AFFECTS YOUR DRIVING ABILIT'
   VCCUSEYR= 'USED COCAINE IN PAST 12 MONTHS'
   VCCDRVYR= 'DROVE WITHIN 2 HRS AFTER COCAINE USE PA'
   VCCALCYR= 'HOW OFTEN ALCOHOL USED W/COC & DROVE PS'
   VCCMRJYR= 'HOW OFTEN MARIJUANA USED W/COC & DROVE'
   VCCHERYR= 'HOW OFTEN HEROIN USED W/COC & DROVE PST'
   VCCHALYR= 'HOW OFTEN HALLUC USED W/COC & DROVE PST'
   VCCINHYR= 'HOW OFTEN INHALANT USED W/COC & DROVE P'
   VCCANLYR= 'HOW OFT ANALGESIC USED W/COC & DROVE PS'
   VCCTRNYR= 'HOW OFTEN TRANQ USED W/COC & DROVE PST'
   VCCSTMYR= 'HOW OFT STIMULANT USED W/COC & DROVE PS'
   VCCSEDYR= 'HOW OFT SEDATIVE USED W/COC & DROVE PST'
   VCCOTHYR= 'HOW OFT OTHER DRUG USED W/COC & DROVE P'
   VCCYRS1 = 'OTHER DRUG USED W/COC & DROVE (FIRST ME'
   VCCYRS2 = 'OTHER DRUG USED W/COC & DROVE (SECOND M'
   VCCYRS3 = 'OTHER DRUG USED W/COC & DROVE (THIRD ME'
   VCCYRS4 = 'OTHER DRUG USED W/COC & DROVE (FOURTH M'
   VCCYRS5 = 'OTHER DRUG USED W/COC & DROVE (FIFTH ME'
   VCC30USE= '# DAYS DROVE WITHIN 2 HRS OF COC USE, P'
   VLTCCALC= 'WHAT USED W/COC THE LAST TIME USED COC'
   VLTCCAL1= 'OTHER DRUG USED LAST TIME W/COC (FIRST'
   VLTCCAL2= 'OTHER DRUG USED LAST TIME W/COC (SECOND'
   VLTCCAL3= 'OTHER DRUG USED LAST TIME W/COC (THIRD'
   VLTCCAL4= 'OTHER DRUG USED LAST TIME W/COC (FOURTH'
   VLTCCAL5= 'OTHER DRUG USED LAST TIME W/COC (FIFTH'
   VLTCCFRM= 'PLACE DROVE FROM THE LAST TIME USED COC'
   VLTCCFRS= 'OTHER PLACE DROVE FROM AFTER USING COCA'
   VLTCCTO = '1ST PLACE DROVE TO THE LAST TIME USED C'
   VLTCCTOS= 'OTHER PLACE DROVE TO AFTER USING COCAIN'
   VLTCCHWY= 'DROVE LAST TIME ON HWY/SMALLER ROAD AFT'
   VLTCCURB= 'TYPE OF AREA THE LAST TIME USED COC & D'
   VLTCCWKD= 'DAY OF WEEK THE LAST TIME USED COC & DR'
   VLTCCTIM= 'TIME BEGAN DRIVING THE LAST TIME USED C'
   VLTCCABL= 'HOW MUCH COC AFFECTED DRIVING ABIL THE'
   VCCNOWAY= 'USED COC & DROVE--NO OTHER WAY TO GET T'
   VCCNHIGH= 'USED COC & DROVE--NOT HIGH ENOUGH TO CA'
   VCCNPOLC= 'USED COC & DROVE--POLICE WOULDN''T CATC'
   VCCNODVR= 'USED COC & DROVE--NO ONE ELSE AVAILABLE'
   VCCAPPT = 'USED COC & DROVE--HAD AN APPOINTMENT/CU'
   VCCOTHER= 'USED COC & DROVE FOR SOME OTHER REASON'
   VCCOTHSP= 'OTHER REASON DROVE AFTER USING COCAINE'
   VCCSTOP = 'HOW LIKELY STOPPED BY POLICE IF USE COC'
   VCCABIL = 'HOW MUCH COC AFFECTS YOUR DRIVING ABILI'
   VTRUSEYR= 'USED TRANQUILIZERS IN PAST 12 MONTHS'
   VTRDRVYR= 'DROVE WITHIN 2 HRS AFTER TRANQ USE PAST'
   VTR30USE= '# DAYS DROVE WITHIN 2 HRS OF TRAN USE P'
   VLTTRMED= 'REASON WHY USED TRANQS & DROVE THE LAST'
   VLTTRALC= 'WHAT USED W/TRAN THE LAST TIME TRAN USE'
   VLTTRAL1= 'OTHER DRUG USED LAST TIME W/TRAN (FIRST'
   VLTTRAL2= 'OTHER DRUG USED LAST TIME W/TRAN (SECON'
   VLTTRAL3= 'OTHER DRUG USED LAST TIME W/TRAN (THIRD'
   VLTTRAL4= 'OTHER DRUG USED LAST TIME W/TRAN (FOURT'
   VLTTRAL5= 'OTHER DRUG USED LAST TIME W/TRAN (FIFTH'
   VLTTRABL= 'HOW MUCH TRAN AFFECTED DRIVING ABIL THE'
   VSTUSEYR= 'USED STIMULANTS IN PAST 12 MONTHS'
   VSTDRVYR= 'DROVE WITHIN 2 HRS AFTER STIM USE PAST'
   VST30USE= '# DAYS DROVE WITHIN 2 HRS OF STIM USE P'
   VLTSTMED= 'REASON WHY USED STIMS & DROVE THE LAST'
   VLTSTALC= 'WHAT USED W/STIM THE LAST TIME STIM USE'
   VLTSTAL1= 'OTHER DRUG USED LAST TIME W/STIM (FIRST'
   VLTSTAL2= 'OTHER DRUG USED LAST TIME W/STIM (SECON'
   VLTSTAL3= 'OTHER DRUG USED LAST TIME W/STIM (THIRD'
   VLTSTAL4= 'OTHER DRUG USED LAST TIME W/STIM (FOURT'
   VLTSTAL5= 'OTHER DRUG USED LAST TIME W/STIM (FIFTH'
   VLTSTABL= 'HOW MUCH STIMS AFFECTED DRIVING ABIL TH'
   VSEUSEYR= 'USED SEDATIVES IN PAST 12 MONTHS'
   VSEDRVYR= 'DROVE WITHIN 2 HRS AFTER SEDATIVE USE P'
   VSE30USE= '# DAYS DROVE WITHIN 2 HRS OF SED USE PA'
   VLTSEMED= 'REASON WHY USED SEDS & DROVE THE LAST T'
   VLTSEALC= 'WHAT USED W/SEDS THE LAST TIME SEDS USE'
   VLTSEAL1= 'OTHER DRUG USED LAST TIME W/SEDS (FIRST'
   VLTSEAL2= 'OTHER DRUG USED LAST TIME W/SEDS (SECON'
   VLTSEAL3= 'OTHER DRUG USED LAST TIME W/SEDS (THIRD'
   VLTSEAL4= 'OTHER DRUG USED LAST TIME W/SEDS (FOURT'
   VLTSEAL5= 'OTHER DRUG USED LAST TIME W/SEDS (FIFTH'
   VLTSEABL= 'HOW MUCH SEDS AFFECTED DRIVING ABIL THE'
   SKPWKST3= 'SKP MISSED WRK-DYS TO CHLD-RST Q''S, ON'
   WORKDAYS= '# DAYS MISSED WORK FOR INJURY/ILLNESS PA'
   WORKBLAH= '# DAYS SKIPPED WORK PAST 30 DAYS'
   SKPPREG = 'SKIP OVER PREGNANCY Q''S TO TOTPEOP, ON'
   PREGNANT= 'CURRENTLY PREGNANT'
   PREGMOS = 'NUMBER OF MONTHS PREGNANT'
   TOTPEOP = '# PEOPLE LIVING IN HOUSEHOLD (=IRPEOP)'
   SKPMHC  = 'CHECK ON RESPONDENT AGE'
   DEPRESS = 'FELT DEPRESSED 2 WEEKS OR MORE IN PAST 1'
   DEPDAYS = 'DURING 2 WKS, HOW MUCH OF DAY WERE YOU D'
   DEPFREQ = 'FELT DEPRESSED HOW OFTEN IN 2 WK PERIOD'
   LOSTINT1= 'LOSE INTEREST IN THINGS IN 2 WK PERIOD -'
   TIRED1  = 'FEEL TIRED ALL THE TIME IN 2 WK PERIOD -'
   WTCHNG1 = 'WEIGHT CHANGE PAST 12 MONTHS - VERSION 1'
   LBSCHNG1= '# POUNDS GAINED OR LOST - VERSION 1'
   SLPLOSS1= 'TROUBLE FALLING ASLEEP IN 2 WK PERIOD -'
   SLPFREQ1= 'HOW OFTEN TROUBLE SLEEPING IN 2 WK PER -'
   CONCEN1 = 'HAVE MORE PROBLEM CONCENTRATING THAN USU'
   DOWN1   = 'FEEL NO GOOD, WORTHLESS, DOWN'
   IDEAT1  = 'THINK ABOUT DEATH - OWN, SOMEONE ELSE, G'
   SKPDEP1 = 'ANY BOXED ITEMS MARKED HE-7 TO HE-15'
   DEPWKS1 = '# WEEKS FELT DEPRESSED PAST 12 MONTHS'
   DEPMO1  = 'WHAT MONTH LAST FELT DEPRESSED'
   DEPYR1  = 'WHAT YEAR LAST FELT DEPRESSED - RECODE'
   LOSTINT2= 'LOST INTEREST IN THINGS IN 2 WK PERIOD -'
   LOSINDAY= 'AMT OF DAY LOST INTEREST IN 2 WK PERIOD'
   LOSINFRQ= 'LOST INTEREST HOW OFTEN IN 2 WEEK PERIOD'
   TIRED2  = 'DURING TWO WEEKS, FEEL TIRED OR LOW ON E'
   WTCHNG2 = 'WEIGHT CHANGE IN 2 WEEK PERIOD - VERSION'
   LBSCHNG2= '# POUNDS LOST OR GAINED - VERSION 2'
   SLPLOSS2= 'TROUBLE FALLING ASLEEP IN 2 WK PERIOD -'
   SLPFREQ2= 'HOW OFTEN TROUBLE SLEEPING IN 2 WK PER -'
   CONCEN2 = 'HAVE TROUBLE CONCENTRATING DURING THOSE'
   DOWN2   = 'FEEL DOWN, NO GOOD OR WORTHLESS DURING T'
   IDEAT2  = 'THINK ABOUT DEATH - OWN,SOMEONE ELSE,GEN'
   SKPDEP2 = 'ANY BOXED ITEMS MARKED HE-21 TO HE-28'
   DEPWKS2 = '# WEEKS PAST YEAR LOST INTEREST IN THING'
   DEPMO2  = 'LAST TIME LOST INTEREST IN THINGS > 2 WK'
   DEPYR2  = 'LAST TIME LOST INTEREST IN THINGS > 2 WK'
   WORRIED = 'PERIOD LONGER THAN 1 MONTH FELT ANXIOUS'
   WOREND  = 'PERIOD ENDED OR STILL GOING ON'
   WORNOMO1= '# OF MONTHS BEFORE ANXIETY ENDED - RECOD'
   WORHAPN1= 'WORRIED ABOUT THINGS UNLIKELY TO HAPPEN'
   WORSERI1= 'WORRIED ABOUT THINGS NOT SERIOUS'
   WORDIFF1= 'HAD DIFFERENT WORRIES ON MIND'
   WORNOMO2= '# OF MONTHS ANXIETY GOING ON - RECODE'
   WORHAPN2= 'WORRY ABOUT THINGS UNLIKELY TO HAPPEN'
   WORSERI2= 'WORRY ABOUT THINGS NOT SERIOUS'
   WORDIFF2= 'HAVE DIFFERENT WORRIES ON MIND'
   SKPWOR  = 'WORNOMO1 OR WORNOMO2 IS 6 MONTHS OR MORE'
   WORREST = 'RESTLESS WHEN WORRIED'
   WOREDGE = 'KEYED UP OR ON EDGE WHEN WORRIED'
   WORIRRIT= 'IRRITABLE WHEN WORRIED'
   WORHEART= 'HEART POUNDS OR RACES WHEN WORRIED'
   WORTIRED= 'EASILY TIRED WHEN WORRIED'
   WORSLEEP= 'TROUBLE FALLING ASLEEP WHEN WORRIED'
   WORFAINT= 'FEEL FAINT OR UNREAL WHEN WORRIED'
   FEARPUB = 'BEING IN A PUBLIC PLACE, OR A CROWD OR L'
   FEAROUT = 'LEAVING HOME OR BEING AWAY FROM HOME'
   FEARBRDG= 'FEAR OF CROSSING BRIDGE IN PAST 12 MONTH'
   SKPFEAR1= 'RESPONSE TO FEARPUB, FEAROUT, AND FEARBR'
   FEAROFT = 'HOW OFTEN HAVE THESE FEARS'
   FEARYRS = 'HOW LONG HAD THIS/THESE FEAR(S)'
   FEARMOS = '# OF MONTHS HAD THIS/THESE FEAR(S)'
   FEARFANT= 'WHEN IN THIS SITUATION AFRAID OF FAINTIN'
   FEARTRAP= 'WHEN IN THIS SITUATION WORRY ABOUT BEING'
   FEARHELP= 'WHEN IN THIS SITUATION WORRY NO HELP AVA'
   PANIC1  = 'SPELL WHEN SUDDENLY FRIGHTENED PAST 12 M'
   PANIC2  = 'SUDDEN SPELL HEART RACED IN PAST 12 MO'
   PANICNUM= '# ATTACKS IN PAST 12 MONTHS'
   PANICMO = 'MONTH THAT LAST ATTACK OCCURRED'
   PANICYR = 'YEAR THAT LAST ATTACK OCCURRED'
   PANIDANG= 'HAD ATTACK WHEN NOT IN DANGER PAST 12 MO'
   SKPFEAR2= 'RESPONSE TO FEARPUB, FEAROUT, AND FEARBR'
   PANIFEAR= 'ATTACKS OCCUR IN SITUATION CAUSING STRON'
   PANINOFR= 'HAVE ATTACK WHEN NOT IN SITUATION CAUSIN'
   PANIHART= 'HEART POUNDS WHEN HAVING ATTACKS'
   PANIPAIN= 'TIGHTNESS IN STOMACH WHEN HAVING ATTACKS'
   PANISWET= 'SWEAT WHEN HAVING ATTACKS'
   PANISHAK= 'SHAKE WHEN HAVING ATTACKS'
   PANIHOT = 'HOT FLASHES/CHILLS WHEN HAVING ATTACKS'
   PANIUNRL= 'THINGS SEEM UNREAL WHEN HAVING ATTACKS'
   NUERTMT = '# OF TIMES BEEN TREATED IN EMER. ROOM PA'
   NUHSPOV = '# NIGHTS STAYED IN HOSPITAL OVERNIGHT OR'
   NUHSPPE = '# NIGHT STAYED IN HOSPITAL FOR PSY/EMOTI'
   OUTPTPE = 'BEEN OUTPATIENT AT MENTAL HEALTH CLINIC'
   PROXABLE= 'ANOTHER FAMILY MEMBER THAT CAN GIVE INFO'
   PROXYREL= 'PERSON THAT CAN GIVE MORE INFO ABOUT HEA'
   PROXHOME= 'IS RELATIVE AT HOME'
   PROXJOIN= 'ASK THE RELATIVE TO JOIN US'
   CAREUSU = 'IS THERE USUAL PLACE FOR HEALTH CARE'
   NCARERSN= 'REASON FOR NOT HAVING USUAL SOURCE OF CA'
   NCRRSNSP= 'WHETHER OTHER REASON SPECIFIED FOR NCARE'
   NCRRSNSC= 'CODE OF OTHER REASON SPECIFIED FOR NCARE'
   CAREOFT = 'ONE PLACE GO MOST OFTEN'
   PYRCARE = 'USUALLY HAVE A PLACE TO GO FOR CARE PAST'
   PYRCRTYP= 'PLACE VISITED WHEN NEEDED CARE PAST YEAR'
   PYRCRTSP= 'WHETHER OTHER PLACE SPECIFIED FOR PYRCRT'
   PYRCRTSC= 'CODE OF OTHER PLACE SPECIFIED FOR PYRCRT'
   CARENOW = 'IF NEEDED MEDICAL CARE, WOULD GO TO PLAC'
   MNRSNNCR= 'REASON WOULD NOT USE PLACE ANYMORE'
   MNRSNNSP= 'WHETHER OTHER REASON SPECIFIED FOR MNRSN'
   MNRSNNSC= 'CODE OF OTHER REASON SPECIFIED FOR MNRSN'
   UCARETYP= 'USUAL PLACE VISITED FOR HEALTH CARE'
   UCRTYPSP= 'WHETHER OTHER PLACE SPECIFIED FOR UCARET'
   UCRTYPSC= 'CODE OF OTHER PLACE SPECIFIED FOR UCARET'
   MEDICARE= 'COVERED BY MEDICARE'
   MEDICAID= 'COVERED BY MEDICAID'
   CHAMPUS = 'COVERED BY CHAMPUS, CHAMPVA, VA, MILITAR'
   PRVHLTIN= 'COVERED BY PRIVATE INSURANCE OR HMO'
   GRPHLTIN= 'PRIVATE PLAN OFFERED THROUGH EMPLOYER OR'
   PDHINPRM= 'PRIVATE INSURANCE OBTAINED BY PAYING PRE'
   HLTINALC= 'ALCOHOL ABUSE OR ALCOHOLISM'
   HLTINDRG= 'DRUG ABUSE'
   HLTINMNT= 'MENTAL OR EMOTIONAL DIFFICULTIES'
   SOC1    = 'RESPONDENT RECEIVE SS OR RR PAYMENTS PST'
   SOC2    = 'OTHER FAM RECEIVE SS OR RR PAYMENTS PAST'
   SSI1    = 'RESPONDENT RECEIVE SSI'
   SSI2    = 'OTHER FAMILY MEMBER RECEIVE SSI PAST 12'
   PUB1    = 'RESPONDENT RECEIVE PUBLIC ASSIST/WELFARE'
   PUB2    = 'OTHER FAM RECEIVE PUBLIC ASSIST/WELFARE'
   AFDC    = 'ANY FAMILY MEMBER RECEIVED AFDC OR ADC'
   INT1    = 'RESPONDENT RECEIVE INTEREST ON SAVINGS/B'
   INT2    = 'OTHER FAM RECEIVE INTEREST ON SAVINGS/BO'
   CHD1    = 'RESPONDENT RECEIVE CHILD SUPPORT PAST 12'
   CHD2    = 'OTHER FAM RECEIVE CHILD SUPPORT PAST 12'
   OTH1    = 'RESPONDENT RECEIVE INCOME FROM OTHER SOU'
   OTH2    = 'OTHER FAMILY RECEIVE INCOME FROM OTHER S'
   FSTAMP  = 'ANYONE RECEIVE FOODSTAMPS PAST 12 MONTHS'
   PINC1   = 'TOTAL PERSONAL INCOME'
   SKPTFMIN= 'SKIP OVER TOTAL FAM-INCOME TO TELNO, ON'
   FINC1   = 'TOTAL FAMILY INCOME'
   TELNO   = '# OF TELEPHONE LINES IN HOUSEHOLD'
   IRPINSUR= 'PRIVATE HEALTH INSURANCE - IMPUTATION RE'
   IIPINSUR= 'PRIVATE HEALTH INSURANCE - IMPUTATION IN'
   IRINSUR = 'HEALTH INSURANCE - IMPUTATION REVISED'
   IIINSUR = 'HEALTH INSURANCE - IMPUTATION INDICATOR'
   IRSOC1  = 'RECEIVED INCOME FROM SS/RR - IMPUTATION'
   IISOC1  = 'RECEIVED INCOME FR SS/RR - IMPUTATION IN'
   IRSSI1  = 'RECEIVED INCOME FROM SSI - IMPUTATION RE'
   IISSI1  = 'RECEIVED INCOME FROM SSI - IMPUTATION IN'
   IRPUB1  = 'RESP RECEIVE PUBLIC ASSIST/WELFARE IMPUT'
   IIPUB1  = 'RESP RECEIVE PUBLIC ASSIST/WELFARE IMPUT'
   IRAFDC  = 'ANY FAMILY MEMBER RECEIVED AFDC OR ADC -'
   IIAFDC  = 'ANY FAMILY MEMBER RECEIVED AFDC OR ADC -'
   IRINT1  = 'RECEIVED INTEREST - IMPUTATION REVISED'
   IIINT1  = 'RECEIVED INTEREST - IMPUTATION INDICATOR'
   IRCHD1  = 'RECEIVED CHILD SUPPORT - IMPUTATION REVI'
   IICHD1  = 'RECEIVED FROM CHILD SUPPORT - IMPUTATION'
   IROTH1  = 'RECEIVED OTHER SOURCES - IMPUTATION REVI'
   IIOTH1  = 'RECVD INCOME FR OTHR SOURCS - IMPUTATION'
   IRFSTAMP= 'YOU OR FAMILY HERE RECEIVED FD STAMPS -'
   IIFSTAMP= 'YOU OR FAMILY HERE RECEIVED FD STAMPS -'
   IRPINC1 = 'TOTAL PERSONAL INCOME - IMPUTATION REVIS'
   IIPINC1 = 'TOTAL PERSONAL INCOME - IMPUTATION INDIC'
   IRFINC1 = 'TOTAL FAMILY INCOME - IMPUTATION REVISED'
   IIFINC1 = 'TOTAL FAMILY INCOME - IMPUTATION INDICAT'
   IRSOC2  = 'OTHR FAM RECVD INCOME FR SS/RR - IMPUT.'
   IISOC2  = 'OTHR FAM RECVED INCOME FR SS/RR - IMPUT.'
   IRSSI2  = 'OTHR FAM RECVD INCOME FR SSI - IMPUT. RE'
   IISSI2  = 'OTHR FAM RECVED FROM SSI - IMPUTATION IN'
   IRPUB2  = 'FAMLY RECEIVE PUBLIC ASSIST/WELFARE IMPU'
   IIPUB2  = 'FAMLY RECEIVE PUBLIC ASSIST/WELFARE IMPU'
   IRINT2  = 'OTHR FAM RECVD INTEREST - IMPUTATION REV'
   IIINT2  = 'OTHR FAM RECVD INTEREST - IMPUTATION IND'
   IRCHD2  = 'OTHR FAM RECVED CHILD SUPPORT - IMPUTATI'
   IICHD2  = 'OTHR FAM RECVD FR CHILD SUPPORT - IMPUT.'
   IROTH2  = 'OTHR FAM RECVD OTHR SOURCES - IMPUTATION'
   IIOTH2  = 'OTHR FAM RECVD OTHR SOURCES - IMPUTATION'
   IRPEOP  = 'TOTAL NUMBER OF PEOPLE IN A HOUSEHOLD'
   IRKIDS  = 'TOT NUM OF CHILDREN (UNDER 12 YRS) IN A'
   PARSTAT = 'RESPONDENT''S NUMBER OF CHILDREN'
   FEMBABY = 'RESP IS FEMALE WITH CHILDREN 1 YEAR OLD'
   FEMKIDS = 'RESP IS FEMALE WITH CHILDREN 17 YEARS OL'
   MALEBABY= 'RESP IS MALE WITH CHILDREN 1 YEAR OLD OR'
   MALEKIDS= 'RESP IS MALE WITH CHILDREN 17 YEARS OLD'
   F15_44  = 'FEMALES AGE 15-44'
   M15_44  = 'MALES AGE 15-44'
   PREG    = 'PREGNANT FEMALES AGE 12-44 - RECODED PRE'
   PREG2   = 'PREGNANCY STATUS OF FEMALES AGE 12-44'
   TRIMEST = 'CURRENT TRIMESTER OF PREGNANCY - FEMALES'
   INDCAT  = 'TOTAL PERSONAL INCOME RECODE (13 CATEGS.'
   PERINC  = 'TOTAL PERSONAL INCOME RECODE (5 CATEGORI'
   PERINC2 = 'TOTAL PERSONAL INCOME RECODE (7 CATEGORI'
   PERINC3 = 'TOTAL PERSONAL INCOME RECODE (8 CATEGORI'
   TOTCAT  = 'TOTAL FAMILY INCOME RECODE (13 CATEGORIE'
   FAMINC  = 'TOTAL FAMILY INCOME RECODE (5 CATEGORIES'
   FAMINC2 = 'TOTAL FAMILY INCOME RECODE (7 CATEGORIES'
   FAMINC3 = 'TOTAL FAMILY INCOME RECODE (8 CATEGORIES'
   WELFARE = 'ANY FAMILY MEMBER ON WELFARE IN PAST 12'
   NEEDLREC= 'MOST RECENT TIME USED COC/HER/STM WITH A'
   NEDFLAG4= 'NEEDLE USE (ANY DRUG) - EVER USE'
   NEDYR4  = 'NEEDLE USE WITH COC/HER/STM - PAST YEAR'
   WITHDRW = 'TOTAL SCORE FOR WITHDRAWN'
   SOMCOM  = 'TOTAL SCORE FOR SOMATIC COMPLAINTS'
   ANXDEP  = 'TOTAL SCORE FOR ANXIOUS/DEPRESSED'
   SOCPROB = 'TOTAL SCORE FOR SOCIAL PROBLEMS'
   THPROB  = 'TOTAL SCORE FOR THOUGHT PROBLEMS'
   ATTPROB = 'TOTAL SCORE FOR ATTENTION PROBLEMS'
   DELBEH  = 'TOTAL SCORE FOR DELINQUENT BEHAVIOR'
   AGGBEH  = 'TOTAL SCORE FOR AGGRESSIVE BEHAVIOR'
   WITHDRWT= 'T SCORE FOR WITHDRAWN'
   SOMCOMT = 'T SCORE FOR SOMATIC COMPLAINTS'
   ANXDEPT = 'T SCORE FOR ANXIOUS/DEPRESSED'
   SOCPROBT= 'T SCORE FOR SOCIAL PROBLEMS'
   THPROBT = 'T SCORE FOR THOUGHT PROBLEMS'
   ATTPROBT= 'T SCORE FOR ATTENTION PROBLEMS'
   DELBEHT = 'T SCORE FOR DELINQUENT BEHAVIOR'
   AGGBEHT = 'T SCORE FOR AGGRESSIVE BEHAVIOR'
   SXHIVLF = 'EVER TESTED FOR HIV'
   SXHIVYR = 'TESTED FOR HIV IN PAST YEAR'
   SXREL   = 'SEXUAL RELATNSHIPS (EXCL MARITAL STATUS)'
   SXRELMAR= 'SEXUAL RELATNSHIPS (INCL MARITAL STATUS)'
   SXCONDYR= 'PAST YR CONDOM USE, INDEP OF RISK & PART'
   SXRSKANY= 'ANY OF 5 HIGHER-RISK SEX BEHAVIORS IN PA'
   SXRSKCNT= '# OF 5 HIGHER-RISK SEX BEHAVIORS IN PAST'
   SXDRANY = 'ANY OF 7 DRUG & SEX RISK BEHAVIORS IN PA'
   SXDRCNT = '# OF 7 DRUG & SEX RISK BEHAVIORS IN PAST'
   MDESFS1 = 'MAJOR DEPRESSIVE EPISODE SHORT FORM SCOR'
   MDESFS3 = 'MAJOR DEPRESSIVE EPISODE SHORT FORM SCOR'
   PROBMDE1= 'PROBABILITY OF CASENESS FOR MDE VERSION'
   PROBMDE3= 'PROBABILITY OF CASENESS FOR MDE VERSION'
   MDE1    = 'MAJOR DEPRESSIVE EPISODE VERSION 1'
   MDE3    = 'MAJOR DEPRESSIVE EPISODE VERSION 2'
   GADSFS1 = 'GENERAL ANXIETY DISORDER SHORT FORM SCOR'
   GADSFS3 = 'GENERAL ANXIETY DISORDER SHORT FORM SCOR'
   PROBGAD1= 'PROBABILITY OF CASENESS FOR GAD VERSION'
   PROBGAD3= 'PROBABILITY OF CASENESS FOR GAD VERSION'
   GAD1    = 'GENERAL ANXIETY DISORDER VERSION 1'
   GAD3    = 'GENERAL ANXIETY DISORDER VERSION 2'
   AGPSFS1 = 'AGORAPHOBIA SHORT FORM SCORE 1'
   AGPSFS3 = 'AGORAPHOBIA SHORT FORM SCORE 2'
   PROBAGP1= 'PROB. OF CASENESS FOR AGORA VERSION 1'
   PROBAGP3= 'PROB. OF CASENESS FOR AGORA VERSION 2'
   AGP1    = 'AGORAPHOBIA VERSION 1'
   AGP3    = 'AGORAPHOBIA VERSION 2'
   PASFS1  = 'PANIC ATTACK SHORT FORM SCORE 1'
   PASFS3  = 'PANIC ATTACK SHORT FORM SCORE 2'
   PROBPA1 = 'PROB. OF CASENESS FOR PANIC VERSION 1'
   PROBPA3 = 'PROB. OF CASENESS FOR PANIC VERSION 2'
   PA1     = 'PANIC ATTACK VERSION 1'
   PA3     = 'PANIC ATTACK VERSION 2'
   BHOUR   = 'BEGINNING HOUR OF INTERVIEW'
   BMIN    = 'BEGINNING MINUTE OF INTERVIEW'
   BAP     = 'BEGINNING TIME OF INTERVIEW - AM/PM INDI'
   EAP     = 'AM OR PM WHEN INTERVIEW WAS FINISHED'
   LANGVER = 'LANGUAGE VERSION'
   UNDINT  = 'ESTIMATE RESPONDENT''S UNDERSTANDING OF'
   COOPINT = 'COOPERATION OF RESPONDENT'
   PRIVACY = 'SCALE FOR PRIVACY DURING INTERVIEW'
   PPRES   = 'PARENT(S)'
   SPRES   = 'SPOUSE'
   PARPRES = 'LIVE-IN PARTNER/BOYFRIEND/GIRLFRIEND'
   OARPRES = 'OTHER ADULT RELATIVE(S)'
   OAPRES  = 'OTHER ADULT(S)'
   CPRES   = 'CHILD(REN) UNDER 15'
   OPRESNSP= 'OTHER (PEOPLE PRESENT/LISTENING DURING I'
   OPRESSPA= 'OTHER PERSON PRESENT DURING INTERVIEW -'
   OPRESSPB= 'OTHER PERSON PRESENT DURING INTERVIEW -'
   WHOMARKD= 'WHO MARKED ANSWERS ON ANSWER SHEET'
   QUARTER = 'QUARTER INDICATOR'
   FAMSKIP = 'OTHER FAMILY MEMBERS IN THE HH INDICATOR'
   GQTYPE  = 'TYPE OF GROUP QUARTERS'
   PDEN    = 'POPULATION DENSITY'
   PDEN2   = 'POPULATION DENSITY - FIVE LEVELS'
   REGION  = 'CENSUS REGION'
   DIVISION= 'CENSUS DIVISION CODE'
   ANALWT  = 'FINAL PERSON-LEVEL SAMPLE WEIGHT, = (WT1'
   ANALWT1 = 'ANALYSIS WEIGHT FOR QUARTER 1'
   ANALWT2 = 'ANALYSIS WEIGHT FOR QUARTER 2'
   ANALWT3 = 'ANALYSIS WEIGHT FOR QUARTER 3'
   ANALWT4 = 'ANALYSIS WEIGHT FOR QUARTER 4'
   WT1     = 'PSU WEIGHT'
   WT2     = 'SEGMENT WEIGHT'
   WT3     = 'QUARTER SEGMENT WEIGHT ADJUSTMENT'
   WT4     = 'SUBSEGMENTATION INFLATION WEIGHT'
   WT5     = 'LISTING UNIT WEIGHT'
   WT6     = 'DU POST STRATIFICATION ADJUSTMENT'
   WT7     = 'DU NONRESPONSE ADJUSTMENT'
   WT8     = 'INVERSE OF THE PROB OF SELECTION PERSON'
   WT9     = 'INVERSE OF THE PROB OF SELECT WITHIN AGE'
   WT10    = 'PERSON WEIGHT TRIMMING ADJUSTMENT'
   WT11    = 'PERSON NONRESPONSE/ROSTER ADJUSTMENT'
   WT12    = 'PERSON POST-STRATIFICATION'
   RURORURB= 'RURAL OR URBAN SEGMENT'
   INTMONTH= 'EDITED INTERVIEW MONTH'
   RELINTHH= 'OTHER PERSON INTERVIEWED IN THIS HOUSEH'
   MJTOT3  = '# DAYS USED MARIJUANA IN LIFE'
   COCTOT3 = '# DAYS USED COCAINE IN LIFE'
   ALCDAYS2= '# DAYS DRANK ALCOHOL IN PAST 30'
   AGECAT4 = 'AGE CATEGORIZED: 2 LEVELS'
   MJDY30A3= '# DAYS USED MARIJUANA IN PAST 30'
   ALCDAYS3= '# DAYS DRANK ALCOHOL IN PAST 30'
   DRINKER2= 'DRANK ALCOHOL - PST 3O DAYS'
   HVYDRK3 = 'DRANK ALCOHOL HEAVILY-PST 30 DAYS: 0,1'
   AVCIG2  = '# CIG. SMOKED PER DAY LAST 30'
   RACESEX = 'RACE AND SEX COMBINED'
   NOTMARJ = 'DRUG USE OTHER THAN MARIJUANA-PAST MONTH'
   BINGDRK2= 'BINGE ALCOHOL USE-PST 30 DAYS'
   RACESEX2= 'RACE AND SEX COMBINED - ADDITIONAL VAR'
   IRBTCIG2= 'RECODED BTOLCIG'
   IRBTALC2= 'RECODED BTOLALC'
   IRBTMRJ2= 'RECODED BTOLMRJ'
   IRBTCOC2= 'RECODED BTOLCOC'
   IRGRCIG2= 'RECODED GRTMCIG'
   IRGRALC2= 'RECODED GRTMALC'
   IRGRMRJ2= 'RECODED GRTMMRJ'
   IRGRCOC2= 'RECODED GRTMCOC'
   IRLACIG2= 'RECODED LAMTCIG'
   IRLAALC2= 'RECODED LAMTALC'
   IRLAMRJ2= 'RECODED LAMTMRJ'
   IRLACOC2= 'RECODED LAMTCOC'
   IRACCIG2= 'RECODED ACRDCIG'
   IRACALC2= 'RECODED ACRDALC'
   IRACMRJ2= 'RECODED ACRDMRJ'
   IRACCOC2= 'RECODED ACRDCOC'
   IREMCIG2= 'RECODED EMPBCIG'
   IREMALC2= 'RECODED EMPBALC'
   IREMMRJ2= 'RECODED EMPBMRJ'
   IREMCOC2= 'RECODED EMPBCOC'
   IRHLCIG2= 'RECODED HLPBCIG'
   IRHLALC2= 'RECODED HLPBALC'
   IRHLMRJ2= 'RECODED HLPBMRJ'
   IRHLCOC2= 'RECODED HLPBCOC'
   IRUCCIG2= 'RECODED UCDCIG'
   IRUCALC2= 'RECODED UCDALC'
   IRUCMRJ2= 'RECODED UCDMRJ'
   IRUCCOC2= 'RECODED UCDCOC'
   AVCIG3  = 'RECODED AVCIG'
   ALCPROBS= 'ANY PROBS DUE TO ALCOHOL'
   MJPROBS = 'ANY PROBS DUE TO MARIJUANA'
   COCPROBS= 'ANY PROBS DUE TO COCAINE'
   CIGPROBS= 'ANY PROBS DUE TO CIGARETTES'
   MRJ2PROB= 'ANY 2 PROBS DUE TO MARIJUANA'
   MRJ3PROB= 'ANY 3 PROBS DUE TO MARIJUANA'
   COC2PROB= 'ANY 2 PROBS DUE TO COCAINE'
   COC3PROB= 'ANY 3 PROBS DUE TO COCAINE'
   CIG2PROB= 'ANY 2 PROBS DUE TO CIGARETTES'
   CIG3PROB= 'ANY 3 PROBS DUE TO CIGARETTES'
   ALC2PROB= 'ANY 2 PROBS DUE TO ALCOHOL'
   ALC3PROB= 'ANY 3 PROBS DUE TO ALCOHOL'
   CIGTRY2 = 'AGE FIRST TRIED A CIGARETTE'
   ALCTRY2 = 'AGE HAD FIRST DRINK OF ALCOHOL'
   MJAGE2  = 'AGE FIRST USED MARIJUANA'
   INHAGE2 = 'AGE FIRST SNIFFED INHALANT'
   COCAGE2 = 'AGE FIRST USED COCAINE'
   HALLAGE2= 'AGE FIRST USED HALLUCINOGENS'
   HERAGE2 = 'AGE FIRST USED HEROIN'
   STIMAGE2= 'AGE FIRST USED STIMULANT NON-MED'
   SEDAGE2 = 'AGE FIRST USED SEDATIVE NON-MED'
   TRANAGE2= 'AGE FIRST USED TRANQUILIZER NON-MED'
   ANALAGE2= 'AGE FIRST USED ANALGESICS NON-MED'
   ALCONLYL= 'ONLY ALCOHOL - EVER USED'
   ALCONLYY= 'ONLY ALCOHOL - PAST YEAR USE'
   ALCONLYM= 'ONLY ALCOHOL - PAST MONTH USE'
   ILLONLYL= 'ONLY ILLICIT DRUGS - EVER USED'
   ILLONLYY= 'ONLY ILLICIT DRUGS - PAST YEAR USE'
   ILLONLYM= 'ONLY ILLICIT DRUGS - PAST MONTH USE'
   MRJONLYL= 'ONLY MARIJUANA - EVER USED'
   MRJONLYY= 'ONLY MARIJUANA - PAST YEAR USE'
   MRJONLYM= 'ONLY MARIJUANA - PAST MONTH USE'
   PSYONLYL= 'ONLY PSYCHOTHERAPEUTICS - EVER USED'
   PSYONLYY= 'ONLY PSYCHOTHERAPEUTICS - PAST YR USE'
   PSYONLYM= 'ONLY PSYCHOTHEARPEUTICS - PAST MON USE'
   OTHONLYL= 'ONLY OTHER DRUG COMB. - EVER USED'
   OTHONLYY= 'ONLY OTHER DRUG COMB. - PAST YEAR USE'
   OTHONLYM= 'ONLY OTHER DRUG COMB. - PAST MONTH USE'
   ALCILLL = 'ALCOHOL & ILLICIT DRUGS - EVER USED'
   ALCILLY = 'ALCOHOL & ILLICIT DRUGS - PAST YEAR USE'
   ALCILLM = 'ALCOHOL & ILLICIT DRUGS - PAST MONTH USE'
   ALCMRJL = 'ALCOHOL & MARIJUANA - EVER USED'
   ALCMRJY = 'ALCOHOL & MARIJUANA - PAST YEAR USE'
   ALCMRJM = 'ALCOHOL & MARIJUANA - PAST MONTH USE'
   ALCPSYL = 'ALCOHOL & PSYCHOTHERAPEUTICS - EVER USED'
   ALCPSYY = 'ALCOHOL & PSYCHOTHERAPEUTICS - PAST YR'
   ALCPSYM = 'ALCOHOL & PSYCHOTHEARPEUTICS - PAST MON'
   ALCOTHL = 'ALCOHOL & OTHER DRUG COMB. - EVER USED'
   ALCOTHY = 'ALCOHOL & OTHER DRUG COMB. - PAST YR'
   ALCOTHM = 'ALCOHOL & OTHER DRUG COMB. - PAST MON'
   SUB1LIF = 'USED ONLY 1 SUBSTANCE - EVER'
   SUB2LIF = 'USED ONLY 2 SUBSTANCES - EVER'
   SUB3LIF = 'USED 3 OR MORE SUBSTANCES - EVER'
   SUB1YR  = 'USED ONLY 1 SUBSTANCE - PAST YEAR'
   SUB2YR  = 'USED ONLY 2 SUBSTANCES - PAST YEAR'
   SUB3YR  = 'USE 3 OR MORE SUBSTANCES - PAST YEAR'
   SUB1MON = 'USED ONLY 1 SUBSTANCE - PAST MONTH'
   SUB2MON = 'USED ONLY 2 SBUSTANCES - PAST MONTH'
   SUB3MON = 'USED 3 OR MORE SUBSTANCES - PAST MONTH'
   PSYAGE  = 'AGE FIRST USED PSYCHOTHERAPEUTICS'
   TRMTHLP2= 'TREATMENT RECEIVED FOR DRUGS - RECODE'
   DRNKHLP2= 'TREATMENT RECEIVED FOR ALCOHOL - RECODE'
   DRALHELP= 'TREATMENT RECEIVED FOR DRUGS OR ALCOHOL'
   BKLARCN2= 'ARRSTD& BKED FOR LARCENY/THEFT PAST YR'
   BKBURGL2= 'ARRSTD& BKED FOR BURGLARY/B&E PAST YR'
   BKAGASL2= 'ARRSTD& BKED FOR AGGRAV.ASSAULT PAST YR'
   BKSMASL2= 'ARRSTD& BKED FOR OTHER ASSAULT PAST YR'
   BKMVTHF2= 'ARRSTD& BKED FOR MOTOR VEHICLE THFT PAST'
   BKROB2  = 'ARRSTD& BKED FOR ROBBERY PAST YR'
   BKRAPE2 = 'ARRSTD& BKED FOR FORCIBLE RAPE PAST YR'
   BKMURDE2= 'ARRSTD& BKED FOR MURDER/HOM/MNSLGTR PAST'
   BKARSON2= 'ARRSTD& BKED FOR ARSON PAST YR'
   BKDRVIN2= 'ARRSTD& BKED FOR DUI PAST YR'
   BKDRUNK2= 'ARRSTD& BKED FOR DRNKNSS/LIQ LAW PAST YR'
   BKDRUG2 = 'ARRSTD& BKED FOR POSS/SALE DRUGS PST YR'
   BKPROS2 = 'ARRSTD& BKED FOR PROSTITUTION PAST YR'
   DRUNKYR2= 'DRUNK 51+ DAYS IN PAST YEAR'
   FERTAGE = 'FERTILITY AGE -WOMEN:1=15-25 2=26-44'
   PREG3   = 'PREGNANCY STATUS OF WOMEN AGE 15-44'
   TRIMEST2= 'CURR TRIMEST OF PREG -WOMEN AGE 15-44'
   RSKCIG  = 'GREAT RISK: SMOKE 1+ PACKS CIGS/DAY'
   RSKMJ1  = 'GREAT RISK:USE MRJ ONCE A MONTH'
   RSKMJ2  = 'GREAT RISK:USE MRJ 1-2 TIMES/WEEK'
   RSKCOC1 = 'GREAT RISK:USE COC ONCE A MONTH'
   RSKCOC2 = 'GREAT RISK:USE COC 1-2 TIMES/WEEK'
   RSKALC1 = 'GREAT RISK:4-5 DRINKS NEARLY EVERYDAY'
   RSKALC2 = 'GREAT RISK:5+ DRINKS 1-2 TIMES/WEEK'
   MARUSE  = 'MARIJ- FREQUENCY OF USE IN PST YEAR'
   COCUSE  = 'COCAINE- FREQUENCY OF USE IN PST YEAR'
   ALCUSE  = 'ALCOHOL- FREQUENCY OF USE IN PST YEAR'
   TOTPROB = 'TOTAL SCORE-TOTAL PSYCHOSOC PROB SCALE'
   INT     = 'TOTAL SCORE FOR EMOTIONAL PROBLEM SCALE'
   EXT     = 'TOTAL SCORE FOR BEHAVIORAL PROBLEM SCALE'
   PR_EMOT = 'EMOTIONAL PROB-MENTAL HEALTH RECODE'
   PR_BEHAV= 'BEHAVIORAL PROB-MENTAL HEALTH RECODE'
   PR_TOTAL= 'TOTAL PSYCHOSOCIAL PROB-MH RECODE'
   PR_WD   = 'WITHDRAWN-MENTAL HEALTH RECODE'
   PR_SC   = 'SOMATIC COMPLAINTS-MENTAL HEALTH RECODE'
   PR_AD   = 'ANXIOUS/DEPRESSED-MENTAL HEALTH RECODE'
   PR_SP   = 'SOCIAL PROBLEM-MENTAL HEALTH RECODE'
   PR_TP   = 'THOUGHT PROBLEM-MENTAL HEALTH RECODE'
   PR_AP   = 'ATTENTION PROBLEM-MENTAL HEALTH RECODE'
   PR_DB   = 'DELINQUENT BEHAV-MENTAL HEALTH RECODE'
   PR_AB   = 'AGGRESSIVE BEHAV-MENTAL HEALTH RECODE'
   ANY4MENT= 'Recode Any 1 of 4 MH Illness for adults'
   ALCDRIV = 'DROVE W/IN 2HRS OF DRINKING,PAST YR'
   MRJDRIV = 'DROVE W/IN 2HRS OF USING MRJ,PAST YR'
   AGECAT3 = 'AGE CATEGORIZED: 11 LEVELS'
   DRUNKYR3= 'Drunk/High 3+ days in past year'
   HERNEED2= 'INJECTED HEROIN EVER'
   RSKSELL2= 'SOMEONE APPROACH TO SELL DRUGS PST MON'
   SEXYR   = 'SEXUALLY ACTIVE IN PAST 12 MOS'
   RELNOW  = 'CURRENTLY IN ONGOING RELA-SHIP'
   HIVTEST = 'EVER HAD BLOOD TEST FOR HIV'
   CDALWAYS= 'ALWAYS USED CONDOMS PAST YR'
   CDSOME  = 'SOMETIMES USED CONDOMS PAST YR'
   CDNEVER = 'NEVER USED CONDOMS PAST YR'
   YRDIFPP1= '1 SEX PARTNER PAST 12 MOS'
   YRDIFPP2= '2+ SEX PARTNERS PAST 12 MOS'
   EHOUR   = 'HOUR WHEN INTERVIEW WAS FINISHED'
   EMIN    = 'MINUTE WHEN INTERVIEW WAS FINISHED'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (VESTR >= 9981) THEN VESTR = .;
   IF (SKPMARTL = 9) THEN SKPMARTL = .;
   IF (MARITAL >= 81) THEN MARITAL = .;
   IF (NOMARR >= 81) THEN NOMARR = .;
   IF (SKPMILT = 9) THEN SKPMILT = .;
   IF (SERVICE >= 81) THEN SERVICE = .;
   IF (MILSTAT >= 81) THEN MILSTAT = .;
   IF (EDUC >= 81) THEN EDUC = .;
   IF (DIPLOMA >= 81) THEN DIPLOMA = .;
   IF (ENROLLD >= 81) THEN ENROLLD = .;
   IF (WORKSTAT >= 81) THEN WORKSTAT = .;
   IF (HTININCH >= 981) THEN HTININCH = .;
   IF (POUNDS >= 981) THEN POUNDS = .;
   IF (HEALTH >= 81) THEN HEALTH = .;
   IF (CIGEVER >= 81) THEN CIGEVER = .;
   IF (CIGTRY >= 981) THEN CIGTRY = .;
   IF (CIGTOT >= 81) THEN CIGTOT = .;
   IF (CIGREC >= 81) THEN CIGREC = .;
   IF (CIG30USE >= 81) THEN CIG30USE = .;
   IF (AVCIG >= 81) THEN AVCIG = .;
   IF (CIG30WOK >= 81) THEN CIG30WOK = .;
   IF (CIGEVYDA >= 81) THEN CIGEVYDA = .;
   IF (CIGAGE >= 981) THEN CIGAGE = .;
   IF (CIGYRS >= 981) THEN CIGYRS = .;
   IF (SNUFEVER >= 81) THEN SNUFEVER = .;
   IF (SNUFREC >= 81) THEN SNUFREC = .;
   IF (SKPALCRD >= 81) THEN SKPALCRD = .;
   IF (ALCREAD >= 81) THEN ALCREAD = .;
   IF (ALCEVER = 9) THEN ALCEVER = .;
   IF (ALCTRY >= 981) THEN ALCTRY = .;
   IF (ALCREC >= 81) THEN ALCREC = .;
   IF (ALCPAT >= 81) THEN ALCPAT = .;
   IF (DRUNKYR >= 81) THEN DRUNKYR = .;
   IF (ALCDAYS >= 81) THEN ALCDAYS = .;
   IF (NODR30A >= 81) THEN NODR30A = .;
   IF (DR5DAY >= 81) THEN DR5DAY = .;
   IF (MJEVER = 9) THEN MJEVER = .;
   IF (MJAGE >= 981) THEN MJAGE = .;
   IF (MJTOT >= 81) THEN MJTOT = .;
   IF (MJREC >= 81) THEN MJREC = .;
   IF (MJYRFREQ >= 81) THEN MJYRFREQ = .;
   IF (MJDAY30A >= 81) THEN MJDAY30A = .;
   IF (SKPCOCRD >= 81) THEN SKPCOCRD = .;
   IF (COCREAD >= 81) THEN COCREAD = .;
   IF (COCEVER = 9) THEN COCEVER = .;
   IF (COCAGE >= 981) THEN COCAGE = .;
   IF (COCTOT >= 81) THEN COCTOT = .;
   IF (COCREC >= 81) THEN COCREC = .;
   IF (COCYRFRQ >= 81) THEN COCYRFRQ = .;
   IF (COCUS30A >= 81) THEN COCUS30A = .;
   IF (SKPCRKRD >= 81) THEN SKPCRKRD = .;
   IF (CRKREAD >= 81) THEN CRKREAD = .;
   IF (CRKEVER >= 81) THEN CRKEVER = .;
   IF (CRKAGE >= 981) THEN CRKAGE = .;
   IF (CRKTOT >= 81) THEN CRKTOT = .;
   IF (CRAKREC >= 81) THEN CRAKREC = .;
   IF (CRKYRFRQ >= 81) THEN CRKYRFRQ = .;
   IF (CRKUS30A >= 81) THEN CRKUS30A = .;
   IF (SKPHERRD >= 81) THEN SKPHERRD = .;
   IF (HERREAD >= 81) THEN HERREAD = .;
   IF (HEREVER >= 81) THEN HEREVER = .;
   IF (HERAGE >= 981) THEN HERAGE = .;
   IF (HERTOT >= 81) THEN HERTOT = .;
   IF (HERREC >= 81) THEN HERREC = .;
   IF (HERYRFRQ >= 81) THEN HERYRFRQ = .;
   IF (HER30USE >= 81) THEN HER30USE = .;
   IF (SKPHALRD >= 81) THEN SKPHALRD = .;
   IF (HALREAD >= 81) THEN HALREAD = .;
   IF (LSD >= 81) THEN LSD = .;
   IF (PCP >= 81) THEN PCP = .;
   IF (PEYOTE >= 81) THEN PEYOTE = .;
   IF (MESC >= 81) THEN MESC = .;
   IF (PSILCY >= 81) THEN PSILCY = .;
   IF (ECSTASY >= 81) THEN ECSTASY = .;
   IF (HALDKNAM >= 81) THEN HALDKNAM = .;
   IF (HALNOLST >= 81) THEN HALNOLST = .;
   IF (HALNEWA >= 9981) THEN HALNEWA = .;
   IF (HALNEWB >= 9981) THEN HALNEWB = .;
   IF (HALNEWC >= 9981) THEN HALNEWC = .;
   IF (HALNEWD >= 9981) THEN HALNEWD = .;
   IF (HALNEWE >= 9981) THEN HALNEWE = .;
   IF (HALLAGE >= 981) THEN HALLAGE = .;
   IF (HALLTOT >= 81) THEN HALLTOT = .;
   IF (HALLREC >= 81) THEN HALLREC = .;
   IF (HALYRFRQ >= 81) THEN HALYRFRQ = .;
   IF (HAL30USE >= 81) THEN HAL30USE = .;
   IF (LSDREC >= 81) THEN LSDREC = .;
   IF (PCPREC >= 81) THEN PCPREC = .;
   IF (SKPINHRD >= 81) THEN SKPINHRD = .;
   IF (INHREAD >= 81) THEN INHREAD = .;
   IF (AMYLNIT >= 81) THEN AMYLNIT = .;
   IF (CLEFLU >= 81) THEN CLEFLU = .;
   IF (GAS >= 81) THEN GAS = .;
   IF (GLUE >= 81) THEN GLUE = .;
   IF (ETHER >= 81) THEN ETHER = .;
   IF (SOLVENT >= 81) THEN SOLVENT = .;
   IF (LGAS >= 81) THEN LGAS = .;
   IF (NITOXID >= 81) THEN NITOXID = .;
   IF (SPPAINT >= 81) THEN SPPAINT = .;
   IF (AEROS >= 81) THEN AEROS = .;
   IF (INHDKNAM >= 81) THEN INHDKNAM = .;
   IF (INHNOLST >= 81) THEN INHNOLST = .;
   IF (INHNEWA >= 9981) THEN INHNEWA = .;
   IF (INHNEWB >= 9981) THEN INHNEWB = .;
   IF (INHNEWC >= 9981) THEN INHNEWC = .;
   IF (INHNEWD >= 9981) THEN INHNEWD = .;
   IF (INHNEWE >= 9981) THEN INHNEWE = .;
   IF (INHAGE >= 981) THEN INHAGE = .;
   IF (INHTOT >= 81) THEN INHTOT = .;
   IF (INHREC >= 81) THEN INHREC = .;
   IF (INHYRFRQ >= 81) THEN INHYRFRQ = .;
   IF (INHDY30A >= 81) THEN INHDY30A = .;
   IF (SKPANLRD >= 81) THEN SKPANLRD = .;
   IF (ANLREAD >= 81) THEN ANLREAD = .;
   IF (CODEINE >= 81) THEN CODEINE = .;
   IF (DARVON >= 81) THEN DARVON = .;
   IF (DEMEROL >= 81) THEN DEMEROL = .;
   IF (DILAUD >= 81) THEN DILAUD = .;
   IF (METHDON >= 81) THEN METHDON = .;
   IF (MORPHINE >= 81) THEN MORPHINE = .;
   IF (PERCODAN >= 81) THEN PERCODAN = .;
   IF (TALWIN >= 81) THEN TALWIN = .;
   IF (TYLCOD >= 81) THEN TYLCOD = .;
   IF (ANLDKNAM >= 81) THEN ANLDKNAM = .;
   IF (ANLNOLST >= 81) THEN ANLNOLST = .;
   IF (ANALNEWA >= 9981) THEN ANALNEWA = .;
   IF (ANALNEWB >= 9981) THEN ANALNEWB = .;
   IF (ANALNEWC >= 9981) THEN ANALNEWC = .;
   IF (ANALNEWD >= 9981) THEN ANALNEWD = .;
   IF (ANALNEWE >= 9981) THEN ANALNEWE = .;
   IF (ANALNONE >= 81) THEN ANALNONE = .;
   IF (ANALAGE >= 981) THEN ANALAGE = .;
   IF (ANALTOT >= 81) THEN ANALTOT = .;
   IF (ANALREC >= 81) THEN ANALREC = .;
   IF (ANLYRFRQ >= 81) THEN ANLYRFRQ = .;
   IF (SKPTRNRD >= 81) THEN SKPTRNRD = .;
   IF (TRNREAD >= 81) THEN TRNREAD = .;
   IF (ATARAX >= 81) THEN ATARAX = .;
   IF (ATIVAN >= 81) THEN ATIVAN = .;
   IF (DIAZEPAM >= 81) THEN DIAZEPAM = .;
   IF (LIBRIUM >= 81) THEN LIBRIUM = .;
   IF (TRANXENE >= 81) THEN TRANXENE = .;
   IF (VALIUM >= 81) THEN VALIUM = .;
   IF (XANAX >= 81) THEN XANAX = .;
   IF (TRDKNAM >= 81) THEN TRDKNAM = .;
   IF (TRNOLST >= 81) THEN TRNOLST = .;
   IF (TRNEWA >= 9981) THEN TRNEWA = .;
   IF (TRNEWB >= 9981) THEN TRNEWB = .;
   IF (TRNEWC >= 9981) THEN TRNEWC = .;
   IF (TRNEWD >= 9981) THEN TRNEWD = .;
   IF (TRNEWE >= 9981) THEN TRNEWE = .;
   IF (NOTRANQ >= 81) THEN NOTRANQ = .;
   IF (TRANAGE >= 981) THEN TRANAGE = .;
   IF (TRANTOT >= 81) THEN TRANTOT = .;
   IF (TRANREC >= 81) THEN TRANREC = .;
   IF (TRNYRFRQ >= 81) THEN TRNYRFRQ = .;
   IF (SKPSTMRD >= 81) THEN SKPSTMRD = .;
   IF (STMREAD >= 81) THEN STMREAD = .;
   IF (BENZ >= 81) THEN BENZ = .;
   IF (BIPHET >= 81) THEN BIPHET = .;
   IF (DEXAMYL >= 81) THEN DEXAMYL = .;
   IF (DEXED >= 81) THEN DEXED = .;
   IF (FASTIN >= 81) THEN FASTIN = .;
   IF (IONAMIN >= 81) THEN IONAMIN = .;
   IF (METHAMP >= 81) THEN METHAMP = .;
   IF (METHI >= 81) THEN METHI = .;
   IF (PRELUDIN >= 81) THEN PRELUDIN = .;
   IF (STMDKNAM >= 81) THEN STMDKNAM = .;
   IF (STMNOLST >= 81) THEN STMNOLST = .;
   IF (STIMNEWA >= 9981) THEN STIMNEWA = .;
   IF (STIMNEWB >= 9981) THEN STIMNEWB = .;
   IF (STIMNEWC >= 9981) THEN STIMNEWC = .;
   IF (STIMNEWD >= 9981) THEN STIMNEWD = .;
   IF (STIMNEWE >= 9981) THEN STIMNEWE = .;
   IF (NOSTIMS >= 81) THEN NOSTIMS = .;
   IF (STIMAGE >= 981) THEN STIMAGE = .;
   IF (STIMTOT >= 81) THEN STIMTOT = .;
   IF (STIMREC >= 81) THEN STIMREC = .;
   IF (STMYRFRQ >= 81) THEN STMYRFRQ = .;
   IF (SKPSEDRD >= 81) THEN SKPSEDRD = .;
   IF (SEDREAD >= 81) THEN SEDREAD = .;
   IF (DALMANE >= 81) THEN DALMANE = .;
   IF (HALCION >= 81) THEN HALCION = .;
   IF (METHAQ >= 81) THEN METHAQ = .;
   IF (NEMBUTAL >= 81) THEN NEMBUTAL = .;
   IF (PHENOBAR >= 81) THEN PHENOBAR = .;
   IF (PLACIDYL >= 81) THEN PLACIDYL = .;
   IF (SECONAL >= 81) THEN SECONAL = .;
   IF (TUINAL >= 81) THEN TUINAL = .;
   IF (SEDDKNAM >= 81) THEN SEDDKNAM = .;
   IF (SEDNOLST >= 81) THEN SEDNOLST = .;
   IF (SEDNEWA >= 9981) THEN SEDNEWA = .;
   IF (SEDNEWB >= 9981) THEN SEDNEWB = .;
   IF (SEDNEWC >= 9981) THEN SEDNEWC = .;
   IF (SEDNEWD >= 9981) THEN SEDNEWD = .;
   IF (SEDNEWE >= 9981) THEN SEDNEWE = .;
   IF (NOSEDAT >= 81) THEN NOSEDAT = .;
   IF (SEDAGE >= 981) THEN SEDAGE = .;
   IF (SEDTOT >= 81) THEN SEDTOT = .;
   IF (SEDREC >= 81) THEN SEDREC = .;
   IF (SEDYRFRQ >= 81) THEN SEDYRFRQ = .;
   IF (BIRMONTH >= 81) THEN BIRMONTH = .;
   IF (BIRYEAR >= 9981) THEN BIRYEAR = .;
   IF (IIAGE = 9) THEN IIAGE = .;
   IF (IRSEX = 9) THEN IRSEX = .;
   IF (IISEX = 9) THEN IISEX = .;
   IF (IRRACE = 9) THEN IRRACE = .;
   IF (IIRACE = 9) THEN IIRACE = .;
   IF (IRHOIND = 9) THEN IRHOIND = .;
   IF (IIHOIND = 9) THEN IIHOIND = .;
   IF (IRHOGRP >= 81) THEN IRHOGRP = .;
   IF (IIHOGRP = 9) THEN IIHOGRP = .;
   IF (IRHOGRP2 >= 81) THEN IRHOGRP2 = .;
   IF (IIHOGRP2 = 9) THEN IIHOGRP2 = .;
   IF (IRMARIT >= 81) THEN IRMARIT = .;
   IF (IIMARIT = 9) THEN IIMARIT = .;
   IF (IREDUC >= 81) THEN IREDUC = .;
   IF (IIEDUC = 9) THEN IIEDUC = .;
   IF (IRHSGRAD = 9) THEN IRHSGRAD = .;
   IF (IIHSGRAD = 9) THEN IIHSGRAD = .;
   IF (IRWORKST >= 81) THEN IRWORKST = .;
   IF (IIWORKST = 9) THEN IIWORKST = .;
   IF (IRCIGRC = 9) THEN IRCIGRC = .;
   IF (IICIGRC = 9) THEN IICIGRC = .;
   IF (IROTBRC = 9) THEN IROTBRC = .;
   IF (IIOTBRC = 9) THEN IIOTBRC = .;
   IF (IRALCRC = 9) THEN IRALCRC = .;
   IF (IIALCRC = 9) THEN IIALCRC = .;
   IF (IRMJRC = 9) THEN IRMJRC = .;
   IF (IIMJRC = 9) THEN IIMJRC = .;
   IF (IRCOCRC = 9) THEN IRCOCRC = .;
   IF (IICOCRC = 9) THEN IICOCRC = .;
   IF (IRCRKRC = 9) THEN IRCRKRC = .;
   IF (IICRKRC = 9) THEN IICRKRC = .;
   IF (IRHERRC = 9) THEN IRHERRC = .;
   IF (IIHERRC = 9) THEN IIHERRC = .;
   IF (IRHALRC = 9) THEN IRHALRC = .;
   IF (IIHALRC = 9) THEN IIHALRC = .;
   IF (IRLSDRC = 9) THEN IRLSDRC = .;
   IF (IILSDRC = 9) THEN IILSDRC = .;
   IF (IRPCPRC = 9) THEN IRPCPRC = .;
   IF (IIPCPRC = 9) THEN IIPCPRC = .;
   IF (IRINHRC = 9) THEN IRINHRC = .;
   IF (IIINHRC = 9) THEN IIINHRC = .;
   IF (IRANLRC = 9) THEN IRANLRC = .;
   IF (IIANLRC = 9) THEN IIANLRC = .;
   IF (IRTRNRC = 9) THEN IRTRNRC = .;
   IF (IITRNRC = 9) THEN IITRNRC = .;
   IF (IRSTMRC = 9) THEN IRSTMRC = .;
   IF (IISTMRC = 9) THEN IISTMRC = .;
   IF (IRSEDRC = 9) THEN IRSEDRC = .;
   IF (IISEDRC = 9) THEN IISEDRC = .;
   IF (IRALCFQ >= 81) THEN IRALCFQ = .;
   IF (IIALCFQ = 9) THEN IIALCFQ = .;
   IF (IRMJFQ >= 81) THEN IRMJFQ = .;
   IF (IIMJFQ = 9) THEN IIMJFQ = .;
   IF (IRCOCFQ >= 81) THEN IRCOCFQ = .;
   IF (IICOCFQ = 9) THEN IICOCFQ = .;
   IF (IRCRKFQ >= 81) THEN IRCRKFQ = .;
   IF (IICRKFQ = 9) THEN IICRKFQ = .;
   IF (IRHERFQ >= 81) THEN IRHERFQ = .;
   IF (IIHERFQ = 9) THEN IIHERFQ = .;
   IF (IRHALFQ >= 81) THEN IRHALFQ = .;
   IF (IIHALFQ = 9) THEN IIHALFQ = .;
   IF (IRINHFQ >= 81) THEN IRINHFQ = .;
   IF (IIINHFQ = 9) THEN IIINHFQ = .;
   IF (IRANLFQ >= 81) THEN IRANLFQ = .;
   IF (IIANLFQ = 9) THEN IIANLFQ = .;
   IF (IRTRNFQ >= 81) THEN IRTRNFQ = .;
   IF (IITRNFQ = 9) THEN IITRNFQ = .;
   IF (IRSTMFQ >= 81) THEN IRSTMFQ = .;
   IF (IISTMFQ = 9) THEN IISTMFQ = .;
   IF (IRSEDFQ >= 81) THEN IRSEDFQ = .;
   IF (IISEDFQ = 9) THEN IISEDFQ = .;
   IF (CATAGE = 9) THEN CATAGE = .;
   IF (CATAG2 = 9) THEN CATAG2 = .;
   IF (CATAG3 = 9) THEN CATAG3 = .;
   IF (RACE = 9) THEN RACE = .;
   IF (HISPRACE = 9) THEN HISPRACE = .;
   IF (EDUCCAT2 = 9) THEN EDUCCAT2 = .;
   IF (EMPSTAT2 = 9) THEN EMPSTAT2 = .;
   IF (MARISTAT = 9) THEN MARISTAT = .;
   IF (NOTMAR = 9) THEN NOTMAR = .;
   IF (CIGFLAG = 9) THEN CIGFLAG = .;
   IF (CIGYR = 9) THEN CIGYR = .;
   IF (CIGMON = 9) THEN CIGMON = .;
   IF (SMKFLAG = 9) THEN SMKFLAG = .;
   IF (SMKYR = 9) THEN SMKYR = .;
   IF (SMKMON = 9) THEN SMKMON = .;
   IF (ALCFLAG = 9) THEN ALCFLAG = .;
   IF (ALCYR = 9) THEN ALCYR = .;
   IF (ALCMON = 9) THEN ALCMON = .;
   IF (MRJFLAG = 9) THEN MRJFLAG = .;
   IF (MRJYR = 9) THEN MRJYR = .;
   IF (MRJMON = 9) THEN MRJMON = .;
   IF (COCFLAG = 9) THEN COCFLAG = .;
   IF (COCYR = 9) THEN COCYR = .;
   IF (COCMON = 9) THEN COCMON = .;
   IF (CRKFLAG = 9) THEN CRKFLAG = .;
   IF (CRKYR = 9) THEN CRKYR = .;
   IF (CRKMON = 9) THEN CRKMON = .;
   IF (HERFLAG = 9) THEN HERFLAG = .;
   IF (HERYR = 9) THEN HERYR = .;
   IF (HERMON = 9) THEN HERMON = .;
   IF (HALFLAG = 9) THEN HALFLAG = .;
   IF (HALYR = 9) THEN HALYR = .;
   IF (HALMON = 9) THEN HALMON = .;
   IF (LSDFLAG = 9) THEN LSDFLAG = .;
   IF (LSDYR = 9) THEN LSDYR = .;
   IF (LSDMON = 9) THEN LSDMON = .;
   IF (PCPFLAG = 9) THEN PCPFLAG = .;
   IF (PCPYR = 9) THEN PCPYR = .;
   IF (PCPMON = 9) THEN PCPMON = .;
   IF (INHFLAG = 9) THEN INHFLAG = .;
   IF (INHYR = 9) THEN INHYR = .;
   IF (INHMON = 9) THEN INHMON = .;
   IF (ANLFLAG = 9) THEN ANLFLAG = .;
   IF (ANLYR = 9) THEN ANLYR = .;
   IF (ANLMON = 9) THEN ANLMON = .;
   IF (TRQFLAG = 9) THEN TRQFLAG = .;
   IF (TRQYR = 9) THEN TRQYR = .;
   IF (TRQMON = 9) THEN TRQMON = .;
   IF (STMFLAG = 9) THEN STMFLAG = .;
   IF (STMYR = 9) THEN STMYR = .;
   IF (STMMON = 9) THEN STMMON = .;
   IF (SEDFLAG = 9) THEN SEDFLAG = .;
   IF (SEDYR = 9) THEN SEDYR = .;
   IF (SEDMON = 9) THEN SEDMON = .;
   IF (ALCYRF = 9) THEN ALCYRF = .;
   IF (ALCMONF = 9) THEN ALCMONF = .;
   IF (ALCWKF = 9) THEN ALCWKF = .;
   IF (ALCOCCF = 9) THEN ALCOCCF = .;
   IF (ALCDLYF = 9) THEN ALCDLYF = .;
   IF (MRJYRF = 9) THEN MRJYRF = .;
   IF (MRJMONF = 9) THEN MRJMONF = .;
   IF (MRJWKF = 9) THEN MRJWKF = .;
   IF (MRJOCCF = 9) THEN MRJOCCF = .;
   IF (MRJDLYF = 9) THEN MRJDLYF = .;
   IF (COCYRF = 9) THEN COCYRF = .;
   IF (COCMONF = 9) THEN COCMONF = .;
   IF (COCWKF = 9) THEN COCWKF = .;
   IF (COCOCCF = 9) THEN COCOCCF = .;
   IF (COCDLYF = 9) THEN COCDLYF = .;
   IF (CRKYRF = 9) THEN CRKYRF = .;
   IF (CRKMONF = 9) THEN CRKMONF = .;
   IF (CRKWKF = 9) THEN CRKWKF = .;
   IF (CRKOCCF = 9) THEN CRKOCCF = .;
   IF (CRKDLYF = 9) THEN CRKDLYF = .;
   IF (HERYRF = 9) THEN HERYRF = .;
   IF (HERMONF = 9) THEN HERMONF = .;
   IF (HERWKF = 9) THEN HERWKF = .;
   IF (HEROCCF = 9) THEN HEROCCF = .;
   IF (HERDLYF = 9) THEN HERDLYF = .;
   IF (HALYRF = 9) THEN HALYRF = .;
   IF (HALMONF = 9) THEN HALMONF = .;
   IF (HALWKF = 9) THEN HALWKF = .;
   IF (HALOCCF = 9) THEN HALOCCF = .;
   IF (HALDLYF = 9) THEN HALDLYF = .;
   IF (INHYRF = 9) THEN INHYRF = .;
   IF (INHMONF = 9) THEN INHMONF = .;
   IF (INHWKF = 9) THEN INHWKF = .;
   IF (INHOCCF = 9) THEN INHOCCF = .;
   IF (INHDLYF = 9) THEN INHDLYF = .;
   IF (ANLYRF = 9) THEN ANLYRF = .;
   IF (ANLMONF = 9) THEN ANLMONF = .;
   IF (ANLWKF = 9) THEN ANLWKF = .;
   IF (ANLOCCF = 9) THEN ANLOCCF = .;
   IF (ANLDLYF = 9) THEN ANLDLYF = .;
   IF (TRQYRF = 9) THEN TRQYRF = .;
   IF (TRQMONF = 9) THEN TRQMONF = .;
   IF (TRQWKF = 9) THEN TRQWKF = .;
   IF (TRQOCCF = 9) THEN TRQOCCF = .;
   IF (TRQDLYF = 9) THEN TRQDLYF = .;
   IF (STMYRF = 9) THEN STMYRF = .;
   IF (STMMONF = 9) THEN STMMONF = .;
   IF (STMWKF = 9) THEN STMWKF = .;
   IF (STMOCCF = 9) THEN STMOCCF = .;
   IF (STMDLYF = 9) THEN STMDLYF = .;
   IF (SEDYRF = 9) THEN SEDYRF = .;
   IF (SEDMONF = 9) THEN SEDMONF = .;
   IF (SEDWKF = 9) THEN SEDWKF = .;
   IF (SEDOCCF = 9) THEN SEDOCCF = .;
   IF (SEDDLYF = 9) THEN SEDDLYF = .;
   IF (PSYFLAG2 = 9) THEN PSYFLAG2 = .;
   IF (PSYYR2 = 9) THEN PSYYR2 = .;
   IF (PSYMON2 = 9) THEN PSYMON2 = .;
   IF (SUMFLAG = 9) THEN SUMFLAG = .;
   IF (SUMYR = 9) THEN SUMYR = .;
   IF (SUMMON = 9) THEN SUMMON = .;
   IF (MJOFLAG = 9) THEN MJOFLAG = .;
   IF (MJOYR2 = 9) THEN MJOYR2 = .;
   IF (MJOMON2 = 9) THEN MJOMON2 = .;
   IF (IEMFLAG = 9) THEN IEMFLAG = .;
   IF (IEMYR = 9) THEN IEMYR = .;
   IF (IEMMON = 9) THEN IEMMON = .;
   IF (BINGEDRK = 9) THEN BINGEDRK = .;
   IF (HVYDRK2 = 9) THEN HVYDRK2 = .;
   IF (BINGEHVY = 9) THEN BINGEHVY = .;
   IF (PEYOTE2 = 9) THEN PEYOTE2 = .;
   IF (MESC2 = 9) THEN MESC2 = .;
   IF (PSILCY2 = 9) THEN PSILCY2 = .;
   IF (ECSTASY2 = 9) THEN ECSTASY2 = .;
   IF (METHAMP2 = 9) THEN METHAMP2 = .;
   IF (HERSMOK2 = 9) THEN HERSMOK2 = .;
   IF (HERSNIF2 = 9) THEN HERSNIF2 = .;
   IF (AMYLNIT2 = 9) THEN AMYLNIT2 = .;
   IF (CLEFLU2 = 9) THEN CLEFLU2 = .;
   IF (GAS2 = 9) THEN GAS2 = .;
   IF (GLUE2 = 9) THEN GLUE2 = .;
   IF (ETHER2 = 9) THEN ETHER2 = .;
   IF (SOLVENT2 = 9) THEN SOLVENT2 = .;
   IF (LGAS2 = 9) THEN LGAS2 = .;
   IF (NITOXID2 = 9) THEN NITOXID2 = .;
   IF (SPPAINT2 = 9) THEN SPPAINT2 = .;
   IF (AEROS2 = 9) THEN AEROS2 = .;
   IF (CG04 >= 81) THEN CG04 = .;
   IF (CG12 >= 81) THEN CG12 = .;
   IF (AL03 >= 81) THEN AL03 = .;
   IF (AL04 >= 81) THEN AL04 = .;
   IF (MJ04 >= 81) THEN MJ04 = .;
   IF (MJ05 >= 81) THEN MJ05 = .;
   IF (CC04 >= 81) THEN CC04 = .;
   IF (CC05 >= 81) THEN CC05 = .;
   IF (CK04 >= 81) THEN CK04 = .;
   IF (CK05 >= 81) THEN CK05 = .;
   IF (HE04 >= 81) THEN HE04 = .;
   IF (HE05 >= 81) THEN HE05 = .;
   IF (LS04 >= 81) THEN LS04 = .;
   IF (LS05 >= 81) THEN LS05 = .;
   IF (LS07 >= 81) THEN LS07 = .;
   IF (LS08 >= 81) THEN LS08 = .;
   IF (IN04 >= 81) THEN IN04 = .;
   IF (IN05 >= 81) THEN IN05 = .;
   IF (PK04 >= 81) THEN PK04 = .;
   IF (PK05 >= 81) THEN PK05 = .;
   IF (TR04 >= 81) THEN TR04 = .;
   IF (TR05 >= 81) THEN TR05 = .;
   IF (ST04 >= 81) THEN ST04 = .;
   IF (ST05 >= 81) THEN ST05 = .;
   IF (SE04 >= 81) THEN SE04 = .;
   IF (SE05 >= 81) THEN SE05 = .;
   IF (SKPSDRD >= 81) THEN SKPSDRD = .;
   IF (SDREAD >= 81) THEN SDREAD = .;
   IF (HRANYFRM >= 81) THEN HRANYFRM = .;
   IF (HERSMOKE >= 81) THEN HERSMOKE = .;
   IF (HRSMKREC >= 81) THEN HRSMKREC = .;
   IF (HERSNIFF >= 81) THEN HERSNIFF = .;
   IF (HRSNFREC >= 81) THEN HRSNFREC = .;
   IF (GNNDLLIF >= 81) THEN GNNDLLIF = .;
   IF (COCNEEDL >= 81) THEN COCNEEDL = .;
   IF (CONDLREC >= 81) THEN CONDLREC = .;
   IF (HERNEEDL >= 81) THEN HERNEEDL = .;
   IF (HRNDLREC >= 81) THEN HRNDLREC = .;
   IF (STNEEDLE >= 81) THEN STNEEDLE = .;
   IF (STNDLREC >= 81) THEN STNDLREC = .;
   IF (GNNDREUS >= 81) THEN GNNDREUS = .;
   IF (GNNDLSH1 >= 81) THEN GNNDLSH1 = .;
   IF (GNNDCLEN >= 81) THEN GNNDCLEN = .;
   IF (GNNDLSH2 >= 81) THEN GNNDLSH2 = .;
   IF (GNNDGET >= 81) THEN GNNDGET = .;
   IF (GNNDGTSP >= 81) THEN GNNDGTSP = .;
   IF (SKPRSKRD >= 81) THEN SKPRSKRD = .;
   IF (RSKREAD >= 81) THEN RSKREAD = .;
   IF (RSKPKCIG >= 81) THEN RSKPKCIG = .;
   IF (RSKMJOCC >= 81) THEN RSKMJOCC = .;
   IF (RSKMJREG >= 81) THEN RSKMJREG = .;
   IF (RKCOCOCC >= 81) THEN RKCOCOCC = .;
   IF (RKCOCREG >= 81) THEN RKCOCREG = .;
   IF (RK5DRINK >= 81) THEN RK5DRINK = .;
   IF (RSKBINGE >= 81) THEN RSKBINGE = .;
   IF (RSKDIFMJ >= 81) THEN RSKDIFMJ = .;
   IF (RKDIFCOC >= 81) THEN RKDIFCOC = .;
   IF (RKDIFCRK >= 81) THEN RKDIFCRK = .;
   IF (RKDIFHER >= 81) THEN RKDIFHER = .;
   IF (RSKSELL >= 81) THEN RSKSELL = .;
   IF (SKPDRGRD >= 81) THEN SKPDRGRD = .;
   IF (DRGREAD >= 81) THEN DRGREAD = .;
   IF (USEDCIG >= 81) THEN USEDCIG = .;
   IF (USEDALC >= 81) THEN USEDALC = .;
   IF (USEDMRJ >= 81) THEN USEDMRJ = .;
   IF (USEDCOC >= 81) THEN USEDCOC = .;
   IF (USEDHER >= 81) THEN USEDHER = .;
   IF (USEDHAL >= 81) THEN USEDHAL = .;
   IF (USEDINH >= 81) THEN USEDINH = .;
   IF (USEDANL >= 81) THEN USEDANL = .;
   IF (USEDTRN >= 81) THEN USEDTRN = .;
   IF (USEDSTM >= 81) THEN USEDSTM = .;
   IF (USEDSED >= 81) THEN USEDSED = .;
   IF (NODRUGYR >= 81) THEN NODRUGYR = .;
   IF (GRTMCIG >= 81) THEN GRTMCIG = .;
   IF (GRTMALC >= 81) THEN GRTMALC = .;
   IF (GRTMMRJ >= 81) THEN GRTMMRJ = .;
   IF (GRTMCOC >= 81) THEN GRTMCOC = .;
   IF (GRTMHER >= 81) THEN GRTMHER = .;
   IF (GRTMHAL >= 81) THEN GRTMHAL = .;
   IF (GRTMINH >= 81) THEN GRTMINH = .;
   IF (GRTMANL >= 81) THEN GRTMANL = .;
   IF (GRTMTRN >= 81) THEN GRTMTRN = .;
   IF (GRTMSTM >= 81) THEN GRTMSTM = .;
   IF (GRTMSED >= 81) THEN GRTMSED = .;
   IF (LAMTCIG >= 81) THEN LAMTCIG = .;
   IF (LAMTALC >= 81) THEN LAMTALC = .;
   IF (LAMTMRJ >= 81) THEN LAMTMRJ = .;
   IF (LAMTCOC >= 81) THEN LAMTCOC = .;
   IF (LAMTHER >= 81) THEN LAMTHER = .;
   IF (LAMTHAL >= 81) THEN LAMTHAL = .;
   IF (LAMTINH >= 81) THEN LAMTINH = .;
   IF (LAMTANL >= 81) THEN LAMTANL = .;
   IF (LAMTTRN >= 81) THEN LAMTTRN = .;
   IF (LAMTSTM >= 81) THEN LAMTSTM = .;
   IF (LAMTSED >= 81) THEN LAMTSED = .;
   IF (BTOLCIG >= 81) THEN BTOLCIG = .;
   IF (BTOLALC >= 81) THEN BTOLALC = .;
   IF (BTOLMRJ >= 81) THEN BTOLMRJ = .;
   IF (BTOLCOC >= 81) THEN BTOLCOC = .;
   IF (BTOLHER >= 81) THEN BTOLHER = .;
   IF (BTOLHAL >= 81) THEN BTOLHAL = .;
   IF (BTOLINH >= 81) THEN BTOLINH = .;
   IF (BTOLANL >= 81) THEN BTOLANL = .;
   IF (BTOLTRN >= 81) THEN BTOLTRN = .;
   IF (BTOLSTM >= 81) THEN BTOLSTM = .;
   IF (BTOLSED >= 81) THEN BTOLSED = .;
   IF (ACRDCIG >= 81) THEN ACRDCIG = .;
   IF (ACRDALC >= 81) THEN ACRDALC = .;
   IF (ACRDMRJ >= 81) THEN ACRDMRJ = .;
   IF (ACRDCOC >= 81) THEN ACRDCOC = .;
   IF (ACRDHER >= 81) THEN ACRDHER = .;
   IF (ACRDHAL >= 81) THEN ACRDHAL = .;
   IF (ACRDINH >= 81) THEN ACRDINH = .;
   IF (ACRDANL >= 81) THEN ACRDANL = .;
   IF (ACRDTRN >= 81) THEN ACRDTRN = .;
   IF (ACRDSTM >= 81) THEN ACRDSTM = .;
   IF (ACRDSED >= 81) THEN ACRDSED = .;
   IF (EMPBCIG >= 81) THEN EMPBCIG = .;
   IF (EMPBALC >= 81) THEN EMPBALC = .;
   IF (EMPBMRJ >= 81) THEN EMPBMRJ = .;
   IF (EMPBCOC >= 81) THEN EMPBCOC = .;
   IF (EMPBHER >= 81) THEN EMPBHER = .;
   IF (EMPBHAL >= 81) THEN EMPBHAL = .;
   IF (EMPBINH >= 81) THEN EMPBINH = .;
   IF (EMPBANL >= 81) THEN EMPBANL = .;
   IF (EMPBTRN >= 81) THEN EMPBTRN = .;
   IF (EMPBSTM >= 81) THEN EMPBSTM = .;
   IF (EMPBSED >= 81) THEN EMPBSED = .;
   IF (HLPBCIG >= 81) THEN HLPBCIG = .;
   IF (HLPBALC >= 81) THEN HLPBALC = .;
   IF (HLPBMRJ >= 81) THEN HLPBMRJ = .;
   IF (HLPBCOC >= 81) THEN HLPBCOC = .;
   IF (HLPBHER >= 81) THEN HLPBHER = .;
   IF (HLPBHAL >= 81) THEN HLPBHAL = .;
   IF (HLPBINH >= 81) THEN HLPBINH = .;
   IF (HLPBANL >= 81) THEN HLPBANL = .;
   IF (HLPBTRN >= 81) THEN HLPBTRN = .;
   IF (HLPBSTM >= 81) THEN HLPBSTM = .;
   IF (HLPBSED >= 81) THEN HLPBSED = .;
   IF (UCDCIG >= 81) THEN UCDCIG = .;
   IF (UCDALC >= 81) THEN UCDALC = .;
   IF (UCDMRJ >= 81) THEN UCDMRJ = .;
   IF (UCDCOC >= 81) THEN UCDCOC = .;
   IF (UCDHER >= 81) THEN UCDHER = .;
   IF (UCDHAL >= 81) THEN UCDHAL = .;
   IF (UCDINH >= 81) THEN UCDINH = .;
   IF (UCDANL >= 81) THEN UCDANL = .;
   IF (UCDTRN >= 81) THEN UCDTRN = .;
   IF (UCDSTM >= 81) THEN UCDSTM = .;
   IF (UCDSED >= 81) THEN UCDSED = .;
   IF (SKPSPTRD >= 81) THEN SKPSPTRD = .;
   IF (SPTREAD >= 81) THEN SPTREAD = .;
   IF (NDTXRCVD >= 81) THEN NDTXRCVD = .;
   IF (NDTXNEED >= 81) THEN NDTXNEED = .;
   IF (NDTXALC >= 81) THEN NDTXALC = .;
   IF (NDTXMJ >= 81) THEN NDTXMJ = .;
   IF (NDTXCOC >= 81) THEN NDTXCOC = .;
   IF (NDTXHER >= 81) THEN NDTXHER = .;
   IF (NDTXHAL >= 81) THEN NDTXHAL = .;
   IF (NDTXINH >= 81) THEN NDTXINH = .;
   IF (NDTXANL >= 81) THEN NDTXANL = .;
   IF (NDTXTRAN >= 81) THEN NDTXTRAN = .;
   IF (NDTXSTIM >= 81) THEN NDTXSTIM = .;
   IF (NDTXSED >= 81) THEN NDTXSED = .;
   IF (NDTXSOD >= 81) THEN NDTXSOD = .;
   IF (NDTXDRG1 >= 9981) THEN NDTXDRG1 = .;
   IF (NDTXDRG2 >= 9981) THEN NDTXDRG2 = .;
   IF (NDTXDRG3 >= 9981) THEN NDTXDRG3 = .;
   IF (NDTXDRG4 >= 9981) THEN NDTXDRG4 = .;
   IF (NDTXDRG5 >= 9981) THEN NDTXDRG5 = .;
   IF (NDTXSTEP >= 81) THEN NDTXSTEP = .;
   IF (NDTXTRSP >= 81) THEN NDTXTRSP = .;
   IF (NDTXTFAR >= 81) THEN NDTXTFAR = .;
   IF (NDTXBDHR >= 81) THEN NDTXBDHR = .;
   IF (NDTXOPEN >= 81) THEN NDTXOPEN = .;
   IF (NDTXTYPE >= 81) THEN NDTXTYPE = .;
   IF (NDTXMONY >= 81) THEN NDTXMONY = .;
   IF (NDTXHCAP >= 81) THEN NDTXHCAP = .;
   IF (NDTXTCMP >= 81) THEN NDTXTCMP = .;
   IF (NDTXLANG >= 81) THEN NDTXLANG = .;
   IF (NDTXSPSV >= 81) THEN NDTXSPSV = .;
   IF (NDTXSOR >= 81) THEN NDTXSOR = .;
   IF (NDTXRSC1 >= 81) THEN NDTXRSC1 = .;
   IF (BOOKED >= 81) THEN BOOKED = .;
   IF (NOBOOKYR >= 81) THEN NOBOOKYR = .;
   IF (BKLARCNY >= 81) THEN BKLARCNY = .;
   IF (BKBURGL >= 81) THEN BKBURGL = .;
   IF (BKAGASLT >= 81) THEN BKAGASLT = .;
   IF (BKSMASLT >= 81) THEN BKSMASLT = .;
   IF (BKMVTHFT >= 81) THEN BKMVTHFT = .;
   IF (BKROB >= 81) THEN BKROB = .;
   IF (BKRAPE >= 81) THEN BKRAPE = .;
   IF (BKMURDER >= 81) THEN BKMURDER = .;
   IF (BKARSON >= 81) THEN BKARSON = .;
   IF (BKDRVINF >= 81) THEN BKDRVINF = .;
   IF (BKDRUNK >= 81) THEN BKDRUNK = .;
   IF (BKDRUG >= 81) THEN BKDRUG = .;
   IF (BKPROS >= 81) THEN BKPROS = .;
   IF (BKVANDAL >= 81) THEN BKVANDAL = .;
   IF (BKOTH >= 81) THEN BKOTH = .;
   IF (BKOTHOFF >= 81) THEN BKOTHOFF = .;
   IF (PROBATON >= 81) THEN PROBATON = .;
   IF (PAROLE >= 81) THEN PAROLE = .;
   IF (DRVALDR >= 81) THEN DRVALDR = .;
   IF (DRIVEAL >= 81) THEN DRIVEAL = .;
   IF (DRIVEDR >= 81) THEN DRIVEDR = .;
   IF (SKPTMTRD >= 81) THEN SKPTMTRD = .;
   IF (TMTREAD >= 81) THEN TMTREAD = .;
   IF (TXEVER >= 81) THEN TXEVER = .;
   IF (TXTIMELF >= 975) THEN TXTIMELF = .;
   IF (TXYRFREQ >= 975) THEN TXYRFREQ = .;
   IF (TXALHOSP >= 81) THEN TXALHOSP = .;
   IF (TXALRFIN >= 81) THEN TXALRFIN = .;
   IF (TXALRFOP >= 81) THEN TXALRFOP = .;
   IF (TXALMHC >= 81) THEN TXALMHC = .;
   IF (TXALEMRG >= 81) THEN TXALEMRG = .;
   IF (TXALDOC >= 81) THEN TXALDOC = .;
   IF (TXALJAIL >= 81) THEN TXALJAIL = .;
   IF (TXALSHG >= 81) THEN TXALSHG = .;
   IF (TXALSOP >= 81) THEN TXALSOP = .;
   IF (TXALSP >= 81) THEN TXALSP = .;
   IF (TXDRHOSP >= 81) THEN TXDRHOSP = .;
   IF (TXDRFIN >= 81) THEN TXDRFIN = .;
   IF (TXDRFOP >= 81) THEN TXDRFOP = .;
   IF (TXDRMHC >= 81) THEN TXDRMHC = .;
   IF (TXDREMRG >= 81) THEN TXDREMRG = .;
   IF (TXDRDOC >= 81) THEN TXDRDOC = .;
   IF (TXDRJAIL >= 81) THEN TXDRJAIL = .;
   IF (TXDRSHG >= 81) THEN TXDRSHG = .;
   IF (TXDRSOP >= 81) THEN TXDRSOP = .;
   IF (TXDRSP >= 81) THEN TXDRSP = .;
   IF (TXYREMRG >= 975) THEN TXYREMRG = .;
   IF (TXADGREC >= 81) THEN TXADGREC = .;
   IF (TXLTHOSP >= 81) THEN TXLTHOSP = .;
   IF (TXLTRFIN >= 81) THEN TXLTRFIN = .;
   IF (TXLTRFOP >= 81) THEN TXLTRFOP = .;
   IF (TXLTMHC >= 81) THEN TXLTMHC = .;
   IF (TXLTEMRG >= 81) THEN TXLTEMRG = .;
   IF (TXLTDOC >= 81) THEN TXLTDOC = .;
   IF (TXLTJAIL >= 81) THEN TXLTJAIL = .;
   IF (TXLTSHG >= 81) THEN TXLTSHG = .;
   IF (TXLTSOP >= 81) THEN TXLTSOP = .;
   IF (TXLTSP >= 81) THEN TXLTSP = .;
   IF (TXLTALC >= 81) THEN TXLTALC = .;
   IF (TXLTMJ >= 81) THEN TXLTMJ = .;
   IF (TXLTCOC >= 81) THEN TXLTCOC = .;
   IF (TXLTHER >= 81) THEN TXLTHER = .;
   IF (TXLTHAL >= 81) THEN TXLTHAL = .;
   IF (TXLTINH >= 81) THEN TXLTINH = .;
   IF (TXLTANL >= 81) THEN TXLTANL = .;
   IF (TXLTRAN >= 81) THEN TXLTRAN = .;
   IF (TXLTSTIM >= 81) THEN TXLTSTIM = .;
   IF (TXLTSED >= 81) THEN TXLTSED = .;
   IF (TXLTSOD >= 81) THEN TXLTSOD = .;
   IF (TXLTA >= 9981) THEN TXLTA = .;
   IF (TXLTB >= 9981) THEN TXLTB = .;
   IF (TXLTC >= 9981) THEN TXLTC = .;
   IF (TXLTD >= 9981) THEN TXLTD = .;
   IF (TXLTE >= 9981) THEN TXLTE = .;
   IF (TXDRGA >= 9981) THEN TXDRGA = .;
   IF (TXDRGB >= 9981) THEN TXDRGB = .;
   IF (TXDRGC >= 9981) THEN TXDRGC = .;
   IF (TXDRGD >= 9981) THEN TXDRGD = .;
   IF (TXDRGE >= 9981) THEN TXDRGE = .;
   IF (TXOUTC >= 81) THEN TXOUTC = .;
   IF (TXTIME >= 9975) THEN TXTIME = .;
   IF (TXPDINS >= 81) THEN TXPDINS = .;
   IF (TXPDCARE >= 81) THEN TXPDCARE = .;
   IF (TXPDCAID >= 81) THEN TXPDCAID = .;
   IF (TXPDSAVE >= 81) THEN TXPDSAVE = .;
   IF (TXPDFMLY >= 81) THEN TXPDFMLY = .;
   IF (TXPDEMPL >= 81) THEN TXPDEMPL = .;
   IF (TXPDFREE >= 81) THEN TXPDFREE = .;
   IF (TXPDSOS >= 81) THEN TXPDSOS = .;
   IF (TXPDSP >= 81) THEN TXPDSP = .;
   IF (TXENROLL >= 81) THEN TXENROLL = .;
   IF (SKYCPBAN = 9) THEN SKYCPBAN = .;
   IF (SKPYCRD >= 81) THEN SKPYCRD = .;
   IF (YCREAD >= 81) THEN YCREAD = .;
   IF (YACTYNG >= 81) THEN YACTYNG = .;
   IF (YALLERGY >= 81) THEN YALLERGY = .;
   IF (YARGUE >= 81) THEN YARGUE = .;
   IF (YASTHMA >= 81) THEN YASTHMA = .;
   IF (YACOPPSX >= 81) THEN YACOPPSX = .;
   IF (YLKANIML >= 81) THEN YLKANIML = .;
   IF (YBRAG >= 81) THEN YBRAG = .;
   IF (YTRBCONC >= 81) THEN YTRBCONC = .;
   IF (YCNTHGTS >= 81) THEN YCNTHGTS = .;
   IF (YTRBSIT >= 81) THEN YTRBSIT = .;
   IF (YDPTADLT >= 81) THEN YDPTADLT = .;
   IF (YFLONELY >= 81) THEN YFLONELY = .;
   IF (YFLCONFU >= 81) THEN YFLCONFU = .;
   IF (YCRYLOT >= 81) THEN YCRYLOT = .;
   IF (YHONEST >= 81) THEN YHONEST = .;
   IF (YMEANOTH >= 81) THEN YMEANOTH = .;
   IF (YDAYDREM >= 81) THEN YDAYDREM = .;
   IF (YTRYKLSF >= 81) THEN YTRYKLSF = .;
   IF (YTRYATTN >= 81) THEN YTRYATTN = .;
   IF (YDSTYTHG >= 81) THEN YDSTYTHG = .;
   IF (YDSTYOTH >= 81) THEN YDSTYOTH = .;
   IF (YDSBYPAR >= 81) THEN YDSBYPAR = .;
   IF (YDSBYSCH >= 81) THEN YDSBYSCH = .;
   IF (YDNTEATW >= 81) THEN YDNTEATW = .;
   IF (YDNTKIDS >= 81) THEN YDNTKIDS = .;
   IF (YDNTGLTY >= 81) THEN YDNTGLTY = .;
   IF (YJEALOTH >= 81) THEN YJEALOTH = .;
   IF (YHELPOTH >= 81) THEN YHELPOTH = .;
   IF (YAFRPLAC >= 81) THEN YAFRPLAC = .;
   IF (YAFRSCHL >= 81) THEN YAFRSCHL = .;
   IF (YAFRBAD >= 81) THEN YAFRBAD = .;
   IF (YFLPRFCT >= 81) THEN YFLPRFCT = .;
   IF (YFLNOLOV >= 81) THEN YFLNOLOV = .;
   IF (YFLGETME >= 81) THEN YFLGETME = .;
   IF (YFLWTHLS >= 81) THEN YFLWTHLS = .;
   IF (YACCHURT >= 81) THEN YACCHURT = .;
   IF (YFIGHTS >= 81) THEN YFIGHTS = .;
   IF (YGTEASED >= 81) THEN YGTEASED = .;
   IF (YKIDSTRB >= 81) THEN YKIDSTRB = .;
   IF (YHRVOICS >= 81) THEN YHRVOICS = .;
   IF (YACTTNK >= 81) THEN YACTTNK = .;
   IF (YALONE >= 81) THEN YALONE = .;
   IF (YLIE >= 81) THEN YLIE = .;
   IF (YBITNAIL >= 81) THEN YBITNAIL = .;
   IF (YNERVOUS >= 81) THEN YNERVOUS = .;
   IF (YBTWITCH >= 81) THEN YBTWITCH = .;
   IF (YNGHTMAR >= 81) THEN YNGHTMAR = .;
   IF (YNOTKIDS >= 81) THEN YNOTKIDS = .;
   IF (YDOBETTR >= 81) THEN YDOBETTR = .;
   IF (YANXIOUS >= 81) THEN YANXIOUS = .;
   IF (YFLDIZZY >= 81) THEN YFLDIZZY = .;
   IF (YFLGUILT >= 81) THEN YFLGUILT = .;
   IF (YEATMUCH >= 81) THEN YEATMUCH = .;
   IF (YFLTIRED >= 81) THEN YFLTIRED = .;
   IF (YOVRWGHT >= 81) THEN YOVRWGHT = .;
   IF (YACHES >= 81) THEN YACHES = .;
   IF (YHEADACH >= 81) THEN YHEADACH = .;
   IF (YNAUSEA >= 81) THEN YNAUSEA = .;
   IF (YEYEPROB >= 81) THEN YEYEPROB = .;
   IF (YRASHES >= 81) THEN YRASHES = .;
   IF (YCRAMPS >= 81) THEN YCRAMPS = .;
   IF (YVOMIT >= 81) THEN YVOMIT = .;
   IF (YATTACK >= 81) THEN YATTACK = .;
   IF (YPKBPART >= 81) THEN YPKBPART = .;
   IF (YPFRNDLY >= 81) THEN YPFRNDLY = .;
   IF (YTRYTHNG >= 81) THEN YTRYTHNG = .;
   IF (YSCPOOR >= 81) THEN YSCPOOR = .;
   IF (YCLUMSY >= 81) THEN YCLUMSY = .;
   IF (YOLDKIDS >= 81) THEN YOLDKIDS = .;
   IF (YYNGKIDS >= 81) THEN YYNGKIDS = .;
   IF (YRFSTALK >= 81) THEN YRFSTALK = .;
   IF (YREPACTN >= 81) THEN YREPACTN = .;
   IF (YRUNHOME >= 81) THEN YRUNHOME = .;
   IF (YSCREAM >= 81) THEN YSCREAM = .;
   IF (YSECRET >= 81) THEN YSECRET = .;
   IF (YSEETHNG >= 81) THEN YSEETHNG = .;
   IF (YSLFCONS >= 81) THEN YSLFCONS = .;
   IF (YSETFIRE >= 81) THEN YSETFIRE = .;
   IF (YWELHNDS >= 81) THEN YWELHNDS = .;
   IF (YSHOWOFF >= 81) THEN YSHOWOFF = .;
   IF (YSHY >= 81) THEN YSHY = .;
   IF (YSLPLESS >= 81) THEN YSLPLESS = .;
   IF (YSLPMORE >= 81) THEN YSLPMORE = .;
   IF (YGDIMAG >= 81) THEN YGDIMAG = .;
   IF (YSPCHPRB >= 81) THEN YSPCHPRB = .;
   IF (YSTDRGHT >= 81) THEN YSTDRGHT = .;
   IF (YSTEALHO >= 81) THEN YSTEALHO = .;
   IF (YSTEALPL >= 81) THEN YSTEALPL = .;
   IF (YDNTNEED >= 81) THEN YDNTNEED = .;
   IF (YDOSTRNG >= 81) THEN YDOSTRNG = .;
   IF (YTHSTRNG >= 81) THEN YTHSTRNG = .;
   IF (YSTUBORN >= 81) THEN YSTUBORN = .;
   IF (YMOODS >= 81) THEN YMOODS = .;
   IF (YENJOY >= 81) THEN YENJOY = .;
   IF (YSUSPICS >= 81) THEN YSUSPICS = .;
   IF (YDRTLANG >= 81) THEN YDRTLANG = .;
   IF (YTHKKLSF >= 81) THEN YTHKKLSF = .;
   IF (YLKLAUGH >= 81) THEN YLKLAUGH = .;
   IF (YTALKMCH >= 81) THEN YTALKMCH = .;
   IF (YTEASE >= 81) THEN YTEASE = .;
   IF (YTEMPER >= 81) THEN YTEMPER = .;
   IF (YTHNKSEX >= 81) THEN YTHNKSEX = .;
   IF (YTHRTPEO >= 81) THEN YTHRTPEO = .;
   IF (YLKHELP >= 81) THEN YLKHELP = .;
   IF (YCONNEAT >= 81) THEN YCONNEAT = .;
   IF (YTRBSLEP >= 81) THEN YTRBSLEP = .;
   IF (YSKIPSCH >= 81) THEN YSKIPSCH = .;
   IF (YNOENRGY >= 81) THEN YNOENRGY = .;
   IF (YUNHAPPY >= 81) THEN YUNHAPPY = .;
   IF (YLOUDER >= 81) THEN YLOUDER = .;
   IF (YUSEDRUG >= 81) THEN YUSEDRUG = .;
   IF (YFAIROTH >= 81) THEN YFAIROTH = .;
   IF (YENJYJOK >= 81) THEN YENJYJOK = .;
   IF (YLIFEASY >= 81) THEN YLIFEASY = .;
   IF (YTRYHELP >= 81) THEN YTRYHELP = .;
   IF (YWSOPPSX >= 81) THEN YWSOPPSX = .;
   IF (YINVOTH >= 81) THEN YINVOTH = .;
   IF (YWORRY >= 81) THEN YWORRY = .;
   IF (SKPBDBAN >= 81) THEN SKPBDBAN = .;
   IF (SKPPBRD >= 81) THEN SKPPBRD = .;
   IF (PBREAD >= 81) THEN PBREAD = .;
   IF (XSEXYR >= 81) THEN XSEXYR = .;
   IF (XRELNOW >= 81) THEN XRELNOW = .;
   IF (XRELYR >= 81) THEN XRELYR = .;
   IF (XRELCDV >= 81) THEN XRELCDV = .;
   IF (XRELCDA >= 81) THEN XRELCDA = .;
   IF (XNRELYR >= 81) THEN XNRELYR = .;
   IF (XNRELCDV >= 81) THEN XNRELCDV = .;
   IF (XNRELCDA >= 81) THEN XNRELCDA = .;
   IF (XYRDIFPP >= 81) THEN XYRDIFPP = .;
   IF (XYRWTHMF >= 81) THEN XYRWTHMF = .;
   IF (XYRHIV >= 81) THEN XYRHIV = .;
   IF (XYRMONEY >= 81) THEN XYRMONEY = .;
   IF (XYRDRUGS >= 81) THEN XYRDRUGS = .;
   IF (XCDEVER >= 81) THEN XCDEVER = .;
   IF (XCDLAST >= 81) THEN XCDLAST = .;
   IF (XCDPREG >= 81) THEN XCDPREG = .;
   IF (XCDSTD >= 81) THEN XCDSTD = .;
   IF (XCDNMESS >= 81) THEN XCDNMESS = .;
   IF (XCDOTRSN >= 81) THEN XCDOTRSN = .;
   IF (XCDRSN1 >= 81) THEN XCDRSN1 = .;
   IF (XNCDPREG >= 81) THEN XNCDPREG = .;
   IF (XNCDMONO >= 81) THEN XNCDMONO = .;
   IF (XNCDSTD >= 81) THEN XNCDSTD = .;
   IF (XNCDOBC >= 81) THEN XNCDOBC = .;
   IF (XNCDRELG >= 81) THEN XNCDRELG = .;
   IF (XNCDPTNR >= 81) THEN XNCDPTNR = .;
   IF (XNCDNA >= 81) THEN XNCDNA = .;
   IF (XNCDHOW >= 81) THEN XNCDHOW = .;
   IF (XNCDSAFE >= 81) THEN XNCDSAFE = .;
   IF (XNCDORSN >= 81) THEN XNCDORSN = .;
   IF (XNCDRSN1 >= 81) THEN XNCDRSN1 = .;
   IF (XCDMOOD >= 81) THEN XCDMOOD = .;
   IF (XCDRESP >= 81) THEN XCDRESP = .;
   IF (XCDFEEL >= 81) THEN XCDFEEL = .;
   IF (XCDTRST >= 81) THEN XCDTRST = .;
   IF (XCDEMBR >= 81) THEN XCDEMBR = .;
   IF (XCDCOST >= 81) THEN XCDCOST = .;
   IF (XRELLAST >= 81) THEN XRELLAST = .;
   IF (XLFBLOOD >= 81) THEN XLFBLOOD = .;
   IF (XBLD385 >= 81) THEN XBLD385 = .;
   IF (XLTBLDMO >= 81) THEN XLTBLDMO = .;
   IF (XLTBLDYR >= 981) THEN XLTBLDYR = .;
   IF (XHIVTEST >= 81) THEN XHIVTEST = .;
   IF (XLTHIVMO >= 81) THEN XLTHIVMO = .;
   IF (XLTHIVYR >= 981) THEN XLTHIVYR = .;
   IF (XHIVRSLT >= 81) THEN XHIVRSLT = .;
   IF (SKPDBRD >= 81) THEN SKPDBRD = .;
   IF (DBREAD >= 81) THEN DBREAD = .;
   IF (VDRVYR >= 81) THEN VDRVYR = .;
   IF (VYRFREQ >= 81) THEN VYRFREQ = .;
   IF (VALDRVYR >= 81) THEN VALDRVYR = .;
   IF (VALYRFRQ >= 81) THEN VALYRFRQ = .;
   IF (VAL30USE >= 81) THEN VAL30USE = .;
   IF (VALCNODR >= 81) THEN VALCNODR = .;
   IF (VALCTIME >= 81) THEN VALCTIME = .;
   IF (VALDTIME >= 81) THEN VALDTIME = .;
   IF (VMJUSEYR >= 81) THEN VMJUSEYR = .;
   IF (VMJDRVYR >= 81) THEN VMJDRVYR = .;
   IF (VMJALCYR >= 81) THEN VMJALCYR = .;
   IF (VMJCOCYR >= 81) THEN VMJCOCYR = .;
   IF (VMJHERYR >= 81) THEN VMJHERYR = .;
   IF (VMJHALYR >= 81) THEN VMJHALYR = .;
   IF (VMJINHYR >= 81) THEN VMJINHYR = .;
   IF (VMJANLYR >= 81) THEN VMJANLYR = .;
   IF (VMJTRNYR >= 81) THEN VMJTRNYR = .;
   IF (VMJSTMYR >= 81) THEN VMJSTMYR = .;
   IF (VMJSEDYR >= 81) THEN VMJSEDYR = .;
   IF (VMJOTHYR >= 81) THEN VMJOTHYR = .;
   IF (VMJYRS1 >= 9981) THEN VMJYRS1 = .;
   IF (VMJYRS2 >= 9981) THEN VMJYRS2 = .;
   IF (VMJYRS3 >= 9981) THEN VMJYRS3 = .;
   IF (VMJYRS4 >= 9981) THEN VMJYRS4 = .;
   IF (VMJYRS5 >= 9981) THEN VMJYRS5 = .;
   IF (VMJ30USE >= 81) THEN VMJ30USE = .;
   IF (VLTMJALC >= 81) THEN VLTMJALC = .;
   IF (VLTMJAL1 >= 9981) THEN VLTMJAL1 = .;
   IF (VLTMJAL2 >= 9981) THEN VLTMJAL2 = .;
   IF (VLTMJAL3 >= 9981) THEN VLTMJAL3 = .;
   IF (VLTMJAL4 >= 9981) THEN VLTMJAL4 = .;
   IF (VLTMJAL5 >= 9981) THEN VLTMJAL5 = .;
   IF (VLTMJFRM >= 81) THEN VLTMJFRM = .;
   IF (VLTMJFRS >= 81) THEN VLTMJFRS = .;
   IF (VLTMJTO >= 81) THEN VLTMJTO = .;
   IF (VLTMJTOS >= 81) THEN VLTMJTOS = .;
   IF (VLTMJHWY >= 81) THEN VLTMJHWY = .;
   IF (VLTMJURB >= 81) THEN VLTMJURB = .;
   IF (VLTMJWKD >= 81) THEN VLTMJWKD = .;
   IF (VLTMJTIM >= 81) THEN VLTMJTIM = .;
   IF (VLTMJABL >= 81) THEN VLTMJABL = .;
   IF (VMJNOWAY >= 81) THEN VMJNOWAY = .;
   IF (VMJNHIGH >= 81) THEN VMJNHIGH = .;
   IF (VMJNPOLC >= 81) THEN VMJNPOLC = .;
   IF (VMJNODVR >= 81) THEN VMJNODVR = .;
   IF (VMJAPPT >= 81) THEN VMJAPPT = .;
   IF (VMJOTHER >= 81) THEN VMJOTHER = .;
   IF (VMJOTHSP >= 81) THEN VMJOTHSP = .;
   IF (VMJSTOP >= 81) THEN VMJSTOP = .;
   IF (VMJABIL >= 81) THEN VMJABIL = .;
   IF (VCCUSEYR >= 81) THEN VCCUSEYR = .;
   IF (VCCDRVYR >= 81) THEN VCCDRVYR = .;
   IF (VCCALCYR >= 81) THEN VCCALCYR = .;
   IF (VCCMRJYR >= 81) THEN VCCMRJYR = .;
   IF (VCCHERYR >= 81) THEN VCCHERYR = .;
   IF (VCCHALYR >= 81) THEN VCCHALYR = .;
   IF (VCCINHYR >= 81) THEN VCCINHYR = .;
   IF (VCCANLYR >= 81) THEN VCCANLYR = .;
   IF (VCCTRNYR >= 81) THEN VCCTRNYR = .;
   IF (VCCSTMYR >= 81) THEN VCCSTMYR = .;
   IF (VCCSEDYR >= 81) THEN VCCSEDYR = .;
   IF (VCCOTHYR >= 81) THEN VCCOTHYR = .;
   IF (VCCYRS1 >= 9981) THEN VCCYRS1 = .;
   IF (VCCYRS2 >= 9981) THEN VCCYRS2 = .;
   IF (VCCYRS3 >= 9981) THEN VCCYRS3 = .;
   IF (VCCYRS4 >= 9981) THEN VCCYRS4 = .;
   IF (VCCYRS5 >= 9981) THEN VCCYRS5 = .;
   IF (VCC30USE >= 81) THEN VCC30USE = .;
   IF (VLTCCALC >= 81) THEN VLTCCALC = .;
   IF (VLTCCAL1 >= 9981) THEN VLTCCAL1 = .;
   IF (VLTCCAL2 >= 9981) THEN VLTCCAL2 = .;
   IF (VLTCCAL3 >= 9981) THEN VLTCCAL3 = .;
   IF (VLTCCAL4 >= 9981) THEN VLTCCAL4 = .;
   IF (VLTCCAL5 >= 9981) THEN VLTCCAL5 = .;
   IF (VLTCCFRM >= 81) THEN VLTCCFRM = .;
   IF (VLTCCFRS >= 81) THEN VLTCCFRS = .;
   IF (VLTCCTO >= 81) THEN VLTCCTO = .;
   IF (VLTCCTOS >= 81) THEN VLTCCTOS = .;
   IF (VLTCCHWY >= 81) THEN VLTCCHWY = .;
   IF (VLTCCURB >= 81) THEN VLTCCURB = .;
   IF (VLTCCWKD >= 81) THEN VLTCCWKD = .;
   IF (VLTCCTIM >= 81) THEN VLTCCTIM = .;
   IF (VLTCCABL >= 81) THEN VLTCCABL = .;
   IF (VCCNOWAY >= 81) THEN VCCNOWAY = .;
   IF (VCCNHIGH >= 81) THEN VCCNHIGH = .;
   IF (VCCNPOLC >= 81) THEN VCCNPOLC = .;
   IF (VCCNODVR >= 81) THEN VCCNODVR = .;
   IF (VCCAPPT >= 81) THEN VCCAPPT = .;
   IF (VCCOTHER >= 81) THEN VCCOTHER = .;
   IF (VCCOTHSP >= 81) THEN VCCOTHSP = .;
   IF (VCCSTOP >= 81) THEN VCCSTOP = .;
   IF (VCCABIL >= 81) THEN VCCABIL = .;
   IF (VTRUSEYR >= 81) THEN VTRUSEYR = .;
   IF (VTRDRVYR >= 81) THEN VTRDRVYR = .;
   IF (VTR30USE >= 81) THEN VTR30USE = .;
   IF (VLTTRMED >= 81) THEN VLTTRMED = .;
   IF (VLTTRALC >= 81) THEN VLTTRALC = .;
   IF (VLTTRAL1 >= 9981) THEN VLTTRAL1 = .;
   IF (VLTTRAL2 >= 9981) THEN VLTTRAL2 = .;
   IF (VLTTRAL3 >= 9981) THEN VLTTRAL3 = .;
   IF (VLTTRAL4 >= 9981) THEN VLTTRAL4 = .;
   IF (VLTTRAL5 >= 9981) THEN VLTTRAL5 = .;
   IF (VLTTRABL >= 81) THEN VLTTRABL = .;
   IF (VSTUSEYR >= 81) THEN VSTUSEYR = .;
   IF (VSTDRVYR >= 81) THEN VSTDRVYR = .;
   IF (VST30USE >= 81) THEN VST30USE = .;
   IF (VLTSTMED >= 81) THEN VLTSTMED = .;
   IF (VLTSTALC >= 81) THEN VLTSTALC = .;
   IF (VLTSTAL1 >= 9981) THEN VLTSTAL1 = .;
   IF (VLTSTAL2 >= 9981) THEN VLTSTAL2 = .;
   IF (VLTSTAL3 >= 9981) THEN VLTSTAL3 = .;
   IF (VLTSTAL4 >= 9981) THEN VLTSTAL4 = .;
   IF (VLTSTAL5 >= 9981) THEN VLTSTAL5 = .;
   IF (VLTSTABL >= 81) THEN VLTSTABL = .;
   IF (VSEUSEYR >= 81) THEN VSEUSEYR = .;
   IF (VSEDRVYR >= 81) THEN VSEDRVYR = .;
   IF (VSE30USE >= 81) THEN VSE30USE = .;
   IF (VLTSEMED >= 81) THEN VLTSEMED = .;
   IF (VLTSEALC >= 81) THEN VLTSEALC = .;
   IF (VLTSEAL1 >= 9981) THEN VLTSEAL1 = .;
   IF (VLTSEAL2 >= 9981) THEN VLTSEAL2 = .;
   IF (VLTSEAL3 >= 9981) THEN VLTSEAL3 = .;
   IF (VLTSEAL4 >= 9981) THEN VLTSEAL4 = .;
   IF (VLTSEAL5 >= 9981) THEN VLTSEAL5 = .;
   IF (VLTSEABL >= 81) THEN VLTSEABL = .;
   IF (SKPWKST3 >= 81) THEN SKPWKST3 = .;
   IF (WORKDAYS >= 81) THEN WORKDAYS = .;
   IF (WORKBLAH >= 81) THEN WORKBLAH = .;
   IF (SKPPREG = 9) THEN SKPPREG = .;
   IF (PREGNANT >= 81) THEN PREGNANT = .;
   IF (PREGMOS >= 81) THEN PREGMOS = .;
   IF (TOTPEOP >= 81) THEN TOTPEOP = .;
   IF (SKPMHC = 9) THEN SKPMHC = .;
   IF (DEPRESS >= 81) THEN DEPRESS = .;
   IF (DEPDAYS >= 81) THEN DEPDAYS = .;
   IF (DEPFREQ >= 81) THEN DEPFREQ = .;
   IF (LOSTINT1 >= 81) THEN LOSTINT1 = .;
   IF (TIRED1 >= 81) THEN TIRED1 = .;
   IF (WTCHNG1 >= 81) THEN WTCHNG1 = .;
   IF (LBSCHNG1 >= 981) THEN LBSCHNG1 = .;
   IF (SLPLOSS1 >= 81) THEN SLPLOSS1 = .;
   IF (SLPFREQ1 >= 81) THEN SLPFREQ1 = .;
   IF (CONCEN1 >= 81) THEN CONCEN1 = .;
   IF (DOWN1 >= 81) THEN DOWN1 = .;
   IF (IDEAT1 >= 81) THEN IDEAT1 = .;
   IF (SKPDEP1 >= 81) THEN SKPDEP1 = .;
   IF (DEPWKS1 >= 81) THEN DEPWKS1 = .;
   IF (DEPMO1 >= 81) THEN DEPMO1 = .;
   IF (DEPYR1 >= 981) THEN DEPYR1 = .;
   IF (LOSTINT2 >= 81) THEN LOSTINT2 = .;
   IF (LOSINDAY >= 81) THEN LOSINDAY = .;
   IF (LOSINFRQ >= 81) THEN LOSINFRQ = .;
   IF (TIRED2 >= 81) THEN TIRED2 = .;
   IF (WTCHNG2 >= 81) THEN WTCHNG2 = .;
   IF (LBSCHNG2 >= 981) THEN LBSCHNG2 = .;
   IF (SLPLOSS2 >= 81) THEN SLPLOSS2 = .;
   IF (SLPFREQ2 >= 81) THEN SLPFREQ2 = .;
   IF (CONCEN2 >= 81) THEN CONCEN2 = .;
   IF (DOWN2 >= 81) THEN DOWN2 = .;
   IF (IDEAT2 >= 81) THEN IDEAT2 = .;
   IF (SKPDEP2 >= 81) THEN SKPDEP2 = .;
   IF (DEPWKS2 >= 81) THEN DEPWKS2 = .;
   IF (DEPMO2 >= 81) THEN DEPMO2 = .;
   IF (DEPYR2 >= 981) THEN DEPYR2 = .;
   IF (WORRIED >= 81) THEN WORRIED = .;
   IF (WOREND >= 81) THEN WOREND = .;
   IF (WORNOMO1 >= 9981) THEN WORNOMO1 = .;
   IF (WORHAPN1 >= 81) THEN WORHAPN1 = .;
   IF (WORSERI1 >= 81) THEN WORSERI1 = .;
   IF (WORDIFF1 >= 81) THEN WORDIFF1 = .;
   IF (WORNOMO2 >= 9981) THEN WORNOMO2 = .;
   IF (WORHAPN2 >= 81) THEN WORHAPN2 = .;
   IF (WORSERI2 >= 81) THEN WORSERI2 = .;
   IF (WORDIFF2 >= 81) THEN WORDIFF2 = .;
   IF (SKPWOR >= 81) THEN SKPWOR = .;
   IF (WORREST >= 81) THEN WORREST = .;
   IF (WOREDGE >= 81) THEN WOREDGE = .;
   IF (WORIRRIT >= 81) THEN WORIRRIT = .;
   IF (WORHEART >= 81) THEN WORHEART = .;
   IF (WORTIRED >= 81) THEN WORTIRED = .;
   IF (WORSLEEP >= 81) THEN WORSLEEP = .;
   IF (WORFAINT >= 81) THEN WORFAINT = .;
   IF (FEARPUB >= 81) THEN FEARPUB = .;
   IF (FEAROUT >= 81) THEN FEAROUT = .;
   IF (FEARBRDG >= 81) THEN FEARBRDG = .;
   IF (SKPFEAR1 >= 81) THEN SKPFEAR1 = .;
   IF (FEAROFT >= 81) THEN FEAROFT = .;
   IF (FEARYRS >= 81) THEN FEARYRS = .;
   IF (FEARMOS >= 81) THEN FEARMOS = .;
   IF (FEARFANT >= 81) THEN FEARFANT = .;
   IF (FEARTRAP >= 81) THEN FEARTRAP = .;
   IF (FEARHELP >= 81) THEN FEARHELP = .;
   IF (PANIC1 >= 81) THEN PANIC1 = .;
   IF (PANIC2 >= 81) THEN PANIC2 = .;
   IF (PANICNUM >= 981) THEN PANICNUM = .;
   IF (PANICMO >= 81) THEN PANICMO = .;
   IF (PANICYR >= 981) THEN PANICYR = .;
   IF (PANIDANG >= 81) THEN PANIDANG = .;
   IF (SKPFEAR2 >= 81) THEN SKPFEAR2 = .;
   IF (PANIFEAR >= 81) THEN PANIFEAR = .;
   IF (PANINOFR >= 81) THEN PANINOFR = .;
   IF (PANIHART >= 81) THEN PANIHART = .;
   IF (PANIPAIN >= 81) THEN PANIPAIN = .;
   IF (PANISWET >= 81) THEN PANISWET = .;
   IF (PANISHAK >= 81) THEN PANISHAK = .;
   IF (PANIHOT >= 81) THEN PANIHOT = .;
   IF (PANIUNRL >= 81) THEN PANIUNRL = .;
   IF (NUERTMT >= 81) THEN NUERTMT = .;
   IF (NUHSPOV >= 81) THEN NUHSPOV = .;
   IF (NUHSPPE >= 81) THEN NUHSPPE = .;
   IF (OUTPTPE >= 81) THEN OUTPTPE = .;
   IF (PROXABLE >= 81) THEN PROXABLE = .;
   IF (PROXYREL >= 981) THEN PROXYREL = .;
   IF (PROXHOME >= 81) THEN PROXHOME = .;
   IF (PROXJOIN >= 81) THEN PROXJOIN = .;
   IF (CAREUSU >= 81) THEN CAREUSU = .;
   IF (NCARERSN >= 81) THEN NCARERSN = .;
   IF (NCRRSNSP >= 81) THEN NCRRSNSP = .;
   IF (NCRRSNSC >= 81) THEN NCRRSNSC = .;
   IF (CAREOFT >= 81) THEN CAREOFT = .;
   IF (PYRCARE >= 81) THEN PYRCARE = .;
   IF (PYRCRTYP >= 81) THEN PYRCRTYP = .;
   IF (PYRCRTSP >= 81) THEN PYRCRTSP = .;
   IF (PYRCRTSC >= 81) THEN PYRCRTSC = .;
   IF (CARENOW >= 81) THEN CARENOW = .;
   IF (MNRSNNCR >= 81) THEN MNRSNNCR = .;
   IF (MNRSNNSP >= 81) THEN MNRSNNSP = .;
   IF (MNRSNNSC >= 81) THEN MNRSNNSC = .;
   IF (UCARETYP >= 81) THEN UCARETYP = .;
   IF (UCRTYPSP >= 81) THEN UCRTYPSP = .;
   IF (UCRTYPSC >= 81) THEN UCRTYPSC = .;
   IF (MEDICARE >= 81) THEN MEDICARE = .;
   IF (MEDICAID >= 81) THEN MEDICAID = .;
   IF (CHAMPUS >= 81) THEN CHAMPUS = .;
   IF (PRVHLTIN >= 81) THEN PRVHLTIN = .;
   IF (GRPHLTIN >= 81) THEN GRPHLTIN = .;
   IF (PDHINPRM >= 81) THEN PDHINPRM = .;
   IF (HLTINALC >= 81) THEN HLTINALC = .;
   IF (HLTINDRG >= 81) THEN HLTINDRG = .;
   IF (HLTINMNT >= 81) THEN HLTINMNT = .;
   IF (SOC1 >= 81) THEN SOC1 = .;
   IF (SOC2 >= 81) THEN SOC2 = .;
   IF (SSI1 >= 81) THEN SSI1 = .;
   IF (SSI2 >= 81) THEN SSI2 = .;
   IF (PUB1 >= 81) THEN PUB1 = .;
   IF (PUB2 >= 81) THEN PUB2 = .;
   IF (AFDC >= 81) THEN AFDC = .;
   IF (INT1 >= 81) THEN INT1 = .;
   IF (INT2 >= 81) THEN INT2 = .;
   IF (CHD1 >= 81) THEN CHD1 = .;
   IF (CHD2 >= 81) THEN CHD2 = .;
   IF (OTH1 >= 81) THEN OTH1 = .;
   IF (OTH2 >= 81) THEN OTH2 = .;
   IF (FSTAMP >= 81) THEN FSTAMP = .;
   IF (PINC1 >= 81) THEN PINC1 = .;
   IF (SKPTFMIN >= 81) THEN SKPTFMIN = .;
   IF (FINC1 >= 81) THEN FINC1 = .;
   IF (TELNO >= 81) THEN TELNO = .;
   IF (IRPINSUR = 9) THEN IRPINSUR = .;
   IF (IIPINSUR = 9) THEN IIPINSUR = .;
   IF (IRINSUR = 9) THEN IRINSUR = .;
   IF (IIINSUR = 9) THEN IIINSUR = .;
   IF (IRSOC1 = 9) THEN IRSOC1 = .;
   IF (IISOC1 = 9) THEN IISOC1 = .;
   IF (IRSSI1 = 9) THEN IRSSI1 = .;
   IF (IISSI1 = 9) THEN IISSI1 = .;
   IF (IRPUB1 = 9) THEN IRPUB1 = .;
   IF (IIPUB1 = 9) THEN IIPUB1 = .;
   IF (IRAFDC = 9) THEN IRAFDC = .;
   IF (IIAFDC = 9) THEN IIAFDC = .;
   IF (IRINT1 = 9) THEN IRINT1 = .;
   IF (IIINT1 = 9) THEN IIINT1 = .;
   IF (IRCHD1 = 9) THEN IRCHD1 = .;
   IF (IICHD1 = 9) THEN IICHD1 = .;
   IF (IROTH1 = 9) THEN IROTH1 = .;
   IF (IIOTH1 = 9) THEN IIOTH1 = .;
   IF (IRFSTAMP = 9) THEN IRFSTAMP = .;
   IF (IIFSTAMP = 9) THEN IIFSTAMP = .;
   IF (IRPINC1 = 9) THEN IRPINC1 = .;
   IF (IIPINC1 = 9) THEN IIPINC1 = .;
   IF (IRFINC1 = 9) THEN IRFINC1 = .;
   IF (IIFINC1 = 9) THEN IIFINC1 = .;
   IF (IRSOC2 = 9) THEN IRSOC2 = .;
   IF (IISOC2 = 9) THEN IISOC2 = .;
   IF (IRSSI2 = 9) THEN IRSSI2 = .;
   IF (IISSI2 = 9) THEN IISSI2 = .;
   IF (IRPUB2 = 9) THEN IRPUB2 = .;
   IF (IIPUB2 = 9) THEN IIPUB2 = .;
   IF (IRINT2 = 9) THEN IRINT2 = .;
   IF (IIINT2 = 9) THEN IIINT2 = .;
   IF (IRCHD2 = 9) THEN IRCHD2 = .;
   IF (IICHD2 = 9) THEN IICHD2 = .;
   IF (IROTH2 = 9) THEN IROTH2 = .;
   IF (IIOTH2 = 9) THEN IIOTH2 = .;
   IF (IRPEOP >= 81) THEN IRPEOP = .;
   IF (PARSTAT = 9) THEN PARSTAT = .;
   IF (FEMBABY = 9) THEN FEMBABY = .;
   IF (FEMKIDS = 9) THEN FEMKIDS = .;
   IF (MALEBABY = 9) THEN MALEBABY = .;
   IF (MALEKIDS = 9) THEN MALEKIDS = .;
   IF (F15_44 = 9) THEN F15_44 = .;
   IF (M15_44 = 9) THEN M15_44 = .;
   IF (PREG = 9) THEN PREG = .;
   IF (PREG2 = 9) THEN PREG2 = .;
   IF (TRIMEST = 9) THEN TRIMEST = .;
   IF (INDCAT >= 81) THEN INDCAT = .;
   IF (PERINC = 9) THEN PERINC = .;
   IF (PERINC2 = 9) THEN PERINC2 = .;
   IF (PERINC3 = 9) THEN PERINC3 = .;
   IF (TOTCAT >= 81) THEN TOTCAT = .;
   IF (FAMINC = 9) THEN FAMINC = .;
   IF (FAMINC2 = 9) THEN FAMINC2 = .;
   IF (FAMINC3 = 9) THEN FAMINC3 = .;
   IF (WELFARE = 9) THEN WELFARE = .;
   IF (NEEDLREC >= 81) THEN NEEDLREC = .;
   IF (NEDFLAG4 = 9) THEN NEDFLAG4 = .;
   IF (NEDYR4 = 9) THEN NEDYR4 = .;
   IF (WITHDRW >= 81) THEN WITHDRW = .;
   IF (SOMCOM >= 81) THEN SOMCOM = .;
   IF (ANXDEP >= 81) THEN ANXDEP = .;
   IF (SOCPROB >= 81) THEN SOCPROB = .;
   IF (THPROB >= 81) THEN THPROB = .;
   IF (ATTPROB >= 81) THEN ATTPROB = .;
   IF (DELBEH >= 81) THEN DELBEH = .;
   IF (AGGBEH >= 81) THEN AGGBEH = .;
   IF (WITHDRWT >= 981) THEN WITHDRWT = .;
   IF (SOMCOMT >= 981) THEN SOMCOMT = .;
   IF (ANXDEPT >= 981) THEN ANXDEPT = .;
   IF (SOCPROBT >= 981) THEN SOCPROBT = .;
   IF (THPROBT >= 981) THEN THPROBT = .;
   IF (ATTPROBT >= 981) THEN ATTPROBT = .;
   IF (DELBEHT >= 981) THEN DELBEHT = .;
   IF (AGGBEHT >= 981) THEN AGGBEHT = .;
   IF (SXHIVLF >= 81) THEN SXHIVLF = .;
   IF (SXHIVYR >= 81) THEN SXHIVYR = .;
   IF (SXREL >= 81) THEN SXREL = .;
   IF (SXRELMAR >= 81) THEN SXRELMAR = .;
   IF (SXCONDYR >= 81) THEN SXCONDYR = .;
   IF (SXRSKANY >= 81) THEN SXRSKANY = .;
   IF (SXRSKCNT >= 81) THEN SXRSKCNT = .;
   IF (SXDRANY >= 81) THEN SXDRANY = .;
   IF (SXDRCNT >= 81) THEN SXDRCNT = .;
   IF (MDESFS1 >= 81) THEN MDESFS1 = .;
   IF (MDESFS3 >= 81) THEN MDESFS3 = .;
   IF (PROBMDE1 >= 81.0000) THEN PROBMDE1 = .;
   IF (PROBMDE3 >= 81.0000) THEN PROBMDE3 = .;
   IF (MDE1 >= 81) THEN MDE1 = .;
   IF (MDE3 >= 81) THEN MDE3 = .;
   IF (GADSFS1 >= 81) THEN GADSFS1 = .;
   IF (GADSFS3 >= 81) THEN GADSFS3 = .;
   IF (PROBGAD1 >= 81.0000) THEN PROBGAD1 = .;
   IF (PROBGAD3 >= 81.0000) THEN PROBGAD3 = .;
   IF (GAD1 >= 81) THEN GAD1 = .;
   IF (GAD3 >= 81) THEN GAD3 = .;
   IF (AGPSFS1 >= 81) THEN AGPSFS1 = .;
   IF (AGPSFS3 >= 81) THEN AGPSFS3 = .;
   IF (PROBAGP1 >= 81) THEN PROBAGP1 = .;
   IF (PROBAGP3 >= 81) THEN PROBAGP3 = .;
   IF (AGP1 >= 81) THEN AGP1 = .;
   IF (AGP3 >= 81) THEN AGP3 = .;
   IF (PASFS1 >= 81) THEN PASFS1 = .;
   IF (PASFS3 >= 81) THEN PASFS3 = .;
   IF (PROBPA1 >= 81.0000) THEN PROBPA1 = .;
   IF (PROBPA3 >= 81.0000) THEN PROBPA3 = .;
   IF (PA1 >= 81) THEN PA1 = .;
   IF (PA3 >= 81) THEN PA3 = .;
   IF (BHOUR = 98) THEN BHOUR = .;
   IF (BMIN = 98) THEN BMIN = .;
   IF (BAP = 98) THEN BAP = .;
   IF (EAP = 98) THEN EAP = .;
   IF (LANGVER = 9) THEN LANGVER = .;
   IF (UNDINT >= 81) THEN UNDINT = .;
   IF (COOPINT >= 81) THEN COOPINT = .;
   IF (PRIVACY >= 81) THEN PRIVACY = .;
   IF (PPRES >= 81) THEN PPRES = .;
   IF (SPRES >= 81) THEN SPRES = .;
   IF (PARPRES >= 81) THEN PARPRES = .;
   IF (OARPRES >= 81) THEN OARPRES = .;
   IF (OAPRES >= 81) THEN OAPRES = .;
   IF (CPRES >= 81) THEN CPRES = .;
   IF (OPRESNSP >= 81) THEN OPRESNSP = .;
   IF (OPRESSPA >= 981) THEN OPRESSPA = .;
   IF (OPRESSPB >= 981) THEN OPRESSPB = .;
   IF (WHOMARKD >= 81) THEN WHOMARKD = .;
   IF (QUARTER = 9) THEN QUARTER = .;
   IF (FAMSKIP = 9) THEN FAMSKIP = .;
   IF (GQTYPE = 9) THEN GQTYPE = .;
   IF (PDEN = 9) THEN PDEN = .;
   IF (PDEN2 = 9) THEN PDEN2 = .;
   IF (REGION = 9) THEN REGION = .;
   IF (DIVISION = 9) THEN DIVISION = .;
   IF (RURORURB = 9) THEN RURORURB = .;
   IF (RELINTHH >= 81) THEN RELINTHH = .;
   IF (MJTOT3 >= 81) THEN MJTOT3 = .;
   IF (COCTOT3 >= 81) THEN COCTOT3 = .;
   IF (ALCDAYS2 = 6) THEN ALCDAYS2 = .;
   IF (MJDY30A3 = 6) THEN MJDY30A3 = .;
   IF (ALCDAYS3 = 6) THEN ALCDAYS3 = .;
   IF (AVCIG2 = 4) THEN AVCIG2 = .;
   IF (NOTMARJ = 9) THEN NOTMARJ = .;
   IF (RACESEX2 = 9) THEN RACESEX2 = .;
   IF (CIGTRY2 >= 81) THEN CIGTRY2 = .;
   IF (ALCTRY2 >= 81) THEN ALCTRY2 = .;
   IF (MJAGE2 >= 81) THEN MJAGE2 = .;
   IF (INHAGE2 >= 81) THEN INHAGE2 = .;
   IF (COCAGE2 >= 81) THEN COCAGE2 = .;
   IF (HALLAGE2 >= 81) THEN HALLAGE2 = .;
   IF (HERAGE2 >= 81) THEN HERAGE2 = .;
   IF (STIMAGE2 >= 81) THEN STIMAGE2 = .;
   IF (SEDAGE2 >= 81) THEN SEDAGE2 = .;
   IF (TRANAGE2 >= 81) THEN TRANAGE2 = .;
   IF (ANALAGE2 >= 81) THEN ANALAGE2 = .;
   IF (ALCONLYL = 9) THEN ALCONLYL = .;
   IF (ALCONLYY = 9) THEN ALCONLYY = .;
   IF (ALCONLYM = 9) THEN ALCONLYM = .;
   IF (ILLONLYL = 9) THEN ILLONLYL = .;
   IF (ILLONLYY = 9) THEN ILLONLYY = .;
   IF (ILLONLYM = 9) THEN ILLONLYM = .;
   IF (MRJONLYL = 9) THEN MRJONLYL = .;
   IF (MRJONLYY = 9) THEN MRJONLYY = .;
   IF (MRJONLYM = 9) THEN MRJONLYM = .;
   IF (PSYONLYL = 9) THEN PSYONLYL = .;
   IF (PSYONLYY = 9) THEN PSYONLYY = .;
   IF (PSYONLYM = 9) THEN PSYONLYM = .;
   IF (OTHONLYL = 9) THEN OTHONLYL = .;
   IF (OTHONLYY = 9) THEN OTHONLYY = .;
   IF (OTHONLYM = 9) THEN OTHONLYM = .;
   IF (ALCILLL = 9) THEN ALCILLL = .;
   IF (ALCILLY = 9) THEN ALCILLY = .;
   IF (ALCILLM = 9) THEN ALCILLM = .;
   IF (ALCMRJL = 9) THEN ALCMRJL = .;
   IF (ALCMRJY = 9) THEN ALCMRJY = .;
   IF (ALCMRJM = 9) THEN ALCMRJM = .;
   IF (ALCPSYL = 9) THEN ALCPSYL = .;
   IF (ALCPSYY = 9) THEN ALCPSYY = .;
   IF (ALCPSYM = 9) THEN ALCPSYM = .;
   IF (ALCOTHL = 9) THEN ALCOTHL = .;
   IF (ALCOTHY = 9) THEN ALCOTHY = .;
   IF (ALCOTHM = 9) THEN ALCOTHM = .;
   IF (SUB1LIF = 9) THEN SUB1LIF = .;
   IF (SUB2LIF = 9) THEN SUB2LIF = .;
   IF (SUB3LIF = 9) THEN SUB3LIF = .;
   IF (SUB1YR = 9) THEN SUB1YR = .;
   IF (SUB2YR = 9) THEN SUB2YR = .;
   IF (SUB3YR = 9) THEN SUB3YR = .;
   IF (SUB1MON = 9) THEN SUB1MON = .;
   IF (SUB2MON = 9) THEN SUB2MON = .;
   IF (SUB3MON = 9) THEN SUB3MON = .;
   IF (PSYAGE >= 81) THEN PSYAGE = .;
   IF (FERTAGE >= 81) THEN FERTAGE = .;
   IF (PREG3 >= 81) THEN PREG3 = .;
   IF (TRIMEST2 >= 81) THEN TRIMEST2 = .;
   IF (RSKCIG >= 81) THEN RSKCIG = .;
   IF (RSKMJ1 >= 81) THEN RSKMJ1 = .;
   IF (RSKMJ2 >= 81) THEN RSKMJ2 = .;
   IF (RSKCOC1 >= 81) THEN RSKCOC1 = .;
   IF (RSKCOC2 >= 81) THEN RSKCOC2 = .;
   IF (RSKALC1 >= 81) THEN RSKALC1 = .;
   IF (RSKALC2 >= 81) THEN RSKALC2 = .;
   IF (TOTPROB >= 981.0000) THEN TOTPROB = .;
   IF (INT >= 81.0000) THEN INT = .;
   IF (EXT >= 81) THEN EXT = .;
   IF (PR_EMOT >= 81) THEN PR_EMOT = .;
   IF (PR_BEHAV >= 81) THEN PR_BEHAV = .;
   IF (PR_TOTAL >= 81) THEN PR_TOTAL = .;
   IF (PR_WD >= 81) THEN PR_WD = .;
   IF (PR_SC >= 81) THEN PR_SC = .;
   IF (PR_AD >= 81) THEN PR_AD = .;
   IF (PR_SP >= 81) THEN PR_SP = .;
   IF (PR_TP >= 81) THEN PR_TP = .;
   IF (PR_AP >= 81) THEN PR_AP = .;
   IF (PR_DB >= 81) THEN PR_DB = .;
   IF (PR_AB >= 81) THEN PR_AB = .;
   IF (ANY4MENT >= 81) THEN ANY4MENT = .;
   IF (AGECAT3 >= 81) THEN AGECAT3 = .;
   IF (DRUNKYR3 >= 81) THEN DRUNKYR3 = .;
   IF (SEXYR >= 81) THEN SEXYR = .;
   IF (RELNOW >= 81) THEN RELNOW = .;
   IF (HIVTEST >= 81) THEN HIVTEST = .;
   IF (CDALWAYS >= 81) THEN CDALWAYS = .;
   IF (CDSOME >= 81) THEN CDSOME = .;
   IF (CDNEVER >= 81) THEN CDNEVER = .;
   IF (YRDIFPP1 >= 81) THEN YRDIFPP1 = .;
   IF (YRDIFPP2 >= 81) THEN YRDIFPP2 = .;
   IF (EHOUR >= 81) THEN EHOUR = .;
   IF (EMIN >= 81) THEN EMIN = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT SKPMARTL skpmartl. MARITAL marital. NOMARR nomarr.
         SKPMILT skpmilt. SERVICE service. MILSTAT milstat.
         EDUC educ. DIPLOMA diploma. ENROLLD enrolld.
         WORKSTAT workstat. HTININCH htininch. POUNDS pounds.
         HEALTH health. CIGEVER cigever. CIGTRY cigtry.
         CIGTOT cigtot. CIGREC cigrec. CIG30USE cig30use.
         AVCIG avcig. CIG30WOK cig30wok. CIGEVYDA cigevyda.
         CIGAGE cigage. CIGYRS cigyrs. SNUFEVER snufever.
         SNUFREC snufrec. SKPALCRD skpalcrd. ALCREAD alcread.
         ALCEVER alcever. ALCTRY alctry. ALCREC alcrec.
         ALCPAT alcpat. DRUNKYR drunkyr. ALCDAYS alcdays.
         NODR30A nodr30a. DR5DAY dr5day. MJEVER mjever.
         MJAGE mjage. MJTOT mjtot. MJREC mjrec.
         MJYRFREQ mjyrfreq. MJDAY30A mjday30a. SKPCOCRD skpcocrd.
         COCREAD cocread. COCEVER cocever. COCAGE cocage.
         COCTOT coctot. COCREC cocrec. COCYRFRQ cocyrfrq.
         COCUS30A cocus30a. SKPCRKRD skpcrkrd. CRKREAD crkread.
         CRKEVER crkever. CRKAGE crkage. CRKTOT crktot.
         CRAKREC crakrec. CRKYRFRQ crkyrfrq. CRKUS30A crkus30a.
         SKPHERRD skpherrd. HERREAD herread. HEREVER herever.
         HERAGE herage. HERTOT hertot. HERREC herrec.
         HERYRFRQ heryrfrq. HER30USE her30use. SKPHALRD skphalrd.
         HALREAD halread. LSD lsd. PCP pcp.
         PEYOTE peyote. MESC mesc. PSILCY psilcy.
         ECSTASY ecstasy. HALDKNAM haldknam. HALNOLST halnolst.
         HALNEWA halnewa. HALNEWB halnewb. HALNEWC halnewc.
         HALNEWD halnewd. HALNEWE halnewe. HALLAGE hallage.
         HALLTOT halltot. HALLREC hallrec. HALYRFRQ halyrfrq.
         HAL30USE hal30use. LSDREC lsdrec. PCPREC pcprec.
         SKPINHRD skpinhrd. INHREAD inhread. AMYLNIT amylnit.
         CLEFLU cleflu. GAS gas. GLUE glue.
         ETHER ether. SOLVENT solvent. LGAS lgas.
         NITOXID nitoxid. SPPAINT sppaint. AEROS aeros.
         INHDKNAM inhdknam. INHNOLST inhnolst. INHNEWA inhnewa.
         INHNEWB inhnewb. INHNEWC inhnewc. INHNEWD inhnewd.
         INHNEWE inhnewe. INHAGE inhage. INHTOT inhtot.
         INHREC inhrec. INHYRFRQ inhyrfrq. INHDY30A inhdy30a.
         SKPANLRD skpanlrd. ANLREAD anlread. CODEINE codeine.
         DARVON darvon. DEMEROL demerol. DILAUD dilaud.
         METHDON methdon. MORPHINE morphine. PERCODAN percodan.
         TALWIN talwin. TYLCOD tylcod. ANLDKNAM anldknam.
         ANLNOLST anlnolst. ANALNEWA analnewa. ANALNEWB analnewb.
         ANALNEWC analnewc. ANALNEWD analnewd. ANALNEWE analnewe.
         ANALNONE analnone. ANALAGE analage. ANALTOT analtot.
         ANALREC analrec. ANLYRFRQ anlyrfrq. SKPTRNRD skptrnrd.
         TRNREAD trnread. ATARAX atarax. ATIVAN ativan.
         DIAZEPAM diazepam. LIBRIUM librium. TRANXENE tranxene.
         VALIUM valium. XANAX xanax. TRDKNAM trdknam.
         TRNOLST trnolst. TRNEWA trnewa. TRNEWB trnewb.
         TRNEWC trnewc. TRNEWD trnewd. TRNEWE trnewe.
         NOTRANQ notranq. TRANAGE tranage. TRANTOT trantot.
         TRANREC tranrec. TRNYRFRQ trnyrfrq. SKPSTMRD skpstmrd.
         STMREAD stmread. BENZ benz. BIPHET biphet.
         DEXAMYL dexamyl. DEXED dexed. FASTIN fastin.
         IONAMIN ionamin. METHAMP methamp. METHI methi.
         PRELUDIN preludin. STMDKNAM stmdknam. STMNOLST stmnolst.
         STIMNEWA stimnewa. STIMNEWB stimnewb. STIMNEWC stimnewc.
         STIMNEWD stimnewd. STIMNEWE stimnewe. NOSTIMS nostims.
         STIMAGE stimage. STIMTOT stimtot. STIMREC stimrec.
         STMYRFRQ stmyrfrq. SKPSEDRD skpsedrd. SEDREAD sedread.
         DALMANE dalmane. HALCION halcion. METHAQ methaq.
         NEMBUTAL nembutal. PHENOBAR phenobar. PLACIDYL placidyl.
         SECONAL seconal. TUINAL tuinal. SEDDKNAM seddknam.
         SEDNOLST sednolst. SEDNEWA sednewa. SEDNEWB sednewb.
         SEDNEWC sednewc. SEDNEWD sednewd. SEDNEWE sednewe.
         NOSEDAT nosedat. SEDAGE sedage. SEDTOT sedtot.
         SEDREC sedrec. SEDYRFRQ sedyrfrq. BIRMONTH birmonth.
         BIRYEAR biryear. IIAGE iiage. IRSEX irsex.
         IISEX iisex. IRRACE irrace. IIRACE iirace.
         IRHOIND irhoind. IIHOIND iihoind. IRHOGRP irhogrp.
         IIHOGRP iihogrp. IRHOGRP2 irhogrpf. IIHOGRP2 iihogrpf.
         IRMARIT irmarit. IIMARIT iimarit. IREDUC ireduc.
         IIEDUC iieduc. IRHSGRAD irhsgrad. IIHSGRAD iihsgrad.
         IRWORKST irworkst. IIWORKST iiworkst. IRCIGRC ircigrc.
         IICIGRC iicigrc. IROTBRC irotbrc. IIOTBRC iiotbrc.
         IRALCRC iralcrc. IIALCRC iialcrc. IRMJRC irmjrc.
         IIMJRC iimjrc. IRCOCRC ircocrc. IICOCRC iicocrc.
         IRCRKRC ircrkrc. IICRKRC iicrkrc. IRHERRC irherrc.
         IIHERRC iiherrc. IRHALRC irhalrc. IIHALRC iihalrc.
         IRLSDRC irlsdrc. IILSDRC iilsdrc. IRPCPRC irpcprc.
         IIPCPRC iipcprc. IRINHRC irinhrc. IIINHRC iiinhrc.
         IRANLRC iranlrc. IIANLRC iianlrc. IRTRNRC irtrnrc.
         IITRNRC iitrnrc. IRSTMRC irstmrc. IISTMRC iistmrc.
         IRSEDRC irsedrc. IISEDRC iisedrc. IRALCFQ iralcfq.
         IIALCFQ iialcfq. IRMJFQ irmjfq. IIMJFQ iimjfq.
         IRCOCFQ ircocfq. IICOCFQ iicocfq. IRCRKFQ ircrkfq.
         IICRKFQ iicrkfq. IRHERFQ irherfq. IIHERFQ iiherfq.
         IRHALFQ irhalfq. IIHALFQ iihalfq. IRINHFQ irinhfq.
         IIINHFQ iiinhfq. IRANLFQ iranlfq. IIANLFQ iianlfq.
         IRTRNFQ irtrnfq. IITRNFQ iitrnfq. IRSTMFQ irstmfq.
         IISTMFQ iistmfq. IRSEDFQ irsedfq. IISEDFQ iisedfq.
         CATAGE catage. CATAG2 catag2ff. CATAG3 catag3ff.
         RACE race. HISPRACE hisprace. EDUCCAT2 educcatf.
         EMPSTAT2 empstatf. MARISTAT maristat. NOTMAR notmar.
         CIGFLAG cigflag. CIGYR cigyr. CIGMON cigmon.
         SMKFLAG smkflag. SMKYR smkyr. SMKMON smkmon.
         ALCFLAG alcflag. ALCYR alcyr. ALCMON alcmon.
         MRJFLAG mrjflag. MRJYR mrjyr. MRJMON mrjmon.
         COCFLAG cocflag. COCYR cocyr. COCMON cocmon.
         CRKFLAG crkflag. CRKYR crkyr. CRKMON crkmon.
         HERFLAG herflag. HERYR heryr. HERMON hermon.
         HALFLAG halflag. HALYR halyr. HALMON halmon.
         LSDFLAG lsdflag. LSDYR lsdyr. LSDMON lsdmon.
         PCPFLAG pcpflag. PCPYR pcpyr. PCPMON pcpmon.
         INHFLAG inhflag. INHYR inhyr. INHMON inhmon.
         ANLFLAG anlflag. ANLYR anlyr. ANLMON anlmon.
         TRQFLAG trqflag. TRQYR trqyr. TRQMON trqmon.
         STMFLAG stmflag. STMYR stmyr. STMMON stmmon.
         SEDFLAG sedflag. SEDYR sedyr. SEDMON sedmon.
         ALCYRF alcyrf. ALCMONF alcmonf. ALCWKF alcwkf.
         ALCOCCF alcoccf. ALCDLYF alcdlyf. MRJYRF mrjyrf.
         MRJMONF mrjmonf. MRJWKF mrjwkf. MRJOCCF mrjoccf.
         MRJDLYF mrjdlyf. COCYRF cocyrf. COCMONF cocmonf.
         COCWKF cocwkf. COCOCCF cococcf. COCDLYF cocdlyf.
         CRKYRF crkyrf. CRKMONF crkmonf. CRKWKF crkwkf.
         CRKOCCF crkoccf. CRKDLYF crkdlyf. HERYRF heryrf.
         HERMONF hermonf. HERWKF herwkf. HEROCCF heroccf.
         HERDLYF herdlyf. HALYRF halyrf. HALMONF halmonf.
         HALWKF halwkf. HALOCCF haloccf. HALDLYF haldlyf.
         INHYRF inhyrf. INHMONF inhmonf. INHWKF inhwkf.
         INHOCCF inhoccf. INHDLYF inhdlyf. ANLYRF anlyrf.
         ANLMONF anlmonf. ANLWKF anlwkf. ANLOCCF anloccf.
         ANLDLYF anldlyf. TRQYRF trqyrf. TRQMONF trqmonf.
         TRQWKF trqwkf. TRQOCCF trqoccf. TRQDLYF trqdlyf.
         STMYRF stmyrf. STMMONF stmmonf. STMWKF stmwkf.
         STMOCCF stmoccf. STMDLYF stmdlyf. SEDYRF sedyrf.
         SEDMONF sedmonf. SEDWKF sedwkf. SEDOCCF sedoccf.
         SEDDLYF seddlyf. PSYFLAG2 psyflagf. PSYYR2 psyyr2ff.
         PSYMON2 psymon2f. SUMFLAG sumflag. SUMYR sumyr.
         SUMMON summon. MJOFLAG mjoflag. MJOYR2 mjoyr2ff.
         MJOMON2 mjomon2f. IEMFLAG iemflag. IEMYR iemyr.
         IEMMON iemmon. BINGEDRK bingedrk. HVYDRK2 hvydrk2f.
         BINGEHVY bingehvy. PEYOTE2 peyote2f. MESC2 mesc2fff.
         PSILCY2 psilcy2f. ECSTASY2 ecstasyf. METHAMP2 methampf.
         HERSMOK2 hersmokf. HERSNIF2 hersniff. AMYLNIT2 amylnitf.
         CLEFLU2 cleflu2f. GAS2 gas2ffff. GLUE2 glue2fff.
         ETHER2 ether2ff. SOLVENT2 solventf. LGAS2 lgas2fff.
         NITOXID2 nitoxidf. SPPAINT2 sppaintf. AEROS2 aeros2ff.
         CG04 cg04ffff. CG12 cg12ffff. AL03 al03ffff.
         AL04 al04ffff. MJ04 mj04ffff. MJ05 mj05ffff.
         CC04 cc04ffff. CC05 cc05ffff. CK04 ck04ffff.
         CK05 ck05ffff. HE04 he04ffff. HE05 he05ffff.
         LS04 ls04ffff. LS05 ls05ffff. LS07 ls07ffff.
         LS08 ls08ffff. IN04 in04ffff. IN05 in05ffff.
         PK04 pk04ffff. PK05 pk05ffff. TR04 tr04ffff.
         TR05 tr05ffff. ST04 st04ffff. ST05 st05ffff.
         SE04 se04ffff. SE05 se05ffff. SKPSDRD skpsdrd.
         SDREAD sdread. HRANYFRM hranyfrm. HERSMOKE hersmoke.
         HRSMKREC hrsmkrec. HERSNIFF hersni0f. HRSNFREC hrsnfrec.
         GNNDLLIF gnndllif. COCNEEDL cocneedl. CONDLREC condlrec.
         HERNEEDL herneedl. HRNDLREC hrndlrec. STNEEDLE stneedle.
         STNDLREC stndlrec. GNNDREUS gnndreus. GNNDLSH1 gnndlshf.
         GNNDCLEN gnndclen. GNNDLSH2 gnndls0f. GNNDGET gnndget.
         GNNDGTSP gnndgtsp. SKPRSKRD skprskrd. RSKREAD rskread.
         RSKPKCIG rskpkcig. RSKMJOCC rskmjocc. RSKMJREG rskmjreg.
         RKCOCOCC rkcococc. RKCOCREG rkcocreg. RK5DRINK rk5drink.
         RSKBINGE rskbinge. RSKDIFMJ rskdifmj. RKDIFCOC rkdifcoc.
         RKDIFCRK rkdifcrk. RKDIFHER rkdifher. RSKSELL rsksell.
         SKPDRGRD skpdrgrd. DRGREAD drgread. USEDCIG usedcig.
         USEDALC usedalc. USEDMRJ usedmrj. USEDCOC usedcoc.
         USEDHER usedher. USEDHAL usedhal. USEDINH usedinh.
         USEDANL usedanl. USEDTRN usedtrn. USEDSTM usedstm.
         USEDSED usedsed. NODRUGYR nodrugyr. GRTMCIG grtmcig.
         GRTMALC grtmalc. GRTMMRJ grtmmrj. GRTMCOC grtmcoc.
         GRTMHER grtmher. GRTMHAL grtmhal. GRTMINH grtminh.
         GRTMANL grtmanl. GRTMTRN grtmtrn. GRTMSTM grtmstm.
         GRTMSED grtmsed. LAMTCIG lamtcig. LAMTALC lamtalc.
         LAMTMRJ lamtmrj. LAMTCOC lamtcoc. LAMTHER lamther.
         LAMTHAL lamthal. LAMTINH lamtinh. LAMTANL lamtanl.
         LAMTTRN lamttrn. LAMTSTM lamtstm. LAMTSED lamtsed.
         BTOLCIG btolcig. BTOLALC btolalc. BTOLMRJ btolmrj.
         BTOLCOC btolcoc. BTOLHER btolher. BTOLHAL btolhal.
         BTOLINH btolinh. BTOLANL btolanl. BTOLTRN btoltrn.
         BTOLSTM btolstm. BTOLSED btolsed. ACRDCIG acrdcig.
         ACRDALC acrdalc. ACRDMRJ acrdmrj. ACRDCOC acrdcoc.
         ACRDHER acrdher. ACRDHAL acrdhal. ACRDINH acrdinh.
         ACRDANL acrdanl. ACRDTRN acrdtrn. ACRDSTM acrdstm.
         ACRDSED acrdsed. EMPBCIG empbcig. EMPBALC empbalc.
         EMPBMRJ empbmrj. EMPBCOC empbcoc. EMPBHER empbher.
         EMPBHAL empbhal. EMPBINH empbinh. EMPBANL empbanl.
         EMPBTRN empbtrn. EMPBSTM empbstm. EMPBSED empbsed.
         HLPBCIG hlpbcig. HLPBALC hlpbalc. HLPBMRJ hlpbmrj.
         HLPBCOC hlpbcoc. HLPBHER hlpbher. HLPBHAL hlpbhal.
         HLPBINH hlpbinh. HLPBANL hlpbanl. HLPBTRN hlpbtrn.
         HLPBSTM hlpbstm. HLPBSED hlpbsed. UCDCIG ucdcig.
         UCDALC ucdalc. UCDMRJ ucdmrj. UCDCOC ucdcoc.
         UCDHER ucdher. UCDHAL ucdhal. UCDINH ucdinh.
         UCDANL ucdanl. UCDTRN ucdtrn. UCDSTM ucdstm.
         UCDSED ucdsed. SKPSPTRD skpsptrd. SPTREAD sptread.
         NDTXRCVD ndtxrcvd. NDTXNEED ndtxneed. NDTXALC ndtxalc.
         NDTXMJ ndtxmj. NDTXCOC ndtxcoc. NDTXHER ndtxher.
         NDTXHAL ndtxhal. NDTXINH ndtxinh. NDTXANL ndtxanl.
         NDTXTRAN ndtxtran. NDTXSTIM ndtxstim. NDTXSED ndtxsed.
         NDTXSOD ndtxsod. NDTXDRG1 ndtxdrgf. NDTXDRG2 ndtxdr0f.
         NDTXDRG3 ndtxdr1f. NDTXDRG4 ndtxdr2f. NDTXDRG5 ndtxdr3f.
         NDTXSTEP ndtxstep. NDTXTRSP ndtxtrsp. NDTXTFAR ndtxtfar.
         NDTXBDHR ndtxbdhr. NDTXOPEN ndtxopen. NDTXTYPE ndtxtype.
         NDTXMONY ndtxmony. NDTXHCAP ndtxhcap. NDTXTCMP ndtxtcmp.
         NDTXLANG ndtxlang. NDTXSPSV ndtxspsv. NDTXSOR ndtxsor.
         NDTXRSC1 ndtxrscf. BOOKED booked. NOBOOKYR nobookyr.
         BKLARCNY bklarcny. BKBURGL bkburgl. BKAGASLT bkagaslt.
         BKSMASLT bksmaslt. BKMVTHFT bkmvthft. BKROB bkrob.
         BKRAPE bkrape. BKMURDER bkmurder. BKARSON bkarson.
         BKDRVINF bkdrvinf. BKDRUNK bkdrunk. BKDRUG bkdrug.
         BKPROS bkpros. BKVANDAL bkvandal. BKOTH bkoth.
         BKOTHOFF bkothoff. PROBATON probaton. PAROLE parole.
         DRVALDR drvaldr. DRIVEAL driveal. DRIVEDR drivedr.
         SKPTMTRD skptmtrd. TMTREAD tmtread. TXEVER txever.
         TXTIMELF txtimelf. TXYRFREQ txyrfreq. TXALHOSP txalhosp.
         TXALRFIN txalrfin. TXALRFOP txalrfop. TXALMHC txalmhc.
         TXALEMRG txalemrg. TXALDOC txaldoc. TXALJAIL txaljail.
         TXALSHG txalshg. TXALSOP txalsop. TXALSP txalsp.
         TXDRHOSP txdrhosp. TXDRFIN txdrfin. TXDRFOP txdrfop.
         TXDRMHC txdrmhc. TXDREMRG txdremrg. TXDRDOC txdrdoc.
         TXDRJAIL txdrjail. TXDRSHG txdrshg. TXDRSOP txdrsop.
         TXDRSP txdrsp. TXYREMRG txyremrg. TXADGREC txadgrec.
         TXLTHOSP txlthosp. TXLTRFIN txltrfin. TXLTRFOP txltrfop.
         TXLTMHC txltmhc. TXLTEMRG txltemrg. TXLTDOC txltdoc.
         TXLTJAIL txltjail. TXLTSHG txltshg. TXLTSOP txltsop.
         TXLTSP txltsp. TXLTALC txltalc. TXLTMJ txltmj.
         TXLTCOC txltcoc. TXLTHER txlther. TXLTHAL txlthal.
         TXLTINH txltinh. TXLTANL txltanl. TXLTRAN txltran.
         TXLTSTIM txltstim. TXLTSED txltsed. TXLTSOD txltsod.
         TXLTA txlta. TXLTB txltb. TXLTC txltc.
         TXLTD txltd. TXLTE txlte. TXDRGA txdrga.
         TXDRGB txdrgb. TXDRGC txdrgc. TXDRGD txdrgd.
         TXDRGE txdrge. TXOUTC txoutc. TXTIME txtime.
         TXPDINS txpdins. TXPDCARE txpdcare. TXPDCAID txpdcaid.
         TXPDSAVE txpdsave. TXPDFMLY txpdfmly. TXPDEMPL txpdempl.
         TXPDFREE txpdfree. TXPDSOS txpdsos. TXPDSP txpdsp.
         TXENROLL txenroll. SKYCPBAN skycpban. SKPYCRD skpycrd.
         YCREAD ycread. YACTYNG yactyng. YALLERGY yallergy.
         YARGUE yargue. YASTHMA yasthma. YACOPPSX yacoppsx.
         YLKANIML ylkaniml. YBRAG ybrag. YTRBCONC ytrbconc.
         YCNTHGTS ycnthgts. YTRBSIT ytrbsit. YDPTADLT ydptadlt.
         YFLONELY yflonely. YFLCONFU yflconfu. YCRYLOT ycrylot.
         YHONEST yhonest. YMEANOTH ymeanoth. YDAYDREM ydaydrem.
         YTRYKLSF ytryklsf. YTRYATTN ytryattn. YDSTYTHG ydstythg.
         YDSTYOTH ydstyoth. YDSBYPAR ydsbypar. YDSBYSCH ydsbysch.
         YDNTEATW ydnteatw. YDNTKIDS ydntkids. YDNTGLTY ydntglty.
         YJEALOTH yjealoth. YHELPOTH yhelpoth. YAFRPLAC yafrplac.
         YAFRSCHL yafrschl. YAFRBAD yafrbad. YFLPRFCT yflprfct.
         YFLNOLOV yflnolov. YFLGETME yflgetme. YFLWTHLS yflwthls.
         YACCHURT yacchurt. YFIGHTS yfights. YGTEASED ygteased.
         YKIDSTRB ykidstrb. YHRVOICS yhrvoics. YACTTNK yacttnk.
         YALONE yalone. YLIE ylie. YBITNAIL ybitnail.
         YNERVOUS ynervous. YBTWITCH ybtwitch. YNGHTMAR ynghtmar.
         YNOTKIDS ynotkids. YDOBETTR ydobettr. YANXIOUS yanxious.
         YFLDIZZY yfldizzy. YFLGUILT yflguilt. YEATMUCH yeatmuch.
         YFLTIRED yfltired. YOVRWGHT yovrwght. YACHES yaches.
         YHEADACH yheadach. YNAUSEA ynausea. YEYEPROB yeyeprob.
         YRASHES yrashes. YCRAMPS ycramps. YVOMIT yvomit.
         YATTACK yattack. YPKBPART ypkbpart. YPFRNDLY ypfrndly.
         YTRYTHNG ytrythng. YSCPOOR yscpoor. YCLUMSY yclumsy.
         YOLDKIDS yoldkids. YYNGKIDS yyngkids. YRFSTALK yrfstalk.
         YREPACTN yrepactn. YRUNHOME yrunhome. YSCREAM yscream.
         YSECRET ysecret. YSEETHNG yseethng. YSLFCONS yslfcons.
         YSETFIRE ysetfire. YWELHNDS ywelhnds. YSHOWOFF yshowoff.
         YSHY yshy. YSLPLESS yslpless. YSLPMORE yslpmore.
         YGDIMAG ygdimag. YSPCHPRB yspchprb. YSTDRGHT ystdrght.
         YSTEALHO ystealho. YSTEALPL ystealpl. YDNTNEED ydntneed.
         YDOSTRNG ydostrng. YTHSTRNG ythstrng. YSTUBORN ystuborn.
         YMOODS ymoods. YENJOY yenjoy. YSUSPICS ysuspics.
         YDRTLANG ydrtlang. YTHKKLSF ythkklsf. YLKLAUGH ylklaugh.
         YTALKMCH ytalkmch. YTEASE ytease. YTEMPER ytemper.
         YTHNKSEX ythnksex. YTHRTPEO ythrtpeo. YLKHELP ylkhelp.
         YCONNEAT yconneat. YTRBSLEP ytrbslep. YSKIPSCH yskipsch.
         YNOENRGY ynoenrgy. YUNHAPPY yunhappy. YLOUDER ylouder.
         YUSEDRUG yusedrug. YFAIROTH yfairoth. YENJYJOK yenjyjok.
         YLIFEASY ylifeasy. YTRYHELP ytryhelp. YWSOPPSX ywsoppsx.
         YINVOTH yinvoth. YWORRY yworry. SKPBDBAN skpbdban.
         SKPPBRD skppbrd. PBREAD pbread. XSEXYR xsexyr.
         XRELNOW xrelnow. XRELYR xrelyr. XRELCDV xrelcdv.
         XRELCDA xrelcda. XNRELYR xnrelyr. XNRELCDV xnrelcdv.
         XNRELCDA xnrelcda. XYRDIFPP xyrdifpp. XYRWTHMF xyrwthmf.
         XYRHIV xyrhiv. XYRMONEY xyrmoney. XYRDRUGS xyrdrugs.
         XCDEVER xcdever. XCDLAST xcdlast. XCDPREG xcdpreg.
         XCDSTD xcdstd. XCDNMESS xcdnmess. XCDOTRSN xcdotrsn.
         XCDRSN1 xcdrsn1f. XNCDPREG xncdpreg. XNCDMONO xncdmono.
         XNCDSTD xncdstd. XNCDOBC xncdobc. XNCDRELG xncdrelg.
         XNCDPTNR xncdptnr. XNCDNA xncdna. XNCDHOW xncdhow.
         XNCDSAFE xncdsafe. XNCDORSN xncdorsn. XNCDRSN1 xncdrsnf.
         XCDMOOD xcdmood. XCDRESP xcdresp. XCDFEEL xcdfeel.
         XCDTRST xcdtrst. XCDEMBR xcdembr. XCDCOST xcdcost.
         XRELLAST xrellast. XLFBLOOD xlfblood. XBLD385 xbld385f.
         XLTBLDMO xltbldmo. XLTBLDYR xltbldyr. XHIVTEST xhivtest.
         XLTHIVMO xlthivmo. XLTHIVYR xlthivyr. XHIVRSLT xhivrslt.
         SKPDBRD skpdbrd. DBREAD dbread. VDRVYR vdrvyr.
         VYRFREQ vyrfreq. VALDRVYR valdrvyr. VALYRFRQ valyrfrq.
         VAL30USE val30use. VALCNODR valcnodr. VALCTIME valctime.
         VALDTIME valdtime. VMJUSEYR vmjuseyr. VMJDRVYR vmjdrvyr.
         VMJALCYR vmjalcyr. VMJCOCYR vmjcocyr. VMJHERYR vmjheryr.
         VMJHALYR vmjhalyr. VMJINHYR vmjinhyr. VMJANLYR vmjanlyr.
         VMJTRNYR vmjtrnyr. VMJSTMYR vmjstmyr. VMJSEDYR vmjsedyr.
         VMJOTHYR vmjothyr. VMJYRS1 vmjyrs1f. VMJYRS2 vmjyrs2f.
         VMJYRS3 vmjyrs3f. VMJYRS4 vmjyrs4f. VMJYRS5 vmjyrs5f.
         VMJ30USE vmj30use. VLTMJALC vltmjalc. VLTMJAL1 vltmjalf.
         VLTMJAL2 vltmja0f. VLTMJAL3 vltmja1f. VLTMJAL4 vltmja2f.
         VLTMJAL5 vltmja3f. VLTMJFRM vltmjfrm. VLTMJFRS vltmjfrs.
         VLTMJTO vltmjto. VLTMJTOS vltmjtos. VLTMJHWY vltmjhwy.
         VLTMJURB vltmjurb. VLTMJWKD vltmjwkd. VLTMJTIM vltmjtim.
         VLTMJABL vltmjabl. VMJNOWAY vmjnoway. VMJNHIGH vmjnhigh.
         VMJNPOLC vmjnpolc. VMJNODVR vmjnodvr. VMJAPPT vmjappt.
         VMJOTHER vmjother. VMJOTHSP vmjothsp. VMJSTOP vmjstop.
         VMJABIL vmjabil. VCCUSEYR vccuseyr. VCCDRVYR vccdrvyr.
         VCCALCYR vccalcyr. VCCMRJYR vccmrjyr. VCCHERYR vccheryr.
         VCCHALYR vcchalyr. VCCINHYR vccinhyr. VCCANLYR vccanlyr.
         VCCTRNYR vcctrnyr. VCCSTMYR vccstmyr. VCCSEDYR vccsedyr.
         VCCOTHYR vccothyr. VCCYRS1 vccyrs1f. VCCYRS2 vccyrs2f.
         VCCYRS3 vccyrs3f. VCCYRS4 vccyrs4f. VCCYRS5 vccyrs5f.
         VCC30USE vcc30use. VLTCCALC vltccalc. VLTCCAL1 vltccalf.
         VLTCCAL2 vltcca0f. VLTCCAL3 vltcca1f. VLTCCAL4 vltcca2f.
         VLTCCAL5 vltcca3f. VLTCCFRM vltccfrm. VLTCCFRS vltccfrs.
         VLTCCTO vltccto. VLTCCTOS vltcctos. VLTCCHWY vltcchwy.
         VLTCCURB vltccurb. VLTCCWKD vltccwkd. VLTCCTIM vltcctim.
         VLTCCABL vltccabl. VCCNOWAY vccnoway. VCCNHIGH vccnhigh.
         VCCNPOLC vccnpolc. VCCNODVR vccnodvr. VCCAPPT vccappt.
         VCCOTHER vccother. VCCOTHSP vccothsp. VCCSTOP vccstop.
         VCCABIL vccabil. VTRUSEYR vtruseyr. VTRDRVYR vtrdrvyr.
         VTR30USE vtr30use. VLTTRMED vlttrmed. VLTTRALC vlttralc.
         VLTTRAL1 vlttralf. VLTTRAL2 vlttra0f. VLTTRAL3 vlttra1f.
         VLTTRAL4 vlttra2f. VLTTRAL5 vlttra3f. VLTTRABL vlttrabl.
         VSTUSEYR vstuseyr. VSTDRVYR vstdrvyr. VST30USE vst30use.
         VLTSTMED vltstmed. VLTSTALC vltstalc. VLTSTAL1 vltstalf.
         VLTSTAL2 vltsta0f. VLTSTAL3 vltsta1f. VLTSTAL4 vltsta2f.
         VLTSTAL5 vltsta3f. VLTSTABL vltstabl. VSEUSEYR vseuseyr.
         VSEDRVYR vsedrvyr. VSE30USE vse30use. VLTSEMED vltsemed.
         VLTSEALC vltsealc. VLTSEAL1 vltsealf. VLTSEAL2 vltsea0f.
         VLTSEAL3 vltsea1f. VLTSEAL4 vltsea2f. VLTSEAL5 vltsea3f.
         VLTSEABL vltseabl. SKPWKST3 skpwkstf. WORKDAYS workdays.
         WORKBLAH workblah. SKPPREG skppreg. PREGNANT pregnant.
         PREGMOS pregmos. SKPMHC skpmhc. DEPRESS depress.
         DEPDAYS depdays. DEPFREQ depfreq. LOSTINT1 lostintf.
         TIRED1 tired1ff. WTCHNG1 wtchng1f. LBSCHNG1 lbschngf.
         SLPLOSS1 slplossf. SLPFREQ1 slpfreqf. CONCEN1 concen1f.
         DOWN1 down1fff. IDEAT1 ideat1ff. SKPDEP1 skpdep1f.
         DEPWKS1 depwks1f. DEPMO1 depmo1ff. DEPYR1 depyr1ff.
         LOSTINT2 lostin0f. LOSINDAY losinday. LOSINFRQ losinfrq.
         TIRED2 tired2ff. WTCHNG2 wtchng2f. LBSCHNG2 lbschn0f.
         SLPLOSS2 slplos0f. SLPFREQ2 slpfre0f. CONCEN2 concen2f.
         DOWN2 down2fff. IDEAT2 ideat2ff. SKPDEP2 skpdep2f.
         DEPWKS2 depwks2f. DEPMO2 depmo2ff. DEPYR2 depyr2ff.
         WORRIED worried. WOREND worend. WORNOMO1 wornomof.
         WORHAPN1 worhapnf. WORSERI1 worserif. WORDIFF1 wordifff.
         WORNOMO2 wornom0f. WORHAPN2 worhap0f. WORSERI2 worser0f.
         WORDIFF2 wordif0f. SKPWOR skpwor. WORREST worrest.
         WOREDGE woredge. WORIRRIT worirrit. WORHEART worheart.
         WORTIRED wortired. WORSLEEP worsleep. WORFAINT worfaint.
         FEARPUB fearpub. FEAROUT fearout. FEARBRDG fearbrdg.
         SKPFEAR1 skpfearf. FEAROFT fearoft. FEARYRS fearyrs.
         FEARMOS fearmos. FEARFANT fearfant. FEARTRAP feartrap.
         FEARHELP fearhelp. PANIC1 panic1ff. PANIC2 panic2ff.
         PANICNUM panicnum. PANICMO panicmo. PANICYR panicyr.
         PANIDANG panidang. SKPFEAR2 skpfea0f. PANIFEAR panifear.
         PANINOFR paninofr. PANIHART panihart. PANIPAIN panipain.
         PANISWET paniswet. PANISHAK panishak. PANIHOT panihot.
         PANIUNRL paniunrl. NUERTMT nuertmt. NUHSPOV nuhspov.
         NUHSPPE nuhsppe. OUTPTPE outptpe. PROXABLE proxable.
         PROXYREL proxyrel. PROXHOME proxhome. PROXJOIN proxjoin.
         CAREUSU careusu. NCARERSN ncarersn. NCRRSNSP ncrrsnsp.
         NCRRSNSC ncrrsnsc. CAREOFT careoft. PYRCARE pyrcare.
         PYRCRTYP pyrcrtyp. PYRCRTSP pyrcrtsp. PYRCRTSC pyrcrtsc.
         CARENOW carenow. MNRSNNCR mnrsnncr. MNRSNNSP mnrsnnsp.
         MNRSNNSC mnrsnnsc. UCARETYP ucaretyp. UCRTYPSP ucrtypsp.
         UCRTYPSC ucrtypsc. MEDICARE medicare. MEDICAID medicaid.
         CHAMPUS champus. PRVHLTIN prvhltin. GRPHLTIN grphltin.
         PDHINPRM pdhinprm. HLTINALC hltinalc. HLTINDRG hltindrg.
         HLTINMNT hltinmnt. SOC1 soc1ffff. SOC2 soc2ffff.
         SSI1 ssi1ffff. SSI2 ssi2ffff. PUB1 pub1ffff.
         PUB2 pub2ffff. AFDC afdc. INT1 int1ffff.
         INT2 int2ffff. CHD1 chd1ffff. CHD2 chd2ffff.
         OTH1 oth1ffff. OTH2 oth2ffff. FSTAMP fstamp.
         PINC1 pinc1fff. SKPTFMIN skptfmin. FINC1 finc1fff.
         TELNO telno. IRPINSUR irpinsur. IIPINSUR iipinsur.
         IRINSUR irinsur. IIINSUR iiinsur. IRSOC1 irsoc1ff.
         IISOC1 iisoc1ff. IRSSI1 irssi1ff. IISSI1 iissi1ff.
         IRPUB1 irpub1ff. IIPUB1 iipub1ff. IRAFDC irafdc.
         IIAFDC iiafdc. IRINT1 irint1ff. IIINT1 iiint1ff.
         IRCHD1 irchd1ff. IICHD1 iichd1ff. IROTH1 iroth1ff.
         IIOTH1 iioth1ff. IRFSTAMP irfstamp. IIFSTAMP iifstamp.
         IRPINC1 irpinc1f. IIPINC1 iipinc1f. IRFINC1 irfinc1f.
         IIFINC1 iifinc1f. IRSOC2 irsoc2ff. IISOC2 iisoc2ff.
         IRSSI2 irssi2ff. IISSI2 iissi2ff. IRPUB2 irpub2ff.
         IIPUB2 iipub2ff. IRINT2 irint2ff. IIINT2 iiint2ff.
         IRCHD2 irchd2ff. IICHD2 iichd2ff. IROTH2 iroth2ff.
         IIOTH2 iioth2ff. IRKIDS irkids. PARSTAT parstat.
         FEMBABY fembaby. FEMKIDS femkids. MALEBABY malebaby.
         MALEKIDS malekids. F15_44 f15_44ff. M15_44 m15_44ff.
         PREG preg. PREG2 preg2fff. TRIMEST trimest.
         INDCAT indcat. PERINC perinc. PERINC2 perinc2f.
         PERINC3 perinc3f. TOTCAT totcat. FAMINC faminc.
         FAMINC2 faminc2f. FAMINC3 faminc3f. WELFARE welfare.
         NEEDLREC needlrec. NEDFLAG4 nedflagf. NEDYR4 nedyr4ff.
         WITHDRW withdrw. SOMCOM somcom. ANXDEP anxdep.
         SOCPROB socprob. THPROB thprob. ATTPROB attprob.
         DELBEH delbeh. AGGBEH aggbeh. WITHDRWT withdrwt.
         SOMCOMT somcomt. ANXDEPT anxdept. SOCPROBT socprobt.
         THPROBT thprobt. ATTPROBT attprobt. DELBEHT delbeht.
         AGGBEHT aggbeht. SXHIVLF sxhivlf. SXHIVYR sxhivyr.
         SXREL sxrel. SXRELMAR sxrelmar. SXCONDYR sxcondyr.
         SXRSKANY sxrskany. SXRSKCNT sxrskcnt. SXDRANY sxdrany.
         SXDRCNT sxdrcnt. MDESFS1 mdesfs1f. MDESFS3 mdesfs3f.
         PROBMDE1 probmdef. PROBMDE3 probmd0f. MDE1 mde1ffff.
         MDE3 mde3ffff. GADSFS1 gadsfs1f. GADSFS3 gadsfs3f.
         PROBGAD1 probgadf. PROBGAD3 probga0f. GAD1 gad1ffff.
         GAD3 gad3ffff. AGPSFS1 agpsfs1f. AGPSFS3 agpsfs3f.
         PROBAGP1 probagpf. PROBAGP3 probag0f. AGP1 agp1ffff.
         AGP3 agp3ffff. PASFS1 pasfs1ff. PASFS3 pasfs3ff.
         PROBPA1 probpa1f. PROBPA3 probpa3f. PA1 pa1fffff.
         PA3 pa3fffff. BHOUR bhour. BMIN bmin.
         BAP bap. EAP eap. LANGVER langver.
         UNDINT undint. COOPINT coopint. PRIVACY privacy.
         PPRES ppres. SPRES spres. PARPRES parpres.
         OARPRES oarpres. OAPRES oapres. CPRES cpres.
         OPRESNSP opresnsp. OPRESSPA opresspa. OPRESSPB opresspb.
         WHOMARKD whomarkd. QUARTER quarter. FAMSKIP famskip.
         GQTYPE gqtype. PDEN pden. PDEN2 pden2fff.
         REGION region. DIVISION division. RURORURB rurorurb.
         RELINTHH relinthh. MJTOT3 mjtot3ff. COCTOT3 coctot3f.
         ALCDAYS2 alcdaysf. AGECAT4 agecat4f. MJDY30A3 mjdy30af.
         ALCDAYS3 alcday0f. DRINKER2 drinkerf. HVYDRK3 hvydrk3f.
         AVCIG2 avcig2ff. RACESEX racesex. NOTMARJ notmarj.
         BINGDRK2 bingdrkf. RACESEX2 racesexf. IRBTCIG2 irbtcigf.
         IRBTALC2 irbtalcf. IRBTMRJ2 irbtmrjf. IRBTCOC2 irbtcocf.
         IRGRCIG2 irgrcigf. IRGRALC2 irgralcf. IRGRMRJ2 irgrmrjf.
         IRGRCOC2 irgrcocf. IRLACIG2 irlacigf. IRLAALC2 irlaalcf.
         IRLAMRJ2 irlamrjf. IRLACOC2 irlacocf. IRACCIG2 iraccigf.
         IRACALC2 iracalcf. IRACMRJ2 iracmrjf. IRACCOC2 iraccocf.
         IREMCIG2 iremcigf. IREMALC2 iremalcf. IREMMRJ2 iremmrjf.
         IREMCOC2 iremcocf. IRHLCIG2 irhlcigf. IRHLALC2 irhlalcf.
         IRHLMRJ2 irhlmrjf. IRHLCOC2 irhlcocf. IRUCCIG2 iruccigf.
         IRUCALC2 irucalcf. IRUCMRJ2 irucmrjf. IRUCCOC2 iruccocf.
         AVCIG3 avcig3ff. ALCPROBS alcprobs. MJPROBS mjprobs.
         COCPROBS cocprobs. CIGPROBS cigprobs. MRJ2PROB mrj2prob.
         MRJ3PROB mrj3prob. COC2PROB coc2prob. COC3PROB coc3prob.
         CIG2PROB cig2prob. CIG3PROB cig3prob. ALC2PROB alc2prob.
         ALC3PROB alc3prob. CIGTRY2 cigtry2f. ALCTRY2 alctry2f.
         MJAGE2 mjage2ff. INHAGE2 inhage2f. COCAGE2 cocage2f.
         HALLAGE2 hallagef. HERAGE2 herage2f. STIMAGE2 stimagef.
         SEDAGE2 sedage2f. TRANAGE2 tranagef. ANALAGE2 analagef.
         ALCONLYL alconlyl. ALCONLYY alconlyy. ALCONLYM alconlym.
         ILLONLYL illonlyl. ILLONLYY illonlyy. ILLONLYM illonlym.
         MRJONLYL mrjonlyl. MRJONLYY mrjonlyy. MRJONLYM mrjonlym.
         PSYONLYL psyonlyl. PSYONLYY psyonlyy. PSYONLYM psyonlym.
         OTHONLYL othonlyl. OTHONLYY othonlyy. OTHONLYM othonlym.
         ALCILLL alcilll. ALCILLY alcilly. ALCILLM alcillm.
         ALCMRJL alcmrjl. ALCMRJY alcmrjy. ALCMRJM alcmrjm.
         ALCPSYL alcpsyl. ALCPSYY alcpsyy. ALCPSYM alcpsym.
         ALCOTHL alcothl. ALCOTHY alcothy. ALCOTHM alcothm.
         SUB1LIF sub1lif. SUB2LIF sub2lif. SUB3LIF sub3lif.
         SUB1YR sub1yr. SUB2YR sub2yr. SUB3YR sub3yr.
         SUB1MON sub1mon. SUB2MON sub2mon. SUB3MON sub3mon.
         PSYAGE psyage. TRMTHLP2 trmthlpf. DRNKHLP2 drnkhlpf.
         DRALHELP dralhelp. BKLARCN2 bklarcnf. BKBURGL2 bkburglf.
         BKAGASL2 bkagaslf. BKSMASL2 bksmaslf. BKMVTHF2 bkmvthff.
         BKROB2 bkrob2ff. BKRAPE2 bkrape2f. BKMURDE2 bkmurdef.
         BKARSON2 bkarsonf. BKDRVIN2 bkdrvi0f. BKDRUNK2 bkdrunkf.
         BKDRUG2 bkdrug2f. BKPROS2 bkpros2f. DRUNKYR2 drunkyrf.
         FERTAGE fertage. PREG3 preg3fff. TRIMEST2 trimestf.
         RSKCIG rskcig. RSKMJ1 rskmj1ff. RSKMJ2 rskmj2ff.
         RSKCOC1 rskcoc1f. RSKCOC2 rskcoc2f. RSKALC1 rskalc1f.
         RSKALC2 rskalc2f. MARUSE maruse. COCUSE cocuse.
         ALCUSE alcuse. TOTPROB totprob. INT int.
         EXT ext. PR_EMOT pr_emot. PR_BEHAV pr_behav.
         PR_TOTAL pr_total. PR_WD pr_wd. PR_SC pr_sc.
         PR_AD pr_ad. PR_SP pr_sp. PR_TP pr_tp.
         PR_AP pr_ap. PR_DB pr_db. PR_AB pr_ab.
         ANY4MENT any4ment. ALCDRIV alcdriv. MRJDRIV mrjdriv.
         AGECAT3 agecat3f. DRUNKYR3 drunky0f. HERNEED2 herneedf.
         RSKSELL2 rsksellf. SEXYR sexyr. RELNOW relnow.
         HIVTEST hivtest. CDALWAYS cdalways. CDSOME cdsome.
         CDNEVER cdnever. YRDIFPP1 yrdifppf. YRDIFPP2 yrdifp0f.
         EHOUR ehour. EMIN emin.  ;
*/

RUN ;
